accounts

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIAccountAuthenticatorAddAccount                      = binder.FirstCallTransaction + 0
	TransactionIAccountAuthenticatorConfirmCredentials              = binder.FirstCallTransaction + 1
	TransactionIAccountAuthenticatorGetAuthToken                    = binder.FirstCallTransaction + 2
	TransactionIAccountAuthenticatorGetAuthTokenLabel               = binder.FirstCallTransaction + 3
	TransactionIAccountAuthenticatorUpdateCredentials               = binder.FirstCallTransaction + 4
	TransactionIAccountAuthenticatorEditProperties                  = binder.FirstCallTransaction + 5
	TransactionIAccountAuthenticatorHasFeatures                     = binder.FirstCallTransaction + 6
	TransactionIAccountAuthenticatorGetAccountRemovalAllowed        = binder.FirstCallTransaction + 7
	TransactionIAccountAuthenticatorGetAccountCredentialsForCloning = binder.FirstCallTransaction + 8
	TransactionIAccountAuthenticatorAddAccountFromCredentials       = binder.FirstCallTransaction + 9
	TransactionIAccountAuthenticatorStartAddAccountSession          = binder.FirstCallTransaction + 10
	TransactionIAccountAuthenticatorStartUpdateCredentialsSession   = binder.FirstCallTransaction + 11
	TransactionIAccountAuthenticatorFinishSession                   = binder.FirstCallTransaction + 12
	TransactionIAccountAuthenticatorIsCredentialsUpdateSuggested    = binder.FirstCallTransaction + 13
)
const (
	MethodIAccountAuthenticatorAddAccount                      = "addAccount"
	MethodIAccountAuthenticatorConfirmCredentials              = "confirmCredentials"
	MethodIAccountAuthenticatorGetAuthToken                    = "getAuthToken"
	MethodIAccountAuthenticatorGetAuthTokenLabel               = "getAuthTokenLabel"
	MethodIAccountAuthenticatorUpdateCredentials               = "updateCredentials"
	MethodIAccountAuthenticatorEditProperties                  = "editProperties"
	MethodIAccountAuthenticatorHasFeatures                     = "hasFeatures"
	MethodIAccountAuthenticatorGetAccountRemovalAllowed        = "getAccountRemovalAllowed"
	MethodIAccountAuthenticatorGetAccountCredentialsForCloning = "getAccountCredentialsForCloning"
	MethodIAccountAuthenticatorAddAccountFromCredentials       = "addAccountFromCredentials"
	MethodIAccountAuthenticatorStartAddAccountSession          = "startAddAccountSession"
	MethodIAccountAuthenticatorStartUpdateCredentialsSession   = "startUpdateCredentialsSession"
	MethodIAccountAuthenticatorFinishSession                   = "finishSession"
	MethodIAccountAuthenticatorIsCredentialsUpdateSuggested    = "isCredentialsUpdateSuggested"
)
const (
	TransactionIAccountAuthenticatorResponseOnResult           = binder.FirstCallTransaction + 0
	TransactionIAccountAuthenticatorResponseOnRequestContinued = binder.FirstCallTransaction + 1
	TransactionIAccountAuthenticatorResponseOnError            = binder.FirstCallTransaction + 2
)
const (
	MethodIAccountAuthenticatorResponseOnResult           = "onResult"
	MethodIAccountAuthenticatorResponseOnRequestContinued = "onRequestContinued"
	MethodIAccountAuthenticatorResponseOnError            = "onError"
)
const (
	TransactionIAccountManagerGetPassword                                  = binder.FirstCallTransaction + 0
	TransactionIAccountManagerGetUserData                                  = binder.FirstCallTransaction + 1
	TransactionIAccountManagerGetAuthenticatorTypes                        = binder.FirstCallTransaction + 2
	TransactionIAccountManagerGetAccountsForPackage                        = binder.FirstCallTransaction + 3
	TransactionIAccountManagerGetAccountsByTypeForPackage                  = binder.FirstCallTransaction + 4
	TransactionIAccountManagerGetAccountsAsUser                            = binder.FirstCallTransaction + 5
	TransactionIAccountManagerHasFeatures                                  = binder.FirstCallTransaction + 6
	TransactionIAccountManagerGetAccountByTypeAndFeatures                  = binder.FirstCallTransaction + 7
	TransactionIAccountManagerGetAccountsByFeatures                        = binder.FirstCallTransaction + 8
	TransactionIAccountManagerAddAccountExplicitly                         = binder.FirstCallTransaction + 9
	TransactionIAccountManagerRemoveAccountAsUser                          = binder.FirstCallTransaction + 10
	TransactionIAccountManagerRemoveAccountExplicitly                      = binder.FirstCallTransaction + 11
	TransactionIAccountManagerCopyAccountToUser                            = binder.FirstCallTransaction + 12
	TransactionIAccountManagerInvalidateAuthToken                          = binder.FirstCallTransaction + 13
	TransactionIAccountManagerPeekAuthToken                                = binder.FirstCallTransaction + 14
	TransactionIAccountManagerSetAuthToken                                 = binder.FirstCallTransaction + 15
	TransactionIAccountManagerSetPassword                                  = binder.FirstCallTransaction + 16
	TransactionIAccountManagerClearPassword                                = binder.FirstCallTransaction + 17
	TransactionIAccountManagerSetUserData                                  = binder.FirstCallTransaction + 18
	TransactionIAccountManagerUpdateAppPermission                          = binder.FirstCallTransaction + 19
	TransactionIAccountManagerGetAuthToken                                 = binder.FirstCallTransaction + 20
	TransactionIAccountManagerAddAccount                                   = binder.FirstCallTransaction + 21
	TransactionIAccountManagerAddAccountAsUser                             = binder.FirstCallTransaction + 22
	TransactionIAccountManagerUpdateCredentials                            = binder.FirstCallTransaction + 23
	TransactionIAccountManagerEditProperties                               = binder.FirstCallTransaction + 24
	TransactionIAccountManagerConfirmCredentialsAsUser                     = binder.FirstCallTransaction + 25
	TransactionIAccountManagerAccountAuthenticated                         = binder.FirstCallTransaction + 26
	TransactionIAccountManagerGetAuthTokenLabel                            = binder.FirstCallTransaction + 27
	TransactionIAccountManagerAddSharedAccountsFromParentUser              = binder.FirstCallTransaction + 28
	TransactionIAccountManagerRenameAccount                                = binder.FirstCallTransaction + 29
	TransactionIAccountManagerGetPreviousName                              = binder.FirstCallTransaction + 30
	TransactionIAccountManagerStartAddAccountSession                       = binder.FirstCallTransaction + 31
	TransactionIAccountManagerStartUpdateCredentialsSession                = binder.FirstCallTransaction + 32
	TransactionIAccountManagerFinishSessionAsUser                          = binder.FirstCallTransaction + 33
	TransactionIAccountManagerSomeUserHasAccount                           = binder.FirstCallTransaction + 34
	TransactionIAccountManagerIsCredentialsUpdateSuggested                 = binder.FirstCallTransaction + 35
	TransactionIAccountManagerGetPackagesAndVisibilityForAccount           = binder.FirstCallTransaction + 36
	TransactionIAccountManagerAddAccountExplicitlyWithVisibility           = binder.FirstCallTransaction + 37
	TransactionIAccountManagerSetAccountVisibility                         = binder.FirstCallTransaction + 38
	TransactionIAccountManagerGetAccountVisibility                         = binder.FirstCallTransaction + 39
	TransactionIAccountManagerGetAccountsAndVisibilityForPackage           = binder.FirstCallTransaction + 40
	TransactionIAccountManagerRegisterAccountListener                      = binder.FirstCallTransaction + 41
	TransactionIAccountManagerUnregisterAccountListener                    = binder.FirstCallTransaction + 42
	TransactionIAccountManagerHasAccountAccess                             = binder.FirstCallTransaction + 43
	TransactionIAccountManagerCreateRequestAccountAccessIntentSenderAsUser = binder.FirstCallTransaction + 44
	TransactionIAccountManagerOnAccountAccessed                            = binder.FirstCallTransaction + 45
)
const (
	MethodIAccountManagerGetPassword                                  = "getPassword"
	MethodIAccountManagerGetUserData                                  = "getUserData"
	MethodIAccountManagerGetAuthenticatorTypes                        = "getAuthenticatorTypes"
	MethodIAccountManagerGetAccountsForPackage                        = "getAccountsForPackage"
	MethodIAccountManagerGetAccountsByTypeForPackage                  = "getAccountsByTypeForPackage"
	MethodIAccountManagerGetAccountsAsUser                            = "getAccountsAsUser"
	MethodIAccountManagerHasFeatures                                  = "hasFeatures"
	MethodIAccountManagerGetAccountByTypeAndFeatures                  = "getAccountByTypeAndFeatures"
	MethodIAccountManagerGetAccountsByFeatures                        = "getAccountsByFeatures"
	MethodIAccountManagerAddAccountExplicitly                         = "addAccountExplicitly"
	MethodIAccountManagerRemoveAccountAsUser                          = "removeAccountAsUser"
	MethodIAccountManagerRemoveAccountExplicitly                      = "removeAccountExplicitly"
	MethodIAccountManagerCopyAccountToUser                            = "copyAccountToUser"
	MethodIAccountManagerInvalidateAuthToken                          = "invalidateAuthToken"
	MethodIAccountManagerPeekAuthToken                                = "peekAuthToken"
	MethodIAccountManagerSetAuthToken                                 = "setAuthToken"
	MethodIAccountManagerSetPassword                                  = "setPassword"
	MethodIAccountManagerClearPassword                                = "clearPassword"
	MethodIAccountManagerSetUserData                                  = "setUserData"
	MethodIAccountManagerUpdateAppPermission                          = "updateAppPermission"
	MethodIAccountManagerGetAuthToken                                 = "getAuthToken"
	MethodIAccountManagerAddAccount                                   = "addAccount"
	MethodIAccountManagerAddAccountAsUser                             = "addAccountAsUser"
	MethodIAccountManagerUpdateCredentials                            = "updateCredentials"
	MethodIAccountManagerEditProperties                               = "editProperties"
	MethodIAccountManagerConfirmCredentialsAsUser                     = "confirmCredentialsAsUser"
	MethodIAccountManagerAccountAuthenticated                         = "accountAuthenticated"
	MethodIAccountManagerGetAuthTokenLabel                            = "getAuthTokenLabel"
	MethodIAccountManagerAddSharedAccountsFromParentUser              = "addSharedAccountsFromParentUser"
	MethodIAccountManagerRenameAccount                                = "renameAccount"
	MethodIAccountManagerGetPreviousName                              = "getPreviousName"
	MethodIAccountManagerStartAddAccountSession                       = "startAddAccountSession"
	MethodIAccountManagerStartUpdateCredentialsSession                = "startUpdateCredentialsSession"
	MethodIAccountManagerFinishSessionAsUser                          = "finishSessionAsUser"
	MethodIAccountManagerSomeUserHasAccount                           = "someUserHasAccount"
	MethodIAccountManagerIsCredentialsUpdateSuggested                 = "isCredentialsUpdateSuggested"
	MethodIAccountManagerGetPackagesAndVisibilityForAccount           = "getPackagesAndVisibilityForAccount"
	MethodIAccountManagerAddAccountExplicitlyWithVisibility           = "addAccountExplicitlyWithVisibility"
	MethodIAccountManagerSetAccountVisibility                         = "setAccountVisibility"
	MethodIAccountManagerGetAccountVisibility                         = "getAccountVisibility"
	MethodIAccountManagerGetAccountsAndVisibilityForPackage           = "getAccountsAndVisibilityForPackage"
	MethodIAccountManagerRegisterAccountListener                      = "registerAccountListener"
	MethodIAccountManagerUnregisterAccountListener                    = "unregisterAccountListener"
	MethodIAccountManagerHasAccountAccess                             = "hasAccountAccess"
	MethodIAccountManagerCreateRequestAccountAccessIntentSenderAsUser = "createRequestAccountAccessIntentSenderAsUser"
	MethodIAccountManagerOnAccountAccessed                            = "onAccountAccessed"
)
const (
	TransactionIAccountManagerResponseOnResult = binder.FirstCallTransaction + 0
	TransactionIAccountManagerResponseOnError  = binder.FirstCallTransaction + 1
)
const (
	MethodIAccountManagerResponseOnResult = "onResult"
	MethodIAccountManagerResponseOnError  = "onError"
)
const DescriptorIAccountAuthenticator = "android.accounts.IAccountAuthenticator"
const DescriptorIAccountAuthenticatorResponse = "android.accounts.IAccountAuthenticatorResponse"
const DescriptorIAccountManager = "android.accounts.IAccountManager"
const DescriptorIAccountManagerResponse = "android.accounts.IAccountManagerResponse"

Variables

This section is empty.

Functions

This section is empty.

Types

type Account

type Account struct {
	Name     string
	Type     string
	AccessId string
}

func (*Account) MarshalParcel

func (s *Account) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Account) UnmarshalParcel

func (s *Account) UnmarshalParcel(
	p *parcel.Parcel,
) error

type AccountAuthenticatorProxy

type AccountAuthenticatorProxy struct {
	Remote binder.IBinder
}

func NewAccountAuthenticatorProxy

func NewAccountAuthenticatorProxy(
	remote binder.IBinder,
) *AccountAuthenticatorProxy

func (*AccountAuthenticatorProxy) AddAccount

func (p *AccountAuthenticatorProxy) AddAccount(
	ctx context.Context,
	response IAccountAuthenticatorResponse,
	accountType string,
	authTokenType string,
	requiredFeatures []string,
	options os.Bundle,
) error

func (*AccountAuthenticatorProxy) AddAccountFromCredentials

func (p *AccountAuthenticatorProxy) AddAccountFromCredentials(
	ctx context.Context,
	response IAccountAuthenticatorResponse,
	account Account,
	accountCredentials os.Bundle,
) error

func (*AccountAuthenticatorProxy) AsBinder

func (*AccountAuthenticatorProxy) ConfirmCredentials

func (p *AccountAuthenticatorProxy) ConfirmCredentials(
	ctx context.Context,
	response IAccountAuthenticatorResponse,
	account Account,
	options os.Bundle,
) error

func (*AccountAuthenticatorProxy) EditProperties

func (p *AccountAuthenticatorProxy) EditProperties(
	ctx context.Context,
	response IAccountAuthenticatorResponse,
	accountType string,
) error

func (*AccountAuthenticatorProxy) FinishSession

func (p *AccountAuthenticatorProxy) FinishSession(
	ctx context.Context,
	response IAccountAuthenticatorResponse,
	accountType string,
	sessionBundle os.Bundle,
) error

func (*AccountAuthenticatorProxy) GetAccountCredentialsForCloning

func (p *AccountAuthenticatorProxy) GetAccountCredentialsForCloning(
	ctx context.Context,
	response IAccountAuthenticatorResponse,
	account Account,
) error

func (*AccountAuthenticatorProxy) GetAccountRemovalAllowed

func (p *AccountAuthenticatorProxy) GetAccountRemovalAllowed(
	ctx context.Context,
	response IAccountAuthenticatorResponse,
	account Account,
) error

func (*AccountAuthenticatorProxy) GetAuthToken

func (p *AccountAuthenticatorProxy) GetAuthToken(
	ctx context.Context,
	response IAccountAuthenticatorResponse,
	account Account,
	authTokenType string,
	options os.Bundle,
) error

func (*AccountAuthenticatorProxy) GetAuthTokenLabel

func (p *AccountAuthenticatorProxy) GetAuthTokenLabel(
	ctx context.Context,
	response IAccountAuthenticatorResponse,
	authTokenType string,
) error

func (*AccountAuthenticatorProxy) HasFeatures

func (p *AccountAuthenticatorProxy) HasFeatures(
	ctx context.Context,
	response IAccountAuthenticatorResponse,
	account Account,
	features []string,
) error

func (*AccountAuthenticatorProxy) IsCredentialsUpdateSuggested

func (p *AccountAuthenticatorProxy) IsCredentialsUpdateSuggested(
	ctx context.Context,
	response IAccountAuthenticatorResponse,
	account Account,
	statusToken string,
) error

func (*AccountAuthenticatorProxy) StartAddAccountSession

func (p *AccountAuthenticatorProxy) StartAddAccountSession(
	ctx context.Context,
	response IAccountAuthenticatorResponse,
	accountType string,
	authTokenType string,
	requiredFeatures []string,
	options os.Bundle,
) error

func (*AccountAuthenticatorProxy) StartUpdateCredentialsSession

func (p *AccountAuthenticatorProxy) StartUpdateCredentialsSession(
	ctx context.Context,
	response IAccountAuthenticatorResponse,
	account Account,
	authTokenType string,
	options os.Bundle,
) error

func (*AccountAuthenticatorProxy) UpdateCredentials

func (p *AccountAuthenticatorProxy) UpdateCredentials(
	ctx context.Context,
	response IAccountAuthenticatorResponse,
	account Account,
	authTokenType string,
	options os.Bundle,
) error

type AccountAuthenticatorResponseProxy

type AccountAuthenticatorResponseProxy struct {
	Remote binder.IBinder
}

func NewAccountAuthenticatorResponseProxy

func NewAccountAuthenticatorResponseProxy(
	remote binder.IBinder,
) *AccountAuthenticatorResponseProxy

func (*AccountAuthenticatorResponseProxy) AsBinder

func (*AccountAuthenticatorResponseProxy) OnError

func (p *AccountAuthenticatorResponseProxy) OnError(
	ctx context.Context,
	errorCode int32,
	errorMessage string,
) error

func (*AccountAuthenticatorResponseProxy) OnRequestContinued

func (p *AccountAuthenticatorResponseProxy) OnRequestContinued(
	ctx context.Context,
) error

func (*AccountAuthenticatorResponseProxy) OnResult

func (p *AccountAuthenticatorResponseProxy) OnResult(
	ctx context.Context,
	value os.Bundle,
) error

type AccountAuthenticatorResponseStub

type AccountAuthenticatorResponseStub struct {
	Impl      IAccountAuthenticatorResponse
	Transport binder.VersionAwareTransport
}

AccountAuthenticatorResponseStub dispatches incoming binder transactions to a typed IAccountAuthenticatorResponse implementation.

func (*AccountAuthenticatorResponseStub) Descriptor

func (s *AccountAuthenticatorResponseStub) Descriptor() string

func (*AccountAuthenticatorResponseStub) OnTransaction

type AccountAuthenticatorStub

type AccountAuthenticatorStub struct {
	Impl      IAccountAuthenticator
	Transport binder.VersionAwareTransport
}

AccountAuthenticatorStub dispatches incoming binder transactions to a typed IAccountAuthenticator implementation.

func (*AccountAuthenticatorStub) Descriptor

func (s *AccountAuthenticatorStub) Descriptor() string

func (*AccountAuthenticatorStub) OnTransaction

func (s *AccountAuthenticatorStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type AccountManagerProxy

type AccountManagerProxy struct {
	Remote binder.IBinder
}

func GetAccountManager

func GetAccountManager(
	ctx context.Context,
	sm *servicemanager.ServiceManager,
) (*AccountManagerProxy, error)

GetAccountManager retrieves the AccountService service and returns a typed proxy.

func NewAccountManagerProxy

func NewAccountManagerProxy(
	remote binder.IBinder,
) *AccountManagerProxy

func (*AccountManagerProxy) AccountAuthenticated

func (p *AccountManagerProxy) AccountAuthenticated(
	ctx context.Context,
	account Account,
) (bool, error)

func (*AccountManagerProxy) AddAccount

func (p *AccountManagerProxy) AddAccount(
	ctx context.Context,
	response IAccountManagerResponse,
	accountType string,
	authTokenType string,
	requiredFeatures []string,
	expectActivityLaunch bool,
	options os.Bundle,
) error

func (*AccountManagerProxy) AddAccountAsUser

func (p *AccountManagerProxy) AddAccountAsUser(
	ctx context.Context,
	response IAccountManagerResponse,
	accountType string,
	authTokenType string,
	requiredFeatures []string,
	expectActivityLaunch bool,
	options os.Bundle,
) error

func (*AccountManagerProxy) AddAccountExplicitly

func (p *AccountManagerProxy) AddAccountExplicitly(
	ctx context.Context,
	account Account,
	password string,
	extras os.Bundle,
) (bool, error)

func (*AccountManagerProxy) AddAccountExplicitlyWithVisibility

func (p *AccountManagerProxy) AddAccountExplicitlyWithVisibility(
	ctx context.Context,
	account Account,
	password string,
	extras os.Bundle,
	visibility map[any]any,
) (bool, error)

func (*AccountManagerProxy) AddSharedAccountsFromParentUser

func (p *AccountManagerProxy) AddSharedAccountsFromParentUser(
	ctx context.Context,
	parentUserId int32,
) error

func (*AccountManagerProxy) AsBinder

func (p *AccountManagerProxy) AsBinder() binder.IBinder

func (*AccountManagerProxy) ClearPassword

func (p *AccountManagerProxy) ClearPassword(
	ctx context.Context,
	account Account,
) error

func (*AccountManagerProxy) ConfirmCredentialsAsUser

func (p *AccountManagerProxy) ConfirmCredentialsAsUser(
	ctx context.Context,
	response IAccountManagerResponse,
	account Account,
	options os.Bundle,
	expectActivityLaunch bool,
) error

func (*AccountManagerProxy) CopyAccountToUser

func (p *AccountManagerProxy) CopyAccountToUser(
	ctx context.Context,
	response IAccountManagerResponse,
	account Account,
	userFrom int32,
	userTo int32,
) error

func (*AccountManagerProxy) CreateRequestAccountAccessIntentSenderAsUser

func (p *AccountManagerProxy) CreateRequestAccountAccessIntentSenderAsUser(
	ctx context.Context,
	account Account,
	packageName string,
	userHandle os.UserHandle,
) (types.IntentSender, error)

func (*AccountManagerProxy) EditProperties

func (p *AccountManagerProxy) EditProperties(
	ctx context.Context,
	response IAccountManagerResponse,
	accountType string,
	expectActivityLaunch bool,
) error

func (*AccountManagerProxy) FinishSessionAsUser

func (p *AccountManagerProxy) FinishSessionAsUser(
	ctx context.Context,
	response IAccountManagerResponse,
	sessionBundle os.Bundle,
	expectActivityLaunch bool,
	appInfo os.Bundle,
) error

func (*AccountManagerProxy) GetAccountByTypeAndFeatures

func (p *AccountManagerProxy) GetAccountByTypeAndFeatures(
	ctx context.Context,
	response IAccountManagerResponse,
	accountType string,
	features []string,
) error

func (*AccountManagerProxy) GetAccountVisibility

func (p *AccountManagerProxy) GetAccountVisibility(
	ctx context.Context,
	a Account,
	packageName string,
) (int32, error)

func (*AccountManagerProxy) GetAccountsAndVisibilityForPackage

func (p *AccountManagerProxy) GetAccountsAndVisibilityForPackage(
	ctx context.Context,
	packageName string,
	accountType string,
) (map[any]any, error)

func (*AccountManagerProxy) GetAccountsAsUser

func (p *AccountManagerProxy) GetAccountsAsUser(
	ctx context.Context,
	accountType string,
) ([]Account, error)

func (*AccountManagerProxy) GetAccountsByFeatures

func (p *AccountManagerProxy) GetAccountsByFeatures(
	ctx context.Context,
	response IAccountManagerResponse,
	accountType string,
	features []string,
) error

func (*AccountManagerProxy) GetAccountsByTypeForPackage

func (p *AccountManagerProxy) GetAccountsByTypeForPackage(
	ctx context.Context,
	type_ string,
	packageName string,
) ([]Account, error)

func (*AccountManagerProxy) GetAccountsForPackage

func (p *AccountManagerProxy) GetAccountsForPackage(
	ctx context.Context,
	packageName string,
	uid int32,
) ([]Account, error)

func (*AccountManagerProxy) GetAuthToken

func (p *AccountManagerProxy) GetAuthToken(
	ctx context.Context,
	response IAccountManagerResponse,
	account Account,
	authTokenType string,
	notifyOnAuthFailure bool,
	expectActivityLaunch bool,
	options os.Bundle,
) error

func (*AccountManagerProxy) GetAuthTokenLabel

func (p *AccountManagerProxy) GetAuthTokenLabel(
	ctx context.Context,
	response IAccountManagerResponse,
	accountType string,
	authTokenType string,
) error

func (*AccountManagerProxy) GetAuthenticatorTypes

func (p *AccountManagerProxy) GetAuthenticatorTypes(
	ctx context.Context,
) ([]AuthenticatorDescription, error)

func (*AccountManagerProxy) GetPackagesAndVisibilityForAccount

func (p *AccountManagerProxy) GetPackagesAndVisibilityForAccount(
	ctx context.Context,
	account Account,
) (map[any]any, error)

func (*AccountManagerProxy) GetPassword

func (p *AccountManagerProxy) GetPassword(
	ctx context.Context,
	account Account,
) (string, error)

func (*AccountManagerProxy) GetPreviousName

func (p *AccountManagerProxy) GetPreviousName(
	ctx context.Context,
	account Account,
) (string, error)

func (*AccountManagerProxy) GetUserData

func (p *AccountManagerProxy) GetUserData(
	ctx context.Context,
	account Account,
	key string,
) (string, error)

func (*AccountManagerProxy) HasAccountAccess

func (p *AccountManagerProxy) HasAccountAccess(
	ctx context.Context,
	account Account,
	packageName string,
	userHandle os.UserHandle,
) (bool, error)

func (*AccountManagerProxy) HasFeatures

func (p *AccountManagerProxy) HasFeatures(
	ctx context.Context,
	response IAccountManagerResponse,
	account Account,
	features []string,
) error

func (*AccountManagerProxy) InvalidateAuthToken

func (p *AccountManagerProxy) InvalidateAuthToken(
	ctx context.Context,
	accountType string,
	authToken string,
) error

func (*AccountManagerProxy) IsCredentialsUpdateSuggested

func (p *AccountManagerProxy) IsCredentialsUpdateSuggested(
	ctx context.Context,
	response IAccountManagerResponse,
	account Account,
	statusToken string,
) error

func (*AccountManagerProxy) OnAccountAccessed

func (p *AccountManagerProxy) OnAccountAccessed(
	ctx context.Context,
	token string,
) error

func (*AccountManagerProxy) PeekAuthToken

func (p *AccountManagerProxy) PeekAuthToken(
	ctx context.Context,
	account Account,
	authTokenType string,
) (string, error)

func (*AccountManagerProxy) RegisterAccountListener

func (p *AccountManagerProxy) RegisterAccountListener(
	ctx context.Context,
	accountTypes []string,
) error

func (*AccountManagerProxy) RemoveAccountAsUser

func (p *AccountManagerProxy) RemoveAccountAsUser(
	ctx context.Context,
	response IAccountManagerResponse,
	account Account,
	expectActivityLaunch bool,
) error

func (*AccountManagerProxy) RemoveAccountExplicitly

func (p *AccountManagerProxy) RemoveAccountExplicitly(
	ctx context.Context,
	account Account,
) (bool, error)

func (*AccountManagerProxy) RenameAccount

func (p *AccountManagerProxy) RenameAccount(
	ctx context.Context,
	response IAccountManagerResponse,
	accountToRename Account,
	newName string,
) error

func (*AccountManagerProxy) SetAccountVisibility

func (p *AccountManagerProxy) SetAccountVisibility(
	ctx context.Context,
	a Account,
	packageName string,
	newVisibility int32,
) (bool, error)

func (*AccountManagerProxy) SetAuthToken

func (p *AccountManagerProxy) SetAuthToken(
	ctx context.Context,
	account Account,
	authTokenType string,
	authToken string,
) error

func (*AccountManagerProxy) SetPassword

func (p *AccountManagerProxy) SetPassword(
	ctx context.Context,
	account Account,
	password string,
) error

func (*AccountManagerProxy) SetUserData

func (p *AccountManagerProxy) SetUserData(
	ctx context.Context,
	account Account,
	key string,
	value string,
) error

func (*AccountManagerProxy) SomeUserHasAccount

func (p *AccountManagerProxy) SomeUserHasAccount(
	ctx context.Context,
	account Account,
) (bool, error)

func (*AccountManagerProxy) StartAddAccountSession

func (p *AccountManagerProxy) StartAddAccountSession(
	ctx context.Context,
	response IAccountManagerResponse,
	accountType string,
	authTokenType string,
	requiredFeatures []string,
	expectActivityLaunch bool,
	options os.Bundle,
) error

func (*AccountManagerProxy) StartUpdateCredentialsSession

func (p *AccountManagerProxy) StartUpdateCredentialsSession(
	ctx context.Context,
	response IAccountManagerResponse,
	account Account,
	authTokenType string,
	expectActivityLaunch bool,
	options os.Bundle,
) error

func (*AccountManagerProxy) UnregisterAccountListener

func (p *AccountManagerProxy) UnregisterAccountListener(
	ctx context.Context,
	accountTypes []string,
) error

func (*AccountManagerProxy) UpdateAppPermission

func (p *AccountManagerProxy) UpdateAppPermission(
	ctx context.Context,
	account Account,
	authTokenType string,
	uid int32,
	value bool,
) error

func (*AccountManagerProxy) UpdateCredentials

func (p *AccountManagerProxy) UpdateCredentials(
	ctx context.Context,
	response IAccountManagerResponse,
	account Account,
	authTokenType string,
	expectActivityLaunch bool,
	options os.Bundle,
) error

type AccountManagerResponseProxy

type AccountManagerResponseProxy struct {
	Remote binder.IBinder
}

func NewAccountManagerResponseProxy

func NewAccountManagerResponseProxy(
	remote binder.IBinder,
) *AccountManagerResponseProxy

func (*AccountManagerResponseProxy) AsBinder

func (*AccountManagerResponseProxy) OnError

func (p *AccountManagerResponseProxy) OnError(
	ctx context.Context,
	errorCode int32,
	errorMessage string,
) error

func (*AccountManagerResponseProxy) OnResult

func (p *AccountManagerResponseProxy) OnResult(
	ctx context.Context,
	value os.Bundle,
) error

type AccountManagerResponseStub

type AccountManagerResponseStub struct {
	Impl      IAccountManagerResponse
	Transport binder.VersionAwareTransport
}

AccountManagerResponseStub dispatches incoming binder transactions to a typed IAccountManagerResponse implementation.

func (*AccountManagerResponseStub) Descriptor

func (s *AccountManagerResponseStub) Descriptor() string

func (*AccountManagerResponseStub) OnTransaction

func (s *AccountManagerResponseStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type AccountManagerStub

type AccountManagerStub struct {
	Impl      IAccountManager
	Transport binder.VersionAwareTransport
}

AccountManagerStub dispatches incoming binder transactions to a typed IAccountManager implementation.

func (*AccountManagerStub) Descriptor

func (s *AccountManagerStub) Descriptor() string

func (*AccountManagerStub) OnTransaction

func (s *AccountManagerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type AuthenticatorDescription

type AuthenticatorDescription struct {
	Type                 string
	PackageName          string
	LabelId              int32
	IconId               int32
	SmallIconId          int32
	AccountPreferencesId int32
}

func (*AuthenticatorDescription) MarshalParcel

func (s *AuthenticatorDescription) MarshalParcel(
	p *parcel.Parcel,
) error

func (*AuthenticatorDescription) UnmarshalParcel

func (s *AuthenticatorDescription) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IAccountAuthenticator

type IAccountAuthenticator interface {
	AsBinder() binder.IBinder
	AddAccount(ctx context.Context, response IAccountAuthenticatorResponse, accountType string, authTokenType string, requiredFeatures []string, options os.Bundle) error
	ConfirmCredentials(ctx context.Context, response IAccountAuthenticatorResponse, account Account, options os.Bundle) error
	GetAuthToken(ctx context.Context, response IAccountAuthenticatorResponse, account Account, authTokenType string, options os.Bundle) error
	GetAuthTokenLabel(ctx context.Context, response IAccountAuthenticatorResponse, authTokenType string) error
	UpdateCredentials(ctx context.Context, response IAccountAuthenticatorResponse, account Account, authTokenType string, options os.Bundle) error
	EditProperties(ctx context.Context, response IAccountAuthenticatorResponse, accountType string) error
	HasFeatures(ctx context.Context, response IAccountAuthenticatorResponse, account Account, features []string) error
	GetAccountRemovalAllowed(ctx context.Context, response IAccountAuthenticatorResponse, account Account) error
	GetAccountCredentialsForCloning(ctx context.Context, response IAccountAuthenticatorResponse, account Account) error
	AddAccountFromCredentials(ctx context.Context, response IAccountAuthenticatorResponse, account Account, accountCredentials os.Bundle) error
	StartAddAccountSession(ctx context.Context, response IAccountAuthenticatorResponse, accountType string, authTokenType string, requiredFeatures []string, options os.Bundle) error
	StartUpdateCredentialsSession(ctx context.Context, response IAccountAuthenticatorResponse, account Account, authTokenType string, options os.Bundle) error
	FinishSession(ctx context.Context, response IAccountAuthenticatorResponse, accountType string, sessionBundle os.Bundle) error
	IsCredentialsUpdateSuggested(ctx context.Context, response IAccountAuthenticatorResponse, account Account, statusToken string) error
}

func NewAccountAuthenticatorStub

func NewAccountAuthenticatorStub(
	impl IAccountAuthenticatorServer,
) IAccountAuthenticator

NewAccountAuthenticatorStub creates a server-side IAccountAuthenticator wrapping the given server implementation. The returned value satisfies IAccountAuthenticator and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IAccountAuthenticatorResponse

type IAccountAuthenticatorResponse interface {
	AsBinder() binder.IBinder
	OnResult(ctx context.Context, value os.Bundle) error
	OnRequestContinued(ctx context.Context) error
	OnError(ctx context.Context, errorCode int32, errorMessage string) error
}

func NewAccountAuthenticatorResponseStub

func NewAccountAuthenticatorResponseStub(
	impl IAccountAuthenticatorResponseServer,
) IAccountAuthenticatorResponse

NewAccountAuthenticatorResponseStub creates a server-side IAccountAuthenticatorResponse wrapping the given server implementation. The returned value satisfies IAccountAuthenticatorResponse and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IAccountAuthenticatorResponseServer

type IAccountAuthenticatorResponseServer interface {
	OnResult(ctx context.Context, value os.Bundle) error
	OnRequestContinued(ctx context.Context) error
	OnError(ctx context.Context, errorCode int32, errorMessage string) error
}

IAccountAuthenticatorResponseServer is the server-side interface that user implementations provide to NewAccountAuthenticatorResponseStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IAccountAuthenticatorServer

type IAccountAuthenticatorServer interface {
	AddAccount(ctx context.Context, response IAccountAuthenticatorResponse, accountType string, authTokenType string, requiredFeatures []string, options os.Bundle) error
	ConfirmCredentials(ctx context.Context, response IAccountAuthenticatorResponse, account Account, options os.Bundle) error
	GetAuthToken(ctx context.Context, response IAccountAuthenticatorResponse, account Account, authTokenType string, options os.Bundle) error
	GetAuthTokenLabel(ctx context.Context, response IAccountAuthenticatorResponse, authTokenType string) error
	UpdateCredentials(ctx context.Context, response IAccountAuthenticatorResponse, account Account, authTokenType string, options os.Bundle) error
	EditProperties(ctx context.Context, response IAccountAuthenticatorResponse, accountType string) error
	HasFeatures(ctx context.Context, response IAccountAuthenticatorResponse, account Account, features []string) error
	GetAccountRemovalAllowed(ctx context.Context, response IAccountAuthenticatorResponse, account Account) error
	GetAccountCredentialsForCloning(ctx context.Context, response IAccountAuthenticatorResponse, account Account) error
	AddAccountFromCredentials(ctx context.Context, response IAccountAuthenticatorResponse, account Account, accountCredentials os.Bundle) error
	StartAddAccountSession(ctx context.Context, response IAccountAuthenticatorResponse, accountType string, authTokenType string, requiredFeatures []string, options os.Bundle) error
	StartUpdateCredentialsSession(ctx context.Context, response IAccountAuthenticatorResponse, account Account, authTokenType string, options os.Bundle) error
	FinishSession(ctx context.Context, response IAccountAuthenticatorResponse, accountType string, sessionBundle os.Bundle) error
	IsCredentialsUpdateSuggested(ctx context.Context, response IAccountAuthenticatorResponse, account Account, statusToken string) error
}

IAccountAuthenticatorServer is the server-side interface that user implementations provide to NewAccountAuthenticatorStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IAccountManager

type IAccountManager interface {
	AsBinder() binder.IBinder
	GetPassword(ctx context.Context, account Account) (string, error)
	GetUserData(ctx context.Context, account Account, key string) (string, error)
	GetAuthenticatorTypes(ctx context.Context) ([]AuthenticatorDescription, error)
	GetAccountsForPackage(ctx context.Context, packageName string, uid int32) ([]Account, error)
	GetAccountsByTypeForPackage(ctx context.Context, type_ string, packageName string) ([]Account, error)
	GetAccountsAsUser(ctx context.Context, accountType string) ([]Account, error)
	HasFeatures(ctx context.Context, response IAccountManagerResponse, account Account, features []string) error
	GetAccountByTypeAndFeatures(ctx context.Context, response IAccountManagerResponse, accountType string, features []string) error
	GetAccountsByFeatures(ctx context.Context, response IAccountManagerResponse, accountType string, features []string) error
	AddAccountExplicitly(ctx context.Context, account Account, password string, extras os.Bundle) (bool, error)
	RemoveAccountAsUser(ctx context.Context, response IAccountManagerResponse, account Account, expectActivityLaunch bool) error
	RemoveAccountExplicitly(ctx context.Context, account Account) (bool, error)
	CopyAccountToUser(ctx context.Context, response IAccountManagerResponse, account Account, userFrom int32, userTo int32) error
	InvalidateAuthToken(ctx context.Context, accountType string, authToken string) error
	PeekAuthToken(ctx context.Context, account Account, authTokenType string) (string, error)
	SetAuthToken(ctx context.Context, account Account, authTokenType string, authToken string) error
	SetPassword(ctx context.Context, account Account, password string) error
	ClearPassword(ctx context.Context, account Account) error
	SetUserData(ctx context.Context, account Account, key string, value string) error
	UpdateAppPermission(ctx context.Context, account Account, authTokenType string, uid int32, value bool) error
	GetAuthToken(ctx context.Context, response IAccountManagerResponse, account Account, authTokenType string, notifyOnAuthFailure bool, expectActivityLaunch bool, options os.Bundle) error
	AddAccount(ctx context.Context, response IAccountManagerResponse, accountType string, authTokenType string, requiredFeatures []string, expectActivityLaunch bool, options os.Bundle) error
	AddAccountAsUser(ctx context.Context, response IAccountManagerResponse, accountType string, authTokenType string, requiredFeatures []string, expectActivityLaunch bool, options os.Bundle) error
	UpdateCredentials(ctx context.Context, response IAccountManagerResponse, account Account, authTokenType string, expectActivityLaunch bool, options os.Bundle) error
	EditProperties(ctx context.Context, response IAccountManagerResponse, accountType string, expectActivityLaunch bool) error
	ConfirmCredentialsAsUser(ctx context.Context, response IAccountManagerResponse, account Account, options os.Bundle, expectActivityLaunch bool) error
	AccountAuthenticated(ctx context.Context, account Account) (bool, error)
	GetAuthTokenLabel(ctx context.Context, response IAccountManagerResponse, accountType string, authTokenType string) error
	AddSharedAccountsFromParentUser(ctx context.Context, parentUserId int32) error
	RenameAccount(ctx context.Context, response IAccountManagerResponse, accountToRename Account, newName string) error
	GetPreviousName(ctx context.Context, account Account) (string, error)
	StartAddAccountSession(ctx context.Context, response IAccountManagerResponse, accountType string, authTokenType string, requiredFeatures []string, expectActivityLaunch bool, options os.Bundle) error
	StartUpdateCredentialsSession(ctx context.Context, response IAccountManagerResponse, account Account, authTokenType string, expectActivityLaunch bool, options os.Bundle) error
	FinishSessionAsUser(ctx context.Context, response IAccountManagerResponse, sessionBundle os.Bundle, expectActivityLaunch bool, appInfo os.Bundle) error
	SomeUserHasAccount(ctx context.Context, account Account) (bool, error)
	IsCredentialsUpdateSuggested(ctx context.Context, response IAccountManagerResponse, account Account, statusToken string) error
	GetPackagesAndVisibilityForAccount(ctx context.Context, account Account) (map[any]any, error)
	AddAccountExplicitlyWithVisibility(ctx context.Context, account Account, password string, extras os.Bundle, visibility map[any]any) (bool, error)
	SetAccountVisibility(ctx context.Context, a Account, packageName string, newVisibility int32) (bool, error)
	GetAccountVisibility(ctx context.Context, a Account, packageName string) (int32, error)
	GetAccountsAndVisibilityForPackage(ctx context.Context, packageName string, accountType string) (map[any]any, error)
	RegisterAccountListener(ctx context.Context, accountTypes []string) error
	UnregisterAccountListener(ctx context.Context, accountTypes []string) error
	HasAccountAccess(ctx context.Context, account Account, packageName string, userHandle os.UserHandle) (bool, error)
	CreateRequestAccountAccessIntentSenderAsUser(ctx context.Context, account Account, packageName string, userHandle os.UserHandle) (types.IntentSender, error)
	OnAccountAccessed(ctx context.Context, token string) error
}

func NewAccountManagerStub

func NewAccountManagerStub(
	impl IAccountManagerServer,
) IAccountManager

NewAccountManagerStub creates a server-side IAccountManager wrapping the given server implementation. The returned value satisfies IAccountManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IAccountManagerResponse

type IAccountManagerResponse interface {
	AsBinder() binder.IBinder
	OnResult(ctx context.Context, value os.Bundle) error
	OnError(ctx context.Context, errorCode int32, errorMessage string) error
}

func NewAccountManagerResponseStub

func NewAccountManagerResponseStub(
	impl IAccountManagerResponseServer,
) IAccountManagerResponse

NewAccountManagerResponseStub creates a server-side IAccountManagerResponse wrapping the given server implementation. The returned value satisfies IAccountManagerResponse and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IAccountManagerResponseServer

type IAccountManagerResponseServer interface {
	OnResult(ctx context.Context, value os.Bundle) error
	OnError(ctx context.Context, errorCode int32, errorMessage string) error
}

IAccountManagerResponseServer is the server-side interface that user implementations provide to NewAccountManagerResponseStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IAccountManagerServer

type IAccountManagerServer interface {
	GetPassword(ctx context.Context, account Account) (string, error)
	GetUserData(ctx context.Context, account Account, key string) (string, error)
	GetAuthenticatorTypes(ctx context.Context) ([]AuthenticatorDescription, error)
	GetAccountsForPackage(ctx context.Context, packageName string, uid int32) ([]Account, error)
	GetAccountsByTypeForPackage(ctx context.Context, type_ string, packageName string) ([]Account, error)
	GetAccountsAsUser(ctx context.Context, accountType string) ([]Account, error)
	HasFeatures(ctx context.Context, response IAccountManagerResponse, account Account, features []string) error
	GetAccountByTypeAndFeatures(ctx context.Context, response IAccountManagerResponse, accountType string, features []string) error
	GetAccountsByFeatures(ctx context.Context, response IAccountManagerResponse, accountType string, features []string) error
	AddAccountExplicitly(ctx context.Context, account Account, password string, extras os.Bundle) (bool, error)
	RemoveAccountAsUser(ctx context.Context, response IAccountManagerResponse, account Account, expectActivityLaunch bool) error
	RemoveAccountExplicitly(ctx context.Context, account Account) (bool, error)
	CopyAccountToUser(ctx context.Context, response IAccountManagerResponse, account Account, userFrom int32, userTo int32) error
	InvalidateAuthToken(ctx context.Context, accountType string, authToken string) error
	PeekAuthToken(ctx context.Context, account Account, authTokenType string) (string, error)
	SetAuthToken(ctx context.Context, account Account, authTokenType string, authToken string) error
	SetPassword(ctx context.Context, account Account, password string) error
	ClearPassword(ctx context.Context, account Account) error
	SetUserData(ctx context.Context, account Account, key string, value string) error
	UpdateAppPermission(ctx context.Context, account Account, authTokenType string, uid int32, value bool) error
	GetAuthToken(ctx context.Context, response IAccountManagerResponse, account Account, authTokenType string, notifyOnAuthFailure bool, expectActivityLaunch bool, options os.Bundle) error
	AddAccount(ctx context.Context, response IAccountManagerResponse, accountType string, authTokenType string, requiredFeatures []string, expectActivityLaunch bool, options os.Bundle) error
	AddAccountAsUser(ctx context.Context, response IAccountManagerResponse, accountType string, authTokenType string, requiredFeatures []string, expectActivityLaunch bool, options os.Bundle) error
	UpdateCredentials(ctx context.Context, response IAccountManagerResponse, account Account, authTokenType string, expectActivityLaunch bool, options os.Bundle) error
	EditProperties(ctx context.Context, response IAccountManagerResponse, accountType string, expectActivityLaunch bool) error
	ConfirmCredentialsAsUser(ctx context.Context, response IAccountManagerResponse, account Account, options os.Bundle, expectActivityLaunch bool) error
	AccountAuthenticated(ctx context.Context, account Account) (bool, error)
	GetAuthTokenLabel(ctx context.Context, response IAccountManagerResponse, accountType string, authTokenType string) error
	AddSharedAccountsFromParentUser(ctx context.Context, parentUserId int32) error
	RenameAccount(ctx context.Context, response IAccountManagerResponse, accountToRename Account, newName string) error
	GetPreviousName(ctx context.Context, account Account) (string, error)
	StartAddAccountSession(ctx context.Context, response IAccountManagerResponse, accountType string, authTokenType string, requiredFeatures []string, expectActivityLaunch bool, options os.Bundle) error
	StartUpdateCredentialsSession(ctx context.Context, response IAccountManagerResponse, account Account, authTokenType string, expectActivityLaunch bool, options os.Bundle) error
	FinishSessionAsUser(ctx context.Context, response IAccountManagerResponse, sessionBundle os.Bundle, expectActivityLaunch bool, appInfo os.Bundle) error
	SomeUserHasAccount(ctx context.Context, account Account) (bool, error)
	IsCredentialsUpdateSuggested(ctx context.Context, response IAccountManagerResponse, account Account, statusToken string) error
	GetPackagesAndVisibilityForAccount(ctx context.Context, account Account) (map[any]any, error)
	AddAccountExplicitlyWithVisibility(ctx context.Context, account Account, password string, extras os.Bundle, visibility map[any]any) (bool, error)
	SetAccountVisibility(ctx context.Context, a Account, packageName string, newVisibility int32) (bool, error)
	GetAccountVisibility(ctx context.Context, a Account, packageName string) (int32, error)
	GetAccountsAndVisibilityForPackage(ctx context.Context, packageName string, accountType string) (map[any]any, error)
	RegisterAccountListener(ctx context.Context, accountTypes []string) error
	UnregisterAccountListener(ctx context.Context, accountTypes []string) error
	HasAccountAccess(ctx context.Context, account Account, packageName string, userHandle os.UserHandle) (bool, error)
	CreateRequestAccountAccessIntentSenderAsUser(ctx context.Context, account Account, packageName string, userHandle os.UserHandle) (types.IntentSender, error)
	OnAccountAccessed(ctx context.Context, token string) error
}

IAccountManagerServer is the server-side interface that user implementations provide to NewAccountManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

Directories

Path Synopsis

Jump to