backup

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIBackupManagerDataChangedForUser                    = binder.FirstCallTransaction + 0
	TransactionIBackupManagerDataChanged                           = binder.FirstCallTransaction + 1
	TransactionIBackupManagerClearBackupDataForUser                = binder.FirstCallTransaction + 2
	TransactionIBackupManagerClearBackupData                       = binder.FirstCallTransaction + 3
	TransactionIBackupManagerInitializeTransportsForUser           = binder.FirstCallTransaction + 4
	TransactionIBackupManagerAgentConnectedForUser                 = binder.FirstCallTransaction + 5
	TransactionIBackupManagerAgentConnected                        = binder.FirstCallTransaction + 6
	TransactionIBackupManagerAgentDisconnectedForUser              = binder.FirstCallTransaction + 7
	TransactionIBackupManagerAgentDisconnected                     = binder.FirstCallTransaction + 8
	TransactionIBackupManagerRestoreAtInstallForUser               = binder.FirstCallTransaction + 9
	TransactionIBackupManagerRestoreAtInstall                      = binder.FirstCallTransaction + 10
	TransactionIBackupManagerSetBackupEnabledForUser               = binder.FirstCallTransaction + 11
	TransactionIBackupManagerSetFrameworkSchedulingEnabledForUser  = binder.FirstCallTransaction + 12
	TransactionIBackupManagerSetBackupEnabled                      = binder.FirstCallTransaction + 13
	TransactionIBackupManagerSetAutoRestoreForUser                 = binder.FirstCallTransaction + 14
	TransactionIBackupManagerSetAutoRestore                        = binder.FirstCallTransaction + 15
	TransactionIBackupManagerIsBackupEnabledForUser                = binder.FirstCallTransaction + 16
	TransactionIBackupManagerIsBackupEnabled                       = binder.FirstCallTransaction + 17
	TransactionIBackupManagerSetBackupPassword                     = binder.FirstCallTransaction + 18
	TransactionIBackupManagerHasBackupPassword                     = binder.FirstCallTransaction + 19
	TransactionIBackupManagerBackupNowForUser                      = binder.FirstCallTransaction + 20
	TransactionIBackupManagerBackupNow                             = binder.FirstCallTransaction + 21
	TransactionIBackupManagerAdbBackup                             = binder.FirstCallTransaction + 22
	TransactionIBackupManagerFullTransportBackupForUser            = binder.FirstCallTransaction + 23
	TransactionIBackupManagerAdbRestore                            = binder.FirstCallTransaction + 24
	TransactionIBackupManagerAcknowledgeFullBackupOrRestoreForUser = binder.FirstCallTransaction + 25
	TransactionIBackupManagerAcknowledgeFullBackupOrRestore        = binder.FirstCallTransaction + 26
	TransactionIBackupManagerUpdateTransportAttributesForUser      = binder.FirstCallTransaction + 27
	TransactionIBackupManagerGetCurrentTransportForUser            = binder.FirstCallTransaction + 28
	TransactionIBackupManagerGetCurrentTransport                   = binder.FirstCallTransaction + 29
	TransactionIBackupManagerGetCurrentTransportComponentForUser   = binder.FirstCallTransaction + 30
	TransactionIBackupManagerListAllTransportsForUser              = binder.FirstCallTransaction + 31
	TransactionIBackupManagerListAllTransports                     = binder.FirstCallTransaction + 32
	TransactionIBackupManagerListAllTransportComponentsForUser     = binder.FirstCallTransaction + 33
	TransactionIBackupManagerGetTransportWhitelist                 = binder.FirstCallTransaction + 34
	TransactionIBackupManagerSelectBackupTransportForUser          = binder.FirstCallTransaction + 35
	TransactionIBackupManagerSelectBackupTransport                 = binder.FirstCallTransaction + 36
	TransactionIBackupManagerSelectBackupTransportAsyncForUser     = binder.FirstCallTransaction + 37
	TransactionIBackupManagerGetConfigurationIntentForUser         = binder.FirstCallTransaction + 38
	TransactionIBackupManagerGetConfigurationIntent                = binder.FirstCallTransaction + 39
	TransactionIBackupManagerGetDestinationStringForUser           = binder.FirstCallTransaction + 40
	TransactionIBackupManagerGetDestinationString                  = binder.FirstCallTransaction + 41
	TransactionIBackupManagerGetDataManagementIntentForUser        = binder.FirstCallTransaction + 42
	TransactionIBackupManagerGetDataManagementIntent               = binder.FirstCallTransaction + 43
	TransactionIBackupManagerGetDataManagementLabelForUser         = binder.FirstCallTransaction + 44
	TransactionIBackupManagerBeginRestoreSessionForUser            = binder.FirstCallTransaction + 45
	TransactionIBackupManagerOpCompleteForUser                     = binder.FirstCallTransaction + 46
	TransactionIBackupManagerOpComplete                            = binder.FirstCallTransaction + 47
	TransactionIBackupManagerSetBackupServiceActive                = binder.FirstCallTransaction + 48
	TransactionIBackupManagerIsBackupServiceActive                 = binder.FirstCallTransaction + 49
	TransactionIBackupManagerIsUserReadyForBackup                  = binder.FirstCallTransaction + 50
	TransactionIBackupManagerGetAvailableRestoreTokenForUser       = binder.FirstCallTransaction + 51
	TransactionIBackupManagerIsAppEligibleForBackupForUser         = binder.FirstCallTransaction + 52
	TransactionIBackupManagerFilterAppsEligibleForBackupForUser    = binder.FirstCallTransaction + 53
	TransactionIBackupManagerRequestBackupForUser                  = binder.FirstCallTransaction + 54
	TransactionIBackupManagerRequestBackup                         = binder.FirstCallTransaction + 55
	TransactionIBackupManagerCancelBackupsForUser                  = binder.FirstCallTransaction + 56
	TransactionIBackupManagerCancelBackups                         = binder.FirstCallTransaction + 57
	TransactionIBackupManagerGetUserForAncestralSerialNumber       = binder.FirstCallTransaction + 58
	TransactionIBackupManagerSetAncestralSerialNumber              = binder.FirstCallTransaction + 59
	TransactionIBackupManagerExcludeKeysFromRestore                = binder.FirstCallTransaction + 60
	TransactionIBackupManagerReportDelayedRestoreResult            = binder.FirstCallTransaction + 61
)
const (
	MethodIBackupManagerDataChangedForUser                    = "dataChangedForUser"
	MethodIBackupManagerDataChanged                           = "dataChanged"
	MethodIBackupManagerClearBackupDataForUser                = "clearBackupDataForUser"
	MethodIBackupManagerClearBackupData                       = "clearBackupData"
	MethodIBackupManagerInitializeTransportsForUser           = "initializeTransportsForUser"
	MethodIBackupManagerAgentConnectedForUser                 = "agentConnectedForUser"
	MethodIBackupManagerAgentConnected                        = "agentConnected"
	MethodIBackupManagerAgentDisconnectedForUser              = "agentDisconnectedForUser"
	MethodIBackupManagerAgentDisconnected                     = "agentDisconnected"
	MethodIBackupManagerRestoreAtInstallForUser               = "restoreAtInstallForUser"
	MethodIBackupManagerRestoreAtInstall                      = "restoreAtInstall"
	MethodIBackupManagerSetBackupEnabledForUser               = "setBackupEnabledForUser"
	MethodIBackupManagerSetFrameworkSchedulingEnabledForUser  = "setFrameworkSchedulingEnabledForUser"
	MethodIBackupManagerSetBackupEnabled                      = "setBackupEnabled"
	MethodIBackupManagerSetAutoRestoreForUser                 = "setAutoRestoreForUser"
	MethodIBackupManagerSetAutoRestore                        = "setAutoRestore"
	MethodIBackupManagerIsBackupEnabledForUser                = "isBackupEnabledForUser"
	MethodIBackupManagerIsBackupEnabled                       = "isBackupEnabled"
	MethodIBackupManagerSetBackupPassword                     = "setBackupPassword"
	MethodIBackupManagerHasBackupPassword                     = "hasBackupPassword"
	MethodIBackupManagerBackupNowForUser                      = "backupNowForUser"
	MethodIBackupManagerBackupNow                             = "backupNow"
	MethodIBackupManagerAdbBackup                             = "adbBackup"
	MethodIBackupManagerFullTransportBackupForUser            = "fullTransportBackupForUser"
	MethodIBackupManagerAdbRestore                            = "adbRestore"
	MethodIBackupManagerAcknowledgeFullBackupOrRestoreForUser = "acknowledgeFullBackupOrRestoreForUser"
	MethodIBackupManagerAcknowledgeFullBackupOrRestore        = "acknowledgeFullBackupOrRestore"
	MethodIBackupManagerUpdateTransportAttributesForUser      = "updateTransportAttributesForUser"
	MethodIBackupManagerGetCurrentTransportForUser            = "getCurrentTransportForUser"
	MethodIBackupManagerGetCurrentTransport                   = "getCurrentTransport"
	MethodIBackupManagerGetCurrentTransportComponentForUser   = "getCurrentTransportComponentForUser"
	MethodIBackupManagerListAllTransportsForUser              = "listAllTransportsForUser"
	MethodIBackupManagerListAllTransports                     = "listAllTransports"
	MethodIBackupManagerListAllTransportComponentsForUser     = "listAllTransportComponentsForUser"
	MethodIBackupManagerGetTransportWhitelist                 = "getTransportWhitelist"
	MethodIBackupManagerSelectBackupTransportForUser          = "selectBackupTransportForUser"
	MethodIBackupManagerSelectBackupTransport                 = "selectBackupTransport"
	MethodIBackupManagerSelectBackupTransportAsyncForUser     = "selectBackupTransportAsyncForUser"
	MethodIBackupManagerGetConfigurationIntentForUser         = "getConfigurationIntentForUser"
	MethodIBackupManagerGetConfigurationIntent                = "getConfigurationIntent"
	MethodIBackupManagerGetDestinationStringForUser           = "getDestinationStringForUser"
	MethodIBackupManagerGetDestinationString                  = "getDestinationString"
	MethodIBackupManagerGetDataManagementIntentForUser        = "getDataManagementIntentForUser"
	MethodIBackupManagerGetDataManagementIntent               = "getDataManagementIntent"
	MethodIBackupManagerGetDataManagementLabelForUser         = "getDataManagementLabelForUser"
	MethodIBackupManagerBeginRestoreSessionForUser            = "beginRestoreSessionForUser"
	MethodIBackupManagerOpCompleteForUser                     = "opCompleteForUser"
	MethodIBackupManagerOpComplete                            = "opComplete"
	MethodIBackupManagerSetBackupServiceActive                = "setBackupServiceActive"
	MethodIBackupManagerIsBackupServiceActive                 = "isBackupServiceActive"
	MethodIBackupManagerIsUserReadyForBackup                  = "isUserReadyForBackup"
	MethodIBackupManagerGetAvailableRestoreTokenForUser       = "getAvailableRestoreTokenForUser"
	MethodIBackupManagerIsAppEligibleForBackupForUser         = "isAppEligibleForBackupForUser"
	MethodIBackupManagerFilterAppsEligibleForBackupForUser    = "filterAppsEligibleForBackupForUser"
	MethodIBackupManagerRequestBackupForUser                  = "requestBackupForUser"
	MethodIBackupManagerRequestBackup                         = "requestBackup"
	MethodIBackupManagerCancelBackupsForUser                  = "cancelBackupsForUser"
	MethodIBackupManagerCancelBackups                         = "cancelBackups"
	MethodIBackupManagerGetUserForAncestralSerialNumber       = "getUserForAncestralSerialNumber"
	MethodIBackupManagerSetAncestralSerialNumber              = "setAncestralSerialNumber"
	MethodIBackupManagerExcludeKeysFromRestore                = "excludeKeysFromRestore"
	MethodIBackupManagerReportDelayedRestoreResult            = "reportDelayedRestoreResult"
)
const (
	TransactionIBackupObserverOnUpdate       = binder.FirstCallTransaction + 0
	TransactionIBackupObserverOnResult       = binder.FirstCallTransaction + 1
	TransactionIBackupObserverBackupFinished = binder.FirstCallTransaction + 2
)
const (
	MethodIBackupObserverOnUpdate       = "onUpdate"
	MethodIBackupObserverOnResult       = "onResult"
	MethodIBackupObserverBackupFinished = "backupFinished"
)
const (
	TransactionIFullBackupRestoreObserverOnStartBackup    = binder.FirstCallTransaction + 0
	TransactionIFullBackupRestoreObserverOnBackupPackage  = binder.FirstCallTransaction + 1
	TransactionIFullBackupRestoreObserverOnEndBackup      = binder.FirstCallTransaction + 2
	TransactionIFullBackupRestoreObserverOnStartRestore   = binder.FirstCallTransaction + 3
	TransactionIFullBackupRestoreObserverOnRestorePackage = binder.FirstCallTransaction + 4
	TransactionIFullBackupRestoreObserverOnEndRestore     = binder.FirstCallTransaction + 5
	TransactionIFullBackupRestoreObserverOnTimeout        = binder.FirstCallTransaction + 6
)
const (
	MethodIFullBackupRestoreObserverOnStartBackup    = "onStartBackup"
	MethodIFullBackupRestoreObserverOnBackupPackage  = "onBackupPackage"
	MethodIFullBackupRestoreObserverOnEndBackup      = "onEndBackup"
	MethodIFullBackupRestoreObserverOnStartRestore   = "onStartRestore"
	MethodIFullBackupRestoreObserverOnRestorePackage = "onRestorePackage"
	MethodIFullBackupRestoreObserverOnEndRestore     = "onEndRestore"
	MethodIFullBackupRestoreObserverOnTimeout        = "onTimeout"
)
const (
	TransactionIRestoreObserverRestoreSetsAvailable = binder.FirstCallTransaction + 0
	TransactionIRestoreObserverRestoreStarting      = binder.FirstCallTransaction + 1
	TransactionIRestoreObserverOnUpdate             = binder.FirstCallTransaction + 2
	TransactionIRestoreObserverRestoreFinished      = binder.FirstCallTransaction + 3
)
const (
	MethodIRestoreObserverRestoreSetsAvailable = "restoreSetsAvailable"
	MethodIRestoreObserverRestoreStarting      = "restoreStarting"
	MethodIRestoreObserverOnUpdate             = "onUpdate"
	MethodIRestoreObserverRestoreFinished      = "restoreFinished"
)
const (
	TransactionIRestoreSessionGetAvailableRestoreSets = binder.FirstCallTransaction + 0
	TransactionIRestoreSessionRestoreAll              = binder.FirstCallTransaction + 1
	TransactionIRestoreSessionRestorePackages         = binder.FirstCallTransaction + 2
	TransactionIRestoreSessionRestorePackage          = binder.FirstCallTransaction + 3
	TransactionIRestoreSessionEndRestoreSession       = binder.FirstCallTransaction + 4
)
const (
	MethodIRestoreSessionGetAvailableRestoreSets = "getAvailableRestoreSets"
	MethodIRestoreSessionRestoreAll              = "restoreAll"
	MethodIRestoreSessionRestorePackages         = "restorePackages"
	MethodIRestoreSessionRestorePackage          = "restorePackage"
	MethodIRestoreSessionEndRestoreSession       = "endRestoreSession"
)
const (
	TransactionISelectBackupTransportCallbackOnSuccess = binder.FirstCallTransaction + 0
	TransactionISelectBackupTransportCallbackOnFailure = binder.FirstCallTransaction + 1
)
const (
	MethodISelectBackupTransportCallbackOnSuccess = "onSuccess"
	MethodISelectBackupTransportCallbackOnFailure = "onFailure"
)
const DescriptorIBackupCallback = "android.app.backup.IBackupCallback"
const DescriptorIBackupManager = "android.app.backup.IBackupManager"
const DescriptorIBackupManagerMonitor = "android.app.backup.IBackupManagerMonitor"
const DescriptorIBackupObserver = "android.app.backup.IBackupObserver"
const DescriptorIFullBackupRestoreObserver = "android.app.backup.IFullBackupRestoreObserver"
const DescriptorIRestoreObserver = "android.app.backup.IRestoreObserver"
const DescriptorIRestoreSession = "android.app.backup.IRestoreSession"
const DescriptorISelectBackupTransportCallback = "android.app.backup.ISelectBackupTransportCallback"
const (
	MethodIBackupCallbackOperationComplete = "operationComplete"
)
const (
	MethodIBackupManagerMonitorOnEvent = "onEvent"
)
const (
	TransactionIBackupCallbackOperationComplete = binder.FirstCallTransaction + 0
)
const (
	TransactionIBackupManagerMonitorOnEvent = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type BackupCallbackProxy

type BackupCallbackProxy struct {
	Remote binder.IBinder
}

func NewBackupCallbackProxy

func NewBackupCallbackProxy(
	remote binder.IBinder,
) *BackupCallbackProxy

func (*BackupCallbackProxy) AsBinder

func (p *BackupCallbackProxy) AsBinder() binder.IBinder

func (*BackupCallbackProxy) OperationComplete

func (p *BackupCallbackProxy) OperationComplete(
	ctx context.Context,
	result int64,
) error

type BackupCallbackStub

type BackupCallbackStub struct {
	Impl      IBackupCallback
	Transport binder.VersionAwareTransport
}

BackupCallbackStub dispatches incoming binder transactions to a typed IBackupCallback implementation.

func (*BackupCallbackStub) Descriptor

func (s *BackupCallbackStub) Descriptor() string

func (*BackupCallbackStub) OnTransaction

func (s *BackupCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type BackupManagerMonitorProxy

type BackupManagerMonitorProxy struct {
	Remote binder.IBinder
}

func NewBackupManagerMonitorProxy

func NewBackupManagerMonitorProxy(
	remote binder.IBinder,
) *BackupManagerMonitorProxy

func (*BackupManagerMonitorProxy) AsBinder

func (*BackupManagerMonitorProxy) OnEvent

func (p *BackupManagerMonitorProxy) OnEvent(
	ctx context.Context,
	event os.Bundle,
) error

type BackupManagerMonitorStub

type BackupManagerMonitorStub struct {
	Impl      IBackupManagerMonitor
	Transport binder.VersionAwareTransport
}

BackupManagerMonitorStub dispatches incoming binder transactions to a typed IBackupManagerMonitor implementation.

func (*BackupManagerMonitorStub) Descriptor

func (s *BackupManagerMonitorStub) Descriptor() string

func (*BackupManagerMonitorStub) OnTransaction

func (s *BackupManagerMonitorStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type BackupManagerProxy

type BackupManagerProxy struct {
	Remote binder.IBinder
}

func NewBackupManagerProxy

func NewBackupManagerProxy(
	remote binder.IBinder,
) *BackupManagerProxy

func (*BackupManagerProxy) AcknowledgeFullBackupOrRestore

func (p *BackupManagerProxy) AcknowledgeFullBackupOrRestore(
	ctx context.Context,
	token int32,
	allow bool,
	curPassword string,
	encryptionPassword string,
	observer IFullBackupRestoreObserver,
) error

func (*BackupManagerProxy) AcknowledgeFullBackupOrRestoreForUser

func (p *BackupManagerProxy) AcknowledgeFullBackupOrRestoreForUser(
	ctx context.Context,
	token int32,
	allow bool,
	curPassword string,
	encryptionPassword string,
	observer IFullBackupRestoreObserver,
) error

func (*BackupManagerProxy) AdbBackup

func (p *BackupManagerProxy) AdbBackup(
	ctx context.Context,
	fd int32,
	includeApks bool,
	includeObbs bool,
	includeShared bool,
	doWidgets bool,
	allApps bool,
	allIncludesSystem bool,
	doCompress bool,
	doKeyValue bool,
	packageNames []string,
) error

func (*BackupManagerProxy) AdbRestore

func (p *BackupManagerProxy) AdbRestore(
	ctx context.Context,
	fd int32,
) error

func (*BackupManagerProxy) AgentConnected

func (p *BackupManagerProxy) AgentConnected(
	ctx context.Context,
	packageName string,
	agent binder.IBinder,
) error

func (*BackupManagerProxy) AgentConnectedForUser

func (p *BackupManagerProxy) AgentConnectedForUser(
	ctx context.Context,
	packageName string,
	agent binder.IBinder,
) error

func (*BackupManagerProxy) AgentDisconnected

func (p *BackupManagerProxy) AgentDisconnected(
	ctx context.Context,
	packageName string,
) error

func (*BackupManagerProxy) AgentDisconnectedForUser

func (p *BackupManagerProxy) AgentDisconnectedForUser(
	ctx context.Context,
	packageName string,
) error

func (*BackupManagerProxy) AsBinder

func (p *BackupManagerProxy) AsBinder() binder.IBinder

func (*BackupManagerProxy) BackupNow

func (p *BackupManagerProxy) BackupNow(
	ctx context.Context,
) error

func (*BackupManagerProxy) BackupNowForUser

func (p *BackupManagerProxy) BackupNowForUser(
	ctx context.Context,
) error

func (*BackupManagerProxy) BeginRestoreSessionForUser

func (p *BackupManagerProxy) BeginRestoreSessionForUser(
	ctx context.Context,
	packageName string,
	transportID string,
) (IRestoreSession, error)

func (*BackupManagerProxy) CancelBackups

func (p *BackupManagerProxy) CancelBackups(
	ctx context.Context,
) error

func (*BackupManagerProxy) CancelBackupsForUser

func (p *BackupManagerProxy) CancelBackupsForUser(
	ctx context.Context,
) error

func (*BackupManagerProxy) ClearBackupData

func (p *BackupManagerProxy) ClearBackupData(
	ctx context.Context,
	transportName string,
	packageName string,
) error

func (*BackupManagerProxy) ClearBackupDataForUser

func (p *BackupManagerProxy) ClearBackupDataForUser(
	ctx context.Context,
	transportName string,
	packageName string,
) error

func (*BackupManagerProxy) DataChanged

func (p *BackupManagerProxy) DataChanged(
	ctx context.Context,
	packageName string,
) error

func (*BackupManagerProxy) DataChangedForUser

func (p *BackupManagerProxy) DataChangedForUser(
	ctx context.Context,
	packageName string,
) error

func (*BackupManagerProxy) ExcludeKeysFromRestore

func (p *BackupManagerProxy) ExcludeKeysFromRestore(
	ctx context.Context,
	packageName string,
	keys []string,
) error

func (*BackupManagerProxy) FilterAppsEligibleForBackupForUser

func (p *BackupManagerProxy) FilterAppsEligibleForBackupForUser(
	ctx context.Context,
	packages []string,
) ([]string, error)

func (*BackupManagerProxy) FullTransportBackupForUser

func (p *BackupManagerProxy) FullTransportBackupForUser(
	ctx context.Context,
	packageNames []string,
) error

func (*BackupManagerProxy) GetAvailableRestoreTokenForUser

func (p *BackupManagerProxy) GetAvailableRestoreTokenForUser(
	ctx context.Context,
	packageName string,
) (int64, error)

func (*BackupManagerProxy) GetConfigurationIntent

func (p *BackupManagerProxy) GetConfigurationIntent(
	ctx context.Context,
	transport string,
) (content.Intent, error)

func (*BackupManagerProxy) GetConfigurationIntentForUser

func (p *BackupManagerProxy) GetConfigurationIntentForUser(
	ctx context.Context,
	transport string,
) (content.Intent, error)

func (*BackupManagerProxy) GetCurrentTransport

func (p *BackupManagerProxy) GetCurrentTransport(
	ctx context.Context,
) (string, error)

func (*BackupManagerProxy) GetCurrentTransportComponentForUser

func (p *BackupManagerProxy) GetCurrentTransportComponentForUser(
	ctx context.Context,
) (content.ComponentName, error)

func (*BackupManagerProxy) GetCurrentTransportForUser

func (p *BackupManagerProxy) GetCurrentTransportForUser(
	ctx context.Context,
) (string, error)

func (*BackupManagerProxy) GetDataManagementIntent

func (p *BackupManagerProxy) GetDataManagementIntent(
	ctx context.Context,
	transport string,
) (content.Intent, error)

func (*BackupManagerProxy) GetDataManagementIntentForUser

func (p *BackupManagerProxy) GetDataManagementIntentForUser(
	ctx context.Context,
	transport string,
) (content.Intent, error)

func (*BackupManagerProxy) GetDataManagementLabelForUser

func (p *BackupManagerProxy) GetDataManagementLabelForUser(
	ctx context.Context,
	transport string,
) (string, error)

func (*BackupManagerProxy) GetDestinationString

func (p *BackupManagerProxy) GetDestinationString(
	ctx context.Context,
	transport string,
) (string, error)

func (*BackupManagerProxy) GetDestinationStringForUser

func (p *BackupManagerProxy) GetDestinationStringForUser(
	ctx context.Context,
	transport string,
) (string, error)

func (*BackupManagerProxy) GetTransportWhitelist

func (p *BackupManagerProxy) GetTransportWhitelist(
	ctx context.Context,
) ([]string, error)

func (*BackupManagerProxy) GetUserForAncestralSerialNumber

func (p *BackupManagerProxy) GetUserForAncestralSerialNumber(
	ctx context.Context,
	ancestralSerialNumber int64,
) (os.UserHandle, error)

func (*BackupManagerProxy) HasBackupPassword

func (p *BackupManagerProxy) HasBackupPassword(
	ctx context.Context,
) (bool, error)

func (*BackupManagerProxy) InitializeTransportsForUser

func (p *BackupManagerProxy) InitializeTransportsForUser(
	ctx context.Context,
	transportNames []string,
	observer IBackupObserver,
) error

func (*BackupManagerProxy) IsAppEligibleForBackupForUser

func (p *BackupManagerProxy) IsAppEligibleForBackupForUser(
	ctx context.Context,
	packageName string,
) (bool, error)

func (*BackupManagerProxy) IsBackupEnabled

func (p *BackupManagerProxy) IsBackupEnabled(
	ctx context.Context,
) (bool, error)

func (*BackupManagerProxy) IsBackupEnabledForUser

func (p *BackupManagerProxy) IsBackupEnabledForUser(
	ctx context.Context,
) (bool, error)

func (*BackupManagerProxy) IsBackupServiceActive

func (p *BackupManagerProxy) IsBackupServiceActive(
	ctx context.Context,
	whichUser int32,
) (bool, error)

func (*BackupManagerProxy) IsUserReadyForBackup

func (p *BackupManagerProxy) IsUserReadyForBackup(
	ctx context.Context,
) (bool, error)

func (*BackupManagerProxy) ListAllTransportComponentsForUser

func (p *BackupManagerProxy) ListAllTransportComponentsForUser(
	ctx context.Context,
) ([]content.ComponentName, error)

func (*BackupManagerProxy) ListAllTransports

func (p *BackupManagerProxy) ListAllTransports(
	ctx context.Context,
) ([]string, error)

func (*BackupManagerProxy) ListAllTransportsForUser

func (p *BackupManagerProxy) ListAllTransportsForUser(
	ctx context.Context,
) ([]string, error)

func (*BackupManagerProxy) OpComplete

func (p *BackupManagerProxy) OpComplete(
	ctx context.Context,
	token int32,
	result int64,
) error

func (*BackupManagerProxy) OpCompleteForUser

func (p *BackupManagerProxy) OpCompleteForUser(
	ctx context.Context,
	token int32,
	result int64,
) error

func (*BackupManagerProxy) ReportDelayedRestoreResult

func (p *BackupManagerProxy) ReportDelayedRestoreResult(
	ctx context.Context,
	packageName string,
	results []BackupRestoreEventLoggerDataTypeResult,
) error

func (*BackupManagerProxy) RequestBackup

func (p *BackupManagerProxy) RequestBackup(
	ctx context.Context,
	packages []string,
	observer IBackupObserver,
	monitor IBackupManagerMonitor,
	flags int32,
) (int32, error)

func (*BackupManagerProxy) RequestBackupForUser

func (p *BackupManagerProxy) RequestBackupForUser(
	ctx context.Context,
	packages []string,
	observer IBackupObserver,
	monitor IBackupManagerMonitor,
	flags int32,
) (int32, error)

func (*BackupManagerProxy) RestoreAtInstall

func (p *BackupManagerProxy) RestoreAtInstall(
	ctx context.Context,
	packageName string,
	token int32,
) error

func (*BackupManagerProxy) RestoreAtInstallForUser

func (p *BackupManagerProxy) RestoreAtInstallForUser(
	ctx context.Context,
	packageName string,
	token int32,
) error

func (*BackupManagerProxy) SelectBackupTransport

func (p *BackupManagerProxy) SelectBackupTransport(
	ctx context.Context,
	transport string,
) (string, error)

func (*BackupManagerProxy) SelectBackupTransportAsyncForUser

func (p *BackupManagerProxy) SelectBackupTransportAsyncForUser(
	ctx context.Context,
	transport content.ComponentName,
	listener ISelectBackupTransportCallback,
) error

func (*BackupManagerProxy) SelectBackupTransportForUser

func (p *BackupManagerProxy) SelectBackupTransportForUser(
	ctx context.Context,
	transport string,
) (string, error)

func (*BackupManagerProxy) SetAncestralSerialNumber

func (p *BackupManagerProxy) SetAncestralSerialNumber(
	ctx context.Context,
	ancestralSerialNumber int64,
) error

func (*BackupManagerProxy) SetAutoRestore

func (p *BackupManagerProxy) SetAutoRestore(
	ctx context.Context,
	doAutoRestore bool,
) error

func (*BackupManagerProxy) SetAutoRestoreForUser

func (p *BackupManagerProxy) SetAutoRestoreForUser(
	ctx context.Context,
	doAutoRestore bool,
) error

func (*BackupManagerProxy) SetBackupEnabled

func (p *BackupManagerProxy) SetBackupEnabled(
	ctx context.Context,
	isEnabled bool,
) error

func (*BackupManagerProxy) SetBackupEnabledForUser

func (p *BackupManagerProxy) SetBackupEnabledForUser(
	ctx context.Context,
	isEnabled bool,
) error

func (*BackupManagerProxy) SetBackupPassword

func (p *BackupManagerProxy) SetBackupPassword(
	ctx context.Context,
	currentPw string,
	newPw string,
) (bool, error)

func (*BackupManagerProxy) SetBackupServiceActive

func (p *BackupManagerProxy) SetBackupServiceActive(
	ctx context.Context,
	whichUser int32,
	makeActive bool,
) error

func (*BackupManagerProxy) SetFrameworkSchedulingEnabledForUser

func (p *BackupManagerProxy) SetFrameworkSchedulingEnabledForUser(
	ctx context.Context,
	isEnabled bool,
) error

func (*BackupManagerProxy) UpdateTransportAttributesForUser

func (p *BackupManagerProxy) UpdateTransportAttributesForUser(
	ctx context.Context,
	transportComponent content.ComponentName,
	name string,
	configurationIntent content.Intent,
	currentDestinationString string,
	dataManagementIntent content.Intent,
	dataManagementLabel string,
) error

type BackupManagerStub

type BackupManagerStub struct {
	Impl      IBackupManager
	Transport binder.VersionAwareTransport
}

BackupManagerStub dispatches incoming binder transactions to a typed IBackupManager implementation.

func (*BackupManagerStub) Descriptor

func (s *BackupManagerStub) Descriptor() string

func (*BackupManagerStub) OnTransaction

func (s *BackupManagerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type BackupObserverProxy

type BackupObserverProxy struct {
	Remote binder.IBinder
}

func NewBackupObserverProxy

func NewBackupObserverProxy(
	remote binder.IBinder,
) *BackupObserverProxy

func (*BackupObserverProxy) AsBinder

func (p *BackupObserverProxy) AsBinder() binder.IBinder

func (*BackupObserverProxy) BackupFinished

func (p *BackupObserverProxy) BackupFinished(
	ctx context.Context,
	status int32,
) error

func (*BackupObserverProxy) OnResult

func (p *BackupObserverProxy) OnResult(
	ctx context.Context,
	target string,
	status int32,
) error

func (*BackupObserverProxy) OnUpdate

func (p *BackupObserverProxy) OnUpdate(
	ctx context.Context,
	currentPackage string,
	backupProgress BackupProgress,
) error

type BackupObserverStub

type BackupObserverStub struct {
	Impl      IBackupObserver
	Transport binder.VersionAwareTransport
}

BackupObserverStub dispatches incoming binder transactions to a typed IBackupObserver implementation.

func (*BackupObserverStub) Descriptor

func (s *BackupObserverStub) Descriptor() string

func (*BackupObserverStub) OnTransaction

func (s *BackupObserverStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type BackupProgress

type BackupProgress struct {
	BytesExpected    int64
	BytesTransferred int64
}

func (*BackupProgress) MarshalParcel

func (s *BackupProgress) MarshalParcel(
	p *parcel.Parcel,
) error

func (*BackupProgress) UnmarshalParcel

func (s *BackupProgress) UnmarshalParcel(
	p *parcel.Parcel,
) error

type BackupRestoreEventLoggerDataTypeResult

type BackupRestoreEventLoggerDataTypeResult struct {
}

func (*BackupRestoreEventLoggerDataTypeResult) MarshalParcel

func (*BackupRestoreEventLoggerDataTypeResult) UnmarshalParcel

func (s *BackupRestoreEventLoggerDataTypeResult) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FullBackupRestoreObserverProxy

type FullBackupRestoreObserverProxy struct {
	Remote binder.IBinder
}

func NewFullBackupRestoreObserverProxy

func NewFullBackupRestoreObserverProxy(
	remote binder.IBinder,
) *FullBackupRestoreObserverProxy

func (*FullBackupRestoreObserverProxy) AsBinder

func (*FullBackupRestoreObserverProxy) OnBackupPackage

func (p *FullBackupRestoreObserverProxy) OnBackupPackage(
	ctx context.Context,
	name string,
) error

func (*FullBackupRestoreObserverProxy) OnEndBackup

func (p *FullBackupRestoreObserverProxy) OnEndBackup(
	ctx context.Context,
) error

func (*FullBackupRestoreObserverProxy) OnEndRestore

func (p *FullBackupRestoreObserverProxy) OnEndRestore(
	ctx context.Context,
) error

func (*FullBackupRestoreObserverProxy) OnRestorePackage

func (p *FullBackupRestoreObserverProxy) OnRestorePackage(
	ctx context.Context,
	name string,
) error

func (*FullBackupRestoreObserverProxy) OnStartBackup

func (p *FullBackupRestoreObserverProxy) OnStartBackup(
	ctx context.Context,
) error

func (*FullBackupRestoreObserverProxy) OnStartRestore

func (p *FullBackupRestoreObserverProxy) OnStartRestore(
	ctx context.Context,
) error

func (*FullBackupRestoreObserverProxy) OnTimeout

func (p *FullBackupRestoreObserverProxy) OnTimeout(
	ctx context.Context,
) error

type FullBackupRestoreObserverStub

type FullBackupRestoreObserverStub struct {
	Impl      IFullBackupRestoreObserver
	Transport binder.VersionAwareTransport
}

FullBackupRestoreObserverStub dispatches incoming binder transactions to a typed IFullBackupRestoreObserver implementation.

func (*FullBackupRestoreObserverStub) Descriptor

func (s *FullBackupRestoreObserverStub) Descriptor() string

func (*FullBackupRestoreObserverStub) OnTransaction

type IBackupCallback

type IBackupCallback interface {
	AsBinder() binder.IBinder
	OperationComplete(ctx context.Context, result int64) error
}

func NewBackupCallbackStub

func NewBackupCallbackStub(
	impl IBackupCallbackServer,
) IBackupCallback

NewBackupCallbackStub creates a server-side IBackupCallback wrapping the given server implementation. The returned value satisfies IBackupCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBackupCallbackServer

type IBackupCallbackServer interface {
	OperationComplete(ctx context.Context, result int64) error
}

IBackupCallbackServer is the server-side interface that user implementations provide to NewBackupCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IBackupManager

type IBackupManager interface {
	AsBinder() binder.IBinder
	DataChangedForUser(ctx context.Context, packageName string) error
	DataChanged(ctx context.Context, packageName string) error
	ClearBackupDataForUser(ctx context.Context, transportName string, packageName string) error
	ClearBackupData(ctx context.Context, transportName string, packageName string) error
	InitializeTransportsForUser(ctx context.Context, transportNames []string, observer IBackupObserver) error
	AgentConnectedForUser(ctx context.Context, packageName string, agent binder.IBinder) error
	AgentConnected(ctx context.Context, packageName string, agent binder.IBinder) error
	AgentDisconnectedForUser(ctx context.Context, packageName string) error
	AgentDisconnected(ctx context.Context, packageName string) error
	RestoreAtInstallForUser(ctx context.Context, packageName string, token int32) error
	RestoreAtInstall(ctx context.Context, packageName string, token int32) error
	SetBackupEnabledForUser(ctx context.Context, isEnabled bool) error
	SetFrameworkSchedulingEnabledForUser(ctx context.Context, isEnabled bool) error
	SetBackupEnabled(ctx context.Context, isEnabled bool) error
	SetAutoRestoreForUser(ctx context.Context, doAutoRestore bool) error
	SetAutoRestore(ctx context.Context, doAutoRestore bool) error
	IsBackupEnabledForUser(ctx context.Context) (bool, error)
	IsBackupEnabled(ctx context.Context) (bool, error)
	SetBackupPassword(ctx context.Context, currentPw string, newPw string) (bool, error)
	HasBackupPassword(ctx context.Context) (bool, error)
	BackupNowForUser(ctx context.Context) error
	BackupNow(ctx context.Context) error
	AdbBackup(ctx context.Context, fd int32, includeApks bool, includeObbs bool, includeShared bool, doWidgets bool, allApps bool, allIncludesSystem bool, doCompress bool, doKeyValue bool, packageNames []string) error
	FullTransportBackupForUser(ctx context.Context, packageNames []string) error
	AdbRestore(ctx context.Context, fd int32) error
	AcknowledgeFullBackupOrRestoreForUser(ctx context.Context, token int32, allow bool, curPassword string, encryptionPassword string, observer IFullBackupRestoreObserver) error
	AcknowledgeFullBackupOrRestore(ctx context.Context, token int32, allow bool, curPassword string, encryptionPassword string, observer IFullBackupRestoreObserver) error
	UpdateTransportAttributesForUser(ctx context.Context, transportComponent content.ComponentName, name string, configurationIntent content.Intent, currentDestinationString string, dataManagementIntent content.Intent, dataManagementLabel string) error
	GetCurrentTransportForUser(ctx context.Context) (string, error)
	GetCurrentTransport(ctx context.Context) (string, error)
	GetCurrentTransportComponentForUser(ctx context.Context) (content.ComponentName, error)
	ListAllTransportsForUser(ctx context.Context) ([]string, error)
	ListAllTransports(ctx context.Context) ([]string, error)
	ListAllTransportComponentsForUser(ctx context.Context) ([]content.ComponentName, error)
	GetTransportWhitelist(ctx context.Context) ([]string, error)
	SelectBackupTransportForUser(ctx context.Context, transport string) (string, error)
	SelectBackupTransport(ctx context.Context, transport string) (string, error)
	SelectBackupTransportAsyncForUser(ctx context.Context, transport content.ComponentName, listener ISelectBackupTransportCallback) error
	GetConfigurationIntentForUser(ctx context.Context, transport string) (content.Intent, error)
	GetConfigurationIntent(ctx context.Context, transport string) (content.Intent, error)
	GetDestinationStringForUser(ctx context.Context, transport string) (string, error)
	GetDestinationString(ctx context.Context, transport string) (string, error)
	GetDataManagementIntentForUser(ctx context.Context, transport string) (content.Intent, error)
	GetDataManagementIntent(ctx context.Context, transport string) (content.Intent, error)
	GetDataManagementLabelForUser(ctx context.Context, transport string) (string, error)
	BeginRestoreSessionForUser(ctx context.Context, packageName string, transportID string) (IRestoreSession, error)
	OpCompleteForUser(ctx context.Context, token int32, result int64) error
	OpComplete(ctx context.Context, token int32, result int64) error
	SetBackupServiceActive(ctx context.Context, whichUser int32, makeActive bool) error
	IsBackupServiceActive(ctx context.Context, whichUser int32) (bool, error)
	IsUserReadyForBackup(ctx context.Context) (bool, error)
	GetAvailableRestoreTokenForUser(ctx context.Context, packageName string) (int64, error)
	IsAppEligibleForBackupForUser(ctx context.Context, packageName string) (bool, error)
	FilterAppsEligibleForBackupForUser(ctx context.Context, packages []string) ([]string, error)
	RequestBackupForUser(ctx context.Context, packages []string, observer IBackupObserver, monitor IBackupManagerMonitor, flags int32) (int32, error)
	RequestBackup(ctx context.Context, packages []string, observer IBackupObserver, monitor IBackupManagerMonitor, flags int32) (int32, error)
	CancelBackupsForUser(ctx context.Context) error
	CancelBackups(ctx context.Context) error
	GetUserForAncestralSerialNumber(ctx context.Context, ancestralSerialNumber int64) (os.UserHandle, error)
	SetAncestralSerialNumber(ctx context.Context, ancestralSerialNumber int64) error
	ExcludeKeysFromRestore(ctx context.Context, packageName string, keys []string) error
	ReportDelayedRestoreResult(ctx context.Context, packageName string, results []BackupRestoreEventLoggerDataTypeResult) error
}

func NewBackupManagerStub

func NewBackupManagerStub(
	impl IBackupManagerServer,
) IBackupManager

NewBackupManagerStub creates a server-side IBackupManager wrapping the given server implementation. The returned value satisfies IBackupManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBackupManagerMonitor

type IBackupManagerMonitor interface {
	AsBinder() binder.IBinder
	OnEvent(ctx context.Context, event os.Bundle) error
}

func NewBackupManagerMonitorStub

func NewBackupManagerMonitorStub(
	impl IBackupManagerMonitorServer,
) IBackupManagerMonitor

NewBackupManagerMonitorStub creates a server-side IBackupManagerMonitor wrapping the given server implementation. The returned value satisfies IBackupManagerMonitor and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBackupManagerMonitorServer

type IBackupManagerMonitorServer interface {
	OnEvent(ctx context.Context, event os.Bundle) error
}

IBackupManagerMonitorServer is the server-side interface that user implementations provide to NewBackupManagerMonitorStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IBackupManagerServer

type IBackupManagerServer interface {
	DataChangedForUser(ctx context.Context, packageName string) error
	DataChanged(ctx context.Context, packageName string) error
	ClearBackupDataForUser(ctx context.Context, transportName string, packageName string) error
	ClearBackupData(ctx context.Context, transportName string, packageName string) error
	InitializeTransportsForUser(ctx context.Context, transportNames []string, observer IBackupObserver) error
	AgentConnectedForUser(ctx context.Context, packageName string, agent binder.IBinder) error
	AgentConnected(ctx context.Context, packageName string, agent binder.IBinder) error
	AgentDisconnectedForUser(ctx context.Context, packageName string) error
	AgentDisconnected(ctx context.Context, packageName string) error
	RestoreAtInstallForUser(ctx context.Context, packageName string, token int32) error
	RestoreAtInstall(ctx context.Context, packageName string, token int32) error
	SetBackupEnabledForUser(ctx context.Context, isEnabled bool) error
	SetFrameworkSchedulingEnabledForUser(ctx context.Context, isEnabled bool) error
	SetBackupEnabled(ctx context.Context, isEnabled bool) error
	SetAutoRestoreForUser(ctx context.Context, doAutoRestore bool) error
	SetAutoRestore(ctx context.Context, doAutoRestore bool) error
	IsBackupEnabledForUser(ctx context.Context) (bool, error)
	IsBackupEnabled(ctx context.Context) (bool, error)
	SetBackupPassword(ctx context.Context, currentPw string, newPw string) (bool, error)
	HasBackupPassword(ctx context.Context) (bool, error)
	BackupNowForUser(ctx context.Context) error
	BackupNow(ctx context.Context) error
	AdbBackup(ctx context.Context, fd int32, includeApks bool, includeObbs bool, includeShared bool, doWidgets bool, allApps bool, allIncludesSystem bool, doCompress bool, doKeyValue bool, packageNames []string) error
	FullTransportBackupForUser(ctx context.Context, packageNames []string) error
	AdbRestore(ctx context.Context, fd int32) error
	AcknowledgeFullBackupOrRestoreForUser(ctx context.Context, token int32, allow bool, curPassword string, encryptionPassword string, observer IFullBackupRestoreObserver) error
	AcknowledgeFullBackupOrRestore(ctx context.Context, token int32, allow bool, curPassword string, encryptionPassword string, observer IFullBackupRestoreObserver) error
	UpdateTransportAttributesForUser(ctx context.Context, transportComponent content.ComponentName, name string, configurationIntent content.Intent, currentDestinationString string, dataManagementIntent content.Intent, dataManagementLabel string) error
	GetCurrentTransportForUser(ctx context.Context) (string, error)
	GetCurrentTransport(ctx context.Context) (string, error)
	GetCurrentTransportComponentForUser(ctx context.Context) (content.ComponentName, error)
	ListAllTransportsForUser(ctx context.Context) ([]string, error)
	ListAllTransports(ctx context.Context) ([]string, error)
	ListAllTransportComponentsForUser(ctx context.Context) ([]content.ComponentName, error)
	GetTransportWhitelist(ctx context.Context) ([]string, error)
	SelectBackupTransportForUser(ctx context.Context, transport string) (string, error)
	SelectBackupTransport(ctx context.Context, transport string) (string, error)
	SelectBackupTransportAsyncForUser(ctx context.Context, transport content.ComponentName, listener ISelectBackupTransportCallback) error
	GetConfigurationIntentForUser(ctx context.Context, transport string) (content.Intent, error)
	GetConfigurationIntent(ctx context.Context, transport string) (content.Intent, error)
	GetDestinationStringForUser(ctx context.Context, transport string) (string, error)
	GetDestinationString(ctx context.Context, transport string) (string, error)
	GetDataManagementIntentForUser(ctx context.Context, transport string) (content.Intent, error)
	GetDataManagementIntent(ctx context.Context, transport string) (content.Intent, error)
	GetDataManagementLabelForUser(ctx context.Context, transport string) (string, error)
	BeginRestoreSessionForUser(ctx context.Context, packageName string, transportID string) (IRestoreSession, error)
	OpCompleteForUser(ctx context.Context, token int32, result int64) error
	OpComplete(ctx context.Context, token int32, result int64) error
	SetBackupServiceActive(ctx context.Context, whichUser int32, makeActive bool) error
	IsBackupServiceActive(ctx context.Context, whichUser int32) (bool, error)
	IsUserReadyForBackup(ctx context.Context) (bool, error)
	GetAvailableRestoreTokenForUser(ctx context.Context, packageName string) (int64, error)
	IsAppEligibleForBackupForUser(ctx context.Context, packageName string) (bool, error)
	FilterAppsEligibleForBackupForUser(ctx context.Context, packages []string) ([]string, error)
	RequestBackupForUser(ctx context.Context, packages []string, observer IBackupObserver, monitor IBackupManagerMonitor, flags int32) (int32, error)
	RequestBackup(ctx context.Context, packages []string, observer IBackupObserver, monitor IBackupManagerMonitor, flags int32) (int32, error)
	CancelBackupsForUser(ctx context.Context) error
	CancelBackups(ctx context.Context) error
	GetUserForAncestralSerialNumber(ctx context.Context, ancestralSerialNumber int64) (os.UserHandle, error)
	SetAncestralSerialNumber(ctx context.Context, ancestralSerialNumber int64) error
	ExcludeKeysFromRestore(ctx context.Context, packageName string, keys []string) error
	ReportDelayedRestoreResult(ctx context.Context, packageName string, results []BackupRestoreEventLoggerDataTypeResult) error
}

IBackupManagerServer is the server-side interface that user implementations provide to NewBackupManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IBackupObserver

type IBackupObserver interface {
	AsBinder() binder.IBinder
	OnUpdate(ctx context.Context, currentPackage string, backupProgress BackupProgress) error
	OnResult(ctx context.Context, target string, status int32) error
	BackupFinished(ctx context.Context, status int32) error
}

func NewBackupObserverStub

func NewBackupObserverStub(
	impl IBackupObserverServer,
) IBackupObserver

NewBackupObserverStub creates a server-side IBackupObserver wrapping the given server implementation. The returned value satisfies IBackupObserver and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBackupObserverServer

type IBackupObserverServer interface {
	OnUpdate(ctx context.Context, currentPackage string, backupProgress BackupProgress) error
	OnResult(ctx context.Context, target string, status int32) error
	BackupFinished(ctx context.Context, status int32) error
}

IBackupObserverServer is the server-side interface that user implementations provide to NewBackupObserverStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IFullBackupRestoreObserver

type IFullBackupRestoreObserver interface {
	AsBinder() binder.IBinder
	OnStartBackup(ctx context.Context) error
	OnBackupPackage(ctx context.Context, name string) error
	OnEndBackup(ctx context.Context) error
	OnStartRestore(ctx context.Context) error
	OnRestorePackage(ctx context.Context, name string) error
	OnEndRestore(ctx context.Context) error
	OnTimeout(ctx context.Context) error
}

func NewFullBackupRestoreObserverStub

func NewFullBackupRestoreObserverStub(
	impl IFullBackupRestoreObserverServer,
) IFullBackupRestoreObserver

NewFullBackupRestoreObserverStub creates a server-side IFullBackupRestoreObserver wrapping the given server implementation. The returned value satisfies IFullBackupRestoreObserver and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IFullBackupRestoreObserverServer

type IFullBackupRestoreObserverServer interface {
	OnStartBackup(ctx context.Context) error
	OnBackupPackage(ctx context.Context, name string) error
	OnEndBackup(ctx context.Context) error
	OnStartRestore(ctx context.Context) error
	OnRestorePackage(ctx context.Context, name string) error
	OnEndRestore(ctx context.Context) error
	OnTimeout(ctx context.Context) error
}

IFullBackupRestoreObserverServer is the server-side interface that user implementations provide to NewFullBackupRestoreObserverStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IRestoreObserver

type IRestoreObserver interface {
	AsBinder() binder.IBinder
	RestoreSetsAvailable(ctx context.Context, result []RestoreSet) error
	RestoreStarting(ctx context.Context, numPackages int32) error
	OnUpdate(ctx context.Context, nowBeingRestored int32, curentPackage string) error
	RestoreFinished(ctx context.Context, error_ int32) error
}

func NewRestoreObserverStub

func NewRestoreObserverStub(
	impl IRestoreObserverServer,
) IRestoreObserver

NewRestoreObserverStub creates a server-side IRestoreObserver wrapping the given server implementation. The returned value satisfies IRestoreObserver and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IRestoreObserverServer

type IRestoreObserverServer interface {
	RestoreSetsAvailable(ctx context.Context, result []RestoreSet) error
	RestoreStarting(ctx context.Context, numPackages int32) error
	OnUpdate(ctx context.Context, nowBeingRestored int32, curentPackage string) error
	RestoreFinished(ctx context.Context, error_ int32) error
}

IRestoreObserverServer is the server-side interface that user implementations provide to NewRestoreObserverStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IRestoreSession

type IRestoreSession interface {
	AsBinder() binder.IBinder
	GetAvailableRestoreSets(ctx context.Context, observer IRestoreObserver, monitor IBackupManagerMonitor) (int32, error)
	RestoreAll(ctx context.Context, token int64, observer IRestoreObserver, monitor IBackupManagerMonitor) (int32, error)
	RestorePackages(ctx context.Context, token int64, observer IRestoreObserver, packages []string, monitor IBackupManagerMonitor) (int32, error)
	RestorePackage(ctx context.Context, packageName string, observer IRestoreObserver, monitor IBackupManagerMonitor) (int32, error)
	EndRestoreSession(ctx context.Context) error
}

func NewRestoreSessionStub

func NewRestoreSessionStub(
	impl IRestoreSessionServer,
) IRestoreSession

NewRestoreSessionStub creates a server-side IRestoreSession wrapping the given server implementation. The returned value satisfies IRestoreSession and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IRestoreSessionServer

type IRestoreSessionServer interface {
	GetAvailableRestoreSets(ctx context.Context, observer IRestoreObserver, monitor IBackupManagerMonitor) (int32, error)
	RestoreAll(ctx context.Context, token int64, observer IRestoreObserver, monitor IBackupManagerMonitor) (int32, error)
	RestorePackages(ctx context.Context, token int64, observer IRestoreObserver, packages []string, monitor IBackupManagerMonitor) (int32, error)
	RestorePackage(ctx context.Context, packageName string, observer IRestoreObserver, monitor IBackupManagerMonitor) (int32, error)
	EndRestoreSession(ctx context.Context) error
}

IRestoreSessionServer is the server-side interface that user implementations provide to NewRestoreSessionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISelectBackupTransportCallback

type ISelectBackupTransportCallback interface {
	AsBinder() binder.IBinder
	OnSuccess(ctx context.Context, transportName string) error
	OnFailure(ctx context.Context, reason int32) error
}

func NewSelectBackupTransportCallbackStub

func NewSelectBackupTransportCallbackStub(
	impl ISelectBackupTransportCallbackServer,
) ISelectBackupTransportCallback

NewSelectBackupTransportCallbackStub creates a server-side ISelectBackupTransportCallback wrapping the given server implementation. The returned value satisfies ISelectBackupTransportCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISelectBackupTransportCallbackServer

type ISelectBackupTransportCallbackServer interface {
	OnSuccess(ctx context.Context, transportName string) error
	OnFailure(ctx context.Context, reason int32) error
}

ISelectBackupTransportCallbackServer is the server-side interface that user implementations provide to NewSelectBackupTransportCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type RestoreDescription

type RestoreDescription struct {
	PackageName string
	DataType    int32
}

func (*RestoreDescription) MarshalParcel

func (s *RestoreDescription) MarshalParcel(
	p *parcel.Parcel,
) error

func (*RestoreDescription) UnmarshalParcel

func (s *RestoreDescription) UnmarshalParcel(
	p *parcel.Parcel,
) error

type RestoreObserverProxy

type RestoreObserverProxy struct {
	Remote binder.IBinder
}

func NewRestoreObserverProxy

func NewRestoreObserverProxy(
	remote binder.IBinder,
) *RestoreObserverProxy

func (*RestoreObserverProxy) AsBinder

func (p *RestoreObserverProxy) AsBinder() binder.IBinder

func (*RestoreObserverProxy) OnUpdate

func (p *RestoreObserverProxy) OnUpdate(
	ctx context.Context,
	nowBeingRestored int32,
	curentPackage string,
) error

func (*RestoreObserverProxy) RestoreFinished

func (p *RestoreObserverProxy) RestoreFinished(
	ctx context.Context,
	error_ int32,
) error

func (*RestoreObserverProxy) RestoreSetsAvailable

func (p *RestoreObserverProxy) RestoreSetsAvailable(
	ctx context.Context,
	result []RestoreSet,
) error

func (*RestoreObserverProxy) RestoreStarting

func (p *RestoreObserverProxy) RestoreStarting(
	ctx context.Context,
	numPackages int32,
) error

type RestoreObserverStub

type RestoreObserverStub struct {
	Impl      IRestoreObserver
	Transport binder.VersionAwareTransport
}

RestoreObserverStub dispatches incoming binder transactions to a typed IRestoreObserver implementation.

func (*RestoreObserverStub) Descriptor

func (s *RestoreObserverStub) Descriptor() string

func (*RestoreObserverStub) OnTransaction

func (s *RestoreObserverStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type RestoreSessionProxy

type RestoreSessionProxy struct {
	Remote binder.IBinder
}

func NewRestoreSessionProxy

func NewRestoreSessionProxy(
	remote binder.IBinder,
) *RestoreSessionProxy

func (*RestoreSessionProxy) AsBinder

func (p *RestoreSessionProxy) AsBinder() binder.IBinder

func (*RestoreSessionProxy) EndRestoreSession

func (p *RestoreSessionProxy) EndRestoreSession(
	ctx context.Context,
) error

func (*RestoreSessionProxy) GetAvailableRestoreSets

func (p *RestoreSessionProxy) GetAvailableRestoreSets(
	ctx context.Context,
	observer IRestoreObserver,
	monitor IBackupManagerMonitor,
) (int32, error)

func (*RestoreSessionProxy) RestoreAll

func (p *RestoreSessionProxy) RestoreAll(
	ctx context.Context,
	token int64,
	observer IRestoreObserver,
	monitor IBackupManagerMonitor,
) (int32, error)

func (*RestoreSessionProxy) RestorePackage

func (p *RestoreSessionProxy) RestorePackage(
	ctx context.Context,
	packageName string,
	observer IRestoreObserver,
	monitor IBackupManagerMonitor,
) (int32, error)

func (*RestoreSessionProxy) RestorePackages

func (p *RestoreSessionProxy) RestorePackages(
	ctx context.Context,
	token int64,
	observer IRestoreObserver,
	packages []string,
	monitor IBackupManagerMonitor,
) (int32, error)

type RestoreSessionStub

type RestoreSessionStub struct {
	Impl      IRestoreSession
	Transport binder.VersionAwareTransport
}

RestoreSessionStub dispatches incoming binder transactions to a typed IRestoreSession implementation.

func (*RestoreSessionStub) Descriptor

func (s *RestoreSessionStub) Descriptor() string

func (*RestoreSessionStub) OnTransaction

func (s *RestoreSessionStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type RestoreSet

type RestoreSet struct {
	Name                 string
	Device               string
	Token                int64
	BackupTransportFlags int32
}

func (*RestoreSet) MarshalParcel

func (s *RestoreSet) MarshalParcel(
	p *parcel.Parcel,
) error

func (*RestoreSet) UnmarshalParcel

func (s *RestoreSet) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SelectBackupTransportCallbackProxy

type SelectBackupTransportCallbackProxy struct {
	Remote binder.IBinder
}

func NewSelectBackupTransportCallbackProxy

func NewSelectBackupTransportCallbackProxy(
	remote binder.IBinder,
) *SelectBackupTransportCallbackProxy

func (*SelectBackupTransportCallbackProxy) AsBinder

func (*SelectBackupTransportCallbackProxy) OnFailure

func (p *SelectBackupTransportCallbackProxy) OnFailure(
	ctx context.Context,
	reason int32,
) error

func (*SelectBackupTransportCallbackProxy) OnSuccess

func (p *SelectBackupTransportCallbackProxy) OnSuccess(
	ctx context.Context,
	transportName string,
) error

type SelectBackupTransportCallbackStub

type SelectBackupTransportCallbackStub struct {
	Impl      ISelectBackupTransportCallback
	Transport binder.VersionAwareTransport
}

SelectBackupTransportCallbackStub dispatches incoming binder transactions to a typed ISelectBackupTransportCallback implementation.

func (*SelectBackupTransportCallbackStub) Descriptor

func (s *SelectBackupTransportCallbackStub) Descriptor() string

func (*SelectBackupTransportCallbackStub) OnTransaction

Jump to