blob

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIBlobStoreManagerCreateSession               = binder.FirstCallTransaction + 0
	TransactionIBlobStoreManagerOpenSession                 = binder.FirstCallTransaction + 1
	TransactionIBlobStoreManagerOpenBlob                    = binder.FirstCallTransaction + 2
	TransactionIBlobStoreManagerAbandonSession              = binder.FirstCallTransaction + 3
	TransactionIBlobStoreManagerAcquireLease                = binder.FirstCallTransaction + 4
	TransactionIBlobStoreManagerReleaseLease                = binder.FirstCallTransaction + 5
	TransactionIBlobStoreManagerReleaseAllLeases            = binder.FirstCallTransaction + 6
	TransactionIBlobStoreManagerGetRemainingLeaseQuotaBytes = binder.FirstCallTransaction + 7
	TransactionIBlobStoreManagerWaitForIdle                 = binder.FirstCallTransaction + 8
	TransactionIBlobStoreManagerQueryBlobsForUser           = binder.FirstCallTransaction + 9
	TransactionIBlobStoreManagerDeleteBlob                  = binder.FirstCallTransaction + 10
	TransactionIBlobStoreManagerGetLeasedBlobs              = binder.FirstCallTransaction + 11
	TransactionIBlobStoreManagerGetLeaseInfo                = binder.FirstCallTransaction + 12
)
const (
	MethodIBlobStoreManagerCreateSession               = "createSession"
	MethodIBlobStoreManagerOpenSession                 = "openSession"
	MethodIBlobStoreManagerOpenBlob                    = "openBlob"
	MethodIBlobStoreManagerAbandonSession              = "abandonSession"
	MethodIBlobStoreManagerAcquireLease                = "acquireLease"
	MethodIBlobStoreManagerReleaseLease                = "releaseLease"
	MethodIBlobStoreManagerReleaseAllLeases            = "releaseAllLeases"
	MethodIBlobStoreManagerGetRemainingLeaseQuotaBytes = "getRemainingLeaseQuotaBytes"
	MethodIBlobStoreManagerWaitForIdle                 = "waitForIdle"
	MethodIBlobStoreManagerQueryBlobsForUser           = "queryBlobsForUser"
	MethodIBlobStoreManagerDeleteBlob                  = "deleteBlob"
	MethodIBlobStoreManagerGetLeasedBlobs              = "getLeasedBlobs"
	MethodIBlobStoreManagerGetLeaseInfo                = "getLeaseInfo"
)
const (
	TransactionIBlobStoreSessionOpenWrite                    = binder.FirstCallTransaction + 0
	TransactionIBlobStoreSessionOpenRead                     = binder.FirstCallTransaction + 1
	TransactionIBlobStoreSessionAllowPackageAccess           = binder.FirstCallTransaction + 2
	TransactionIBlobStoreSessionAllowSameSignatureAccess     = binder.FirstCallTransaction + 3
	TransactionIBlobStoreSessionAllowPublicAccess            = binder.FirstCallTransaction + 4
	TransactionIBlobStoreSessionIsPackageAccessAllowed       = binder.FirstCallTransaction + 5
	TransactionIBlobStoreSessionIsSameSignatureAccessAllowed = binder.FirstCallTransaction + 6
	TransactionIBlobStoreSessionIsPublicAccessAllowed        = binder.FirstCallTransaction + 7
	TransactionIBlobStoreSessionGetSize                      = binder.FirstCallTransaction + 8
	TransactionIBlobStoreSessionClose                        = binder.FirstCallTransaction + 9
	TransactionIBlobStoreSessionAbandon                      = binder.FirstCallTransaction + 10
	TransactionIBlobStoreSessionCommit                       = binder.FirstCallTransaction + 11
)
const (
	MethodIBlobStoreSessionOpenWrite                    = "openWrite"
	MethodIBlobStoreSessionOpenRead                     = "openRead"
	MethodIBlobStoreSessionAllowPackageAccess           = "allowPackageAccess"
	MethodIBlobStoreSessionAllowSameSignatureAccess     = "allowSameSignatureAccess"
	MethodIBlobStoreSessionAllowPublicAccess            = "allowPublicAccess"
	MethodIBlobStoreSessionIsPackageAccessAllowed       = "isPackageAccessAllowed"
	MethodIBlobStoreSessionIsSameSignatureAccessAllowed = "isSameSignatureAccessAllowed"
	MethodIBlobStoreSessionIsPublicAccessAllowed        = "isPublicAccessAllowed"
	MethodIBlobStoreSessionGetSize                      = "getSize"
	MethodIBlobStoreSessionClose                        = "close"
	MethodIBlobStoreSessionAbandon                      = "abandon"
	MethodIBlobStoreSessionCommit                       = "commit"
)
const DescriptorIBlobCommitCallback = "android.app.blob.IBlobCommitCallback"
const DescriptorIBlobStoreManager = "android.app.blob.IBlobStoreManager"
const DescriptorIBlobStoreSession = "android.app.blob.IBlobStoreSession"
const (
	MethodIBlobCommitCallbackOnResult = "onResult"
)
const (
	TransactionIBlobCommitCallbackOnResult = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type BlobCommitCallbackProxy

type BlobCommitCallbackProxy struct {
	Remote binder.IBinder
}

func NewBlobCommitCallbackProxy

func NewBlobCommitCallbackProxy(
	remote binder.IBinder,
) *BlobCommitCallbackProxy

func (*BlobCommitCallbackProxy) AsBinder

func (p *BlobCommitCallbackProxy) AsBinder() binder.IBinder

func (*BlobCommitCallbackProxy) OnResult

func (p *BlobCommitCallbackProxy) OnResult(
	ctx context.Context,
	result int32,
) error

type BlobCommitCallbackStub

type BlobCommitCallbackStub struct {
	Impl      IBlobCommitCallback
	Transport binder.VersionAwareTransport
}

BlobCommitCallbackStub dispatches incoming binder transactions to a typed IBlobCommitCallback implementation.

func (*BlobCommitCallbackStub) Descriptor

func (s *BlobCommitCallbackStub) Descriptor() string

func (*BlobCommitCallbackStub) OnTransaction

func (s *BlobCommitCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type BlobHandle

type BlobHandle struct {
	Algorithm        string
	ExpiryTimeMillis int64
	Tag              string
}

func (*BlobHandle) MarshalParcel

func (s *BlobHandle) MarshalParcel(
	p *parcel.Parcel,
) error

func (*BlobHandle) UnmarshalParcel

func (s *BlobHandle) UnmarshalParcel(
	p *parcel.Parcel,
) error

type BlobInfo

type BlobInfo struct {
	Id           int64
	ExpiryTimeMs int64
	SizeBytes    int64
}

func (*BlobInfo) MarshalParcel

func (s *BlobInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*BlobInfo) UnmarshalParcel

func (s *BlobInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type BlobStoreManagerProxy

type BlobStoreManagerProxy struct {
	Remote binder.IBinder
}

func NewBlobStoreManagerProxy

func NewBlobStoreManagerProxy(
	remote binder.IBinder,
) *BlobStoreManagerProxy

func (*BlobStoreManagerProxy) AbandonSession

func (p *BlobStoreManagerProxy) AbandonSession(
	ctx context.Context,
	sessionId int64,
	packageName string,
) error

func (*BlobStoreManagerProxy) AcquireLease

func (p *BlobStoreManagerProxy) AcquireLease(
	ctx context.Context,
	handle BlobHandle,
	descriptionResId int32,
	description string,
	leaseTimeoutMillis int64,
	packageName string,
) error

func (*BlobStoreManagerProxy) AsBinder

func (p *BlobStoreManagerProxy) AsBinder() binder.IBinder

func (*BlobStoreManagerProxy) CreateSession

func (p *BlobStoreManagerProxy) CreateSession(
	ctx context.Context,
	handle BlobHandle,
	packageName string,
) (int64, error)

func (*BlobStoreManagerProxy) DeleteBlob

func (p *BlobStoreManagerProxy) DeleteBlob(
	ctx context.Context,
	blobId int64,
) error

func (*BlobStoreManagerProxy) GetLeaseInfo

func (p *BlobStoreManagerProxy) GetLeaseInfo(
	ctx context.Context,
	blobHandle BlobHandle,
	packageName string,
) (LeaseInfo, error)

func (*BlobStoreManagerProxy) GetLeasedBlobs

func (p *BlobStoreManagerProxy) GetLeasedBlobs(
	ctx context.Context,
	packageName string,
) ([]BlobHandle, error)

func (*BlobStoreManagerProxy) GetRemainingLeaseQuotaBytes

func (p *BlobStoreManagerProxy) GetRemainingLeaseQuotaBytes(
	ctx context.Context,
	packageName string,
) (int64, error)

func (*BlobStoreManagerProxy) OpenBlob

func (p *BlobStoreManagerProxy) OpenBlob(
	ctx context.Context,
	handle BlobHandle,
	packageName string,
) (int32, error)

func (*BlobStoreManagerProxy) OpenSession

func (p *BlobStoreManagerProxy) OpenSession(
	ctx context.Context,
	sessionId int64,
	packageName string,
) (IBlobStoreSession, error)

func (*BlobStoreManagerProxy) QueryBlobsForUser

func (p *BlobStoreManagerProxy) QueryBlobsForUser(
	ctx context.Context,
) ([]BlobInfo, error)

func (*BlobStoreManagerProxy) ReleaseAllLeases

func (p *BlobStoreManagerProxy) ReleaseAllLeases(
	ctx context.Context,
	packageName string,
) error

func (*BlobStoreManagerProxy) ReleaseLease

func (p *BlobStoreManagerProxy) ReleaseLease(
	ctx context.Context,
	handle BlobHandle,
	packageName string,
) error

func (*BlobStoreManagerProxy) WaitForIdle

func (p *BlobStoreManagerProxy) WaitForIdle(
	ctx context.Context,
	callback os.RemoteCallback,
) error

type BlobStoreManagerStub

type BlobStoreManagerStub struct {
	Impl      IBlobStoreManager
	Transport binder.VersionAwareTransport
}

BlobStoreManagerStub dispatches incoming binder transactions to a typed IBlobStoreManager implementation.

func (*BlobStoreManagerStub) Descriptor

func (s *BlobStoreManagerStub) Descriptor() string

func (*BlobStoreManagerStub) OnTransaction

func (s *BlobStoreManagerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type BlobStoreSessionProxy

type BlobStoreSessionProxy struct {
	Remote binder.IBinder
}

func NewBlobStoreSessionProxy

func NewBlobStoreSessionProxy(
	remote binder.IBinder,
) *BlobStoreSessionProxy

func (*BlobStoreSessionProxy) Abandon

func (p *BlobStoreSessionProxy) Abandon(
	ctx context.Context,
) error

func (*BlobStoreSessionProxy) AllowPackageAccess

func (p *BlobStoreSessionProxy) AllowPackageAccess(
	ctx context.Context,
	packageName string,
	certificate []byte,
) error

func (*BlobStoreSessionProxy) AllowPublicAccess

func (p *BlobStoreSessionProxy) AllowPublicAccess(
	ctx context.Context,
) error

func (*BlobStoreSessionProxy) AllowSameSignatureAccess

func (p *BlobStoreSessionProxy) AllowSameSignatureAccess(
	ctx context.Context,
) error

func (*BlobStoreSessionProxy) AsBinder

func (p *BlobStoreSessionProxy) AsBinder() binder.IBinder

func (*BlobStoreSessionProxy) Close

func (p *BlobStoreSessionProxy) Close(
	ctx context.Context,
) error

func (*BlobStoreSessionProxy) Commit

func (p *BlobStoreSessionProxy) Commit(
	ctx context.Context,
	callback IBlobCommitCallback,
) error

func (*BlobStoreSessionProxy) GetSize

func (p *BlobStoreSessionProxy) GetSize(
	ctx context.Context,
) (int64, error)

func (*BlobStoreSessionProxy) IsPackageAccessAllowed

func (p *BlobStoreSessionProxy) IsPackageAccessAllowed(
	ctx context.Context,
	packageName string,
	certificate []byte,
) (bool, error)

func (*BlobStoreSessionProxy) IsPublicAccessAllowed

func (p *BlobStoreSessionProxy) IsPublicAccessAllowed(
	ctx context.Context,
) (bool, error)

func (*BlobStoreSessionProxy) IsSameSignatureAccessAllowed

func (p *BlobStoreSessionProxy) IsSameSignatureAccessAllowed(
	ctx context.Context,
) (bool, error)

func (*BlobStoreSessionProxy) OpenRead

func (p *BlobStoreSessionProxy) OpenRead(
	ctx context.Context,
) (int32, error)

func (*BlobStoreSessionProxy) OpenWrite

func (p *BlobStoreSessionProxy) OpenWrite(
	ctx context.Context,
	offsetBytes int64,
	lengthBytes int64,
) (int32, error)

type BlobStoreSessionStub

type BlobStoreSessionStub struct {
	Impl      IBlobStoreSession
	Transport binder.VersionAwareTransport
}

BlobStoreSessionStub dispatches incoming binder transactions to a typed IBlobStoreSession implementation.

func (*BlobStoreSessionStub) Descriptor

func (s *BlobStoreSessionStub) Descriptor() string

func (*BlobStoreSessionStub) OnTransaction

func (s *BlobStoreSessionStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IBlobCommitCallback

type IBlobCommitCallback interface {
	AsBinder() binder.IBinder
	OnResult(ctx context.Context, result int32) error
}

func NewBlobCommitCallbackStub

func NewBlobCommitCallbackStub(
	impl IBlobCommitCallbackServer,
) IBlobCommitCallback

NewBlobCommitCallbackStub creates a server-side IBlobCommitCallback wrapping the given server implementation. The returned value satisfies IBlobCommitCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBlobCommitCallbackServer

type IBlobCommitCallbackServer interface {
	OnResult(ctx context.Context, result int32) error
}

IBlobCommitCallbackServer is the server-side interface that user implementations provide to NewBlobCommitCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IBlobStoreManager

type IBlobStoreManager interface {
	AsBinder() binder.IBinder
	CreateSession(ctx context.Context, handle BlobHandle, packageName string) (int64, error)
	OpenSession(ctx context.Context, sessionId int64, packageName string) (IBlobStoreSession, error)
	OpenBlob(ctx context.Context, handle BlobHandle, packageName string) (int32, error)
	AbandonSession(ctx context.Context, sessionId int64, packageName string) error
	AcquireLease(ctx context.Context, handle BlobHandle, descriptionResId int32, description string, leaseTimeoutMillis int64, packageName string) error
	ReleaseLease(ctx context.Context, handle BlobHandle, packageName string) error
	ReleaseAllLeases(ctx context.Context, packageName string) error
	GetRemainingLeaseQuotaBytes(ctx context.Context, packageName string) (int64, error)
	WaitForIdle(ctx context.Context, callback os.RemoteCallback) error
	QueryBlobsForUser(ctx context.Context) ([]BlobInfo, error)
	DeleteBlob(ctx context.Context, blobId int64) error
	GetLeasedBlobs(ctx context.Context, packageName string) ([]BlobHandle, error)
	GetLeaseInfo(ctx context.Context, blobHandle BlobHandle, packageName string) (LeaseInfo, error)
}

func NewBlobStoreManagerStub

func NewBlobStoreManagerStub(
	impl IBlobStoreManagerServer,
) IBlobStoreManager

NewBlobStoreManagerStub creates a server-side IBlobStoreManager wrapping the given server implementation. The returned value satisfies IBlobStoreManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBlobStoreManagerServer

type IBlobStoreManagerServer interface {
	CreateSession(ctx context.Context, handle BlobHandle, packageName string) (int64, error)
	OpenSession(ctx context.Context, sessionId int64, packageName string) (IBlobStoreSession, error)
	OpenBlob(ctx context.Context, handle BlobHandle, packageName string) (int32, error)
	AbandonSession(ctx context.Context, sessionId int64, packageName string) error
	AcquireLease(ctx context.Context, handle BlobHandle, descriptionResId int32, description string, leaseTimeoutMillis int64, packageName string) error
	ReleaseLease(ctx context.Context, handle BlobHandle, packageName string) error
	ReleaseAllLeases(ctx context.Context, packageName string) error
	GetRemainingLeaseQuotaBytes(ctx context.Context, packageName string) (int64, error)
	WaitForIdle(ctx context.Context, callback os.RemoteCallback) error
	QueryBlobsForUser(ctx context.Context) ([]BlobInfo, error)
	DeleteBlob(ctx context.Context, blobId int64) error
	GetLeasedBlobs(ctx context.Context, packageName string) ([]BlobHandle, error)
	GetLeaseInfo(ctx context.Context, blobHandle BlobHandle, packageName string) (LeaseInfo, error)
}

IBlobStoreManagerServer is the server-side interface that user implementations provide to NewBlobStoreManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IBlobStoreSession

type IBlobStoreSession interface {
	AsBinder() binder.IBinder
	OpenWrite(ctx context.Context, offsetBytes int64, lengthBytes int64) (int32, error)
	OpenRead(ctx context.Context) (int32, error)
	AllowPackageAccess(ctx context.Context, packageName string, certificate []byte) error
	AllowSameSignatureAccess(ctx context.Context) error
	AllowPublicAccess(ctx context.Context) error
	IsPackageAccessAllowed(ctx context.Context, packageName string, certificate []byte) (bool, error)
	IsSameSignatureAccessAllowed(ctx context.Context) (bool, error)
	IsPublicAccessAllowed(ctx context.Context) (bool, error)
	GetSize(ctx context.Context) (int64, error)
	Close(ctx context.Context) error
	Abandon(ctx context.Context) error
	Commit(ctx context.Context, callback IBlobCommitCallback) error
}

func NewBlobStoreSessionStub

func NewBlobStoreSessionStub(
	impl IBlobStoreSessionServer,
) IBlobStoreSession

NewBlobStoreSessionStub creates a server-side IBlobStoreSession wrapping the given server implementation. The returned value satisfies IBlobStoreSession and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBlobStoreSessionServer

type IBlobStoreSessionServer interface {
	OpenWrite(ctx context.Context, offsetBytes int64, lengthBytes int64) (int32, error)
	OpenRead(ctx context.Context) (int32, error)
	AllowPackageAccess(ctx context.Context, packageName string, certificate []byte) error
	AllowSameSignatureAccess(ctx context.Context) error
	AllowPublicAccess(ctx context.Context) error
	IsPackageAccessAllowed(ctx context.Context, packageName string, certificate []byte) (bool, error)
	IsSameSignatureAccessAllowed(ctx context.Context) (bool, error)
	IsPublicAccessAllowed(ctx context.Context) (bool, error)
	GetSize(ctx context.Context) (int64, error)
	Close(ctx context.Context) error
	Abandon(ctx context.Context) error
	Commit(ctx context.Context, callback IBlobCommitCallback) error
}

IBlobStoreSessionServer is the server-side interface that user implementations provide to NewBlobStoreSessionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type LeaseInfo

type LeaseInfo struct {
	PackageName      string
	ExpiryTimeMillis int64
	DescriptionResId int32
}

func (*LeaseInfo) MarshalParcel

func (s *LeaseInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*LeaseInfo) UnmarshalParcel

func (s *LeaseInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

Jump to