job

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIJobCallbackAcknowledgeGetTransferredDownloadBytesMessage = binder.FirstCallTransaction + 0
	TransactionIJobCallbackAcknowledgeGetTransferredUploadBytesMessage   = binder.FirstCallTransaction + 1
	TransactionIJobCallbackAcknowledgeStartMessage                       = binder.FirstCallTransaction + 2
	TransactionIJobCallbackAcknowledgeStopMessage                        = binder.FirstCallTransaction + 3
	TransactionIJobCallbackDequeueWork                                   = binder.FirstCallTransaction + 4
	TransactionIJobCallbackCompleteWork                                  = binder.FirstCallTransaction + 5
	TransactionIJobCallbackJobFinished                                   = binder.FirstCallTransaction + 6
	TransactionIJobCallbackUpdateEstimatedNetworkBytes                   = binder.FirstCallTransaction + 7
	TransactionIJobCallbackUpdateTransferredNetworkBytes                 = binder.FirstCallTransaction + 8
	TransactionIJobCallbackSetNotification                               = binder.FirstCallTransaction + 9
)
const (
	MethodIJobCallbackAcknowledgeGetTransferredDownloadBytesMessage = "acknowledgeGetTransferredDownloadBytesMessage"
	MethodIJobCallbackAcknowledgeGetTransferredUploadBytesMessage   = "acknowledgeGetTransferredUploadBytesMessage"
	MethodIJobCallbackAcknowledgeStartMessage                       = "acknowledgeStartMessage"
	MethodIJobCallbackAcknowledgeStopMessage                        = "acknowledgeStopMessage"
	MethodIJobCallbackDequeueWork                                   = "dequeueWork"
	MethodIJobCallbackCompleteWork                                  = "completeWork"
	MethodIJobCallbackJobFinished                                   = "jobFinished"
	MethodIJobCallbackUpdateEstimatedNetworkBytes                   = "updateEstimatedNetworkBytes"
	MethodIJobCallbackUpdateTransferredNetworkBytes                 = "updateTransferredNetworkBytes"
	MethodIJobCallbackSetNotification                               = "setNotification"
)
const (
	TransactionIJobSchedulerSchedule                          = binder.FirstCallTransaction + 0
	TransactionIJobSchedulerEnqueue                           = binder.FirstCallTransaction + 1
	TransactionIJobSchedulerScheduleAsPackage                 = binder.FirstCallTransaction + 2
	TransactionIJobSchedulerCancel                            = binder.FirstCallTransaction + 3
	TransactionIJobSchedulerCancelAll                         = binder.FirstCallTransaction + 4
	TransactionIJobSchedulerCancelAllInNamespace              = binder.FirstCallTransaction + 5
	TransactionIJobSchedulerGetAllPendingJobs                 = binder.FirstCallTransaction + 6
	TransactionIJobSchedulerGetAllPendingJobsInNamespace      = binder.FirstCallTransaction + 7
	TransactionIJobSchedulerGetPendingJob                     = binder.FirstCallTransaction + 8
	TransactionIJobSchedulerGetPendingJobReason               = binder.FirstCallTransaction + 9
	TransactionIJobSchedulerCanRunUserInitiatedJobs           = binder.FirstCallTransaction + 10
	TransactionIJobSchedulerHasRunUserInitiatedJobsPermission = binder.FirstCallTransaction + 11
	TransactionIJobSchedulerGetStartedJobs                    = binder.FirstCallTransaction + 12
	TransactionIJobSchedulerGetAllJobSnapshots                = binder.FirstCallTransaction + 13
	TransactionIJobSchedulerRegisterUserVisibleJobObserver    = binder.FirstCallTransaction + 14
	TransactionIJobSchedulerUnregisterUserVisibleJobObserver  = binder.FirstCallTransaction + 15
	TransactionIJobSchedulerNotePendingUserRequestedAppStop   = binder.FirstCallTransaction + 16
)
const (
	MethodIJobSchedulerSchedule                          = "schedule"
	MethodIJobSchedulerEnqueue                           = "enqueue"
	MethodIJobSchedulerScheduleAsPackage                 = "scheduleAsPackage"
	MethodIJobSchedulerCancel                            = "cancel"
	MethodIJobSchedulerCancelAll                         = "cancelAll"
	MethodIJobSchedulerCancelAllInNamespace              = "cancelAllInNamespace"
	MethodIJobSchedulerGetAllPendingJobs                 = "getAllPendingJobs"
	MethodIJobSchedulerGetAllPendingJobsInNamespace      = "getAllPendingJobsInNamespace"
	MethodIJobSchedulerGetPendingJob                     = "getPendingJob"
	MethodIJobSchedulerGetPendingJobReason               = "getPendingJobReason"
	MethodIJobSchedulerCanRunUserInitiatedJobs           = "canRunUserInitiatedJobs"
	MethodIJobSchedulerHasRunUserInitiatedJobsPermission = "hasRunUserInitiatedJobsPermission"
	MethodIJobSchedulerGetStartedJobs                    = "getStartedJobs"
	MethodIJobSchedulerGetAllJobSnapshots                = "getAllJobSnapshots"
	MethodIJobSchedulerRegisterUserVisibleJobObserver    = "registerUserVisibleJobObserver"
	MethodIJobSchedulerUnregisterUserVisibleJobObserver  = "unregisterUserVisibleJobObserver"
	MethodIJobSchedulerNotePendingUserRequestedAppStop   = "notePendingUserRequestedAppStop"
)
const (
	TransactionIJobServiceStartJob                    = binder.FirstCallTransaction + 0
	TransactionIJobServiceStopJob                     = binder.FirstCallTransaction + 1
	TransactionIJobServiceOnNetworkChanged            = binder.FirstCallTransaction + 2
	TransactionIJobServiceGetTransferredDownloadBytes = binder.FirstCallTransaction + 3
	TransactionIJobServiceGetTransferredUploadBytes   = binder.FirstCallTransaction + 4
)
const (
	MethodIJobServiceStartJob                    = "startJob"
	MethodIJobServiceStopJob                     = "stopJob"
	MethodIJobServiceOnNetworkChanged            = "onNetworkChanged"
	MethodIJobServiceGetTransferredDownloadBytes = "getTransferredDownloadBytes"
	MethodIJobServiceGetTransferredUploadBytes   = "getTransferredUploadBytes"
)
const DescriptorIJobCallback = "android.app.job.IJobCallback"
const DescriptorIJobScheduler = "android.app.job.IJobScheduler"
const DescriptorIJobService = "android.app.job.IJobService"
const DescriptorIUserVisibleJobObserver = "android.app.job.IUserVisibleJobObserver"
const (
	MethodIUserVisibleJobObserverOnUserVisibleJobStateChanged = "onUserVisibleJobStateChanged"
)
const (
	TransactionIUserVisibleJobObserverOnUserVisibleJobStateChanged = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type IJobCallback

type IJobCallback interface {
	AsBinder() binder.IBinder
	AcknowledgeGetTransferredDownloadBytesMessage(ctx context.Context, jobId int32, workId int32, transferredBytes int64) error
	AcknowledgeGetTransferredUploadBytesMessage(ctx context.Context, jobId int32, workId int32, transferredBytes int64) error
	AcknowledgeStartMessage(ctx context.Context, jobId int32, ongoing bool) error
	AcknowledgeStopMessage(ctx context.Context, jobId int32, reschedule bool) error
	DequeueWork(ctx context.Context, jobId int32) (JobWorkItem, error)
	CompleteWork(ctx context.Context, jobId int32, workId int32) (bool, error)
	JobFinished(ctx context.Context, jobId int32, reschedule bool) error
	UpdateEstimatedNetworkBytes(ctx context.Context, jobId int32, item JobWorkItem, downloadBytes int64, uploadBytes int64) error
	UpdateTransferredNetworkBytes(ctx context.Context, jobId int32, item JobWorkItem, transferredDownloadBytes int64, transferredUploadBytes int64) error
	SetNotification(ctx context.Context, jobId int32, notificationId int32, notification app.Notification, jobEndNotificationPolicy int32) error
}

func NewJobCallbackStub

func NewJobCallbackStub(
	impl IJobCallbackServer,
) IJobCallback

NewJobCallbackStub creates a server-side IJobCallback wrapping the given server implementation. The returned value satisfies IJobCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IJobCallbackServer

type IJobCallbackServer interface {
	AcknowledgeGetTransferredDownloadBytesMessage(ctx context.Context, jobId int32, workId int32, transferredBytes int64) error
	AcknowledgeGetTransferredUploadBytesMessage(ctx context.Context, jobId int32, workId int32, transferredBytes int64) error
	AcknowledgeStartMessage(ctx context.Context, jobId int32, ongoing bool) error
	AcknowledgeStopMessage(ctx context.Context, jobId int32, reschedule bool) error
	DequeueWork(ctx context.Context, jobId int32) (JobWorkItem, error)
	CompleteWork(ctx context.Context, jobId int32, workId int32) (bool, error)
	JobFinished(ctx context.Context, jobId int32, reschedule bool) error
	UpdateEstimatedNetworkBytes(ctx context.Context, jobId int32, item JobWorkItem, downloadBytes int64, uploadBytes int64) error
	UpdateTransferredNetworkBytes(ctx context.Context, jobId int32, item JobWorkItem, transferredDownloadBytes int64, transferredUploadBytes int64) error
	SetNotification(ctx context.Context, jobId int32, notificationId int32, notification app.Notification, jobEndNotificationPolicy int32) error
}

IJobCallbackServer is the server-side interface that user implementations provide to NewJobCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IJobScheduler

type IJobScheduler interface {
	AsBinder() binder.IBinder
	Schedule(ctx context.Context, namespace string, job JobInfo) (int32, error)
	Enqueue(ctx context.Context, namespace string, job JobInfo, work JobWorkItem) (int32, error)
	ScheduleAsPackage(ctx context.Context, namespace string, job JobInfo, packageName string, tag string) (int32, error)
	Cancel(ctx context.Context, namespace string, jobId int32) error
	CancelAll(ctx context.Context) error
	CancelAllInNamespace(ctx context.Context, namespace string) error
	GetAllPendingJobs(ctx context.Context) (map[string]pm.ParceledListSlice, error)
	GetAllPendingJobsInNamespace(ctx context.Context, namespace string) (pm.ParceledListSlice, error)
	GetPendingJob(ctx context.Context, namespace string, jobId int32) (JobInfo, error)
	GetPendingJobReason(ctx context.Context, namespace string, jobId int32) (int32, error)
	CanRunUserInitiatedJobs(ctx context.Context, packageName string) (bool, error)
	HasRunUserInitiatedJobsPermission(ctx context.Context, packageName string) (bool, error)
	GetStartedJobs(ctx context.Context) ([]JobInfo, error)
	GetAllJobSnapshots(ctx context.Context) (pm.ParceledListSlice, error)
	RegisterUserVisibleJobObserver(ctx context.Context, observer IUserVisibleJobObserver) error
	UnregisterUserVisibleJobObserver(ctx context.Context, observer IUserVisibleJobObserver) error
	NotePendingUserRequestedAppStop(ctx context.Context, packageName string, debugReason string) error
}

func NewJobSchedulerStub

func NewJobSchedulerStub(
	impl IJobSchedulerServer,
) IJobScheduler

NewJobSchedulerStub creates a server-side IJobScheduler wrapping the given server implementation. The returned value satisfies IJobScheduler and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IJobSchedulerServer

type IJobSchedulerServer interface {
	Schedule(ctx context.Context, namespace string, job JobInfo) (int32, error)
	Enqueue(ctx context.Context, namespace string, job JobInfo, work JobWorkItem) (int32, error)
	ScheduleAsPackage(ctx context.Context, namespace string, job JobInfo, packageName string, tag string) (int32, error)
	Cancel(ctx context.Context, namespace string, jobId int32) error
	CancelAll(ctx context.Context) error
	CancelAllInNamespace(ctx context.Context, namespace string) error
	GetAllPendingJobs(ctx context.Context) (map[string]pm.ParceledListSlice, error)
	GetAllPendingJobsInNamespace(ctx context.Context, namespace string) (pm.ParceledListSlice, error)
	GetPendingJob(ctx context.Context, namespace string, jobId int32) (JobInfo, error)
	GetPendingJobReason(ctx context.Context, namespace string, jobId int32) (int32, error)
	CanRunUserInitiatedJobs(ctx context.Context, packageName string) (bool, error)
	HasRunUserInitiatedJobsPermission(ctx context.Context, packageName string) (bool, error)
	GetStartedJobs(ctx context.Context) ([]JobInfo, error)
	GetAllJobSnapshots(ctx context.Context) (pm.ParceledListSlice, error)
	RegisterUserVisibleJobObserver(ctx context.Context, observer IUserVisibleJobObserver) error
	UnregisterUserVisibleJobObserver(ctx context.Context, observer IUserVisibleJobObserver) error
	NotePendingUserRequestedAppStop(ctx context.Context, packageName string, debugReason string) error
}

IJobSchedulerServer is the server-side interface that user implementations provide to NewJobSchedulerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IJobService

type IJobService interface {
	AsBinder() binder.IBinder
	StartJob(ctx context.Context, jobParams JobParameters) error
	StopJob(ctx context.Context, jobParams JobParameters) error
	OnNetworkChanged(ctx context.Context, jobParams JobParameters) error
	GetTransferredDownloadBytes(ctx context.Context, jobParams JobParameters, jobWorkItem JobWorkItem) error
	GetTransferredUploadBytes(ctx context.Context, jobParams JobParameters, jobWorkItem JobWorkItem) error
}

func NewJobServiceStub

func NewJobServiceStub(
	impl IJobServiceServer,
) IJobService

NewJobServiceStub creates a server-side IJobService wrapping the given server implementation. The returned value satisfies IJobService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IJobServiceServer

type IJobServiceServer interface {
	StartJob(ctx context.Context, jobParams JobParameters) error
	StopJob(ctx context.Context, jobParams JobParameters) error
	OnNetworkChanged(ctx context.Context, jobParams JobParameters) error
	GetTransferredDownloadBytes(ctx context.Context, jobParams JobParameters, jobWorkItem JobWorkItem) error
	GetTransferredUploadBytes(ctx context.Context, jobParams JobParameters, jobWorkItem JobWorkItem) error
}

IJobServiceServer is the server-side interface that user implementations provide to NewJobServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IUserVisibleJobObserver

type IUserVisibleJobObserver interface {
	AsBinder() binder.IBinder
	OnUserVisibleJobStateChanged(ctx context.Context, summary UserVisibleJobSummary, isRunning bool) error
}

func NewUserVisibleJobObserverStub

func NewUserVisibleJobObserverStub(
	impl IUserVisibleJobObserverServer,
) IUserVisibleJobObserver

NewUserVisibleJobObserverStub creates a server-side IUserVisibleJobObserver wrapping the given server implementation. The returned value satisfies IUserVisibleJobObserver and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IUserVisibleJobObserverServer

type IUserVisibleJobObserverServer interface {
	OnUserVisibleJobStateChanged(ctx context.Context, summary UserVisibleJobSummary, isRunning bool) error
}

IUserVisibleJobObserverServer is the server-side interface that user implementations provide to NewUserVisibleJobObserverStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type JobCallbackProxy

type JobCallbackProxy struct {
	Remote binder.IBinder
}

func NewJobCallbackProxy

func NewJobCallbackProxy(
	remote binder.IBinder,
) *JobCallbackProxy

func (*JobCallbackProxy) AcknowledgeGetTransferredDownloadBytesMessage

func (p *JobCallbackProxy) AcknowledgeGetTransferredDownloadBytesMessage(
	ctx context.Context,
	jobId int32,
	workId int32,
	transferredBytes int64,
) error

func (*JobCallbackProxy) AcknowledgeGetTransferredUploadBytesMessage

func (p *JobCallbackProxy) AcknowledgeGetTransferredUploadBytesMessage(
	ctx context.Context,
	jobId int32,
	workId int32,
	transferredBytes int64,
) error

func (*JobCallbackProxy) AcknowledgeStartMessage

func (p *JobCallbackProxy) AcknowledgeStartMessage(
	ctx context.Context,
	jobId int32,
	ongoing bool,
) error

func (*JobCallbackProxy) AcknowledgeStopMessage

func (p *JobCallbackProxy) AcknowledgeStopMessage(
	ctx context.Context,
	jobId int32,
	reschedule bool,
) error

func (*JobCallbackProxy) AsBinder

func (p *JobCallbackProxy) AsBinder() binder.IBinder

func (*JobCallbackProxy) CompleteWork

func (p *JobCallbackProxy) CompleteWork(
	ctx context.Context,
	jobId int32,
	workId int32,
) (bool, error)

func (*JobCallbackProxy) DequeueWork

func (p *JobCallbackProxy) DequeueWork(
	ctx context.Context,
	jobId int32,
) (JobWorkItem, error)

func (*JobCallbackProxy) JobFinished

func (p *JobCallbackProxy) JobFinished(
	ctx context.Context,
	jobId int32,
	reschedule bool,
) error

func (*JobCallbackProxy) SetNotification

func (p *JobCallbackProxy) SetNotification(
	ctx context.Context,
	jobId int32,
	notificationId int32,
	notification app.Notification,
	jobEndNotificationPolicy int32,
) error

func (*JobCallbackProxy) UpdateEstimatedNetworkBytes

func (p *JobCallbackProxy) UpdateEstimatedNetworkBytes(
	ctx context.Context,
	jobId int32,
	item JobWorkItem,
	downloadBytes int64,
	uploadBytes int64,
) error

func (*JobCallbackProxy) UpdateTransferredNetworkBytes

func (p *JobCallbackProxy) UpdateTransferredNetworkBytes(
	ctx context.Context,
	jobId int32,
	item JobWorkItem,
	transferredDownloadBytes int64,
	transferredUploadBytes int64,
) error

type JobCallbackStub

type JobCallbackStub struct {
	Impl      IJobCallback
	Transport binder.VersionAwareTransport
}

JobCallbackStub dispatches incoming binder transactions to a typed IJobCallback implementation.

func (*JobCallbackStub) Descriptor

func (s *JobCallbackStub) Descriptor() string

func (*JobCallbackStub) OnTransaction

func (s *JobCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type JobInfo

type JobInfo struct {
	JobId                     int32
	ConstraintFlags           int32
	TriggerContentUpdateDelay int64
	TriggerContentMaxDelay    int64
	NetworkDownloadBytes      int64
	NetworkUploadBytes        int64
	MinimumNetworkChunkBytes  int64
	MinLatencyMillis          int64
	MaxExecutionDelayMillis   int64
	IntervalMillis            int64
	FlexMillis                int64
	InitialBackoffMillis      int64
	BackoffPolicy             int32
	Bias                      int32
	Priority                  int32
	NumDebugTags              int32
	TraceTag                  string
}

func (*JobInfo) MarshalParcel

func (s *JobInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*JobInfo) UnmarshalParcel

func (s *JobInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type JobParameters

type JobParameters struct {
	JobId              int32
	JobNamespace       string
	IsExpedited        bool
	IsUserInitiated    bool
	StopReason         int32
	InternalStopReason int32
	DebugStopReason    string
}

func (*JobParameters) MarshalParcel

func (s *JobParameters) MarshalParcel(
	p *parcel.Parcel,
) error

func (*JobParameters) UnmarshalParcel

func (s *JobParameters) UnmarshalParcel(
	p *parcel.Parcel,
) error

type JobSchedulerProxy

type JobSchedulerProxy struct {
	Remote binder.IBinder
}

func NewJobSchedulerProxy

func NewJobSchedulerProxy(
	remote binder.IBinder,
) *JobSchedulerProxy

func (*JobSchedulerProxy) AsBinder

func (p *JobSchedulerProxy) AsBinder() binder.IBinder

func (*JobSchedulerProxy) CanRunUserInitiatedJobs

func (p *JobSchedulerProxy) CanRunUserInitiatedJobs(
	ctx context.Context,
	packageName string,
) (bool, error)

func (*JobSchedulerProxy) Cancel

func (p *JobSchedulerProxy) Cancel(
	ctx context.Context,
	namespace string,
	jobId int32,
) error

func (*JobSchedulerProxy) CancelAll

func (p *JobSchedulerProxy) CancelAll(
	ctx context.Context,
) error

func (*JobSchedulerProxy) CancelAllInNamespace

func (p *JobSchedulerProxy) CancelAllInNamespace(
	ctx context.Context,
	namespace string,
) error

func (*JobSchedulerProxy) Enqueue

func (p *JobSchedulerProxy) Enqueue(
	ctx context.Context,
	namespace string,
	job JobInfo,
	work JobWorkItem,
) (int32, error)

func (*JobSchedulerProxy) GetAllJobSnapshots

func (p *JobSchedulerProxy) GetAllJobSnapshots(
	ctx context.Context,
) (pm.ParceledListSlice, error)

func (*JobSchedulerProxy) GetAllPendingJobs

func (p *JobSchedulerProxy) GetAllPendingJobs(
	ctx context.Context,
) (map[string]pm.ParceledListSlice, error)

func (*JobSchedulerProxy) GetAllPendingJobsInNamespace

func (p *JobSchedulerProxy) GetAllPendingJobsInNamespace(
	ctx context.Context,
	namespace string,
) (pm.ParceledListSlice, error)

func (*JobSchedulerProxy) GetPendingJob

func (p *JobSchedulerProxy) GetPendingJob(
	ctx context.Context,
	namespace string,
	jobId int32,
) (JobInfo, error)

func (*JobSchedulerProxy) GetPendingJobReason

func (p *JobSchedulerProxy) GetPendingJobReason(
	ctx context.Context,
	namespace string,
	jobId int32,
) (int32, error)

func (*JobSchedulerProxy) GetStartedJobs

func (p *JobSchedulerProxy) GetStartedJobs(
	ctx context.Context,
) ([]JobInfo, error)

func (*JobSchedulerProxy) HasRunUserInitiatedJobsPermission

func (p *JobSchedulerProxy) HasRunUserInitiatedJobsPermission(
	ctx context.Context,
	packageName string,
) (bool, error)

func (*JobSchedulerProxy) NotePendingUserRequestedAppStop

func (p *JobSchedulerProxy) NotePendingUserRequestedAppStop(
	ctx context.Context,
	packageName string,
	debugReason string,
) error

func (*JobSchedulerProxy) RegisterUserVisibleJobObserver

func (p *JobSchedulerProxy) RegisterUserVisibleJobObserver(
	ctx context.Context,
	observer IUserVisibleJobObserver,
) error

func (*JobSchedulerProxy) Schedule

func (p *JobSchedulerProxy) Schedule(
	ctx context.Context,
	namespace string,
	job JobInfo,
) (int32, error)

func (*JobSchedulerProxy) ScheduleAsPackage

func (p *JobSchedulerProxy) ScheduleAsPackage(
	ctx context.Context,
	namespace string,
	job JobInfo,
	packageName string,
	tag string,
) (int32, error)

func (*JobSchedulerProxy) UnregisterUserVisibleJobObserver

func (p *JobSchedulerProxy) UnregisterUserVisibleJobObserver(
	ctx context.Context,
	observer IUserVisibleJobObserver,
) error

type JobSchedulerStub

type JobSchedulerStub struct {
	Impl      IJobScheduler
	Transport binder.VersionAwareTransport
}

JobSchedulerStub dispatches incoming binder transactions to a typed IJobScheduler implementation.

func (*JobSchedulerStub) Descriptor

func (s *JobSchedulerStub) Descriptor() string

func (*JobSchedulerStub) OnTransaction

func (s *JobSchedulerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type JobServiceProxy

type JobServiceProxy struct {
	Remote binder.IBinder
}

func NewJobServiceProxy

func NewJobServiceProxy(
	remote binder.IBinder,
) *JobServiceProxy

func (*JobServiceProxy) AsBinder

func (p *JobServiceProxy) AsBinder() binder.IBinder

func (*JobServiceProxy) GetTransferredDownloadBytes

func (p *JobServiceProxy) GetTransferredDownloadBytes(
	ctx context.Context,
	jobParams JobParameters,
	jobWorkItem JobWorkItem,
) error

func (*JobServiceProxy) GetTransferredUploadBytes

func (p *JobServiceProxy) GetTransferredUploadBytes(
	ctx context.Context,
	jobParams JobParameters,
	jobWorkItem JobWorkItem,
) error

func (*JobServiceProxy) OnNetworkChanged

func (p *JobServiceProxy) OnNetworkChanged(
	ctx context.Context,
	jobParams JobParameters,
) error

func (*JobServiceProxy) StartJob

func (p *JobServiceProxy) StartJob(
	ctx context.Context,
	jobParams JobParameters,
) error

func (*JobServiceProxy) StopJob

func (p *JobServiceProxy) StopJob(
	ctx context.Context,
	jobParams JobParameters,
) error

type JobServiceStub

type JobServiceStub struct {
	Impl      IJobService
	Transport binder.VersionAwareTransport
}

JobServiceStub dispatches incoming binder transactions to a typed IJobService implementation.

func (*JobServiceStub) Descriptor

func (s *JobServiceStub) Descriptor() string

func (*JobServiceStub) OnTransaction

func (s *JobServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type JobSnapshot

type JobSnapshot struct {
	SatisfiedConstraints int32
	IsRunnable           bool
}

func (*JobSnapshot) MarshalParcel

func (s *JobSnapshot) MarshalParcel(
	p *parcel.Parcel,
) error

func (*JobSnapshot) UnmarshalParcel

func (s *JobSnapshot) UnmarshalParcel(
	p *parcel.Parcel,
) error

type JobWorkItem

type JobWorkItem struct {
	NetworkDownloadBytes int64
	NetworkUploadBytes   int64
	MinimumChunkBytes    int64
	DeliveryCount        int32
	WorkId               int32
}

func (*JobWorkItem) MarshalParcel

func (s *JobWorkItem) MarshalParcel(
	p *parcel.Parcel,
) error

func (*JobWorkItem) UnmarshalParcel

func (s *JobWorkItem) UnmarshalParcel(
	p *parcel.Parcel,
) error

type UserVisibleJobObserverProxy

type UserVisibleJobObserverProxy struct {
	Remote binder.IBinder
}

func NewUserVisibleJobObserverProxy

func NewUserVisibleJobObserverProxy(
	remote binder.IBinder,
) *UserVisibleJobObserverProxy

func (*UserVisibleJobObserverProxy) AsBinder

func (*UserVisibleJobObserverProxy) OnUserVisibleJobStateChanged

func (p *UserVisibleJobObserverProxy) OnUserVisibleJobStateChanged(
	ctx context.Context,
	summary UserVisibleJobSummary,
	isRunning bool,
) error

type UserVisibleJobObserverStub

type UserVisibleJobObserverStub struct {
	Impl      IUserVisibleJobObserver
	Transport binder.VersionAwareTransport
}

UserVisibleJobObserverStub dispatches incoming binder transactions to a typed IUserVisibleJobObserver implementation.

func (*UserVisibleJobObserverStub) Descriptor

func (s *UserVisibleJobObserverStub) Descriptor() string

func (*UserVisibleJobObserverStub) OnTransaction

func (s *UserVisibleJobObserverStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type UserVisibleJobSummary

type UserVisibleJobSummary struct {
	CallingUid         int32
	CallingPackageName string
	SourceUserId       int32
	SourcePackageName  string
	Namespace          string
	JobId              int32
}

func (*UserVisibleJobSummary) MarshalParcel

func (s *UserVisibleJobSummary) MarshalParcel(
	p *parcel.Parcel,
) error

func (*UserVisibleJobSummary) UnmarshalParcel

func (s *UserVisibleJobSummary) UnmarshalParcel(
	p *parcel.Parcel,
) error

Jump to