people

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIPeopleManagerGetConversation                = binder.FirstCallTransaction + 0
	TransactionIPeopleManagerGetRecentConversations         = binder.FirstCallTransaction + 1
	TransactionIPeopleManagerRemoveRecentConversation       = binder.FirstCallTransaction + 2
	TransactionIPeopleManagerRemoveAllRecentConversations   = binder.FirstCallTransaction + 3
	TransactionIPeopleManagerIsConversation                 = binder.FirstCallTransaction + 4
	TransactionIPeopleManagerGetLastInteraction             = binder.FirstCallTransaction + 5
	TransactionIPeopleManagerAddOrUpdateStatus              = binder.FirstCallTransaction + 6
	TransactionIPeopleManagerClearStatus                    = binder.FirstCallTransaction + 7
	TransactionIPeopleManagerClearStatuses                  = binder.FirstCallTransaction + 8
	TransactionIPeopleManagerGetStatuses                    = binder.FirstCallTransaction + 9
	TransactionIPeopleManagerRegisterConversationListener   = binder.FirstCallTransaction + 10
	TransactionIPeopleManagerUnregisterConversationListener = binder.FirstCallTransaction + 11
)
const (
	MethodIPeopleManagerGetConversation                = "getConversation"
	MethodIPeopleManagerGetRecentConversations         = "getRecentConversations"
	MethodIPeopleManagerRemoveRecentConversation       = "removeRecentConversation"
	MethodIPeopleManagerRemoveAllRecentConversations   = "removeAllRecentConversations"
	MethodIPeopleManagerIsConversation                 = "isConversation"
	MethodIPeopleManagerGetLastInteraction             = "getLastInteraction"
	MethodIPeopleManagerAddOrUpdateStatus              = "addOrUpdateStatus"
	MethodIPeopleManagerClearStatus                    = "clearStatus"
	MethodIPeopleManagerClearStatuses                  = "clearStatuses"
	MethodIPeopleManagerGetStatuses                    = "getStatuses"
	MethodIPeopleManagerRegisterConversationListener   = "registerConversationListener"
	MethodIPeopleManagerUnregisterConversationListener = "unregisterConversationListener"
)
const DescriptorIConversationListener = "android.app.people.IConversationListener"
const DescriptorIPeopleManager = "android.app.people.IPeopleManager"
const (
	MethodIConversationListenerOnConversationUpdate = "onConversationUpdate"
)
const (
	TransactionIConversationListenerOnConversationUpdate = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type ConversationChannel

type ConversationChannel struct {
	Uid                      int32
	LastEventTimestamp       int64
	HasActiveNotifications   bool
	HasBirthdayToday         bool
	ShortcutInfo             *pm.ShortcutInfo
	NotificationChannel      *app.NotificationChannel
	NotificationChannelGroup *app.NotificationChannelGroup
}

func (*ConversationChannel) MarshalParcel

func (s *ConversationChannel) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ConversationChannel) UnmarshalParcel

func (s *ConversationChannel) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ConversationListenerProxy

type ConversationListenerProxy struct {
	Remote binder.IBinder
}

func NewConversationListenerProxy

func NewConversationListenerProxy(
	remote binder.IBinder,
) *ConversationListenerProxy

func (*ConversationListenerProxy) AsBinder

func (*ConversationListenerProxy) OnConversationUpdate

func (p *ConversationListenerProxy) OnConversationUpdate(
	ctx context.Context,
	conversation ConversationChannel,
) error

type ConversationListenerStub

type ConversationListenerStub struct {
	Impl      IConversationListener
	Transport binder.VersionAwareTransport
}

ConversationListenerStub dispatches incoming binder transactions to a typed IConversationListener implementation.

func (*ConversationListenerStub) Descriptor

func (s *ConversationListenerStub) Descriptor() string

func (*ConversationListenerStub) OnTransaction

func (s *ConversationListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ConversationStatus

type ConversationStatus struct {
	Id           string
	Activity     int32
	Availability int32
	StartTimeMs  int64
	EndTimeMs    int64
	Icon         *drawable.Icon
}

func (*ConversationStatus) MarshalParcel

func (s *ConversationStatus) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ConversationStatus) UnmarshalParcel

func (s *ConversationStatus) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IConversationListener

type IConversationListener interface {
	AsBinder() binder.IBinder
	OnConversationUpdate(ctx context.Context, conversation ConversationChannel) error
}

func NewConversationListenerStub

func NewConversationListenerStub(
	impl IConversationListenerServer,
) IConversationListener

NewConversationListenerStub creates a server-side IConversationListener wrapping the given server implementation. The returned value satisfies IConversationListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IConversationListenerServer

type IConversationListenerServer interface {
	OnConversationUpdate(ctx context.Context, conversation ConversationChannel) error
}

IConversationListenerServer is the server-side interface that user implementations provide to NewConversationListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IPeopleManager

type IPeopleManager interface {
	AsBinder() binder.IBinder
	GetConversation(ctx context.Context, packageName string, shortcutId string) (ConversationChannel, error)
	GetRecentConversations(ctx context.Context) (pm.ParceledListSlice, error)
	RemoveRecentConversation(ctx context.Context, packageName string, shortcutId string) error
	RemoveAllRecentConversations(ctx context.Context) error
	IsConversation(ctx context.Context, packageName string, shortcutId string) (bool, error)
	GetLastInteraction(ctx context.Context, packageName string, shortcutId string) (int64, error)
	AddOrUpdateStatus(ctx context.Context, packageName string, conversationId string, status ConversationStatus) error
	ClearStatus(ctx context.Context, packageName string, conversationId string, statusId string) error
	ClearStatuses(ctx context.Context, packageName string, conversationId string) error
	GetStatuses(ctx context.Context, packageName string, conversationId string) (pm.ParceledListSlice, error)
	RegisterConversationListener(ctx context.Context, packageName string, shortcutId string, callback IConversationListener) error
	UnregisterConversationListener(ctx context.Context, callback IConversationListener) error
}

func NewPeopleManagerStub

func NewPeopleManagerStub(
	impl IPeopleManagerServer,
) IPeopleManager

NewPeopleManagerStub creates a server-side IPeopleManager wrapping the given server implementation. The returned value satisfies IPeopleManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IPeopleManagerServer

type IPeopleManagerServer interface {
	GetConversation(ctx context.Context, packageName string, shortcutId string) (ConversationChannel, error)
	GetRecentConversations(ctx context.Context) (pm.ParceledListSlice, error)
	RemoveRecentConversation(ctx context.Context, packageName string, shortcutId string) error
	RemoveAllRecentConversations(ctx context.Context) error
	IsConversation(ctx context.Context, packageName string, shortcutId string) (bool, error)
	GetLastInteraction(ctx context.Context, packageName string, shortcutId string) (int64, error)
	AddOrUpdateStatus(ctx context.Context, packageName string, conversationId string, status ConversationStatus) error
	ClearStatus(ctx context.Context, packageName string, conversationId string, statusId string) error
	ClearStatuses(ctx context.Context, packageName string, conversationId string) error
	GetStatuses(ctx context.Context, packageName string, conversationId string) (pm.ParceledListSlice, error)
	RegisterConversationListener(ctx context.Context, packageName string, shortcutId string, callback IConversationListener) error
	UnregisterConversationListener(ctx context.Context, callback IConversationListener) error
}

IPeopleManagerServer is the server-side interface that user implementations provide to NewPeopleManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type PeopleManagerProxy

type PeopleManagerProxy struct {
	Remote binder.IBinder
}

func NewPeopleManagerProxy

func NewPeopleManagerProxy(
	remote binder.IBinder,
) *PeopleManagerProxy

func (*PeopleManagerProxy) AddOrUpdateStatus

func (p *PeopleManagerProxy) AddOrUpdateStatus(
	ctx context.Context,
	packageName string,
	conversationId string,
	status ConversationStatus,
) error

func (*PeopleManagerProxy) AsBinder

func (p *PeopleManagerProxy) AsBinder() binder.IBinder

func (*PeopleManagerProxy) ClearStatus

func (p *PeopleManagerProxy) ClearStatus(
	ctx context.Context,
	packageName string,
	conversationId string,
	statusId string,
) error

func (*PeopleManagerProxy) ClearStatuses

func (p *PeopleManagerProxy) ClearStatuses(
	ctx context.Context,
	packageName string,
	conversationId string,
) error

func (*PeopleManagerProxy) GetConversation

func (p *PeopleManagerProxy) GetConversation(
	ctx context.Context,
	packageName string,
	shortcutId string,
) (ConversationChannel, error)

func (*PeopleManagerProxy) GetLastInteraction

func (p *PeopleManagerProxy) GetLastInteraction(
	ctx context.Context,
	packageName string,
	shortcutId string,
) (int64, error)

func (*PeopleManagerProxy) GetRecentConversations

func (p *PeopleManagerProxy) GetRecentConversations(
	ctx context.Context,
) (pm.ParceledListSlice, error)

func (*PeopleManagerProxy) GetStatuses

func (p *PeopleManagerProxy) GetStatuses(
	ctx context.Context,
	packageName string,
	conversationId string,
) (pm.ParceledListSlice, error)

func (*PeopleManagerProxy) IsConversation

func (p *PeopleManagerProxy) IsConversation(
	ctx context.Context,
	packageName string,
	shortcutId string,
) (bool, error)

func (*PeopleManagerProxy) RegisterConversationListener

func (p *PeopleManagerProxy) RegisterConversationListener(
	ctx context.Context,
	packageName string,
	shortcutId string,
	callback IConversationListener,
) error

func (*PeopleManagerProxy) RemoveAllRecentConversations

func (p *PeopleManagerProxy) RemoveAllRecentConversations(
	ctx context.Context,
) error

func (*PeopleManagerProxy) RemoveRecentConversation

func (p *PeopleManagerProxy) RemoveRecentConversation(
	ctx context.Context,
	packageName string,
	shortcutId string,
) error

func (*PeopleManagerProxy) UnregisterConversationListener

func (p *PeopleManagerProxy) UnregisterConversationListener(
	ctx context.Context,
	callback IConversationListener,
) error

type PeopleManagerStub

type PeopleManagerStub struct {
	Impl      IPeopleManager
	Transport binder.VersionAwareTransport
}

PeopleManagerStub dispatches incoming binder transactions to a typed IPeopleManager implementation.

func (*PeopleManagerStub) Descriptor

func (s *PeopleManagerStub) Descriptor() string

func (*PeopleManagerStub) OnTransaction

func (s *PeopleManagerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to