search

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	TransactionISearchUiManagerCreateSearchSession                      = binder.FirstCallTransaction + 0
	TransactionISearchUiManagerQuery                                    = binder.FirstCallTransaction + 1
	TransactionISearchUiManagerNotifyEvent                              = binder.FirstCallTransaction + 2
	TransactionISearchUiManagerRegisterEmptyQueryResultUpdateCallback   = binder.FirstCallTransaction + 3
	TransactionISearchUiManagerUnregisterEmptyQueryResultUpdateCallback = binder.FirstCallTransaction + 4
	TransactionISearchUiManagerDestroySearchSession                     = binder.FirstCallTransaction + 5
)
const (
	MethodISearchUiManagerCreateSearchSession                      = "createSearchSession"
	MethodISearchUiManagerQuery                                    = "query"
	MethodISearchUiManagerNotifyEvent                              = "notifyEvent"
	MethodISearchUiManagerRegisterEmptyQueryResultUpdateCallback   = "registerEmptyQueryResultUpdateCallback"
	MethodISearchUiManagerUnregisterEmptyQueryResultUpdateCallback = "unregisterEmptyQueryResultUpdateCallback"
	MethodISearchUiManagerDestroySearchSession                     = "destroySearchSession"
)
const DescriptorISearchCallback = "android.app.search.ISearchCallback"
const DescriptorISearchUiManager = "android.app.search.ISearchUiManager"
const (
	MethodISearchCallbackOnResult = "onResult"
)
const (
	TransactionISearchCallbackOnResult = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type ISearchCallback

type ISearchCallback interface {
	AsBinder() binder.IBinder
	OnResult(ctx context.Context, result pm.ParceledListSlice) error
}

func NewSearchCallbackStub

func NewSearchCallbackStub(
	impl ISearchCallbackServer,
) ISearchCallback

NewSearchCallbackStub creates a server-side ISearchCallback wrapping the given server implementation. The returned value satisfies ISearchCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISearchCallbackServer

type ISearchCallbackServer interface {
	OnResult(ctx context.Context, result pm.ParceledListSlice) error
}

ISearchCallbackServer is the server-side interface that user implementations provide to NewSearchCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISearchUiManager

type ISearchUiManager interface {
	AsBinder() binder.IBinder
	CreateSearchSession(ctx context.Context, context_ SearchContext, sessionId SearchSessionId, token binder.IBinder) error
	Query(ctx context.Context, sessionId SearchSessionId, input Query, callback ISearchCallback) error
	NotifyEvent(ctx context.Context, sessionId SearchSessionId, input Query, event SearchTargetEvent) error
	RegisterEmptyQueryResultUpdateCallback(ctx context.Context, sessionId SearchSessionId, callback ISearchCallback) error
	UnregisterEmptyQueryResultUpdateCallback(ctx context.Context, sessionId SearchSessionId, callback ISearchCallback) error
	DestroySearchSession(ctx context.Context, sessionId SearchSessionId) error
}

func NewSearchUiManagerStub

func NewSearchUiManagerStub(
	impl ISearchUiManagerServer,
) ISearchUiManager

NewSearchUiManagerStub creates a server-side ISearchUiManager wrapping the given server implementation. The returned value satisfies ISearchUiManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISearchUiManagerServer

type ISearchUiManagerServer interface {
	CreateSearchSession(ctx context.Context, context_ SearchContext, sessionId SearchSessionId, token binder.IBinder) error
	Query(ctx context.Context, sessionId SearchSessionId, input Query, callback ISearchCallback) error
	NotifyEvent(ctx context.Context, sessionId SearchSessionId, input Query, event SearchTargetEvent) error
	RegisterEmptyQueryResultUpdateCallback(ctx context.Context, sessionId SearchSessionId, callback ISearchCallback) error
	UnregisterEmptyQueryResultUpdateCallback(ctx context.Context, sessionId SearchSessionId, callback ISearchCallback) error
	DestroySearchSession(ctx context.Context, sessionId SearchSessionId) error
}

ISearchUiManagerServer is the server-side interface that user implementations provide to NewSearchUiManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type Query

type Query struct {
	Input           string
	TimestampMillis int64
}

func (*Query) MarshalParcel

func (s *Query) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Query) UnmarshalParcel

func (s *Query) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SearchCallbackProxy

type SearchCallbackProxy struct {
	Remote binder.IBinder
}

func NewSearchCallbackProxy

func NewSearchCallbackProxy(
	remote binder.IBinder,
) *SearchCallbackProxy

func (*SearchCallbackProxy) AsBinder

func (p *SearchCallbackProxy) AsBinder() binder.IBinder

func (*SearchCallbackProxy) OnResult

func (p *SearchCallbackProxy) OnResult(
	ctx context.Context,
	result pm.ParceledListSlice,
) error

type SearchCallbackStub

type SearchCallbackStub struct {
	Impl      ISearchCallback
	Transport binder.VersionAwareTransport
}

SearchCallbackStub dispatches incoming binder transactions to a typed ISearchCallback implementation.

func (*SearchCallbackStub) Descriptor

func (s *SearchCallbackStub) Descriptor() string

func (*SearchCallbackStub) OnTransaction

func (s *SearchCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type SearchContext

type SearchContext struct {
	ResultTypes   int32
	TimeoutMillis int32
	PackageName   string
}

func (*SearchContext) MarshalParcel

func (s *SearchContext) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SearchContext) UnmarshalParcel

func (s *SearchContext) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SearchSessionId

type SearchSessionId struct {
	Id     string
	UserId int32
}

func (*SearchSessionId) MarshalParcel

func (s *SearchSessionId) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SearchSessionId) UnmarshalParcel

func (s *SearchSessionId) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SearchTarget

type SearchTarget struct {
	ResultType            int32
	LayoutType            string
	Id                    string
	ParentId              string
	Score                 float32
	Hidden                bool
	PackageName           string
	ShortcutInfo          *pm.ShortcutInfo
	AppWidgetProviderInfo *appwidget.AppWidgetProviderInfo
}

func (*SearchTarget) MarshalParcel

func (s *SearchTarget) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SearchTarget) UnmarshalParcel

func (s *SearchTarget) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SearchTargetEvent

type SearchTargetEvent struct {
	Location string
	Action   int32
	Flags    int32
}

func (*SearchTargetEvent) MarshalParcel

func (s *SearchTargetEvent) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SearchTargetEvent) UnmarshalParcel

func (s *SearchTargetEvent) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SearchUiManagerProxy

type SearchUiManagerProxy struct {
	Remote binder.IBinder
}

func NewSearchUiManagerProxy

func NewSearchUiManagerProxy(
	remote binder.IBinder,
) *SearchUiManagerProxy

func (*SearchUiManagerProxy) AsBinder

func (p *SearchUiManagerProxy) AsBinder() binder.IBinder

func (*SearchUiManagerProxy) CreateSearchSession

func (p *SearchUiManagerProxy) CreateSearchSession(
	ctx context.Context,
	context_ SearchContext,
	sessionId SearchSessionId,
	token binder.IBinder,
) error

func (*SearchUiManagerProxy) DestroySearchSession

func (p *SearchUiManagerProxy) DestroySearchSession(
	ctx context.Context,
	sessionId SearchSessionId,
) error

func (*SearchUiManagerProxy) NotifyEvent

func (p *SearchUiManagerProxy) NotifyEvent(
	ctx context.Context,
	sessionId SearchSessionId,
	input Query,
	event SearchTargetEvent,
) error

func (*SearchUiManagerProxy) Query

func (p *SearchUiManagerProxy) Query(
	ctx context.Context,
	sessionId SearchSessionId,
	input Query,
	callback ISearchCallback,
) error

func (*SearchUiManagerProxy) RegisterEmptyQueryResultUpdateCallback

func (p *SearchUiManagerProxy) RegisterEmptyQueryResultUpdateCallback(
	ctx context.Context,
	sessionId SearchSessionId,
	callback ISearchCallback,
) error

func (*SearchUiManagerProxy) UnregisterEmptyQueryResultUpdateCallback

func (p *SearchUiManagerProxy) UnregisterEmptyQueryResultUpdateCallback(
	ctx context.Context,
	sessionId SearchSessionId,
	callback ISearchCallback,
) error

type SearchUiManagerStub

type SearchUiManagerStub struct {
	Impl      ISearchUiManager
	Transport binder.VersionAwareTransport
}

SearchUiManagerStub dispatches incoming binder transactions to a typed ISearchUiManager implementation.

func (*SearchUiManagerStub) Descriptor

func (s *SearchUiManagerStub) Descriptor() string

func (*SearchUiManagerStub) OnTransaction

func (s *SearchUiManagerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to