Documentation
¶
Index ¶
Constants ¶
const ( TransactionIArtManagerSnapshotRuntimeProfile = binder.FirstCallTransaction + 0 TransactionIArtManagerIsRuntimeProfilingEnabled = binder.FirstCallTransaction + 1 )
const ( MethodIArtManagerSnapshotRuntimeProfile = "snapshotRuntimeProfile" MethodIArtManagerIsRuntimeProfilingEnabled = "isRuntimeProfilingEnabled" )
const ( TransactionISnapshotRuntimeProfileCallbackOnSuccess = binder.FirstCallTransaction + 0 TransactionISnapshotRuntimeProfileCallbackOnError = binder.FirstCallTransaction + 1 )
const ( MethodISnapshotRuntimeProfileCallbackOnSuccess = "onSuccess" MethodISnapshotRuntimeProfileCallbackOnError = "onError" )
const DescriptorIArtManager = "android.content.pm.dex.IArtManager"
const DescriptorISnapshotRuntimeProfileCallback = "android.content.pm.dex.ISnapshotRuntimeProfileCallback"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ArtManagerProxy ¶
func NewArtManagerProxy ¶
func NewArtManagerProxy( remote binder.IBinder, ) *ArtManagerProxy
func (*ArtManagerProxy) AsBinder ¶
func (p *ArtManagerProxy) AsBinder() binder.IBinder
func (*ArtManagerProxy) IsRuntimeProfilingEnabled ¶
func (*ArtManagerProxy) SnapshotRuntimeProfile ¶
func (p *ArtManagerProxy) SnapshotRuntimeProfile( ctx context.Context, profileType int32, packageName string, codePath string, callback ISnapshotRuntimeProfileCallback, ) error
type ArtManagerStub ¶
type ArtManagerStub struct {
Impl IArtManager
Transport binder.VersionAwareTransport
}
ArtManagerStub dispatches incoming binder transactions to a typed IArtManager implementation.
func (*ArtManagerStub) Descriptor ¶
func (s *ArtManagerStub) Descriptor() string
func (*ArtManagerStub) OnTransaction ¶
func (s *ArtManagerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type IArtManager ¶
type IArtManager interface {
AsBinder() binder.IBinder
SnapshotRuntimeProfile(ctx context.Context, profileType int32, packageName string, codePath string, callback ISnapshotRuntimeProfileCallback) error
IsRuntimeProfilingEnabled(ctx context.Context, profileType int32) (bool, error)
}
func NewArtManagerStub ¶
func NewArtManagerStub( impl IArtManagerServer, ) IArtManager
NewArtManagerStub creates a server-side IArtManager wrapping the given server implementation. The returned value satisfies IArtManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IArtManagerServer ¶
type IArtManagerServer interface {
SnapshotRuntimeProfile(ctx context.Context, profileType int32, packageName string, codePath string, callback ISnapshotRuntimeProfileCallback) error
IsRuntimeProfilingEnabled(ctx context.Context, profileType int32) (bool, error)
}
IArtManagerServer is the server-side interface that user implementations provide to NewArtManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ISnapshotRuntimeProfileCallback ¶
type ISnapshotRuntimeProfileCallback interface {
AsBinder() binder.IBinder
OnSuccess(ctx context.Context, profileReadFd int32) error
OnError(ctx context.Context, errCode int32) error
}
func NewSnapshotRuntimeProfileCallbackStub ¶
func NewSnapshotRuntimeProfileCallbackStub( impl ISnapshotRuntimeProfileCallbackServer, ) ISnapshotRuntimeProfileCallback
NewSnapshotRuntimeProfileCallbackStub creates a server-side ISnapshotRuntimeProfileCallback wrapping the given server implementation. The returned value satisfies ISnapshotRuntimeProfileCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ISnapshotRuntimeProfileCallbackServer ¶
type ISnapshotRuntimeProfileCallbackServer interface {
OnSuccess(ctx context.Context, profileReadFd int32) error
OnError(ctx context.Context, errCode int32) error
}
ISnapshotRuntimeProfileCallbackServer is the server-side interface that user implementations provide to NewSnapshotRuntimeProfileCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type SnapshotRuntimeProfileCallbackProxy ¶
func NewSnapshotRuntimeProfileCallbackProxy ¶
func NewSnapshotRuntimeProfileCallbackProxy( remote binder.IBinder, ) *SnapshotRuntimeProfileCallbackProxy
func (*SnapshotRuntimeProfileCallbackProxy) AsBinder ¶
func (p *SnapshotRuntimeProfileCallbackProxy) AsBinder() binder.IBinder
type SnapshotRuntimeProfileCallbackStub ¶
type SnapshotRuntimeProfileCallbackStub struct {
Impl ISnapshotRuntimeProfileCallback
Transport binder.VersionAwareTransport
}
SnapshotRuntimeProfileCallbackStub dispatches incoming binder transactions to a typed ISnapshotRuntimeProfileCallback implementation.
func (*SnapshotRuntimeProfileCallbackStub) Descriptor ¶
func (s *SnapshotRuntimeProfileCallbackStub) Descriptor() string
func (*SnapshotRuntimeProfileCallbackStub) OnTransaction ¶
func (s *SnapshotRuntimeProfileCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)