credentials

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIClearCredentialStateCallbackOnSuccess = binder.FirstCallTransaction + 0
	TransactionIClearCredentialStateCallbackOnError   = binder.FirstCallTransaction + 1
)
const (
	MethodIClearCredentialStateCallbackOnSuccess = "onSuccess"
	MethodIClearCredentialStateCallbackOnError   = "onError"
)
const (
	TransactionICreateCredentialCallbackOnPendingIntent = binder.FirstCallTransaction + 0
	TransactionICreateCredentialCallbackOnResponse      = binder.FirstCallTransaction + 1
	TransactionICreateCredentialCallbackOnError         = binder.FirstCallTransaction + 2
)
const (
	MethodICreateCredentialCallbackOnPendingIntent = "onPendingIntent"
	MethodICreateCredentialCallbackOnResponse      = "onResponse"
	MethodICreateCredentialCallbackOnError         = "onError"
)
const (
	TransactionICredentialManagerExecuteGetCredential                    = binder.FirstCallTransaction + 0
	TransactionICredentialManagerExecutePrepareGetCredential             = binder.FirstCallTransaction + 1
	TransactionICredentialManagerExecuteCreateCredential                 = binder.FirstCallTransaction + 2
	TransactionICredentialManagerGetCandidateCredentials                 = binder.FirstCallTransaction + 3
	TransactionICredentialManagerClearCredentialState                    = binder.FirstCallTransaction + 4
	TransactionICredentialManagerSetEnabledProviders                     = binder.FirstCallTransaction + 5
	TransactionICredentialManagerRegisterCredentialDescription           = binder.FirstCallTransaction + 6
	TransactionICredentialManagerUnregisterCredentialDescription         = binder.FirstCallTransaction + 7
	TransactionICredentialManagerIsEnabledCredentialProviderService      = binder.FirstCallTransaction + 8
	TransactionICredentialManagerGetCredentialProviderServices           = binder.FirstCallTransaction + 9
	TransactionICredentialManagerGetCredentialProviderServicesForTesting = binder.FirstCallTransaction + 10
	TransactionICredentialManagerIsServiceEnabled                        = binder.FirstCallTransaction + 11
)
const (
	MethodICredentialManagerExecuteGetCredential                    = "executeGetCredential"
	MethodICredentialManagerExecutePrepareGetCredential             = "executePrepareGetCredential"
	MethodICredentialManagerExecuteCreateCredential                 = "executeCreateCredential"
	MethodICredentialManagerGetCandidateCredentials                 = "getCandidateCredentials"
	MethodICredentialManagerClearCredentialState                    = "clearCredentialState"
	MethodICredentialManagerSetEnabledProviders                     = "setEnabledProviders"
	MethodICredentialManagerRegisterCredentialDescription           = "registerCredentialDescription"
	MethodICredentialManagerUnregisterCredentialDescription         = "unregisterCredentialDescription"
	MethodICredentialManagerIsEnabledCredentialProviderService      = "isEnabledCredentialProviderService"
	MethodICredentialManagerGetCredentialProviderServices           = "getCredentialProviderServices"
	MethodICredentialManagerGetCredentialProviderServicesForTesting = "getCredentialProviderServicesForTesting"
	MethodICredentialManagerIsServiceEnabled                        = "isServiceEnabled"
)
const (
	TransactionIGetCandidateCredentialsCallbackOnResponse = binder.FirstCallTransaction + 0
	TransactionIGetCandidateCredentialsCallbackOnError    = binder.FirstCallTransaction + 1
)
const (
	MethodIGetCandidateCredentialsCallbackOnResponse = "onResponse"
	MethodIGetCandidateCredentialsCallbackOnError    = "onError"
)
const (
	TransactionIGetCredentialCallbackOnPendingIntent = binder.FirstCallTransaction + 0
	TransactionIGetCredentialCallbackOnResponse      = binder.FirstCallTransaction + 1
	TransactionIGetCredentialCallbackOnError         = binder.FirstCallTransaction + 2
)
const (
	MethodIGetCredentialCallbackOnPendingIntent = "onPendingIntent"
	MethodIGetCredentialCallbackOnResponse      = "onResponse"
	MethodIGetCredentialCallbackOnError         = "onError"
)
const (
	TransactionIPrepareGetCredentialCallbackOnResponse = binder.FirstCallTransaction + 0
	TransactionIPrepareGetCredentialCallbackOnError    = binder.FirstCallTransaction + 1
)
const (
	MethodIPrepareGetCredentialCallbackOnResponse = "onResponse"
	MethodIPrepareGetCredentialCallbackOnError    = "onError"
)
const (
	TransactionISetEnabledProvidersCallbackOnResponse = binder.FirstCallTransaction + 0
	TransactionISetEnabledProvidersCallbackOnError    = binder.FirstCallTransaction + 1
)
const (
	MethodISetEnabledProvidersCallbackOnResponse = "onResponse"
	MethodISetEnabledProvidersCallbackOnError    = "onError"
)
const DescriptorIClearCredentialStateCallback = "android.credentials.IClearCredentialStateCallback"
const DescriptorICreateCredentialCallback = "android.credentials.ICreateCredentialCallback"
const DescriptorICredentialManager = "android.credentials.ICredentialManager"
const DescriptorIGetCandidateCredentialsCallback = "android.credentials.IGetCandidateCredentialsCallback"
const DescriptorIGetCredentialCallback = "android.credentials.IGetCredentialCallback"
const DescriptorIPrepareGetCredentialCallback = "android.credentials.IPrepareGetCredentialCallback"
const DescriptorISetEnabledProvidersCallback = "android.credentials.ISetEnabledProvidersCallback"

Variables

This section is empty.

Functions

This section is empty.

Types

type ClearCredentialStateCallbackProxy

type ClearCredentialStateCallbackProxy struct {
	Remote binder.IBinder
}

func NewClearCredentialStateCallbackProxy

func NewClearCredentialStateCallbackProxy(
	remote binder.IBinder,
) *ClearCredentialStateCallbackProxy

func (*ClearCredentialStateCallbackProxy) AsBinder

func (*ClearCredentialStateCallbackProxy) OnError

func (p *ClearCredentialStateCallbackProxy) OnError(
	ctx context.Context,
	errorType string,
	message string,
) error

func (*ClearCredentialStateCallbackProxy) OnSuccess

type ClearCredentialStateCallbackStub

type ClearCredentialStateCallbackStub struct {
	Impl      IClearCredentialStateCallback
	Transport binder.VersionAwareTransport
}

ClearCredentialStateCallbackStub dispatches incoming binder transactions to a typed IClearCredentialStateCallback implementation.

func (*ClearCredentialStateCallbackStub) Descriptor

func (s *ClearCredentialStateCallbackStub) Descriptor() string

func (*ClearCredentialStateCallbackStub) OnTransaction

type ClearCredentialStateRequest

type ClearCredentialStateRequest struct {
}

func (*ClearCredentialStateRequest) MarshalParcel

func (s *ClearCredentialStateRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ClearCredentialStateRequest) UnmarshalParcel

func (s *ClearCredentialStateRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CreateCredentialCallbackProxy

type CreateCredentialCallbackProxy struct {
	Remote binder.IBinder
}

func NewCreateCredentialCallbackProxy

func NewCreateCredentialCallbackProxy(
	remote binder.IBinder,
) *CreateCredentialCallbackProxy

func (*CreateCredentialCallbackProxy) AsBinder

func (*CreateCredentialCallbackProxy) OnError

func (p *CreateCredentialCallbackProxy) OnError(
	ctx context.Context,
	errorType string,
	message string,
) error

func (*CreateCredentialCallbackProxy) OnPendingIntent

func (p *CreateCredentialCallbackProxy) OnPendingIntent(
	ctx context.Context,
	pendingIntent types.PendingIntent,
) error

func (*CreateCredentialCallbackProxy) OnResponse

type CreateCredentialCallbackStub

type CreateCredentialCallbackStub struct {
	Impl      ICreateCredentialCallback
	Transport binder.VersionAwareTransport
}

CreateCredentialCallbackStub dispatches incoming binder transactions to a typed ICreateCredentialCallback implementation.

func (*CreateCredentialCallbackStub) Descriptor

func (s *CreateCredentialCallbackStub) Descriptor() string

func (*CreateCredentialCallbackStub) OnTransaction

type CreateCredentialRequest

type CreateCredentialRequest struct {
	Type                        string
	IsSystemProviderRequired    bool
	AlwaysSendAppInfoToProvider bool
	Origin                      string
}

func (*CreateCredentialRequest) MarshalParcel

func (s *CreateCredentialRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CreateCredentialRequest) UnmarshalParcel

func (s *CreateCredentialRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CreateCredentialResponse

type CreateCredentialResponse struct {
}

func (*CreateCredentialResponse) MarshalParcel

func (s *CreateCredentialResponse) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CreateCredentialResponse) UnmarshalParcel

func (s *CreateCredentialResponse) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CredentialDescription

type CredentialDescription struct {
	Type string
}

func (*CredentialDescription) MarshalParcel

func (s *CredentialDescription) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CredentialDescription) UnmarshalParcel

func (s *CredentialDescription) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CredentialManagerProxy

type CredentialManagerProxy struct {
	Remote binder.IBinder
}

func GetCredentialManager

func GetCredentialManager(
	ctx context.Context,
	sm *servicemanager.ServiceManager,
) (*CredentialManagerProxy, error)

GetCredentialManager retrieves the CredentialService service and returns a typed proxy.

func NewCredentialManagerProxy

func NewCredentialManagerProxy(
	remote binder.IBinder,
) *CredentialManagerProxy

func (*CredentialManagerProxy) AsBinder

func (p *CredentialManagerProxy) AsBinder() binder.IBinder

func (*CredentialManagerProxy) ClearCredentialState

func (*CredentialManagerProxy) ExecuteCreateCredential

func (*CredentialManagerProxy) ExecuteGetCredential

func (p *CredentialManagerProxy) ExecuteGetCredential(
	ctx context.Context,
	request GetCredentialRequest,
	callback IGetCredentialCallback,
) (os.ICancellationSignal, error)

func (*CredentialManagerProxy) ExecutePrepareGetCredential

func (p *CredentialManagerProxy) ExecutePrepareGetCredential(
	ctx context.Context,
	request GetCredentialRequest,
	prepareGetCredentialCallback IPrepareGetCredentialCallback,
	getCredentialCallback IGetCredentialCallback,
) (os.ICancellationSignal, error)

func (*CredentialManagerProxy) GetCandidateCredentials

func (p *CredentialManagerProxy) GetCandidateCredentials(
	ctx context.Context,
	request GetCredentialRequest,
	callback IGetCandidateCredentialsCallback,
	clientCallback binder.IBinder,
) (os.ICancellationSignal, error)

func (*CredentialManagerProxy) GetCredentialProviderServices

func (p *CredentialManagerProxy) GetCredentialProviderServices(
	ctx context.Context,
	providerFilter int32,
) ([]CredentialProviderInfo, error)

func (*CredentialManagerProxy) GetCredentialProviderServicesForTesting

func (p *CredentialManagerProxy) GetCredentialProviderServicesForTesting(
	ctx context.Context,
	providerFilter int32,
) ([]CredentialProviderInfo, error)

func (*CredentialManagerProxy) IsEnabledCredentialProviderService

func (p *CredentialManagerProxy) IsEnabledCredentialProviderService(
	ctx context.Context,
	componentName content.ComponentName,
) (bool, error)

func (*CredentialManagerProxy) IsServiceEnabled

func (p *CredentialManagerProxy) IsServiceEnabled(
	ctx context.Context,
) (bool, error)

func (*CredentialManagerProxy) RegisterCredentialDescription

func (p *CredentialManagerProxy) RegisterCredentialDescription(
	ctx context.Context,
	request RegisterCredentialDescriptionRequest,
) error

func (*CredentialManagerProxy) SetEnabledProviders

func (p *CredentialManagerProxy) SetEnabledProviders(
	ctx context.Context,
	primaryProviders []string,
	providers []string,
	callback ISetEnabledProvidersCallback,
) error

func (*CredentialManagerProxy) UnregisterCredentialDescription

func (p *CredentialManagerProxy) UnregisterCredentialDescription(
	ctx context.Context,
	request UnregisterCredentialDescriptionRequest,
) error

type CredentialManagerStub

type CredentialManagerStub struct {
	Impl      ICredentialManager
	Transport binder.VersionAwareTransport
}

CredentialManagerStub dispatches incoming binder transactions to a typed ICredentialManager implementation.

func (*CredentialManagerStub) Descriptor

func (s *CredentialManagerStub) Descriptor() string

func (*CredentialManagerStub) OnTransaction

func (s *CredentialManagerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type CredentialProviderInfo

type CredentialProviderInfo struct {
	IsSystemProvider bool
	IsEnabled        bool
	IsPrimary        bool
}

func (*CredentialProviderInfo) MarshalParcel

func (s *CredentialProviderInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CredentialProviderInfo) UnmarshalParcel

func (s *CredentialProviderInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type GetCandidateCredentialsCallbackProxy

type GetCandidateCredentialsCallbackProxy struct {
	Remote binder.IBinder
}

func NewGetCandidateCredentialsCallbackProxy

func NewGetCandidateCredentialsCallbackProxy(
	remote binder.IBinder,
) *GetCandidateCredentialsCallbackProxy

func (*GetCandidateCredentialsCallbackProxy) AsBinder

func (*GetCandidateCredentialsCallbackProxy) OnError

func (p *GetCandidateCredentialsCallbackProxy) OnError(
	ctx context.Context,
	errorType string,
	message string,
) error

func (*GetCandidateCredentialsCallbackProxy) OnResponse

type GetCandidateCredentialsCallbackStub

type GetCandidateCredentialsCallbackStub struct {
	Impl      IGetCandidateCredentialsCallback
	Transport binder.VersionAwareTransport
}

GetCandidateCredentialsCallbackStub dispatches incoming binder transactions to a typed IGetCandidateCredentialsCallback implementation.

func (*GetCandidateCredentialsCallbackStub) Descriptor

func (*GetCandidateCredentialsCallbackStub) OnTransaction

type GetCandidateCredentialsRequest

type GetCandidateCredentialsRequest struct {
	Origin string
}

func (*GetCandidateCredentialsRequest) MarshalParcel

func (s *GetCandidateCredentialsRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*GetCandidateCredentialsRequest) UnmarshalParcel

func (s *GetCandidateCredentialsRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type GetCandidateCredentialsResponse

type GetCandidateCredentialsResponse struct {
	Intent *types.Intent
}

func (*GetCandidateCredentialsResponse) MarshalParcel

func (s *GetCandidateCredentialsResponse) MarshalParcel(
	p *parcel.Parcel,
) error

func (*GetCandidateCredentialsResponse) UnmarshalParcel

func (s *GetCandidateCredentialsResponse) UnmarshalParcel(
	p *parcel.Parcel,
) error

type GetCredentialCallbackProxy

type GetCredentialCallbackProxy struct {
	Remote binder.IBinder
}

func NewGetCredentialCallbackProxy

func NewGetCredentialCallbackProxy(
	remote binder.IBinder,
) *GetCredentialCallbackProxy

func (*GetCredentialCallbackProxy) AsBinder

func (*GetCredentialCallbackProxy) OnError

func (p *GetCredentialCallbackProxy) OnError(
	ctx context.Context,
	errorType string,
	message string,
) error

func (*GetCredentialCallbackProxy) OnPendingIntent

func (p *GetCredentialCallbackProxy) OnPendingIntent(
	ctx context.Context,
	pendingIntent types.PendingIntent,
) error

func (*GetCredentialCallbackProxy) OnResponse

func (p *GetCredentialCallbackProxy) OnResponse(
	ctx context.Context,
	response GetCredentialResponse,
) error

type GetCredentialCallbackStub

type GetCredentialCallbackStub struct {
	Impl      IGetCredentialCallback
	Transport binder.VersionAwareTransport
}

GetCredentialCallbackStub dispatches incoming binder transactions to a typed IGetCredentialCallback implementation.

func (*GetCredentialCallbackStub) Descriptor

func (s *GetCredentialCallbackStub) Descriptor() string

func (*GetCredentialCallbackStub) OnTransaction

func (s *GetCredentialCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type GetCredentialRequest

type GetCredentialRequest struct {
	AlwaysSendAppInfoToProvider bool
	Origin                      string
}

func (*GetCredentialRequest) MarshalParcel

func (s *GetCredentialRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*GetCredentialRequest) UnmarshalParcel

func (s *GetCredentialRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type GetCredentialResponse

type GetCredentialResponse struct {
}

func (*GetCredentialResponse) MarshalParcel

func (s *GetCredentialResponse) MarshalParcel(
	p *parcel.Parcel,
) error

func (*GetCredentialResponse) UnmarshalParcel

func (s *GetCredentialResponse) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IClearCredentialStateCallback

type IClearCredentialStateCallback interface {
	AsBinder() binder.IBinder
	OnSuccess(ctx context.Context) error
	OnError(ctx context.Context, errorType string, message string) error
}

func NewClearCredentialStateCallbackStub

func NewClearCredentialStateCallbackStub(
	impl IClearCredentialStateCallbackServer,
) IClearCredentialStateCallback

NewClearCredentialStateCallbackStub creates a server-side IClearCredentialStateCallback wrapping the given server implementation. The returned value satisfies IClearCredentialStateCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IClearCredentialStateCallbackServer

type IClearCredentialStateCallbackServer interface {
	OnSuccess(ctx context.Context) error
	OnError(ctx context.Context, errorType string, message string) error
}

IClearCredentialStateCallbackServer is the server-side interface that user implementations provide to NewClearCredentialStateCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ICreateCredentialCallback

type ICreateCredentialCallback interface {
	AsBinder() binder.IBinder
	OnPendingIntent(ctx context.Context, pendingIntent types.PendingIntent) error
	OnResponse(ctx context.Context, response CreateCredentialResponse) error
	OnError(ctx context.Context, errorType string, message string) error
}

func NewCreateCredentialCallbackStub

func NewCreateCredentialCallbackStub(
	impl ICreateCredentialCallbackServer,
) ICreateCredentialCallback

NewCreateCredentialCallbackStub creates a server-side ICreateCredentialCallback wrapping the given server implementation. The returned value satisfies ICreateCredentialCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ICreateCredentialCallbackServer

type ICreateCredentialCallbackServer interface {
	OnPendingIntent(ctx context.Context, pendingIntent types.PendingIntent) error
	OnResponse(ctx context.Context, response CreateCredentialResponse) error
	OnError(ctx context.Context, errorType string, message string) error
}

ICreateCredentialCallbackServer is the server-side interface that user implementations provide to NewCreateCredentialCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ICredentialManager

type ICredentialManager interface {
	AsBinder() binder.IBinder
	ExecuteGetCredential(ctx context.Context, request GetCredentialRequest, callback IGetCredentialCallback) (os.ICancellationSignal, error)
	ExecutePrepareGetCredential(ctx context.Context, request GetCredentialRequest, prepareGetCredentialCallback IPrepareGetCredentialCallback, getCredentialCallback IGetCredentialCallback) (os.ICancellationSignal, error)
	ExecuteCreateCredential(ctx context.Context, request CreateCredentialRequest, callback ICreateCredentialCallback) (os.ICancellationSignal, error)
	GetCandidateCredentials(ctx context.Context, request GetCredentialRequest, callback IGetCandidateCredentialsCallback, clientCallback binder.IBinder) (os.ICancellationSignal, error)
	ClearCredentialState(ctx context.Context, request ClearCredentialStateRequest, callback IClearCredentialStateCallback) (os.ICancellationSignal, error)
	SetEnabledProviders(ctx context.Context, primaryProviders []string, providers []string, callback ISetEnabledProvidersCallback) error
	RegisterCredentialDescription(ctx context.Context, request RegisterCredentialDescriptionRequest) error
	UnregisterCredentialDescription(ctx context.Context, request UnregisterCredentialDescriptionRequest) error
	IsEnabledCredentialProviderService(ctx context.Context, componentName content.ComponentName) (bool, error)
	GetCredentialProviderServices(ctx context.Context, providerFilter int32) ([]CredentialProviderInfo, error)
	GetCredentialProviderServicesForTesting(ctx context.Context, providerFilter int32) ([]CredentialProviderInfo, error)
	IsServiceEnabled(ctx context.Context) (bool, error)
}

func NewCredentialManagerStub

func NewCredentialManagerStub(
	impl ICredentialManagerServer,
) ICredentialManager

NewCredentialManagerStub creates a server-side ICredentialManager wrapping the given server implementation. The returned value satisfies ICredentialManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ICredentialManagerServer

type ICredentialManagerServer interface {
	ExecuteGetCredential(ctx context.Context, request GetCredentialRequest, callback IGetCredentialCallback) (os.ICancellationSignal, error)
	ExecutePrepareGetCredential(ctx context.Context, request GetCredentialRequest, prepareGetCredentialCallback IPrepareGetCredentialCallback, getCredentialCallback IGetCredentialCallback) (os.ICancellationSignal, error)
	ExecuteCreateCredential(ctx context.Context, request CreateCredentialRequest, callback ICreateCredentialCallback) (os.ICancellationSignal, error)
	GetCandidateCredentials(ctx context.Context, request GetCredentialRequest, callback IGetCandidateCredentialsCallback, clientCallback binder.IBinder) (os.ICancellationSignal, error)
	ClearCredentialState(ctx context.Context, request ClearCredentialStateRequest, callback IClearCredentialStateCallback) (os.ICancellationSignal, error)
	SetEnabledProviders(ctx context.Context, primaryProviders []string, providers []string, callback ISetEnabledProvidersCallback) error
	RegisterCredentialDescription(ctx context.Context, request RegisterCredentialDescriptionRequest) error
	UnregisterCredentialDescription(ctx context.Context, request UnregisterCredentialDescriptionRequest) error
	IsEnabledCredentialProviderService(ctx context.Context, componentName content.ComponentName) (bool, error)
	GetCredentialProviderServices(ctx context.Context, providerFilter int32) ([]CredentialProviderInfo, error)
	GetCredentialProviderServicesForTesting(ctx context.Context, providerFilter int32) ([]CredentialProviderInfo, error)
	IsServiceEnabled(ctx context.Context) (bool, error)
}

ICredentialManagerServer is the server-side interface that user implementations provide to NewCredentialManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGetCandidateCredentialsCallback

type IGetCandidateCredentialsCallback interface {
	AsBinder() binder.IBinder
	OnResponse(ctx context.Context, response GetCandidateCredentialsResponse) error
	OnError(ctx context.Context, errorType string, message string) error
}

func NewGetCandidateCredentialsCallbackStub

func NewGetCandidateCredentialsCallbackStub(
	impl IGetCandidateCredentialsCallbackServer,
) IGetCandidateCredentialsCallback

NewGetCandidateCredentialsCallbackStub creates a server-side IGetCandidateCredentialsCallback wrapping the given server implementation. The returned value satisfies IGetCandidateCredentialsCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGetCandidateCredentialsCallbackServer

type IGetCandidateCredentialsCallbackServer interface {
	OnResponse(ctx context.Context, response GetCandidateCredentialsResponse) error
	OnError(ctx context.Context, errorType string, message string) error
}

IGetCandidateCredentialsCallbackServer is the server-side interface that user implementations provide to NewGetCandidateCredentialsCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGetCredentialCallback

type IGetCredentialCallback interface {
	AsBinder() binder.IBinder
	OnPendingIntent(ctx context.Context, pendingIntent types.PendingIntent) error
	OnResponse(ctx context.Context, response GetCredentialResponse) error
	OnError(ctx context.Context, errorType string, message string) error
}

func NewGetCredentialCallbackStub

func NewGetCredentialCallbackStub(
	impl IGetCredentialCallbackServer,
) IGetCredentialCallback

NewGetCredentialCallbackStub creates a server-side IGetCredentialCallback wrapping the given server implementation. The returned value satisfies IGetCredentialCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGetCredentialCallbackServer

type IGetCredentialCallbackServer interface {
	OnPendingIntent(ctx context.Context, pendingIntent types.PendingIntent) error
	OnResponse(ctx context.Context, response GetCredentialResponse) error
	OnError(ctx context.Context, errorType string, message string) error
}

IGetCredentialCallbackServer is the server-side interface that user implementations provide to NewGetCredentialCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IPrepareGetCredentialCallback

type IPrepareGetCredentialCallback interface {
	AsBinder() binder.IBinder
	OnResponse(ctx context.Context, response PrepareGetCredentialResponseInternal) error
	OnError(ctx context.Context, errorType string, message string) error
}

func NewPrepareGetCredentialCallbackStub

func NewPrepareGetCredentialCallbackStub(
	impl IPrepareGetCredentialCallbackServer,
) IPrepareGetCredentialCallback

NewPrepareGetCredentialCallbackStub creates a server-side IPrepareGetCredentialCallback wrapping the given server implementation. The returned value satisfies IPrepareGetCredentialCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IPrepareGetCredentialCallbackServer

type IPrepareGetCredentialCallbackServer interface {
	OnResponse(ctx context.Context, response PrepareGetCredentialResponseInternal) error
	OnError(ctx context.Context, errorType string, message string) error
}

IPrepareGetCredentialCallbackServer is the server-side interface that user implementations provide to NewPrepareGetCredentialCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISetEnabledProvidersCallback

type ISetEnabledProvidersCallback interface {
	AsBinder() binder.IBinder
	OnResponse(ctx context.Context) error
	OnError(ctx context.Context, errorType string, message string) error
}

func NewSetEnabledProvidersCallbackStub

func NewSetEnabledProvidersCallbackStub(
	impl ISetEnabledProvidersCallbackServer,
) ISetEnabledProvidersCallback

NewSetEnabledProvidersCallbackStub creates a server-side ISetEnabledProvidersCallback wrapping the given server implementation. The returned value satisfies ISetEnabledProvidersCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISetEnabledProvidersCallbackServer

type ISetEnabledProvidersCallbackServer interface {
	OnResponse(ctx context.Context) error
	OnError(ctx context.Context, errorType string, message string) error
}

ISetEnabledProvidersCallbackServer is the server-side interface that user implementations provide to NewSetEnabledProvidersCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ListEnabledProvidersResponse

type ListEnabledProvidersResponse struct {
}

func (*ListEnabledProvidersResponse) MarshalParcel

func (s *ListEnabledProvidersResponse) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ListEnabledProvidersResponse) UnmarshalParcel

func (s *ListEnabledProvidersResponse) UnmarshalParcel(
	p *parcel.Parcel,
) error

type PrepareGetCredentialCallbackProxy

type PrepareGetCredentialCallbackProxy struct {
	Remote binder.IBinder
}

func NewPrepareGetCredentialCallbackProxy

func NewPrepareGetCredentialCallbackProxy(
	remote binder.IBinder,
) *PrepareGetCredentialCallbackProxy

func (*PrepareGetCredentialCallbackProxy) AsBinder

func (*PrepareGetCredentialCallbackProxy) OnError

func (p *PrepareGetCredentialCallbackProxy) OnError(
	ctx context.Context,
	errorType string,
	message string,
) error

func (*PrepareGetCredentialCallbackProxy) OnResponse

type PrepareGetCredentialCallbackStub

type PrepareGetCredentialCallbackStub struct {
	Impl      IPrepareGetCredentialCallback
	Transport binder.VersionAwareTransport
}

PrepareGetCredentialCallbackStub dispatches incoming binder transactions to a typed IPrepareGetCredentialCallback implementation.

func (*PrepareGetCredentialCallbackStub) Descriptor

func (s *PrepareGetCredentialCallbackStub) Descriptor() string

func (*PrepareGetCredentialCallbackStub) OnTransaction

type PrepareGetCredentialResponseInternal

type PrepareGetCredentialResponseInternal struct {
	HasQueryApiPermission    bool
	HasAuthenticationResults bool
	HasRemoteResults         bool
	PendingIntent            *types.PendingIntent
}

func (*PrepareGetCredentialResponseInternal) MarshalParcel

func (s *PrepareGetCredentialResponseInternal) MarshalParcel(
	p *parcel.Parcel,
) error

func (*PrepareGetCredentialResponseInternal) UnmarshalParcel

func (s *PrepareGetCredentialResponseInternal) UnmarshalParcel(
	p *parcel.Parcel,
) error

type RegisterCredentialDescriptionRequest

type RegisterCredentialDescriptionRequest struct {
}

func (*RegisterCredentialDescriptionRequest) MarshalParcel

func (s *RegisterCredentialDescriptionRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*RegisterCredentialDescriptionRequest) UnmarshalParcel

func (s *RegisterCredentialDescriptionRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SetEnabledProvidersCallbackProxy

type SetEnabledProvidersCallbackProxy struct {
	Remote binder.IBinder
}

func NewSetEnabledProvidersCallbackProxy

func NewSetEnabledProvidersCallbackProxy(
	remote binder.IBinder,
) *SetEnabledProvidersCallbackProxy

func (*SetEnabledProvidersCallbackProxy) AsBinder

func (*SetEnabledProvidersCallbackProxy) OnError

func (p *SetEnabledProvidersCallbackProxy) OnError(
	ctx context.Context,
	errorType string,
	message string,
) error

func (*SetEnabledProvidersCallbackProxy) OnResponse

func (p *SetEnabledProvidersCallbackProxy) OnResponse(
	ctx context.Context,
) error

type SetEnabledProvidersCallbackStub

type SetEnabledProvidersCallbackStub struct {
	Impl      ISetEnabledProvidersCallback
	Transport binder.VersionAwareTransport
}

SetEnabledProvidersCallbackStub dispatches incoming binder transactions to a typed ISetEnabledProvidersCallback implementation.

func (*SetEnabledProvidersCallbackStub) Descriptor

func (s *SetEnabledProvidersCallbackStub) Descriptor() string

func (*SetEnabledProvidersCallbackStub) OnTransaction

type SetEnabledProvidersRequest

type SetEnabledProvidersRequest struct {
}

func (*SetEnabledProvidersRequest) MarshalParcel

func (s *SetEnabledProvidersRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SetEnabledProvidersRequest) UnmarshalParcel

func (s *SetEnabledProvidersRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type UnregisterCredentialDescriptionRequest

type UnregisterCredentialDescriptionRequest struct {
}

func (*UnregisterCredentialDescriptionRequest) MarshalParcel

func (*UnregisterCredentialDescriptionRequest) UnmarshalParcel

func (s *UnregisterCredentialDescriptionRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

Directories

Path Synopsis

Jump to