Documentation
¶
Index ¶
- Constants
- type FeatureFlagsCallbackProxy
- type FeatureFlagsCallbackStub
- type FeatureFlagsProxy
- func (p *FeatureFlagsProxy) AsBinder() binder.IBinder
- func (p *FeatureFlagsProxy) OverrideFlag(ctx context.Context, flag SyncableFlag) error
- func (p *FeatureFlagsProxy) QueryFlags(ctx context.Context, flagList []SyncableFlag) ([]SyncableFlag, error)
- func (p *FeatureFlagsProxy) RegisterCallback(ctx context.Context, callback IFeatureFlagsCallback) error
- func (p *FeatureFlagsProxy) ResetFlag(ctx context.Context, flag SyncableFlag) error
- func (p *FeatureFlagsProxy) SyncFlags(ctx context.Context, flagList []SyncableFlag) ([]SyncableFlag, error)
- func (p *FeatureFlagsProxy) UnregisterCallback(ctx context.Context, callback IFeatureFlagsCallback) error
- type FeatureFlagsStub
- type IFeatureFlags
- type IFeatureFlagsCallback
- type IFeatureFlagsCallbackServer
- type IFeatureFlagsServer
- type SyncableFlag
Constants ¶
const ( TransactionIFeatureFlagsSyncFlags = binder.FirstCallTransaction + 0 TransactionIFeatureFlagsRegisterCallback = binder.FirstCallTransaction + 1 TransactionIFeatureFlagsUnregisterCallback = binder.FirstCallTransaction + 2 TransactionIFeatureFlagsQueryFlags = binder.FirstCallTransaction + 3 TransactionIFeatureFlagsOverrideFlag = binder.FirstCallTransaction + 4 TransactionIFeatureFlagsResetFlag = binder.FirstCallTransaction + 5 )
const ( MethodIFeatureFlagsSyncFlags = "syncFlags" MethodIFeatureFlagsRegisterCallback = "registerCallback" MethodIFeatureFlagsUnregisterCallback = "unregisterCallback" MethodIFeatureFlagsQueryFlags = "queryFlags" MethodIFeatureFlagsOverrideFlag = "overrideFlag" MethodIFeatureFlagsResetFlag = "resetFlag" )
const DescriptorIFeatureFlags = "android.flags.IFeatureFlags"
const DescriptorIFeatureFlagsCallback = "android.flags.IFeatureFlagsCallback"
const (
MethodIFeatureFlagsCallbackOnFlagChange = "onFlagChange"
)
const (
TransactionIFeatureFlagsCallbackOnFlagChange = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FeatureFlagsCallbackProxy ¶
func NewFeatureFlagsCallbackProxy ¶
func NewFeatureFlagsCallbackProxy( remote binder.IBinder, ) *FeatureFlagsCallbackProxy
func (*FeatureFlagsCallbackProxy) AsBinder ¶
func (p *FeatureFlagsCallbackProxy) AsBinder() binder.IBinder
func (*FeatureFlagsCallbackProxy) OnFlagChange ¶
func (p *FeatureFlagsCallbackProxy) OnFlagChange( ctx context.Context, flag SyncableFlag, ) error
type FeatureFlagsCallbackStub ¶
type FeatureFlagsCallbackStub struct {
Impl IFeatureFlagsCallback
Transport binder.VersionAwareTransport
}
FeatureFlagsCallbackStub dispatches incoming binder transactions to a typed IFeatureFlagsCallback implementation.
func (*FeatureFlagsCallbackStub) Descriptor ¶
func (s *FeatureFlagsCallbackStub) Descriptor() string
func (*FeatureFlagsCallbackStub) OnTransaction ¶
func (s *FeatureFlagsCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type FeatureFlagsProxy ¶
func NewFeatureFlagsProxy ¶
func NewFeatureFlagsProxy( remote binder.IBinder, ) *FeatureFlagsProxy
func (*FeatureFlagsProxy) AsBinder ¶
func (p *FeatureFlagsProxy) AsBinder() binder.IBinder
func (*FeatureFlagsProxy) OverrideFlag ¶
func (p *FeatureFlagsProxy) OverrideFlag( ctx context.Context, flag SyncableFlag, ) error
func (*FeatureFlagsProxy) QueryFlags ¶
func (p *FeatureFlagsProxy) QueryFlags( ctx context.Context, flagList []SyncableFlag, ) ([]SyncableFlag, error)
func (*FeatureFlagsProxy) RegisterCallback ¶
func (p *FeatureFlagsProxy) RegisterCallback( ctx context.Context, callback IFeatureFlagsCallback, ) error
func (*FeatureFlagsProxy) ResetFlag ¶
func (p *FeatureFlagsProxy) ResetFlag( ctx context.Context, flag SyncableFlag, ) error
func (*FeatureFlagsProxy) SyncFlags ¶
func (p *FeatureFlagsProxy) SyncFlags( ctx context.Context, flagList []SyncableFlag, ) ([]SyncableFlag, error)
func (*FeatureFlagsProxy) UnregisterCallback ¶
func (p *FeatureFlagsProxy) UnregisterCallback( ctx context.Context, callback IFeatureFlagsCallback, ) error
type FeatureFlagsStub ¶
type FeatureFlagsStub struct {
Impl IFeatureFlags
Transport binder.VersionAwareTransport
}
FeatureFlagsStub dispatches incoming binder transactions to a typed IFeatureFlags implementation.
func (*FeatureFlagsStub) Descriptor ¶
func (s *FeatureFlagsStub) Descriptor() string
func (*FeatureFlagsStub) OnTransaction ¶
func (s *FeatureFlagsStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type IFeatureFlags ¶
type IFeatureFlags interface {
AsBinder() binder.IBinder
SyncFlags(ctx context.Context, flagList []SyncableFlag) ([]SyncableFlag, error)
RegisterCallback(ctx context.Context, callback IFeatureFlagsCallback) error
UnregisterCallback(ctx context.Context, callback IFeatureFlagsCallback) error
QueryFlags(ctx context.Context, flagList []SyncableFlag) ([]SyncableFlag, error)
OverrideFlag(ctx context.Context, flag SyncableFlag) error
ResetFlag(ctx context.Context, flag SyncableFlag) error
}
func NewFeatureFlagsStub ¶
func NewFeatureFlagsStub( impl IFeatureFlagsServer, ) IFeatureFlags
NewFeatureFlagsStub creates a server-side IFeatureFlags wrapping the given server implementation. The returned value satisfies IFeatureFlags and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IFeatureFlagsCallback ¶
type IFeatureFlagsCallback interface {
AsBinder() binder.IBinder
OnFlagChange(ctx context.Context, flag SyncableFlag) error
}
func NewFeatureFlagsCallbackStub ¶
func NewFeatureFlagsCallbackStub( impl IFeatureFlagsCallbackServer, ) IFeatureFlagsCallback
NewFeatureFlagsCallbackStub creates a server-side IFeatureFlagsCallback wrapping the given server implementation. The returned value satisfies IFeatureFlagsCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IFeatureFlagsCallbackServer ¶
type IFeatureFlagsCallbackServer interface {
OnFlagChange(ctx context.Context, flag SyncableFlag) error
}
IFeatureFlagsCallbackServer is the server-side interface that user implementations provide to NewFeatureFlagsCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IFeatureFlagsServer ¶
type IFeatureFlagsServer interface {
SyncFlags(ctx context.Context, flagList []SyncableFlag) ([]SyncableFlag, error)
RegisterCallback(ctx context.Context, callback IFeatureFlagsCallback) error
UnregisterCallback(ctx context.Context, callback IFeatureFlagsCallback) error
QueryFlags(ctx context.Context, flagList []SyncableFlag) ([]SyncableFlag, error)
OverrideFlag(ctx context.Context, flag SyncableFlag) error
ResetFlag(ctx context.Context, flag SyncableFlag) error
}
IFeatureFlagsServer is the server-side interface that user implementations provide to NewFeatureFlagsStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type SyncableFlag ¶
func (*SyncableFlag) MarshalParcel ¶
func (s *SyncableFlag) MarshalParcel( p *parcel.Parcel, ) error
func (*SyncableFlag) UnmarshalParcel ¶
func (s *SyncableFlag) UnmarshalParcel( p *parcel.Parcel, ) error