face

package
v0.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 28, 2026 License: CC0-1.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIFaceGetSensorProps = binder.FirstCallTransaction + 0
	TransactionIFaceCreateSession  = binder.FirstCallTransaction + 1
)
const (
	MethodIFaceGetSensorProps = "getSensorProps"
	MethodIFaceCreateSession  = "createSession"
)
const (
	TransactionISessionGenerateChallenge            = binder.FirstCallTransaction + 0
	TransactionISessionRevokeChallenge              = binder.FirstCallTransaction + 1
	TransactionISessionGetEnrollmentConfig          = binder.FirstCallTransaction + 2
	TransactionISessionEnroll                       = binder.FirstCallTransaction + 3
	TransactionISessionAuthenticate                 = binder.FirstCallTransaction + 4
	TransactionISessionDetectInteraction            = binder.FirstCallTransaction + 5
	TransactionISessionEnumerateEnrollments         = binder.FirstCallTransaction + 6
	TransactionISessionRemoveEnrollments            = binder.FirstCallTransaction + 7
	TransactionISessionGetFeatures                  = binder.FirstCallTransaction + 8
	TransactionISessionSetFeature                   = binder.FirstCallTransaction + 9
	TransactionISessionGetAuthenticatorId           = binder.FirstCallTransaction + 10
	TransactionISessionInvalidateAuthenticatorId    = binder.FirstCallTransaction + 11
	TransactionISessionResetLockout                 = binder.FirstCallTransaction + 12
	TransactionISessionClose                        = binder.FirstCallTransaction + 13
	TransactionISessionAuthenticateWithContext      = binder.FirstCallTransaction + 14
	TransactionISessionEnrollWithContext            = binder.FirstCallTransaction + 15
	TransactionISessionDetectInteractionWithContext = binder.FirstCallTransaction + 16
	TransactionISessionOnContextChanged             = binder.FirstCallTransaction + 17
	TransactionISessionEnrollWithOptions            = binder.FirstCallTransaction + 18
)
const (
	MethodISessionGenerateChallenge            = "generateChallenge"
	MethodISessionRevokeChallenge              = "revokeChallenge"
	MethodISessionGetEnrollmentConfig          = "getEnrollmentConfig"
	MethodISessionEnroll                       = "enroll"
	MethodISessionAuthenticate                 = "authenticate"
	MethodISessionDetectInteraction            = "detectInteraction"
	MethodISessionEnumerateEnrollments         = "enumerateEnrollments"
	MethodISessionRemoveEnrollments            = "removeEnrollments"
	MethodISessionGetFeatures                  = "getFeatures"
	MethodISessionSetFeature                   = "setFeature"
	MethodISessionGetAuthenticatorId           = "getAuthenticatorId"
	MethodISessionInvalidateAuthenticatorId    = "invalidateAuthenticatorId"
	MethodISessionResetLockout                 = "resetLockout"
	MethodISessionClose                        = "close"
	MethodISessionAuthenticateWithContext      = "authenticateWithContext"
	MethodISessionEnrollWithContext            = "enrollWithContext"
	MethodISessionDetectInteractionWithContext = "detectInteractionWithContext"
	MethodISessionOnContextChanged             = "onContextChanged"
	MethodISessionEnrollWithOptions            = "enrollWithOptions"
)
const (
	TransactionISessionCallbackOnChallengeGenerated         = binder.FirstCallTransaction + 0
	TransactionISessionCallbackOnChallengeRevoked           = binder.FirstCallTransaction + 1
	TransactionISessionCallbackOnAuthenticationFrame        = binder.FirstCallTransaction + 2
	TransactionISessionCallbackOnEnrollmentFrame            = binder.FirstCallTransaction + 3
	TransactionISessionCallbackOnError                      = binder.FirstCallTransaction + 4
	TransactionISessionCallbackOnEnrollmentProgress         = binder.FirstCallTransaction + 5
	TransactionISessionCallbackOnAuthenticationSucceeded    = binder.FirstCallTransaction + 6
	TransactionISessionCallbackOnAuthenticationFailed       = binder.FirstCallTransaction + 7
	TransactionISessionCallbackOnLockoutTimed               = binder.FirstCallTransaction + 8
	TransactionISessionCallbackOnLockoutPermanent           = binder.FirstCallTransaction + 9
	TransactionISessionCallbackOnLockoutCleared             = binder.FirstCallTransaction + 10
	TransactionISessionCallbackOnInteractionDetected        = binder.FirstCallTransaction + 11
	TransactionISessionCallbackOnEnrollmentsEnumerated      = binder.FirstCallTransaction + 12
	TransactionISessionCallbackOnFeaturesRetrieved          = binder.FirstCallTransaction + 13
	TransactionISessionCallbackOnFeatureSet                 = binder.FirstCallTransaction + 14
	TransactionISessionCallbackOnEnrollmentsRemoved         = binder.FirstCallTransaction + 15
	TransactionISessionCallbackOnAuthenticatorIdRetrieved   = binder.FirstCallTransaction + 16
	TransactionISessionCallbackOnAuthenticatorIdInvalidated = binder.FirstCallTransaction + 17
	TransactionISessionCallbackOnSessionClosed              = binder.FirstCallTransaction + 18
)
const (
	MethodISessionCallbackOnChallengeGenerated         = "onChallengeGenerated"
	MethodISessionCallbackOnChallengeRevoked           = "onChallengeRevoked"
	MethodISessionCallbackOnAuthenticationFrame        = "onAuthenticationFrame"
	MethodISessionCallbackOnEnrollmentFrame            = "onEnrollmentFrame"
	MethodISessionCallbackOnError                      = "onError"
	MethodISessionCallbackOnEnrollmentProgress         = "onEnrollmentProgress"
	MethodISessionCallbackOnAuthenticationSucceeded    = "onAuthenticationSucceeded"
	MethodISessionCallbackOnAuthenticationFailed       = "onAuthenticationFailed"
	MethodISessionCallbackOnLockoutTimed               = "onLockoutTimed"
	MethodISessionCallbackOnLockoutPermanent           = "onLockoutPermanent"
	MethodISessionCallbackOnLockoutCleared             = "onLockoutCleared"
	MethodISessionCallbackOnInteractionDetected        = "onInteractionDetected"
	MethodISessionCallbackOnEnrollmentsEnumerated      = "onEnrollmentsEnumerated"
	MethodISessionCallbackOnFeaturesRetrieved          = "onFeaturesRetrieved"
	MethodISessionCallbackOnFeatureSet                 = "onFeatureSet"
	MethodISessionCallbackOnEnrollmentsRemoved         = "onEnrollmentsRemoved"
	MethodISessionCallbackOnAuthenticatorIdRetrieved   = "onAuthenticatorIdRetrieved"
	MethodISessionCallbackOnAuthenticatorIdInvalidated = "onAuthenticatorIdInvalidated"
	MethodISessionCallbackOnSessionClosed              = "onSessionClosed"
)
const DescriptorIFace = "android.hardware.biometrics.face.IFace"
const DescriptorISession = "android.hardware.biometrics.face.ISession"
const DescriptorISessionCallback = "android.hardware.biometrics.face.ISessionCallback"

Variables

This section is empty.

Functions

This section is empty.

Types

type AcquiredInfo

type AcquiredInfo byte
const (
	AcquiredInfoUNKNOWN               AcquiredInfo = 0
	AcquiredInfoGOOD                  AcquiredInfo = 1
	AcquiredInfoINSUFFICIENT          AcquiredInfo = 2
	AcquiredInfoTooBright             AcquiredInfo = 3
	AcquiredInfoTooDark               AcquiredInfo = 4
	AcquiredInfoTooClose              AcquiredInfo = 5
	AcquiredInfoTooFar                AcquiredInfo = 6
	AcquiredInfoFaceTooHigh           AcquiredInfo = 7
	AcquiredInfoFaceTooLow            AcquiredInfo = 8
	AcquiredInfoFaceTooRight          AcquiredInfo = 9
	AcquiredInfoFaceTooLeft           AcquiredInfo = 10
	AcquiredInfoPoorGaze              AcquiredInfo = 11
	AcquiredInfoNotDetected           AcquiredInfo = 12
	AcquiredInfoTooMuchMotion         AcquiredInfo = 13
	AcquiredInfoRECALIBRATE           AcquiredInfo = 14
	AcquiredInfoTooDifferent          AcquiredInfo = 15
	AcquiredInfoTooSimilar            AcquiredInfo = 16
	AcquiredInfoPanTooExtreme         AcquiredInfo = 17
	AcquiredInfoTiltTooExtreme        AcquiredInfo = 18
	AcquiredInfoRollTooExtreme        AcquiredInfo = 19
	AcquiredInfoFaceObscured          AcquiredInfo = 20
	AcquiredInfoSTART                 AcquiredInfo = 21
	AcquiredInfoSensorDirty           AcquiredInfo = 22
	AcquiredInfoVENDOR                AcquiredInfo = 23
	AcquiredInfoFirstFrameReceived    AcquiredInfo = 24
	AcquiredInfoDarkGlassesDetected   AcquiredInfo = 25
	AcquiredInfoMouthCoveringDetected AcquiredInfo = 26
)

type AuthenticationFrame

type AuthenticationFrame struct {
	Data BaseFrame
}

func (*AuthenticationFrame) MarshalParcel

func (s *AuthenticationFrame) MarshalParcel(
	p *parcel.Parcel,
) error

func (*AuthenticationFrame) UnmarshalParcel

func (s *AuthenticationFrame) UnmarshalParcel(
	p *parcel.Parcel,
) error

type BaseFrame

type BaseFrame struct {
	AcquiredInfo  AcquiredInfo
	VendorCode    int32
	Pan           float32
	Tilt          float32
	Distance      float32
	IsCancellable bool
}

func (*BaseFrame) MarshalParcel

func (s *BaseFrame) MarshalParcel(
	p *parcel.Parcel,
) error

func (*BaseFrame) UnmarshalParcel

func (s *BaseFrame) UnmarshalParcel(
	p *parcel.Parcel,
) error

type Cell

type Cell struct {
	X int32
	Y int32
	Z int32
}

func (*Cell) MarshalParcel

func (s *Cell) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Cell) UnmarshalParcel

func (s *Cell) UnmarshalParcel(
	p *parcel.Parcel,
) error

type EnrollmentFrame

type EnrollmentFrame struct {
	Cell  *Cell
	Stage EnrollmentStage
	Data  BaseFrame
}

func (*EnrollmentFrame) MarshalParcel

func (s *EnrollmentFrame) MarshalParcel(
	p *parcel.Parcel,
) error

func (*EnrollmentFrame) UnmarshalParcel

func (s *EnrollmentFrame) UnmarshalParcel(
	p *parcel.Parcel,
) error

type EnrollmentStage

type EnrollmentStage byte
const (
	EnrollmentStageUNKNOWN             EnrollmentStage = 0
	EnrollmentStageFirstFrameReceived  EnrollmentStage = 1
	EnrollmentStageWaitingForCentering EnrollmentStage = 2
	EnrollmentStageHoldStillInCenter   EnrollmentStage = 3
	EnrollmentStageEnrollingMovement1  EnrollmentStage = 4
	EnrollmentStageEnrollingMovement2  EnrollmentStage = 5
	EnrollmentStageEnrollmentFinished  EnrollmentStage = 6
)

type EnrollmentStageConfig

type EnrollmentStageConfig struct {
	Stage EnrollmentStage
	Cells []Cell
}

func (*EnrollmentStageConfig) MarshalParcel

func (s *EnrollmentStageConfig) MarshalParcel(
	p *parcel.Parcel,
) error

func (*EnrollmentStageConfig) UnmarshalParcel

func (s *EnrollmentStageConfig) UnmarshalParcel(
	p *parcel.Parcel,
) error

type EnrollmentType

type EnrollmentType byte
const (
	EnrollmentTypeDEFAULT       EnrollmentType = 0
	EnrollmentTypeACCESSIBILITY EnrollmentType = 1
)

type Error

type Error byte
const (
	ErrorUNKNOWN          Error = 0
	ErrorHwUnavailable    Error = 1
	ErrorUnableToProcess  Error = 2
	ErrorTIMEOUT          Error = 3
	ErrorNoSpace          Error = 4
	ErrorCANCELED         Error = 5
	ErrorUnableToRemove   Error = 6
	ErrorVENDOR           Error = 7
	ErrorReenrollRequired Error = 8
)

type FaceEnrollOptions

type FaceEnrollOptions struct {
	HardwareAuthToken   keymaster.HardwareAuthToken
	EnrollmentType      EnrollmentType
	Features            []Feature
	NativeHandlePreview *common.NativeHandle
	SurfacePreview      *view.Surface
	Context             *biometricsCommon.OperationContext
}

func (*FaceEnrollOptions) MarshalParcel

func (s *FaceEnrollOptions) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FaceEnrollOptions) UnmarshalParcel

func (s *FaceEnrollOptions) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FaceProxy

type FaceProxy struct {
	Remote binder.IBinder
}

func NewFaceProxy

func NewFaceProxy(
	remote binder.IBinder,
) *FaceProxy

func (*FaceProxy) AsBinder

func (p *FaceProxy) AsBinder() binder.IBinder

func (*FaceProxy) CreateSession

func (p *FaceProxy) CreateSession(
	ctx context.Context,
	sensorId int32,
	cb ISessionCallback,
) (ISession, error)

func (*FaceProxy) GetSensorProps

func (p *FaceProxy) GetSensorProps(
	ctx context.Context,
) ([]SensorProps, error)

type FaceSensorType

type FaceSensorType byte
const (
	FaceSensorTypeUNKNOWN FaceSensorType = 0
	FaceSensorTypeRGB     FaceSensorType = 1
	FaceSensorTypeIR      FaceSensorType = 2
)

type FaceStub

type FaceStub struct {
	Impl      IFace
	Transport binder.VersionAwareTransport
}

FaceStub dispatches incoming binder transactions to a typed IFace implementation.

func (*FaceStub) Descriptor

func (s *FaceStub) Descriptor() string

func (*FaceStub) OnTransaction

func (s *FaceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type Feature

type Feature byte
const (
	FeatureRequireAttention    Feature = 0
	FeatureRequireDiversePoses Feature = 1
	FeatureDEBUG               Feature = 2
)

type IFace

type IFace interface {
	AsBinder() binder.IBinder
	GetSensorProps(ctx context.Context) ([]SensorProps, error)
	CreateSession(ctx context.Context, sensorId int32, cb ISessionCallback) (ISession, error)
}

func NewFaceStub

func NewFaceStub(
	impl IFaceServer,
) IFace

NewFaceStub creates a server-side IFace wrapping the given server implementation. The returned value satisfies IFace and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IFaceServer

type IFaceServer interface {
	GetSensorProps(ctx context.Context) ([]SensorProps, error)
	CreateSession(ctx context.Context, sensorId int32, cb ISessionCallback) (ISession, error)
}

IFaceServer is the server-side interface that user implementations provide to NewFaceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISession

type ISession interface {
	AsBinder() binder.IBinder
	GenerateChallenge(ctx context.Context) error
	RevokeChallenge(ctx context.Context, challenge int64) error
	GetEnrollmentConfig(ctx context.Context, enrollmentType EnrollmentType) ([]EnrollmentStageConfig, error)
	Enroll(ctx context.Context, hat keymaster.HardwareAuthToken, type_ EnrollmentType, features []Feature, previewSurface *common.NativeHandle) (biometricsCommon.ICancellationSignal, error)
	Authenticate(ctx context.Context, operationId int64) (biometricsCommon.ICancellationSignal, error)
	DetectInteraction(ctx context.Context) (biometricsCommon.ICancellationSignal, error)
	EnumerateEnrollments(ctx context.Context) error
	RemoveEnrollments(ctx context.Context, enrollmentIds []int32) error
	GetFeatures(ctx context.Context) error
	SetFeature(ctx context.Context, hat keymaster.HardwareAuthToken, feature Feature, enabled bool) error
	GetAuthenticatorId(ctx context.Context) error
	InvalidateAuthenticatorId(ctx context.Context) error
	ResetLockout(ctx context.Context, hat keymaster.HardwareAuthToken) error
	Close(ctx context.Context) error
	AuthenticateWithContext(ctx context.Context, operationId int64, context_ biometricsCommon.OperationContext) (biometricsCommon.ICancellationSignal, error)
	EnrollWithContext(ctx context.Context, hat keymaster.HardwareAuthToken, type_ EnrollmentType, features []Feature, previewSurface *common.NativeHandle, context_ biometricsCommon.OperationContext) (biometricsCommon.ICancellationSignal, error)
	DetectInteractionWithContext(ctx context.Context, context_ biometricsCommon.OperationContext) (biometricsCommon.ICancellationSignal, error)
	OnContextChanged(ctx context.Context, context_ biometricsCommon.OperationContext) error
	EnrollWithOptions(ctx context.Context, options FaceEnrollOptions) (biometricsCommon.ICancellationSignal, error)
}

func NewSessionStub

func NewSessionStub(
	impl ISessionServer,
) ISession

NewSessionStub creates a server-side ISession wrapping the given server implementation. The returned value satisfies ISession and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISessionCallback

type ISessionCallback interface {
	AsBinder() binder.IBinder
	OnChallengeGenerated(ctx context.Context, challenge int64) error
	OnChallengeRevoked(ctx context.Context, challenge int64) error
	OnAuthenticationFrame(ctx context.Context, frame AuthenticationFrame) error
	OnEnrollmentFrame(ctx context.Context, frame EnrollmentFrame) error
	OnError(ctx context.Context, error_ Error, vendorCode int32) error
	OnEnrollmentProgress(ctx context.Context, enrollmentId int32, remaining int32) error
	OnAuthenticationSucceeded(ctx context.Context, enrollmentId int32, hat keymaster.HardwareAuthToken) error
	OnAuthenticationFailed(ctx context.Context) error
	OnLockoutTimed(ctx context.Context, durationMillis int64) error
	OnLockoutPermanent(ctx context.Context) error
	OnLockoutCleared(ctx context.Context) error
	OnInteractionDetected(ctx context.Context) error
	OnEnrollmentsEnumerated(ctx context.Context, enrollmentIds []int32) error
	OnFeaturesRetrieved(ctx context.Context, features []Feature) error
	OnFeatureSet(ctx context.Context, feature Feature) error
	OnEnrollmentsRemoved(ctx context.Context, enrollmentIds []int32) error
	OnAuthenticatorIdRetrieved(ctx context.Context, authenticatorId int64) error
	OnAuthenticatorIdInvalidated(ctx context.Context, newAuthenticatorId int64) error
	OnSessionClosed(ctx context.Context) error
}

func NewSessionCallbackStub

func NewSessionCallbackStub(
	impl ISessionCallbackServer,
) ISessionCallback

NewSessionCallbackStub creates a server-side ISessionCallback wrapping the given server implementation. The returned value satisfies ISessionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISessionCallbackServer

type ISessionCallbackServer interface {
	OnChallengeGenerated(ctx context.Context, challenge int64) error
	OnChallengeRevoked(ctx context.Context, challenge int64) error
	OnAuthenticationFrame(ctx context.Context, frame AuthenticationFrame) error
	OnEnrollmentFrame(ctx context.Context, frame EnrollmentFrame) error
	OnError(ctx context.Context, error_ Error, vendorCode int32) error
	OnEnrollmentProgress(ctx context.Context, enrollmentId int32, remaining int32) error
	OnAuthenticationSucceeded(ctx context.Context, enrollmentId int32, hat keymaster.HardwareAuthToken) error
	OnAuthenticationFailed(ctx context.Context) error
	OnLockoutTimed(ctx context.Context, durationMillis int64) error
	OnLockoutPermanent(ctx context.Context) error
	OnLockoutCleared(ctx context.Context) error
	OnInteractionDetected(ctx context.Context) error
	OnEnrollmentsEnumerated(ctx context.Context, enrollmentIds []int32) error
	OnFeaturesRetrieved(ctx context.Context, features []Feature) error
	OnFeatureSet(ctx context.Context, feature Feature) error
	OnEnrollmentsRemoved(ctx context.Context, enrollmentIds []int32) error
	OnAuthenticatorIdRetrieved(ctx context.Context, authenticatorId int64) error
	OnAuthenticatorIdInvalidated(ctx context.Context, newAuthenticatorId int64) error
	OnSessionClosed(ctx context.Context) error
}

ISessionCallbackServer is the server-side interface that user implementations provide to NewSessionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISessionServer

type ISessionServer interface {
	GenerateChallenge(ctx context.Context) error
	RevokeChallenge(ctx context.Context, challenge int64) error
	GetEnrollmentConfig(ctx context.Context, enrollmentType EnrollmentType) ([]EnrollmentStageConfig, error)
	Enroll(ctx context.Context, hat keymaster.HardwareAuthToken, type_ EnrollmentType, features []Feature, previewSurface *common.NativeHandle) (biometricsCommon.ICancellationSignal, error)
	Authenticate(ctx context.Context, operationId int64) (biometricsCommon.ICancellationSignal, error)
	DetectInteraction(ctx context.Context) (biometricsCommon.ICancellationSignal, error)
	EnumerateEnrollments(ctx context.Context) error
	RemoveEnrollments(ctx context.Context, enrollmentIds []int32) error
	GetFeatures(ctx context.Context) error
	SetFeature(ctx context.Context, hat keymaster.HardwareAuthToken, feature Feature, enabled bool) error
	GetAuthenticatorId(ctx context.Context) error
	InvalidateAuthenticatorId(ctx context.Context) error
	ResetLockout(ctx context.Context, hat keymaster.HardwareAuthToken) error
	Close(ctx context.Context) error
	AuthenticateWithContext(ctx context.Context, operationId int64, context_ biometricsCommon.OperationContext) (biometricsCommon.ICancellationSignal, error)
	EnrollWithContext(ctx context.Context, hat keymaster.HardwareAuthToken, type_ EnrollmentType, features []Feature, previewSurface *common.NativeHandle, context_ biometricsCommon.OperationContext) (biometricsCommon.ICancellationSignal, error)
	DetectInteractionWithContext(ctx context.Context, context_ biometricsCommon.OperationContext) (biometricsCommon.ICancellationSignal, error)
	OnContextChanged(ctx context.Context, context_ biometricsCommon.OperationContext) error
	EnrollWithOptions(ctx context.Context, options FaceEnrollOptions) (biometricsCommon.ICancellationSignal, error)
}

ISessionServer is the server-side interface that user implementations provide to NewSessionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type SensorProps

type SensorProps struct {
	CommonProps               common.CommonProps
	SensorType                FaceSensorType
	HalControlsPreview        bool
	PreviewDisplayId          int32
	EnrollPreviewWidth        int32
	EnrollPreviewHeight       int32
	EnrollTranslationX        float32
	EnrollTranslationY        float32
	EnrollPreviewScale        float32
	SupportsDetectInteraction bool
}

func (*SensorProps) MarshalParcel

func (s *SensorProps) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SensorProps) UnmarshalParcel

func (s *SensorProps) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SessionCallbackProxy

type SessionCallbackProxy struct {
	Remote binder.IBinder
}

func NewSessionCallbackProxy

func NewSessionCallbackProxy(
	remote binder.IBinder,
) *SessionCallbackProxy

func (*SessionCallbackProxy) AsBinder

func (p *SessionCallbackProxy) AsBinder() binder.IBinder

func (*SessionCallbackProxy) OnAuthenticationFailed

func (p *SessionCallbackProxy) OnAuthenticationFailed(
	ctx context.Context,
) error

func (*SessionCallbackProxy) OnAuthenticationFrame

func (p *SessionCallbackProxy) OnAuthenticationFrame(
	ctx context.Context,
	frame AuthenticationFrame,
) error

func (*SessionCallbackProxy) OnAuthenticationSucceeded

func (p *SessionCallbackProxy) OnAuthenticationSucceeded(
	ctx context.Context,
	enrollmentId int32,
	hat keymaster.HardwareAuthToken,
) error

func (*SessionCallbackProxy) OnAuthenticatorIdInvalidated

func (p *SessionCallbackProxy) OnAuthenticatorIdInvalidated(
	ctx context.Context,
	newAuthenticatorId int64,
) error

func (*SessionCallbackProxy) OnAuthenticatorIdRetrieved

func (p *SessionCallbackProxy) OnAuthenticatorIdRetrieved(
	ctx context.Context,
	authenticatorId int64,
) error

func (*SessionCallbackProxy) OnChallengeGenerated

func (p *SessionCallbackProxy) OnChallengeGenerated(
	ctx context.Context,
	challenge int64,
) error

func (*SessionCallbackProxy) OnChallengeRevoked

func (p *SessionCallbackProxy) OnChallengeRevoked(
	ctx context.Context,
	challenge int64,
) error

func (*SessionCallbackProxy) OnEnrollmentFrame

func (p *SessionCallbackProxy) OnEnrollmentFrame(
	ctx context.Context,
	frame EnrollmentFrame,
) error

func (*SessionCallbackProxy) OnEnrollmentProgress

func (p *SessionCallbackProxy) OnEnrollmentProgress(
	ctx context.Context,
	enrollmentId int32,
	remaining int32,
) error

func (*SessionCallbackProxy) OnEnrollmentsEnumerated

func (p *SessionCallbackProxy) OnEnrollmentsEnumerated(
	ctx context.Context,
	enrollmentIds []int32,
) error

func (*SessionCallbackProxy) OnEnrollmentsRemoved

func (p *SessionCallbackProxy) OnEnrollmentsRemoved(
	ctx context.Context,
	enrollmentIds []int32,
) error

func (*SessionCallbackProxy) OnError

func (p *SessionCallbackProxy) OnError(
	ctx context.Context,
	error_ Error,
	vendorCode int32,
) error

func (*SessionCallbackProxy) OnFeatureSet

func (p *SessionCallbackProxy) OnFeatureSet(
	ctx context.Context,
	feature Feature,
) error

func (*SessionCallbackProxy) OnFeaturesRetrieved

func (p *SessionCallbackProxy) OnFeaturesRetrieved(
	ctx context.Context,
	features []Feature,
) error

func (*SessionCallbackProxy) OnInteractionDetected

func (p *SessionCallbackProxy) OnInteractionDetected(
	ctx context.Context,
) error

func (*SessionCallbackProxy) OnLockoutCleared

func (p *SessionCallbackProxy) OnLockoutCleared(
	ctx context.Context,
) error

func (*SessionCallbackProxy) OnLockoutPermanent

func (p *SessionCallbackProxy) OnLockoutPermanent(
	ctx context.Context,
) error

func (*SessionCallbackProxy) OnLockoutTimed

func (p *SessionCallbackProxy) OnLockoutTimed(
	ctx context.Context,
	durationMillis int64,
) error

func (*SessionCallbackProxy) OnSessionClosed

func (p *SessionCallbackProxy) OnSessionClosed(
	ctx context.Context,
) error

type SessionCallbackStub

type SessionCallbackStub struct {
	Impl      ISessionCallback
	Transport binder.VersionAwareTransport
}

SessionCallbackStub dispatches incoming binder transactions to a typed ISessionCallback implementation.

func (*SessionCallbackStub) Descriptor

func (s *SessionCallbackStub) Descriptor() string

func (*SessionCallbackStub) OnTransaction

func (s *SessionCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type SessionProxy

type SessionProxy struct {
	Remote binder.IBinder
}

func NewSessionProxy

func NewSessionProxy(
	remote binder.IBinder,
) *SessionProxy

func (*SessionProxy) AsBinder

func (p *SessionProxy) AsBinder() binder.IBinder

func (*SessionProxy) Authenticate

func (p *SessionProxy) Authenticate(
	ctx context.Context,
	operationId int64,
) (biometricsCommon.ICancellationSignal, error)

func (*SessionProxy) AuthenticateWithContext

func (p *SessionProxy) AuthenticateWithContext(
	ctx context.Context,
	operationId int64,
	context_ biometricsCommon.OperationContext,
) (biometricsCommon.ICancellationSignal, error)

func (*SessionProxy) Close

func (p *SessionProxy) Close(
	ctx context.Context,
) error

func (*SessionProxy) DetectInteraction

func (p *SessionProxy) DetectInteraction(
	ctx context.Context,
) (biometricsCommon.ICancellationSignal, error)

func (*SessionProxy) DetectInteractionWithContext

func (p *SessionProxy) DetectInteractionWithContext(
	ctx context.Context,
	context_ biometricsCommon.OperationContext,
) (biometricsCommon.ICancellationSignal, error)

func (*SessionProxy) Enroll

func (*SessionProxy) EnrollWithContext

func (*SessionProxy) EnrollWithOptions

func (p *SessionProxy) EnrollWithOptions(
	ctx context.Context,
	options FaceEnrollOptions,
) (biometricsCommon.ICancellationSignal, error)

func (*SessionProxy) EnumerateEnrollments

func (p *SessionProxy) EnumerateEnrollments(
	ctx context.Context,
) error

func (*SessionProxy) GenerateChallenge

func (p *SessionProxy) GenerateChallenge(
	ctx context.Context,
) error

func (*SessionProxy) GetAuthenticatorId

func (p *SessionProxy) GetAuthenticatorId(
	ctx context.Context,
) error

func (*SessionProxy) GetEnrollmentConfig

func (p *SessionProxy) GetEnrollmentConfig(
	ctx context.Context,
	enrollmentType EnrollmentType,
) ([]EnrollmentStageConfig, error)

func (*SessionProxy) GetFeatures

func (p *SessionProxy) GetFeatures(
	ctx context.Context,
) error

func (*SessionProxy) InvalidateAuthenticatorId

func (p *SessionProxy) InvalidateAuthenticatorId(
	ctx context.Context,
) error

func (*SessionProxy) OnContextChanged

func (p *SessionProxy) OnContextChanged(
	ctx context.Context,
	context_ biometricsCommon.OperationContext,
) error

func (*SessionProxy) RemoveEnrollments

func (p *SessionProxy) RemoveEnrollments(
	ctx context.Context,
	enrollmentIds []int32,
) error

func (*SessionProxy) ResetLockout

func (p *SessionProxy) ResetLockout(
	ctx context.Context,
	hat keymaster.HardwareAuthToken,
) error

func (*SessionProxy) RevokeChallenge

func (p *SessionProxy) RevokeChallenge(
	ctx context.Context,
	challenge int64,
) error

func (*SessionProxy) SetFeature

func (p *SessionProxy) SetFeature(
	ctx context.Context,
	hat keymaster.HardwareAuthToken,
	feature Feature,
	enabled bool,
) error

type SessionStub

type SessionStub struct {
	Impl      ISession
	Transport binder.VersionAwareTransport
}

SessionStub dispatches incoming binder transactions to a typed ISession implementation.

func (*SessionStub) Descriptor

func (s *SessionStub) Descriptor() string

func (*SessionStub) OnTransaction

func (s *SessionStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to