Documentation
¶
Index ¶
- Constants
- type CameraDeviceCallbacksProxy
- func (p *CameraDeviceCallbacksProxy) AsBinder() binder.IBinder
- func (p *CameraDeviceCallbacksProxy) OnCaptureStarted(ctx context.Context, resultExtras impl.CaptureResultExtras, timestamp int64) error
- func (p *CameraDeviceCallbacksProxy) OnDeviceError(ctx context.Context, errorCode int32, resultExtras impl.CaptureResultExtras) error
- func (p *CameraDeviceCallbacksProxy) OnDeviceIdle(ctx context.Context) error
- func (p *CameraDeviceCallbacksProxy) OnPrepared(ctx context.Context, streamId int32) error
- func (p *CameraDeviceCallbacksProxy) OnRepeatingRequestError(ctx context.Context, lastFrameNumber int64, repeatingRequestId int32) error
- func (p *CameraDeviceCallbacksProxy) OnRequestQueueEmpty(ctx context.Context) error
- func (p *CameraDeviceCallbacksProxy) OnResultReceived(ctx context.Context, result impl.CameraMetadataNative, ...) error
- type CameraDeviceCallbacksStub
- type CameraDeviceUserProxy
- func (p *CameraDeviceUserProxy) AsBinder() binder.IBinder
- func (p *CameraDeviceUserProxy) BeginConfigure(ctx context.Context) error
- func (p *CameraDeviceUserProxy) CancelRequest(ctx context.Context, requestId int32) (int64, error)
- func (p *CameraDeviceUserProxy) CreateDefaultRequest(ctx context.Context, templateId int32) (impl.CameraMetadataNative, error)
- func (p *CameraDeviceUserProxy) CreateInputStream(ctx context.Context, width int32, height int32, format int32, ...) (int32, error)
- func (p *CameraDeviceUserProxy) CreateStream(ctx context.Context, outputConfiguration params.OutputConfiguration) (int32, error)
- func (p *CameraDeviceUserProxy) DeleteStream(ctx context.Context, streamId int32) error
- func (p *CameraDeviceUserProxy) Disconnect(ctx context.Context) error
- func (p *CameraDeviceUserProxy) EndConfigure(ctx context.Context, operatingMode int32, ...) ([]int32, error)
- func (p *CameraDeviceUserProxy) FinalizeOutputConfigurations(ctx context.Context, streamId int32, ...) error
- func (p *CameraDeviceUserProxy) Flush(ctx context.Context) (int64, error)
- func (p *CameraDeviceUserProxy) GetCameraInfo(ctx context.Context) (impl.CameraMetadataNative, error)
- func (p *CameraDeviceUserProxy) GetGlobalAudioRestriction(ctx context.Context) (int32, error)
- func (p *CameraDeviceUserProxy) GetInputSurface(ctx context.Context) (view.Surface, error)
- func (p *CameraDeviceUserProxy) IsSessionConfigurationSupported(ctx context.Context, sessionConfiguration params.SessionConfiguration) (bool, error)
- func (p *CameraDeviceUserProxy) Prepare(ctx context.Context, streamId int32) error
- func (p *CameraDeviceUserProxy) Prepare2(ctx context.Context, maxCount int32, streamId int32) error
- func (p *CameraDeviceUserProxy) SetCameraAudioRestriction(ctx context.Context, mode int32) error
- func (p *CameraDeviceUserProxy) SubmitRequest(ctx context.Context, request CaptureRequest, streaming bool) (utils.SubmitInfo, error)
- func (p *CameraDeviceUserProxy) SubmitRequestList(ctx context.Context, requestList []CaptureRequest, streaming bool) (utils.SubmitInfo, error)
- func (p *CameraDeviceUserProxy) SwitchToOffline(ctx context.Context, callbacks ICameraDeviceCallbacks, ...) (ICameraOfflineSession, error)
- func (p *CameraDeviceUserProxy) TearDown(ctx context.Context, streamId int32) error
- func (p *CameraDeviceUserProxy) UpdateOutputConfiguration(ctx context.Context, streamId int32, ...) error
- func (p *CameraDeviceUserProxy) WaitUntilIdle(ctx context.Context) error
- type CameraDeviceUserStub
- type CameraInjectionCallbackProxy
- type CameraInjectionCallbackStub
- type CameraInjectionSessionProxy
- type CameraInjectionSessionStub
- type CameraOfflineSessionProxy
- type CameraOfflineSessionStub
- type CaptureRequest
- type ICameraDeviceCallbacks
- type ICameraDeviceCallbacksServer
- type ICameraDeviceUser
- type ICameraDeviceUserServer
- type ICameraInjectionCallback
- type ICameraInjectionCallbackServer
- type ICameraInjectionSession
- type ICameraInjectionSessionServer
- type ICameraOfflineSession
- type ICameraOfflineSessionServer
Constants ¶
const ( TransactionICameraDeviceCallbacksOnDeviceError = binder.FirstCallTransaction + 0 TransactionICameraDeviceCallbacksOnDeviceIdle = binder.FirstCallTransaction + 1 TransactionICameraDeviceCallbacksOnCaptureStarted = binder.FirstCallTransaction + 2 TransactionICameraDeviceCallbacksOnResultReceived = binder.FirstCallTransaction + 3 TransactionICameraDeviceCallbacksOnPrepared = binder.FirstCallTransaction + 4 TransactionICameraDeviceCallbacksOnRepeatingRequestError = binder.FirstCallTransaction + 5 TransactionICameraDeviceCallbacksOnRequestQueueEmpty = binder.FirstCallTransaction + 6 )
const ( MethodICameraDeviceCallbacksOnDeviceError = "onDeviceError" MethodICameraDeviceCallbacksOnDeviceIdle = "onDeviceIdle" MethodICameraDeviceCallbacksOnCaptureStarted = "onCaptureStarted" MethodICameraDeviceCallbacksOnResultReceived = "onResultReceived" MethodICameraDeviceCallbacksOnPrepared = "onPrepared" MethodICameraDeviceCallbacksOnRepeatingRequestError = "onRepeatingRequestError" MethodICameraDeviceCallbacksOnRequestQueueEmpty = "onRequestQueueEmpty" )
const ( ICameraDeviceCallbacksErrorCameraInvalidError int32 = -1 ICameraDeviceCallbacksErrorCameraDisconnected int32 = 0 ICameraDeviceCallbacksErrorCameraDevice int32 = 1 ICameraDeviceCallbacksErrorCameraService int32 = 2 ICameraDeviceCallbacksErrorCameraRequest int32 = 3 ICameraDeviceCallbacksErrorCameraResult int32 = 4 ICameraDeviceCallbacksErrorCameraBuffer int32 = 5 ICameraDeviceCallbacksErrorCameraDisabled int32 = 6 )
const ( TransactionICameraDeviceUserDisconnect = binder.FirstCallTransaction + 0 TransactionICameraDeviceUserSubmitRequest = binder.FirstCallTransaction + 1 TransactionICameraDeviceUserSubmitRequestList = binder.FirstCallTransaction + 2 TransactionICameraDeviceUserCancelRequest = binder.FirstCallTransaction + 3 TransactionICameraDeviceUserBeginConfigure = binder.FirstCallTransaction + 4 TransactionICameraDeviceUserEndConfigure = binder.FirstCallTransaction + 5 TransactionICameraDeviceUserIsSessionConfigurationSupported = binder.FirstCallTransaction + 6 TransactionICameraDeviceUserDeleteStream = binder.FirstCallTransaction + 7 TransactionICameraDeviceUserCreateStream = binder.FirstCallTransaction + 8 TransactionICameraDeviceUserCreateInputStream = binder.FirstCallTransaction + 9 TransactionICameraDeviceUserGetInputSurface = binder.FirstCallTransaction + 10 TransactionICameraDeviceUserCreateDefaultRequest = binder.FirstCallTransaction + 11 TransactionICameraDeviceUserGetCameraInfo = binder.FirstCallTransaction + 12 TransactionICameraDeviceUserWaitUntilIdle = binder.FirstCallTransaction + 13 TransactionICameraDeviceUserFlush = binder.FirstCallTransaction + 14 TransactionICameraDeviceUserPrepare = binder.FirstCallTransaction + 15 TransactionICameraDeviceUserTearDown = binder.FirstCallTransaction + 16 TransactionICameraDeviceUserPrepare2 = binder.FirstCallTransaction + 17 TransactionICameraDeviceUserUpdateOutputConfiguration = binder.FirstCallTransaction + 18 TransactionICameraDeviceUserFinalizeOutputConfigurations = binder.FirstCallTransaction + 19 TransactionICameraDeviceUserSetCameraAudioRestriction = binder.FirstCallTransaction + 20 TransactionICameraDeviceUserGetGlobalAudioRestriction = binder.FirstCallTransaction + 21 TransactionICameraDeviceUserSwitchToOffline = binder.FirstCallTransaction + 22 )
const ( MethodICameraDeviceUserDisconnect = "disconnect" MethodICameraDeviceUserSubmitRequest = "submitRequest" MethodICameraDeviceUserSubmitRequestList = "submitRequestList" MethodICameraDeviceUserCancelRequest = "cancelRequest" MethodICameraDeviceUserBeginConfigure = "beginConfigure" MethodICameraDeviceUserEndConfigure = "endConfigure" MethodICameraDeviceUserIsSessionConfigurationSupported = "isSessionConfigurationSupported" MethodICameraDeviceUserDeleteStream = "deleteStream" MethodICameraDeviceUserCreateStream = "createStream" MethodICameraDeviceUserCreateInputStream = "createInputStream" MethodICameraDeviceUserGetInputSurface = "getInputSurface" MethodICameraDeviceUserCreateDefaultRequest = "createDefaultRequest" MethodICameraDeviceUserGetCameraInfo = "getCameraInfo" MethodICameraDeviceUserWaitUntilIdle = "waitUntilIdle" MethodICameraDeviceUserFlush = "flush" MethodICameraDeviceUserPrepare = "prepare" MethodICameraDeviceUserTearDown = "tearDown" MethodICameraDeviceUserPrepare2 = "prepare2" MethodICameraDeviceUserUpdateOutputConfiguration = "updateOutputConfiguration" MethodICameraDeviceUserFinalizeOutputConfigurations = "finalizeOutputConfigurations" MethodICameraDeviceUserSetCameraAudioRestriction = "setCameraAudioRestriction" MethodICameraDeviceUserGetGlobalAudioRestriction = "getGlobalAudioRestriction" MethodICameraDeviceUserSwitchToOffline = "switchToOffline" )
const ( ICameraDeviceUserNoInFlightRepeatingFrames int32 = -1 ICameraDeviceUserNormalMode int32 = 0 ICameraDeviceUserConstrainedHighSpeedMode int32 = 1 ICameraDeviceUserVendorModeStart int32 = 32768 ICameraDeviceUserTemplatePreview int32 = 1 ICameraDeviceUserTemplateStillCapture int32 = 2 ICameraDeviceUserTemplateRecord int32 = 3 ICameraDeviceUserTemplateVideoSnapshot int32 = 4 ICameraDeviceUserTemplateZeroShutterLag int32 = 5 ICameraDeviceUserTemplateManual int32 = 6 ICameraDeviceUserAudioRestrictionNone int32 = 0 ICameraDeviceUserAudioRestrictionVibration int32 = 1 ICameraDeviceUserAudioRestrictionVibrationSound int32 = 3 )
const ( ICameraInjectionCallbackErrorInjectionInvalidError int32 = -1 ICameraInjectionCallbackErrorInjectionSession int32 = 0 ICameraInjectionCallbackErrorInjectionService int32 = 1 ICameraInjectionCallbackErrorInjectionUnsupported int32 = 2 )
const DescriptorICameraDeviceCallbacks = "android.hardware.camera2.ICameraDeviceCallbacks"
const DescriptorICameraDeviceUser = "android.hardware.camera2.ICameraDeviceUser"
const DescriptorICameraInjectionCallback = "android.hardware.camera2.ICameraInjectionCallback"
const DescriptorICameraInjectionSession = "android.hardware.camera2.ICameraInjectionSession"
const DescriptorICameraOfflineSession = "android.hardware.camera2.ICameraOfflineSession"
const (
MethodICameraInjectionCallbackOnInjectionError = "onInjectionError"
)
const (
MethodICameraInjectionSessionStopInjection = "stopInjection"
)
const (
MethodICameraOfflineSessionDisconnect = "disconnect"
)
const (
TransactionICameraInjectionCallbackOnInjectionError = binder.FirstCallTransaction + 0
)
const (
TransactionICameraInjectionSessionStopInjection = binder.FirstCallTransaction + 0
)
const (
TransactionICameraOfflineSessionDisconnect = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CameraDeviceCallbacksProxy ¶
func NewCameraDeviceCallbacksProxy ¶
func NewCameraDeviceCallbacksProxy( remote binder.IBinder, ) *CameraDeviceCallbacksProxy
func (*CameraDeviceCallbacksProxy) AsBinder ¶
func (p *CameraDeviceCallbacksProxy) AsBinder() binder.IBinder
func (*CameraDeviceCallbacksProxy) OnCaptureStarted ¶
func (p *CameraDeviceCallbacksProxy) OnCaptureStarted( ctx context.Context, resultExtras impl.CaptureResultExtras, timestamp int64, ) error
func (*CameraDeviceCallbacksProxy) OnDeviceError ¶
func (p *CameraDeviceCallbacksProxy) OnDeviceError( ctx context.Context, errorCode int32, resultExtras impl.CaptureResultExtras, ) error
func (*CameraDeviceCallbacksProxy) OnDeviceIdle ¶
func (p *CameraDeviceCallbacksProxy) OnDeviceIdle( ctx context.Context, ) error
func (*CameraDeviceCallbacksProxy) OnPrepared ¶
func (p *CameraDeviceCallbacksProxy) OnPrepared( ctx context.Context, streamId int32, ) error
func (*CameraDeviceCallbacksProxy) OnRepeatingRequestError ¶
func (*CameraDeviceCallbacksProxy) OnRequestQueueEmpty ¶
func (p *CameraDeviceCallbacksProxy) OnRequestQueueEmpty( ctx context.Context, ) error
func (*CameraDeviceCallbacksProxy) OnResultReceived ¶
func (p *CameraDeviceCallbacksProxy) OnResultReceived( ctx context.Context, result impl.CameraMetadataNative, resultExtras impl.CaptureResultExtras, physicalCaptureResultInfos []impl.PhysicalCaptureResultInfo, ) error
type CameraDeviceCallbacksStub ¶
type CameraDeviceCallbacksStub struct {
Impl ICameraDeviceCallbacks
Transport binder.VersionAwareTransport
}
CameraDeviceCallbacksStub dispatches incoming binder transactions to a typed ICameraDeviceCallbacks implementation.
func (*CameraDeviceCallbacksStub) Descriptor ¶
func (s *CameraDeviceCallbacksStub) Descriptor() string
func (*CameraDeviceCallbacksStub) OnTransaction ¶
func (s *CameraDeviceCallbacksStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type CameraDeviceUserProxy ¶
func NewCameraDeviceUserProxy ¶
func NewCameraDeviceUserProxy( remote binder.IBinder, ) *CameraDeviceUserProxy
func (*CameraDeviceUserProxy) AsBinder ¶
func (p *CameraDeviceUserProxy) AsBinder() binder.IBinder
func (*CameraDeviceUserProxy) BeginConfigure ¶
func (p *CameraDeviceUserProxy) BeginConfigure( ctx context.Context, ) error
func (*CameraDeviceUserProxy) CancelRequest ¶
func (*CameraDeviceUserProxy) CreateDefaultRequest ¶
func (p *CameraDeviceUserProxy) CreateDefaultRequest( ctx context.Context, templateId int32, ) (impl.CameraMetadataNative, error)
func (*CameraDeviceUserProxy) CreateInputStream ¶
func (*CameraDeviceUserProxy) CreateStream ¶
func (p *CameraDeviceUserProxy) CreateStream( ctx context.Context, outputConfiguration params.OutputConfiguration, ) (int32, error)
func (*CameraDeviceUserProxy) DeleteStream ¶
func (p *CameraDeviceUserProxy) DeleteStream( ctx context.Context, streamId int32, ) error
func (*CameraDeviceUserProxy) Disconnect ¶
func (p *CameraDeviceUserProxy) Disconnect( ctx context.Context, ) error
func (*CameraDeviceUserProxy) EndConfigure ¶
func (p *CameraDeviceUserProxy) EndConfigure( ctx context.Context, operatingMode int32, sessionParams impl.CameraMetadataNative, startTimeMs int64, ) ([]int32, error)
func (*CameraDeviceUserProxy) FinalizeOutputConfigurations ¶
func (p *CameraDeviceUserProxy) FinalizeOutputConfigurations( ctx context.Context, streamId int32, outputConfiguration params.OutputConfiguration, ) error
func (*CameraDeviceUserProxy) Flush ¶
func (p *CameraDeviceUserProxy) Flush( ctx context.Context, ) (int64, error)
func (*CameraDeviceUserProxy) GetCameraInfo ¶
func (p *CameraDeviceUserProxy) GetCameraInfo( ctx context.Context, ) (impl.CameraMetadataNative, error)
func (*CameraDeviceUserProxy) GetGlobalAudioRestriction ¶
func (p *CameraDeviceUserProxy) GetGlobalAudioRestriction( ctx context.Context, ) (int32, error)
func (*CameraDeviceUserProxy) GetInputSurface ¶
func (*CameraDeviceUserProxy) IsSessionConfigurationSupported ¶
func (p *CameraDeviceUserProxy) IsSessionConfigurationSupported( ctx context.Context, sessionConfiguration params.SessionConfiguration, ) (bool, error)
func (*CameraDeviceUserProxy) Prepare ¶
func (p *CameraDeviceUserProxy) Prepare( ctx context.Context, streamId int32, ) error
func (*CameraDeviceUserProxy) SetCameraAudioRestriction ¶
func (p *CameraDeviceUserProxy) SetCameraAudioRestriction( ctx context.Context, mode int32, ) error
func (*CameraDeviceUserProxy) SubmitRequest ¶
func (p *CameraDeviceUserProxy) SubmitRequest( ctx context.Context, request CaptureRequest, streaming bool, ) (utils.SubmitInfo, error)
func (*CameraDeviceUserProxy) SubmitRequestList ¶
func (p *CameraDeviceUserProxy) SubmitRequestList( ctx context.Context, requestList []CaptureRequest, streaming bool, ) (utils.SubmitInfo, error)
func (*CameraDeviceUserProxy) SwitchToOffline ¶
func (p *CameraDeviceUserProxy) SwitchToOffline( ctx context.Context, callbacks ICameraDeviceCallbacks, offlineOutputIds []int32, ) (ICameraOfflineSession, error)
func (*CameraDeviceUserProxy) TearDown ¶
func (p *CameraDeviceUserProxy) TearDown( ctx context.Context, streamId int32, ) error
func (*CameraDeviceUserProxy) UpdateOutputConfiguration ¶
func (p *CameraDeviceUserProxy) UpdateOutputConfiguration( ctx context.Context, streamId int32, outputConfiguration params.OutputConfiguration, ) error
func (*CameraDeviceUserProxy) WaitUntilIdle ¶
func (p *CameraDeviceUserProxy) WaitUntilIdle( ctx context.Context, ) error
type CameraDeviceUserStub ¶
type CameraDeviceUserStub struct {
Impl ICameraDeviceUser
Transport binder.VersionAwareTransport
}
CameraDeviceUserStub dispatches incoming binder transactions to a typed ICameraDeviceUser implementation.
func (*CameraDeviceUserStub) Descriptor ¶
func (s *CameraDeviceUserStub) Descriptor() string
func (*CameraDeviceUserStub) OnTransaction ¶
func (s *CameraDeviceUserStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type CameraInjectionCallbackProxy ¶
func NewCameraInjectionCallbackProxy ¶
func NewCameraInjectionCallbackProxy( remote binder.IBinder, ) *CameraInjectionCallbackProxy
func (*CameraInjectionCallbackProxy) AsBinder ¶
func (p *CameraInjectionCallbackProxy) AsBinder() binder.IBinder
func (*CameraInjectionCallbackProxy) OnInjectionError ¶
func (p *CameraInjectionCallbackProxy) OnInjectionError( ctx context.Context, errorCode int32, ) error
type CameraInjectionCallbackStub ¶
type CameraInjectionCallbackStub struct {
Impl ICameraInjectionCallback
Transport binder.VersionAwareTransport
}
CameraInjectionCallbackStub dispatches incoming binder transactions to a typed ICameraInjectionCallback implementation.
func (*CameraInjectionCallbackStub) Descriptor ¶
func (s *CameraInjectionCallbackStub) Descriptor() string
func (*CameraInjectionCallbackStub) OnTransaction ¶
func (s *CameraInjectionCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type CameraInjectionSessionProxy ¶
func NewCameraInjectionSessionProxy ¶
func NewCameraInjectionSessionProxy( remote binder.IBinder, ) *CameraInjectionSessionProxy
func (*CameraInjectionSessionProxy) AsBinder ¶
func (p *CameraInjectionSessionProxy) AsBinder() binder.IBinder
func (*CameraInjectionSessionProxy) StopInjection ¶
func (p *CameraInjectionSessionProxy) StopInjection( ctx context.Context, ) error
type CameraInjectionSessionStub ¶
type CameraInjectionSessionStub struct {
Impl ICameraInjectionSession
Transport binder.VersionAwareTransport
}
CameraInjectionSessionStub dispatches incoming binder transactions to a typed ICameraInjectionSession implementation.
func (*CameraInjectionSessionStub) Descriptor ¶
func (s *CameraInjectionSessionStub) Descriptor() string
func (*CameraInjectionSessionStub) OnTransaction ¶
func (s *CameraInjectionSessionStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type CameraOfflineSessionProxy ¶
func NewCameraOfflineSessionProxy ¶
func NewCameraOfflineSessionProxy( remote binder.IBinder, ) *CameraOfflineSessionProxy
func (*CameraOfflineSessionProxy) AsBinder ¶
func (p *CameraOfflineSessionProxy) AsBinder() binder.IBinder
func (*CameraOfflineSessionProxy) Disconnect ¶
func (p *CameraOfflineSessionProxy) Disconnect( ctx context.Context, ) error
type CameraOfflineSessionStub ¶
type CameraOfflineSessionStub struct {
Impl ICameraOfflineSession
Transport binder.VersionAwareTransport
}
CameraOfflineSessionStub dispatches incoming binder transactions to a typed ICameraOfflineSession implementation.
func (*CameraOfflineSessionStub) Descriptor ¶
func (s *CameraOfflineSessionStub) Descriptor() string
func (*CameraOfflineSessionStub) OnTransaction ¶
func (s *CameraOfflineSessionStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type CaptureRequest ¶
func (*CaptureRequest) MarshalParcel ¶
func (s *CaptureRequest) MarshalParcel( p *parcel.Parcel, ) error
func (*CaptureRequest) UnmarshalParcel ¶
func (s *CaptureRequest) UnmarshalParcel( p *parcel.Parcel, ) error
type ICameraDeviceCallbacks ¶
type ICameraDeviceCallbacks interface {
AsBinder() binder.IBinder
OnDeviceError(ctx context.Context, errorCode int32, resultExtras impl.CaptureResultExtras) error
OnDeviceIdle(ctx context.Context) error
OnCaptureStarted(ctx context.Context, resultExtras impl.CaptureResultExtras, timestamp int64) error
OnResultReceived(ctx context.Context, result impl.CameraMetadataNative, resultExtras impl.CaptureResultExtras, physicalCaptureResultInfos []impl.PhysicalCaptureResultInfo) error
OnPrepared(ctx context.Context, streamId int32) error
OnRepeatingRequestError(ctx context.Context, lastFrameNumber int64, repeatingRequestId int32) error
OnRequestQueueEmpty(ctx context.Context) error
}
func NewCameraDeviceCallbacksStub ¶
func NewCameraDeviceCallbacksStub( impl ICameraDeviceCallbacksServer, ) ICameraDeviceCallbacks
NewCameraDeviceCallbacksStub creates a server-side ICameraDeviceCallbacks wrapping the given server implementation. The returned value satisfies ICameraDeviceCallbacks and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ICameraDeviceCallbacksServer ¶
type ICameraDeviceCallbacksServer interface {
OnDeviceError(ctx context.Context, errorCode int32, resultExtras impl.CaptureResultExtras) error
OnDeviceIdle(ctx context.Context) error
OnCaptureStarted(ctx context.Context, resultExtras impl.CaptureResultExtras, timestamp int64) error
OnResultReceived(ctx context.Context, result impl.CameraMetadataNative, resultExtras impl.CaptureResultExtras, physicalCaptureResultInfos []impl.PhysicalCaptureResultInfo) error
OnPrepared(ctx context.Context, streamId int32) error
OnRepeatingRequestError(ctx context.Context, lastFrameNumber int64, repeatingRequestId int32) error
OnRequestQueueEmpty(ctx context.Context) error
}
ICameraDeviceCallbacksServer is the server-side interface that user implementations provide to NewCameraDeviceCallbacksStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ICameraDeviceUser ¶
type ICameraDeviceUser interface {
AsBinder() binder.IBinder
Disconnect(ctx context.Context) error
SubmitRequest(ctx context.Context, request CaptureRequest, streaming bool) (utils.SubmitInfo, error)
SubmitRequestList(ctx context.Context, requestList []CaptureRequest, streaming bool) (utils.SubmitInfo, error)
CancelRequest(ctx context.Context, requestId int32) (int64, error)
BeginConfigure(ctx context.Context) error
EndConfigure(ctx context.Context, operatingMode int32, sessionParams impl.CameraMetadataNative, startTimeMs int64) ([]int32, error)
IsSessionConfigurationSupported(ctx context.Context, sessionConfiguration params.SessionConfiguration) (bool, error)
DeleteStream(ctx context.Context, streamId int32) error
CreateStream(ctx context.Context, outputConfiguration params.OutputConfiguration) (int32, error)
CreateInputStream(ctx context.Context, width int32, height int32, format int32, isMultiResolution bool) (int32, error)
GetInputSurface(ctx context.Context) (view.Surface, error)
CreateDefaultRequest(ctx context.Context, templateId int32) (impl.CameraMetadataNative, error)
GetCameraInfo(ctx context.Context) (impl.CameraMetadataNative, error)
WaitUntilIdle(ctx context.Context) error
Flush(ctx context.Context) (int64, error)
Prepare(ctx context.Context, streamId int32) error
TearDown(ctx context.Context, streamId int32) error
Prepare2(ctx context.Context, maxCount int32, streamId int32) error
UpdateOutputConfiguration(ctx context.Context, streamId int32, outputConfiguration params.OutputConfiguration) error
FinalizeOutputConfigurations(ctx context.Context, streamId int32, outputConfiguration params.OutputConfiguration) error
SetCameraAudioRestriction(ctx context.Context, mode int32) error
GetGlobalAudioRestriction(ctx context.Context) (int32, error)
SwitchToOffline(ctx context.Context, callbacks ICameraDeviceCallbacks, offlineOutputIds []int32) (ICameraOfflineSession, error)
}
func NewCameraDeviceUserStub ¶
func NewCameraDeviceUserStub( impl ICameraDeviceUserServer, ) ICameraDeviceUser
NewCameraDeviceUserStub creates a server-side ICameraDeviceUser wrapping the given server implementation. The returned value satisfies ICameraDeviceUser and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ICameraDeviceUserServer ¶
type ICameraDeviceUserServer interface {
Disconnect(ctx context.Context) error
SubmitRequest(ctx context.Context, request CaptureRequest, streaming bool) (utils.SubmitInfo, error)
SubmitRequestList(ctx context.Context, requestList []CaptureRequest, streaming bool) (utils.SubmitInfo, error)
CancelRequest(ctx context.Context, requestId int32) (int64, error)
BeginConfigure(ctx context.Context) error
EndConfigure(ctx context.Context, operatingMode int32, sessionParams impl.CameraMetadataNative, startTimeMs int64) ([]int32, error)
IsSessionConfigurationSupported(ctx context.Context, sessionConfiguration params.SessionConfiguration) (bool, error)
DeleteStream(ctx context.Context, streamId int32) error
CreateStream(ctx context.Context, outputConfiguration params.OutputConfiguration) (int32, error)
CreateInputStream(ctx context.Context, width int32, height int32, format int32, isMultiResolution bool) (int32, error)
GetInputSurface(ctx context.Context) (view.Surface, error)
CreateDefaultRequest(ctx context.Context, templateId int32) (impl.CameraMetadataNative, error)
GetCameraInfo(ctx context.Context) (impl.CameraMetadataNative, error)
WaitUntilIdle(ctx context.Context) error
Flush(ctx context.Context) (int64, error)
Prepare(ctx context.Context, streamId int32) error
TearDown(ctx context.Context, streamId int32) error
Prepare2(ctx context.Context, maxCount int32, streamId int32) error
UpdateOutputConfiguration(ctx context.Context, streamId int32, outputConfiguration params.OutputConfiguration) error
FinalizeOutputConfigurations(ctx context.Context, streamId int32, outputConfiguration params.OutputConfiguration) error
SetCameraAudioRestriction(ctx context.Context, mode int32) error
GetGlobalAudioRestriction(ctx context.Context) (int32, error)
SwitchToOffline(ctx context.Context, callbacks ICameraDeviceCallbacks, offlineOutputIds []int32) (ICameraOfflineSession, error)
}
ICameraDeviceUserServer is the server-side interface that user implementations provide to NewCameraDeviceUserStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ICameraInjectionCallback ¶
type ICameraInjectionCallback interface {
AsBinder() binder.IBinder
OnInjectionError(ctx context.Context, errorCode int32) error
}
func NewCameraInjectionCallbackStub ¶
func NewCameraInjectionCallbackStub( impl ICameraInjectionCallbackServer, ) ICameraInjectionCallback
NewCameraInjectionCallbackStub creates a server-side ICameraInjectionCallback wrapping the given server implementation. The returned value satisfies ICameraInjectionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ICameraInjectionCallbackServer ¶
type ICameraInjectionCallbackServer interface {
OnInjectionError(ctx context.Context, errorCode int32) error
}
ICameraInjectionCallbackServer is the server-side interface that user implementations provide to NewCameraInjectionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ICameraInjectionSession ¶
type ICameraInjectionSession interface {
AsBinder() binder.IBinder
StopInjection(ctx context.Context) error
}
func NewCameraInjectionSessionStub ¶
func NewCameraInjectionSessionStub( impl ICameraInjectionSessionServer, ) ICameraInjectionSession
NewCameraInjectionSessionStub creates a server-side ICameraInjectionSession wrapping the given server implementation. The returned value satisfies ICameraInjectionSession and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ICameraInjectionSessionServer ¶
ICameraInjectionSessionServer is the server-side interface that user implementations provide to NewCameraInjectionSessionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ICameraOfflineSession ¶
type ICameraOfflineSession interface {
AsBinder() binder.IBinder
Disconnect(ctx context.Context) error
}
func NewCameraOfflineSessionStub ¶
func NewCameraOfflineSessionStub( impl ICameraOfflineSessionServer, ) ICameraOfflineSession
NewCameraOfflineSessionStub creates a server-side ICameraOfflineSession wrapping the given server implementation. The returned value satisfies ICameraOfflineSession and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ICameraOfflineSessionServer ¶
ICameraOfflineSessionServer is the server-side interface that user implementations provide to NewCameraOfflineSessionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).