confirmationui

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIConfirmationUIAbort                   = binder.FirstCallTransaction + 0
	TransactionIConfirmationUIDeliverSecureInputEvent = binder.FirstCallTransaction + 1
	TransactionIConfirmationUIPromptUserConfirmation  = binder.FirstCallTransaction + 2
)
const (
	MethodIConfirmationUIAbort                   = "abort"
	MethodIConfirmationUIDeliverSecureInputEvent = "deliverSecureInputEvent"
	MethodIConfirmationUIPromptUserConfirmation  = "promptUserConfirmation"
)
const (
	IConfirmationUIOK                           int32 = 0
	IConfirmationUICANCELED                     int32 = 1
	IConfirmationUIABORTED                      int32 = 2
	IConfirmationUIOperationPending             int32 = 3
	IConfirmationUIIGNORED                      int32 = 4
	IConfirmationUISystemError                  int32 = 5
	IConfirmationUIUNIMPLEMENTED                int32 = 6
	IConfirmationUIUNEXPECTED                   int32 = 7
	IConfirmationUIUiError                      int32 = 65536
	IConfirmationUIUiErrorMissingGlyph          int32 = 65537
	IConfirmationUIUiErrorMessageTooLong        int32 = 65538
	IConfirmationUIUiErrorMalformedUtf8encoding int32 = 65539
	IConfirmationUITestKeyByte                  int32 = 165
	IConfirmationUIMaxMessageSize               int32 = 6144
)
const DescriptorIConfirmationResultCallback = "android.hardware.confirmationui.IConfirmationResultCallback"
const DescriptorIConfirmationUI = "android.hardware.confirmationui.IConfirmationUI"
const (
	MethodIConfirmationResultCallbackResult = "result"
)
const (
	TransactionIConfirmationResultCallbackResult = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type ConfirmationResultCallbackProxy

type ConfirmationResultCallbackProxy struct {
	Remote binder.IBinder
}

func NewConfirmationResultCallbackProxy

func NewConfirmationResultCallbackProxy(
	remote binder.IBinder,
) *ConfirmationResultCallbackProxy

func (*ConfirmationResultCallbackProxy) AsBinder

func (*ConfirmationResultCallbackProxy) Result

func (p *ConfirmationResultCallbackProxy) Result(
	ctx context.Context,
	error_ int32,
	formattedMessage []byte,
	confirmationToken []byte,
) error

type ConfirmationResultCallbackStub

type ConfirmationResultCallbackStub struct {
	Impl      IConfirmationResultCallback
	Transport binder.VersionAwareTransport
}

ConfirmationResultCallbackStub dispatches incoming binder transactions to a typed IConfirmationResultCallback implementation.

func (*ConfirmationResultCallbackStub) Descriptor

func (s *ConfirmationResultCallbackStub) Descriptor() string

func (*ConfirmationResultCallbackStub) OnTransaction

type ConfirmationUIProxy

type ConfirmationUIProxy struct {
	Remote binder.IBinder
}

func NewConfirmationUIProxy

func NewConfirmationUIProxy(
	remote binder.IBinder,
) *ConfirmationUIProxy

func (*ConfirmationUIProxy) Abort

func (p *ConfirmationUIProxy) Abort(
	ctx context.Context,
) error

func (*ConfirmationUIProxy) AsBinder

func (p *ConfirmationUIProxy) AsBinder() binder.IBinder

func (*ConfirmationUIProxy) DeliverSecureInputEvent

func (p *ConfirmationUIProxy) DeliverSecureInputEvent(
	ctx context.Context,
	secureInputToken keymaster.HardwareAuthToken,
) error

func (*ConfirmationUIProxy) PromptUserConfirmation

func (p *ConfirmationUIProxy) PromptUserConfirmation(
	ctx context.Context,
	resultCB IConfirmationResultCallback,
	promptText []byte,
	extraData []byte,
	locale string,
	uiOptions []UIOption,
) error

type ConfirmationUIStub

type ConfirmationUIStub struct {
	Impl      IConfirmationUI
	Transport binder.VersionAwareTransport
}

ConfirmationUIStub dispatches incoming binder transactions to a typed IConfirmationUI implementation.

func (*ConfirmationUIStub) Descriptor

func (s *ConfirmationUIStub) Descriptor() string

func (*ConfirmationUIStub) OnTransaction

func (s *ConfirmationUIStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IConfirmationResultCallback

type IConfirmationResultCallback interface {
	AsBinder() binder.IBinder
	Result(ctx context.Context, error_ int32, formattedMessage []byte, confirmationToken []byte) error
}

func NewConfirmationResultCallbackStub

func NewConfirmationResultCallbackStub(
	impl IConfirmationResultCallbackServer,
) IConfirmationResultCallback

NewConfirmationResultCallbackStub creates a server-side IConfirmationResultCallback wrapping the given server implementation. The returned value satisfies IConfirmationResultCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IConfirmationResultCallbackServer

type IConfirmationResultCallbackServer interface {
	Result(ctx context.Context, error_ int32, formattedMessage []byte, confirmationToken []byte) error
}

IConfirmationResultCallbackServer is the server-side interface that user implementations provide to NewConfirmationResultCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IConfirmationUI

type IConfirmationUI interface {
	AsBinder() binder.IBinder
	Abort(ctx context.Context) error
	DeliverSecureInputEvent(ctx context.Context, secureInputToken keymaster.HardwareAuthToken) error
	PromptUserConfirmation(ctx context.Context, resultCB IConfirmationResultCallback, promptText []byte, extraData []byte, locale string, uiOptions []UIOption) error
}

func NewConfirmationUIStub

func NewConfirmationUIStub(
	impl IConfirmationUIServer,
) IConfirmationUI

NewConfirmationUIStub creates a server-side IConfirmationUI wrapping the given server implementation. The returned value satisfies IConfirmationUI and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IConfirmationUIServer

type IConfirmationUIServer interface {
	Abort(ctx context.Context) error
	DeliverSecureInputEvent(ctx context.Context, secureInputToken keymaster.HardwareAuthToken) error
	PromptUserConfirmation(ctx context.Context, resultCB IConfirmationResultCallback, promptText []byte, extraData []byte, locale string, uiOptions []UIOption) error
}

IConfirmationUIServer is the server-side interface that user implementations provide to NewConfirmationUIStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type TestModeCommands

type TestModeCommands int32
const (
	TestModeCommandsOkEvent     TestModeCommands = 0
	TestModeCommandsCancelEvent TestModeCommands = 1
)

type UIOption

type UIOption int32
const (
	UIOptionAccessibilityInverted  UIOption = 0
	UIOptionAccessibilityMagnified UIOption = 1
)

Jump to