display

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIColorDisplayManagerIsDeviceColorManaged              = binder.FirstCallTransaction + 0
	TransactionIColorDisplayManagerSetSaturationLevel                = binder.FirstCallTransaction + 1
	TransactionIColorDisplayManagerSetAppSaturationLevel             = binder.FirstCallTransaction + 2
	TransactionIColorDisplayManagerIsSaturationActivated             = binder.FirstCallTransaction + 3
	TransactionIColorDisplayManagerGetTransformCapabilities          = binder.FirstCallTransaction + 4
	TransactionIColorDisplayManagerIsNightDisplayActivated           = binder.FirstCallTransaction + 5
	TransactionIColorDisplayManagerSetNightDisplayActivated          = binder.FirstCallTransaction + 6
	TransactionIColorDisplayManagerGetNightDisplayColorTemperature   = binder.FirstCallTransaction + 7
	TransactionIColorDisplayManagerSetNightDisplayColorTemperature   = binder.FirstCallTransaction + 8
	TransactionIColorDisplayManagerGetNightDisplayAutoMode           = binder.FirstCallTransaction + 9
	TransactionIColorDisplayManagerGetNightDisplayAutoModeRaw        = binder.FirstCallTransaction + 10
	TransactionIColorDisplayManagerSetNightDisplayAutoMode           = binder.FirstCallTransaction + 11
	TransactionIColorDisplayManagerGetNightDisplayCustomStartTime    = binder.FirstCallTransaction + 12
	TransactionIColorDisplayManagerSetNightDisplayCustomStartTime    = binder.FirstCallTransaction + 13
	TransactionIColorDisplayManagerGetNightDisplayCustomEndTime      = binder.FirstCallTransaction + 14
	TransactionIColorDisplayManagerSetNightDisplayCustomEndTime      = binder.FirstCallTransaction + 15
	TransactionIColorDisplayManagerGetColorMode                      = binder.FirstCallTransaction + 16
	TransactionIColorDisplayManagerSetColorMode                      = binder.FirstCallTransaction + 17
	TransactionIColorDisplayManagerIsDisplayWhiteBalanceEnabled      = binder.FirstCallTransaction + 18
	TransactionIColorDisplayManagerSetDisplayWhiteBalanceEnabled     = binder.FirstCallTransaction + 19
	TransactionIColorDisplayManagerIsReduceBrightColorsActivated     = binder.FirstCallTransaction + 20
	TransactionIColorDisplayManagerSetReduceBrightColorsActivated    = binder.FirstCallTransaction + 21
	TransactionIColorDisplayManagerGetReduceBrightColorsStrength     = binder.FirstCallTransaction + 22
	TransactionIColorDisplayManagerSetReduceBrightColorsStrength     = binder.FirstCallTransaction + 23
	TransactionIColorDisplayManagerGetReduceBrightColorsOffsetFactor = binder.FirstCallTransaction + 24
)
const (
	MethodIColorDisplayManagerIsDeviceColorManaged              = "isDeviceColorManaged"
	MethodIColorDisplayManagerSetSaturationLevel                = "setSaturationLevel"
	MethodIColorDisplayManagerSetAppSaturationLevel             = "setAppSaturationLevel"
	MethodIColorDisplayManagerIsSaturationActivated             = "isSaturationActivated"
	MethodIColorDisplayManagerGetTransformCapabilities          = "getTransformCapabilities"
	MethodIColorDisplayManagerIsNightDisplayActivated           = "isNightDisplayActivated"
	MethodIColorDisplayManagerSetNightDisplayActivated          = "setNightDisplayActivated"
	MethodIColorDisplayManagerGetNightDisplayColorTemperature   = "getNightDisplayColorTemperature"
	MethodIColorDisplayManagerSetNightDisplayColorTemperature   = "setNightDisplayColorTemperature"
	MethodIColorDisplayManagerGetNightDisplayAutoMode           = "getNightDisplayAutoMode"
	MethodIColorDisplayManagerGetNightDisplayAutoModeRaw        = "getNightDisplayAutoModeRaw"
	MethodIColorDisplayManagerSetNightDisplayAutoMode           = "setNightDisplayAutoMode"
	MethodIColorDisplayManagerGetNightDisplayCustomStartTime    = "getNightDisplayCustomStartTime"
	MethodIColorDisplayManagerSetNightDisplayCustomStartTime    = "setNightDisplayCustomStartTime"
	MethodIColorDisplayManagerGetNightDisplayCustomEndTime      = "getNightDisplayCustomEndTime"
	MethodIColorDisplayManagerSetNightDisplayCustomEndTime      = "setNightDisplayCustomEndTime"
	MethodIColorDisplayManagerGetColorMode                      = "getColorMode"
	MethodIColorDisplayManagerSetColorMode                      = "setColorMode"
	MethodIColorDisplayManagerIsDisplayWhiteBalanceEnabled      = "isDisplayWhiteBalanceEnabled"
	MethodIColorDisplayManagerSetDisplayWhiteBalanceEnabled     = "setDisplayWhiteBalanceEnabled"
	MethodIColorDisplayManagerIsReduceBrightColorsActivated     = "isReduceBrightColorsActivated"
	MethodIColorDisplayManagerSetReduceBrightColorsActivated    = "setReduceBrightColorsActivated"
	MethodIColorDisplayManagerGetReduceBrightColorsStrength     = "getReduceBrightColorsStrength"
	MethodIColorDisplayManagerSetReduceBrightColorsStrength     = "setReduceBrightColorsStrength"
	MethodIColorDisplayManagerGetReduceBrightColorsOffsetFactor = "getReduceBrightColorsOffsetFactor"
)
const (
	IDeviceProductInfoConstantsConnectionToSinkUnknown    int32 = 0
	IDeviceProductInfoConstantsConnectionToSinkBuiltIn    int32 = 1
	IDeviceProductInfoConstantsConnectionToSinkDirect     int32 = 2
	IDeviceProductInfoConstantsConnectionToSinkTransitive int32 = 3
)
const (
	TransactionIDisplayManagerGetDisplayInfo                         = binder.FirstCallTransaction + 0
	TransactionIDisplayManagerGetDisplayIds                          = binder.FirstCallTransaction + 1
	TransactionIDisplayManagerIsUidPresentOnDisplay                  = binder.FirstCallTransaction + 2
	TransactionIDisplayManagerRegisterCallback                       = binder.FirstCallTransaction + 3
	TransactionIDisplayManagerRegisterCallbackWithEventMask          = binder.FirstCallTransaction + 4
	TransactionIDisplayManagerStartWifiDisplayScan                   = binder.FirstCallTransaction + 5
	TransactionIDisplayManagerStopWifiDisplayScan                    = binder.FirstCallTransaction + 6
	TransactionIDisplayManagerConnectWifiDisplay                     = binder.FirstCallTransaction + 7
	TransactionIDisplayManagerDisconnectWifiDisplay                  = binder.FirstCallTransaction + 8
	TransactionIDisplayManagerRenameWifiDisplay                      = binder.FirstCallTransaction + 9
	TransactionIDisplayManagerForgetWifiDisplay                      = binder.FirstCallTransaction + 10
	TransactionIDisplayManagerPauseWifiDisplay                       = binder.FirstCallTransaction + 11
	TransactionIDisplayManagerResumeWifiDisplay                      = binder.FirstCallTransaction + 12
	TransactionIDisplayManagerGetWifiDisplayStatus                   = binder.FirstCallTransaction + 13
	TransactionIDisplayManagerSetUserDisabledHdrTypes                = binder.FirstCallTransaction + 14
	TransactionIDisplayManagerSetAreUserDisabledHdrTypesAllowed      = binder.FirstCallTransaction + 15
	TransactionIDisplayManagerAreUserDisabledHdrTypesAllowed         = binder.FirstCallTransaction + 16
	TransactionIDisplayManagerGetUserDisabledHdrTypes                = binder.FirstCallTransaction + 17
	TransactionIDisplayManagerOverrideHdrTypes                       = binder.FirstCallTransaction + 18
	TransactionIDisplayManagerRequestColorMode                       = binder.FirstCallTransaction + 19
	TransactionIDisplayManagerCreateVirtualDisplay                   = binder.FirstCallTransaction + 20
	TransactionIDisplayManagerResizeVirtualDisplay                   = binder.FirstCallTransaction + 21
	TransactionIDisplayManagerSetVirtualDisplaySurface               = binder.FirstCallTransaction + 22
	TransactionIDisplayManagerReleaseVirtualDisplay                  = binder.FirstCallTransaction + 23
	TransactionIDisplayManagerSetVirtualDisplayState                 = binder.FirstCallTransaction + 24
	TransactionIDisplayManagerGetStableDisplaySize                   = binder.FirstCallTransaction + 25
	TransactionIDisplayManagerGetBrightnessEvents                    = binder.FirstCallTransaction + 26
	TransactionIDisplayManagerGetAmbientBrightnessStats              = binder.FirstCallTransaction + 27
	TransactionIDisplayManagerSetBrightnessConfigurationForUser      = binder.FirstCallTransaction + 28
	TransactionIDisplayManagerSetBrightnessConfigurationForDisplay   = binder.FirstCallTransaction + 29
	TransactionIDisplayManagerGetBrightnessConfigurationForDisplay   = binder.FirstCallTransaction + 30
	TransactionIDisplayManagerGetBrightnessConfigurationForUser      = binder.FirstCallTransaction + 31
	TransactionIDisplayManagerGetDefaultBrightnessConfiguration      = binder.FirstCallTransaction + 32
	TransactionIDisplayManagerIsMinimalPostProcessingRequested       = binder.FirstCallTransaction + 33
	TransactionIDisplayManagerSetTemporaryBrightness                 = binder.FirstCallTransaction + 34
	TransactionIDisplayManagerSetBrightness                          = binder.FirstCallTransaction + 35
	TransactionIDisplayManagerGetBrightness                          = binder.FirstCallTransaction + 36
	TransactionIDisplayManagerSetTemporaryAutoBrightnessAdjustment   = binder.FirstCallTransaction + 37
	TransactionIDisplayManagerGetMinimumBrightnessCurve              = binder.FirstCallTransaction + 38
	TransactionIDisplayManagerGetBrightnessInfo                      = binder.FirstCallTransaction + 39
	TransactionIDisplayManagerGetPreferredWideGamutColorSpaceId      = binder.FirstCallTransaction + 40
	TransactionIDisplayManagerSetUserPreferredDisplayMode            = binder.FirstCallTransaction + 41
	TransactionIDisplayManagerGetUserPreferredDisplayMode            = binder.FirstCallTransaction + 42
	TransactionIDisplayManagerGetSystemPreferredDisplayMode          = binder.FirstCallTransaction + 43
	TransactionIDisplayManagerSetHdrConversionMode                   = binder.FirstCallTransaction + 44
	TransactionIDisplayManagerGetHdrConversionModeSetting            = binder.FirstCallTransaction + 45
	TransactionIDisplayManagerGetHdrConversionMode                   = binder.FirstCallTransaction + 46
	TransactionIDisplayManagerGetSupportedHdrOutputTypes             = binder.FirstCallTransaction + 47
	TransactionIDisplayManagerSetShouldAlwaysRespectAppRequestedMode = binder.FirstCallTransaction + 48
	TransactionIDisplayManagerShouldAlwaysRespectAppRequestedMode    = binder.FirstCallTransaction + 49
	TransactionIDisplayManagerSetRefreshRateSwitchingType            = binder.FirstCallTransaction + 50
	TransactionIDisplayManagerGetRefreshRateSwitchingType            = binder.FirstCallTransaction + 51
	TransactionIDisplayManagerGetDisplayDecorationSupport            = binder.FirstCallTransaction + 52
	TransactionIDisplayManagerSetDisplayIdToMirror                   = binder.FirstCallTransaction + 53
	TransactionIDisplayManagerGetOverlaySupport                      = binder.FirstCallTransaction + 54
	TransactionIDisplayManagerEnableConnectedDisplay                 = binder.FirstCallTransaction + 55
	TransactionIDisplayManagerDisableConnectedDisplay                = binder.FirstCallTransaction + 56
)
const (
	MethodIDisplayManagerGetDisplayInfo                         = "getDisplayInfo"
	MethodIDisplayManagerGetDisplayIds                          = "getDisplayIds"
	MethodIDisplayManagerIsUidPresentOnDisplay                  = "isUidPresentOnDisplay"
	MethodIDisplayManagerRegisterCallback                       = "registerCallback"
	MethodIDisplayManagerRegisterCallbackWithEventMask          = "registerCallbackWithEventMask"
	MethodIDisplayManagerStartWifiDisplayScan                   = "startWifiDisplayScan"
	MethodIDisplayManagerStopWifiDisplayScan                    = "stopWifiDisplayScan"
	MethodIDisplayManagerConnectWifiDisplay                     = "connectWifiDisplay"
	MethodIDisplayManagerDisconnectWifiDisplay                  = "disconnectWifiDisplay"
	MethodIDisplayManagerRenameWifiDisplay                      = "renameWifiDisplay"
	MethodIDisplayManagerForgetWifiDisplay                      = "forgetWifiDisplay"
	MethodIDisplayManagerPauseWifiDisplay                       = "pauseWifiDisplay"
	MethodIDisplayManagerResumeWifiDisplay                      = "resumeWifiDisplay"
	MethodIDisplayManagerGetWifiDisplayStatus                   = "getWifiDisplayStatus"
	MethodIDisplayManagerSetUserDisabledHdrTypes                = "setUserDisabledHdrTypes"
	MethodIDisplayManagerSetAreUserDisabledHdrTypesAllowed      = "setAreUserDisabledHdrTypesAllowed"
	MethodIDisplayManagerAreUserDisabledHdrTypesAllowed         = "areUserDisabledHdrTypesAllowed"
	MethodIDisplayManagerGetUserDisabledHdrTypes                = "getUserDisabledHdrTypes"
	MethodIDisplayManagerOverrideHdrTypes                       = "overrideHdrTypes"
	MethodIDisplayManagerRequestColorMode                       = "requestColorMode"
	MethodIDisplayManagerCreateVirtualDisplay                   = "createVirtualDisplay"
	MethodIDisplayManagerResizeVirtualDisplay                   = "resizeVirtualDisplay"
	MethodIDisplayManagerSetVirtualDisplaySurface               = "setVirtualDisplaySurface"
	MethodIDisplayManagerReleaseVirtualDisplay                  = "releaseVirtualDisplay"
	MethodIDisplayManagerSetVirtualDisplayState                 = "setVirtualDisplayState"
	MethodIDisplayManagerGetStableDisplaySize                   = "getStableDisplaySize"
	MethodIDisplayManagerGetBrightnessEvents                    = "getBrightnessEvents"
	MethodIDisplayManagerGetAmbientBrightnessStats              = "getAmbientBrightnessStats"
	MethodIDisplayManagerSetBrightnessConfigurationForUser      = "setBrightnessConfigurationForUser"
	MethodIDisplayManagerSetBrightnessConfigurationForDisplay   = "setBrightnessConfigurationForDisplay"
	MethodIDisplayManagerGetBrightnessConfigurationForDisplay   = "getBrightnessConfigurationForDisplay"
	MethodIDisplayManagerGetBrightnessConfigurationForUser      = "getBrightnessConfigurationForUser"
	MethodIDisplayManagerGetDefaultBrightnessConfiguration      = "getDefaultBrightnessConfiguration"
	MethodIDisplayManagerIsMinimalPostProcessingRequested       = "isMinimalPostProcessingRequested"
	MethodIDisplayManagerSetTemporaryBrightness                 = "setTemporaryBrightness"
	MethodIDisplayManagerSetBrightness                          = "setBrightness"
	MethodIDisplayManagerGetBrightness                          = "getBrightness"
	MethodIDisplayManagerSetTemporaryAutoBrightnessAdjustment   = "setTemporaryAutoBrightnessAdjustment"
	MethodIDisplayManagerGetMinimumBrightnessCurve              = "getMinimumBrightnessCurve"
	MethodIDisplayManagerGetBrightnessInfo                      = "getBrightnessInfo"
	MethodIDisplayManagerGetPreferredWideGamutColorSpaceId      = "getPreferredWideGamutColorSpaceId"
	MethodIDisplayManagerSetUserPreferredDisplayMode            = "setUserPreferredDisplayMode"
	MethodIDisplayManagerGetUserPreferredDisplayMode            = "getUserPreferredDisplayMode"
	MethodIDisplayManagerGetSystemPreferredDisplayMode          = "getSystemPreferredDisplayMode"
	MethodIDisplayManagerSetHdrConversionMode                   = "setHdrConversionMode"
	MethodIDisplayManagerGetHdrConversionModeSetting            = "getHdrConversionModeSetting"
	MethodIDisplayManagerGetHdrConversionMode                   = "getHdrConversionMode"
	MethodIDisplayManagerGetSupportedHdrOutputTypes             = "getSupportedHdrOutputTypes"
	MethodIDisplayManagerSetShouldAlwaysRespectAppRequestedMode = "setShouldAlwaysRespectAppRequestedMode"
	MethodIDisplayManagerShouldAlwaysRespectAppRequestedMode    = "shouldAlwaysRespectAppRequestedMode"
	MethodIDisplayManagerSetRefreshRateSwitchingType            = "setRefreshRateSwitchingType"
	MethodIDisplayManagerGetRefreshRateSwitchingType            = "getRefreshRateSwitchingType"
	MethodIDisplayManagerGetDisplayDecorationSupport            = "getDisplayDecorationSupport"
	MethodIDisplayManagerSetDisplayIdToMirror                   = "setDisplayIdToMirror"
	MethodIDisplayManagerGetOverlaySupport                      = "getOverlaySupport"
	MethodIDisplayManagerEnableConnectedDisplay                 = "enableConnectedDisplay"
	MethodIDisplayManagerDisableConnectedDisplay                = "disableConnectedDisplay"
)
const (
	TransactionIVirtualDisplayCallbackOnPaused  = binder.FirstCallTransaction + 0
	TransactionIVirtualDisplayCallbackOnResumed = binder.FirstCallTransaction + 1
	TransactionIVirtualDisplayCallbackOnStopped = binder.FirstCallTransaction + 2
)
const (
	MethodIVirtualDisplayCallbackOnPaused  = "onPaused"
	MethodIVirtualDisplayCallbackOnResumed = "onResumed"
	MethodIVirtualDisplayCallbackOnStopped = "onStopped"
)
const DescriptorIColorDisplayManager = "android.hardware.display.IColorDisplayManager"
const DescriptorIDeviceProductInfoConstants = "android.hardware.display.IDeviceProductInfoConstants"
const DescriptorIDisplayManager = "android.hardware.display.IDisplayManager"
const DescriptorIDisplayManagerCallback = "android.hardware.display.IDisplayManagerCallback"
const DescriptorIVirtualDisplayCallback = "android.hardware.display.IVirtualDisplayCallback"
const (
	MethodIDisplayManagerCallbackOnDisplayEvent = "onDisplayEvent"
)
const (
	TransactionIDisplayManagerCallbackOnDisplayEvent = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type AmbientBrightnessDayStats

type AmbientBrightnessDayStats struct {
}

func (*AmbientBrightnessDayStats) MarshalParcel

func (s *AmbientBrightnessDayStats) MarshalParcel(
	p *parcel.Parcel,
) error

func (*AmbientBrightnessDayStats) UnmarshalParcel

func (s *AmbientBrightnessDayStats) UnmarshalParcel(
	p *parcel.Parcel,
) error

type BrightnessChangeEvent

type BrightnessChangeEvent struct {
	Brightness                 float32
	TimeStamp                  int64
	PackageName                string
	UserId                     int32
	UniqueDisplayId            string
	BatteryLevel               float32
	PowerBrightnessFactor      float32
	NightMode                  bool
	ColorTemperature           int32
	ReduceBrightColors         bool
	ReduceBrightColorsStrength int32
	ReduceBrightColorsOffset   float32
	LastBrightness             float32
	IsDefaultBrightnessConfig  bool
	IsUserSetBrightness        bool
	ColorSampleDuration        int64
}

func (*BrightnessChangeEvent) MarshalParcel

func (s *BrightnessChangeEvent) MarshalParcel(
	p *parcel.Parcel,
) error

func (*BrightnessChangeEvent) UnmarshalParcel

func (s *BrightnessChangeEvent) UnmarshalParcel(
	p *parcel.Parcel,
) error

type BrightnessConfiguration

type BrightnessConfiguration struct {
	Description                      string
	ShouldCollectColorSamples        bool
	ShortTermModelTimeout            int64
	ShortTermModelLowerLuxMultiplier float32
	ShortTermModelUpperLuxMultiplier float32
}

func (*BrightnessConfiguration) MarshalParcel

func (s *BrightnessConfiguration) MarshalParcel(
	p *parcel.Parcel,
) error

func (*BrightnessConfiguration) UnmarshalParcel

func (s *BrightnessConfiguration) UnmarshalParcel(
	p *parcel.Parcel,
) error

type BrightnessCorrection

type BrightnessCorrection struct {
}

func (*BrightnessCorrection) MarshalParcel

func (s *BrightnessCorrection) MarshalParcel(
	p *parcel.Parcel,
) error

func (*BrightnessCorrection) UnmarshalParcel

func (s *BrightnessCorrection) UnmarshalParcel(
	p *parcel.Parcel,
) error

type BrightnessInfo

type BrightnessInfo struct {
	Brightness                    float32
	AdjustedBrightness            float32
	BrightnessMinimum             float32
	BrightnessMaximum             float32
	HighBrightnessMode            int32
	HighBrightnessTransitionPoint float32
	BrightnessMaxReason           int32
}

func (*BrightnessInfo) MarshalParcel

func (s *BrightnessInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*BrightnessInfo) UnmarshalParcel

func (s *BrightnessInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ColorDisplayManagerProxy

type ColorDisplayManagerProxy struct {
	Remote binder.IBinder
}

func NewColorDisplayManagerProxy

func NewColorDisplayManagerProxy(
	remote binder.IBinder,
) *ColorDisplayManagerProxy

func (*ColorDisplayManagerProxy) AsBinder

func (p *ColorDisplayManagerProxy) AsBinder() binder.IBinder

func (*ColorDisplayManagerProxy) GetColorMode

func (p *ColorDisplayManagerProxy) GetColorMode(
	ctx context.Context,
) (int32, error)

func (*ColorDisplayManagerProxy) GetNightDisplayAutoMode

func (p *ColorDisplayManagerProxy) GetNightDisplayAutoMode(
	ctx context.Context,
) (int32, error)

func (*ColorDisplayManagerProxy) GetNightDisplayAutoModeRaw

func (p *ColorDisplayManagerProxy) GetNightDisplayAutoModeRaw(
	ctx context.Context,
) (int32, error)

func (*ColorDisplayManagerProxy) GetNightDisplayColorTemperature

func (p *ColorDisplayManagerProxy) GetNightDisplayColorTemperature(
	ctx context.Context,
) (int32, error)

func (*ColorDisplayManagerProxy) GetNightDisplayCustomEndTime

func (p *ColorDisplayManagerProxy) GetNightDisplayCustomEndTime(
	ctx context.Context,
) (Time, error)

func (*ColorDisplayManagerProxy) GetNightDisplayCustomStartTime

func (p *ColorDisplayManagerProxy) GetNightDisplayCustomStartTime(
	ctx context.Context,
) (Time, error)

func (*ColorDisplayManagerProxy) GetReduceBrightColorsOffsetFactor

func (p *ColorDisplayManagerProxy) GetReduceBrightColorsOffsetFactor(
	ctx context.Context,
) (float32, error)

func (*ColorDisplayManagerProxy) GetReduceBrightColorsStrength

func (p *ColorDisplayManagerProxy) GetReduceBrightColorsStrength(
	ctx context.Context,
) (int32, error)

func (*ColorDisplayManagerProxy) GetTransformCapabilities

func (p *ColorDisplayManagerProxy) GetTransformCapabilities(
	ctx context.Context,
) (int32, error)

func (*ColorDisplayManagerProxy) IsDeviceColorManaged

func (p *ColorDisplayManagerProxy) IsDeviceColorManaged(
	ctx context.Context,
) (bool, error)

func (*ColorDisplayManagerProxy) IsDisplayWhiteBalanceEnabled

func (p *ColorDisplayManagerProxy) IsDisplayWhiteBalanceEnabled(
	ctx context.Context,
) (bool, error)

func (*ColorDisplayManagerProxy) IsNightDisplayActivated

func (p *ColorDisplayManagerProxy) IsNightDisplayActivated(
	ctx context.Context,
) (bool, error)

func (*ColorDisplayManagerProxy) IsReduceBrightColorsActivated

func (p *ColorDisplayManagerProxy) IsReduceBrightColorsActivated(
	ctx context.Context,
) (bool, error)

func (*ColorDisplayManagerProxy) IsSaturationActivated

func (p *ColorDisplayManagerProxy) IsSaturationActivated(
	ctx context.Context,
) (bool, error)

func (*ColorDisplayManagerProxy) SetAppSaturationLevel

func (p *ColorDisplayManagerProxy) SetAppSaturationLevel(
	ctx context.Context,
	packageName string,
	saturationLevel int32,
) (bool, error)

func (*ColorDisplayManagerProxy) SetColorMode

func (p *ColorDisplayManagerProxy) SetColorMode(
	ctx context.Context,
	colorMode int32,
) error

func (*ColorDisplayManagerProxy) SetDisplayWhiteBalanceEnabled

func (p *ColorDisplayManagerProxy) SetDisplayWhiteBalanceEnabled(
	ctx context.Context,
	enabled bool,
) (bool, error)

func (*ColorDisplayManagerProxy) SetNightDisplayActivated

func (p *ColorDisplayManagerProxy) SetNightDisplayActivated(
	ctx context.Context,
	activated bool,
) (bool, error)

func (*ColorDisplayManagerProxy) SetNightDisplayAutoMode

func (p *ColorDisplayManagerProxy) SetNightDisplayAutoMode(
	ctx context.Context,
	autoMode int32,
) (bool, error)

func (*ColorDisplayManagerProxy) SetNightDisplayColorTemperature

func (p *ColorDisplayManagerProxy) SetNightDisplayColorTemperature(
	ctx context.Context,
	temperature int32,
) (bool, error)

func (*ColorDisplayManagerProxy) SetNightDisplayCustomEndTime

func (p *ColorDisplayManagerProxy) SetNightDisplayCustomEndTime(
	ctx context.Context,
	time Time,
) (bool, error)

func (*ColorDisplayManagerProxy) SetNightDisplayCustomStartTime

func (p *ColorDisplayManagerProxy) SetNightDisplayCustomStartTime(
	ctx context.Context,
	time Time,
) (bool, error)

func (*ColorDisplayManagerProxy) SetReduceBrightColorsActivated

func (p *ColorDisplayManagerProxy) SetReduceBrightColorsActivated(
	ctx context.Context,
	activated bool,
) (bool, error)

func (*ColorDisplayManagerProxy) SetReduceBrightColorsStrength

func (p *ColorDisplayManagerProxy) SetReduceBrightColorsStrength(
	ctx context.Context,
	strength int32,
) (bool, error)

func (*ColorDisplayManagerProxy) SetSaturationLevel

func (p *ColorDisplayManagerProxy) SetSaturationLevel(
	ctx context.Context,
	saturationLevel int32,
) (bool, error)

type ColorDisplayManagerStub

type ColorDisplayManagerStub struct {
	Impl      IColorDisplayManager
	Transport binder.VersionAwareTransport
}

ColorDisplayManagerStub dispatches incoming binder transactions to a typed IColorDisplayManager implementation.

func (*ColorDisplayManagerStub) Descriptor

func (s *ColorDisplayManagerStub) Descriptor() string

func (*ColorDisplayManagerStub) OnTransaction

func (s *ColorDisplayManagerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type Curve

type Curve struct {
}

func (*Curve) MarshalParcel

func (s *Curve) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Curve) UnmarshalParcel

func (s *Curve) UnmarshalParcel(
	p *parcel.Parcel,
) error

type DeviceProductInfoConstantsProxy

type DeviceProductInfoConstantsProxy struct {
	Remote binder.IBinder
}

func NewDeviceProductInfoConstantsProxy

func NewDeviceProductInfoConstantsProxy(
	remote binder.IBinder,
) *DeviceProductInfoConstantsProxy

func (*DeviceProductInfoConstantsProxy) AsBinder

type DeviceProductInfoConstantsStub

type DeviceProductInfoConstantsStub struct {
	Impl      IDeviceProductInfoConstants
	Transport binder.VersionAwareTransport
}

DeviceProductInfoConstantsStub dispatches incoming binder transactions to a typed IDeviceProductInfoConstants implementation.

func (*DeviceProductInfoConstantsStub) Descriptor

func (s *DeviceProductInfoConstantsStub) Descriptor() string

func (*DeviceProductInfoConstantsStub) OnTransaction

type DisplayManagerCallbackProxy

type DisplayManagerCallbackProxy struct {
	Remote binder.IBinder
}

func NewDisplayManagerCallbackProxy

func NewDisplayManagerCallbackProxy(
	remote binder.IBinder,
) *DisplayManagerCallbackProxy

func (*DisplayManagerCallbackProxy) AsBinder

func (*DisplayManagerCallbackProxy) OnDisplayEvent

func (p *DisplayManagerCallbackProxy) OnDisplayEvent(
	ctx context.Context,
	displayId int32,
	event int32,
) error

type DisplayManagerCallbackStub

type DisplayManagerCallbackStub struct {
	Impl      IDisplayManagerCallback
	Transport binder.VersionAwareTransport
}

DisplayManagerCallbackStub dispatches incoming binder transactions to a typed IDisplayManagerCallback implementation.

func (*DisplayManagerCallbackStub) Descriptor

func (s *DisplayManagerCallbackStub) Descriptor() string

func (*DisplayManagerCallbackStub) OnTransaction

func (s *DisplayManagerCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type DisplayManagerProxy

type DisplayManagerProxy struct {
	Remote binder.IBinder
}

func NewDisplayManagerProxy

func NewDisplayManagerProxy(
	remote binder.IBinder,
) *DisplayManagerProxy

func (*DisplayManagerProxy) AreUserDisabledHdrTypesAllowed

func (p *DisplayManagerProxy) AreUserDisabledHdrTypesAllowed(
	ctx context.Context,
) (bool, error)

func (*DisplayManagerProxy) AsBinder

func (p *DisplayManagerProxy) AsBinder() binder.IBinder

func (*DisplayManagerProxy) ConnectWifiDisplay

func (p *DisplayManagerProxy) ConnectWifiDisplay(
	ctx context.Context,
	address string,
) error

func (*DisplayManagerProxy) CreateVirtualDisplay

func (p *DisplayManagerProxy) CreateVirtualDisplay(
	ctx context.Context,
	virtualDisplayConfig VirtualDisplayConfig,
	callback IVirtualDisplayCallback,
	projectionToken projection.IMediaProjection,
	packageName string,
) (int32, error)

func (*DisplayManagerProxy) DisableConnectedDisplay

func (p *DisplayManagerProxy) DisableConnectedDisplay(
	ctx context.Context,
	displayId int32,
) error

func (*DisplayManagerProxy) DisconnectWifiDisplay

func (p *DisplayManagerProxy) DisconnectWifiDisplay(
	ctx context.Context,
) error

func (*DisplayManagerProxy) EnableConnectedDisplay

func (p *DisplayManagerProxy) EnableConnectedDisplay(
	ctx context.Context,
	displayId int32,
) error

func (*DisplayManagerProxy) ForgetWifiDisplay

func (p *DisplayManagerProxy) ForgetWifiDisplay(
	ctx context.Context,
	address string,
) error

func (*DisplayManagerProxy) GetAmbientBrightnessStats

func (p *DisplayManagerProxy) GetAmbientBrightnessStats(
	ctx context.Context,
) (pm.ParceledListSlice, error)

func (*DisplayManagerProxy) GetBrightness

func (p *DisplayManagerProxy) GetBrightness(
	ctx context.Context,
	displayId int32,
) (float32, error)

func (*DisplayManagerProxy) GetBrightnessConfigurationForDisplay

func (p *DisplayManagerProxy) GetBrightnessConfigurationForDisplay(
	ctx context.Context,
	uniqueDisplayId string,
) (BrightnessConfiguration, error)

func (*DisplayManagerProxy) GetBrightnessConfigurationForUser

func (p *DisplayManagerProxy) GetBrightnessConfigurationForUser(
	ctx context.Context,
) (BrightnessConfiguration, error)

func (*DisplayManagerProxy) GetBrightnessEvents

func (p *DisplayManagerProxy) GetBrightnessEvents(
	ctx context.Context,
) (pm.ParceledListSlice, error)

func (*DisplayManagerProxy) GetBrightnessInfo

func (p *DisplayManagerProxy) GetBrightnessInfo(
	ctx context.Context,
	displayId int32,
) (BrightnessInfo, error)

func (*DisplayManagerProxy) GetDefaultBrightnessConfiguration

func (p *DisplayManagerProxy) GetDefaultBrightnessConfiguration(
	ctx context.Context,
) (BrightnessConfiguration, error)

func (*DisplayManagerProxy) GetDisplayDecorationSupport

func (p *DisplayManagerProxy) GetDisplayDecorationSupport(
	ctx context.Context,
	displayId int32,
) (common.DisplayDecorationSupport, error)

func (*DisplayManagerProxy) GetDisplayIds

func (p *DisplayManagerProxy) GetDisplayIds(
	ctx context.Context,
	includeDisabled bool,
) ([]int32, error)

func (*DisplayManagerProxy) GetDisplayInfo

func (p *DisplayManagerProxy) GetDisplayInfo(
	ctx context.Context,
	displayId int32,
) (gui.DisplayInfo, error)

func (*DisplayManagerProxy) GetHdrConversionMode

func (p *DisplayManagerProxy) GetHdrConversionMode(
	ctx context.Context,
) (HdrConversionMode, error)

func (*DisplayManagerProxy) GetHdrConversionModeSetting

func (p *DisplayManagerProxy) GetHdrConversionModeSetting(
	ctx context.Context,
) (HdrConversionMode, error)

func (*DisplayManagerProxy) GetMinimumBrightnessCurve

func (p *DisplayManagerProxy) GetMinimumBrightnessCurve(
	ctx context.Context,
) (Curve, error)

func (*DisplayManagerProxy) GetOverlaySupport

func (p *DisplayManagerProxy) GetOverlaySupport(
	ctx context.Context,
) (hardware.OverlayProperties, error)

func (*DisplayManagerProxy) GetPreferredWideGamutColorSpaceId

func (p *DisplayManagerProxy) GetPreferredWideGamutColorSpaceId(
	ctx context.Context,
) (int32, error)

func (*DisplayManagerProxy) GetRefreshRateSwitchingType

func (p *DisplayManagerProxy) GetRefreshRateSwitchingType(
	ctx context.Context,
) (int32, error)

func (*DisplayManagerProxy) GetStableDisplaySize

func (p *DisplayManagerProxy) GetStableDisplaySize(
	ctx context.Context,
) (common.Point, error)

func (*DisplayManagerProxy) GetSupportedHdrOutputTypes

func (p *DisplayManagerProxy) GetSupportedHdrOutputTypes(
	ctx context.Context,
) ([]int32, error)

func (*DisplayManagerProxy) GetSystemPreferredDisplayMode

func (p *DisplayManagerProxy) GetSystemPreferredDisplayMode(
	ctx context.Context,
	displayId int32,
) (drm.Mode, error)

func (*DisplayManagerProxy) GetUserDisabledHdrTypes

func (p *DisplayManagerProxy) GetUserDisabledHdrTypes(
	ctx context.Context,
) ([]int32, error)

func (*DisplayManagerProxy) GetUserPreferredDisplayMode

func (p *DisplayManagerProxy) GetUserPreferredDisplayMode(
	ctx context.Context,
	displayId int32,
) (drm.Mode, error)

func (*DisplayManagerProxy) GetWifiDisplayStatus

func (p *DisplayManagerProxy) GetWifiDisplayStatus(
	ctx context.Context,
) (WifiDisplayStatus, error)

func (*DisplayManagerProxy) IsMinimalPostProcessingRequested

func (p *DisplayManagerProxy) IsMinimalPostProcessingRequested(
	ctx context.Context,
	displayId int32,
) (bool, error)

func (*DisplayManagerProxy) IsUidPresentOnDisplay

func (p *DisplayManagerProxy) IsUidPresentOnDisplay(
	ctx context.Context,
	uid int32,
	displayId int32,
) (bool, error)

func (*DisplayManagerProxy) OverrideHdrTypes

func (p *DisplayManagerProxy) OverrideHdrTypes(
	ctx context.Context,
	displayId int32,
	modes []int32,
) error

func (*DisplayManagerProxy) PauseWifiDisplay

func (p *DisplayManagerProxy) PauseWifiDisplay(
	ctx context.Context,
) error

func (*DisplayManagerProxy) RegisterCallback

func (p *DisplayManagerProxy) RegisterCallback(
	ctx context.Context,
	callback IDisplayManagerCallback,
) error

func (*DisplayManagerProxy) RegisterCallbackWithEventMask

func (p *DisplayManagerProxy) RegisterCallbackWithEventMask(
	ctx context.Context,
	callback IDisplayManagerCallback,
	eventsMask int64,
) error

func (*DisplayManagerProxy) ReleaseVirtualDisplay

func (p *DisplayManagerProxy) ReleaseVirtualDisplay(
	ctx context.Context,
	token IVirtualDisplayCallback,
) error

func (*DisplayManagerProxy) RenameWifiDisplay

func (p *DisplayManagerProxy) RenameWifiDisplay(
	ctx context.Context,
	address string,
	alias string,
) error

func (*DisplayManagerProxy) RequestColorMode

func (p *DisplayManagerProxy) RequestColorMode(
	ctx context.Context,
	displayId int32,
	colorMode int32,
) error

func (*DisplayManagerProxy) ResizeVirtualDisplay

func (p *DisplayManagerProxy) ResizeVirtualDisplay(
	ctx context.Context,
	token IVirtualDisplayCallback,
	width int32,
	height int32,
	densityDpi int32,
) error

func (*DisplayManagerProxy) ResumeWifiDisplay

func (p *DisplayManagerProxy) ResumeWifiDisplay(
	ctx context.Context,
) error

func (*DisplayManagerProxy) SetAreUserDisabledHdrTypesAllowed

func (p *DisplayManagerProxy) SetAreUserDisabledHdrTypesAllowed(
	ctx context.Context,
	areUserDisabledHdrTypesAllowed bool,
) error

func (*DisplayManagerProxy) SetBrightness

func (p *DisplayManagerProxy) SetBrightness(
	ctx context.Context,
	displayId int32,
	brightness float32,
) error

func (*DisplayManagerProxy) SetBrightnessConfigurationForDisplay

func (p *DisplayManagerProxy) SetBrightnessConfigurationForDisplay(
	ctx context.Context,
	c BrightnessConfiguration,
	uniqueDisplayId string,
	packageName string,
) error

func (*DisplayManagerProxy) SetBrightnessConfigurationForUser

func (p *DisplayManagerProxy) SetBrightnessConfigurationForUser(
	ctx context.Context,
	c BrightnessConfiguration,
	packageName string,
) error

func (*DisplayManagerProxy) SetDisplayIdToMirror

func (p *DisplayManagerProxy) SetDisplayIdToMirror(
	ctx context.Context,
	token binder.IBinder,
	displayId int32,
) error

func (*DisplayManagerProxy) SetHdrConversionMode

func (p *DisplayManagerProxy) SetHdrConversionMode(
	ctx context.Context,
	hdrConversionMode HdrConversionMode,
) error

func (*DisplayManagerProxy) SetRefreshRateSwitchingType

func (p *DisplayManagerProxy) SetRefreshRateSwitchingType(
	ctx context.Context,
	newValue int32,
) error

func (*DisplayManagerProxy) SetShouldAlwaysRespectAppRequestedMode

func (p *DisplayManagerProxy) SetShouldAlwaysRespectAppRequestedMode(
	ctx context.Context,
	enabled bool,
) error

func (*DisplayManagerProxy) SetTemporaryAutoBrightnessAdjustment

func (p *DisplayManagerProxy) SetTemporaryAutoBrightnessAdjustment(
	ctx context.Context,
	adjustment float32,
) error

func (*DisplayManagerProxy) SetTemporaryBrightness

func (p *DisplayManagerProxy) SetTemporaryBrightness(
	ctx context.Context,
	displayId int32,
	brightness float32,
) error

func (*DisplayManagerProxy) SetUserDisabledHdrTypes

func (p *DisplayManagerProxy) SetUserDisabledHdrTypes(
	ctx context.Context,
	userDisabledTypes []int32,
) error

func (*DisplayManagerProxy) SetUserPreferredDisplayMode

func (p *DisplayManagerProxy) SetUserPreferredDisplayMode(
	ctx context.Context,
	displayId int32,
	mode drm.Mode,
) error

func (*DisplayManagerProxy) SetVirtualDisplayState

func (p *DisplayManagerProxy) SetVirtualDisplayState(
	ctx context.Context,
	token IVirtualDisplayCallback,
	isOn bool,
) error

func (*DisplayManagerProxy) SetVirtualDisplaySurface

func (p *DisplayManagerProxy) SetVirtualDisplaySurface(
	ctx context.Context,
	token IVirtualDisplayCallback,
	surface view.Surface,
) error

func (*DisplayManagerProxy) ShouldAlwaysRespectAppRequestedMode

func (p *DisplayManagerProxy) ShouldAlwaysRespectAppRequestedMode(
	ctx context.Context,
) (bool, error)

func (*DisplayManagerProxy) StartWifiDisplayScan

func (p *DisplayManagerProxy) StartWifiDisplayScan(
	ctx context.Context,
) error

func (*DisplayManagerProxy) StopWifiDisplayScan

func (p *DisplayManagerProxy) StopWifiDisplayScan(
	ctx context.Context,
) error

type DisplayManagerStub

type DisplayManagerStub struct {
	Impl      IDisplayManager
	Transport binder.VersionAwareTransport
}

DisplayManagerStub dispatches incoming binder transactions to a typed IDisplayManager implementation.

func (*DisplayManagerStub) Descriptor

func (s *DisplayManagerStub) Descriptor() string

func (*DisplayManagerStub) OnTransaction

func (s *DisplayManagerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type HdrConversionMode

type HdrConversionMode struct {
	ConversionMode         int32
	PreferredHdrOutputType int32
}

func (*HdrConversionMode) MarshalParcel

func (s *HdrConversionMode) MarshalParcel(
	p *parcel.Parcel,
) error

func (*HdrConversionMode) UnmarshalParcel

func (s *HdrConversionMode) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IColorDisplayManager

type IColorDisplayManager interface {
	AsBinder() binder.IBinder
	IsDeviceColorManaged(ctx context.Context) (bool, error)
	SetSaturationLevel(ctx context.Context, saturationLevel int32) (bool, error)
	SetAppSaturationLevel(ctx context.Context, packageName string, saturationLevel int32) (bool, error)
	IsSaturationActivated(ctx context.Context) (bool, error)
	GetTransformCapabilities(ctx context.Context) (int32, error)
	IsNightDisplayActivated(ctx context.Context) (bool, error)
	SetNightDisplayActivated(ctx context.Context, activated bool) (bool, error)
	GetNightDisplayColorTemperature(ctx context.Context) (int32, error)
	SetNightDisplayColorTemperature(ctx context.Context, temperature int32) (bool, error)
	GetNightDisplayAutoMode(ctx context.Context) (int32, error)
	GetNightDisplayAutoModeRaw(ctx context.Context) (int32, error)
	SetNightDisplayAutoMode(ctx context.Context, autoMode int32) (bool, error)
	GetNightDisplayCustomStartTime(ctx context.Context) (Time, error)
	SetNightDisplayCustomStartTime(ctx context.Context, time Time) (bool, error)
	GetNightDisplayCustomEndTime(ctx context.Context) (Time, error)
	SetNightDisplayCustomEndTime(ctx context.Context, time Time) (bool, error)
	GetColorMode(ctx context.Context) (int32, error)
	SetColorMode(ctx context.Context, colorMode int32) error
	IsDisplayWhiteBalanceEnabled(ctx context.Context) (bool, error)
	SetDisplayWhiteBalanceEnabled(ctx context.Context, enabled bool) (bool, error)
	IsReduceBrightColorsActivated(ctx context.Context) (bool, error)
	SetReduceBrightColorsActivated(ctx context.Context, activated bool) (bool, error)
	GetReduceBrightColorsStrength(ctx context.Context) (int32, error)
	SetReduceBrightColorsStrength(ctx context.Context, strength int32) (bool, error)
	GetReduceBrightColorsOffsetFactor(ctx context.Context) (float32, error)
}

func NewColorDisplayManagerStub

func NewColorDisplayManagerStub(
	impl IColorDisplayManagerServer,
) IColorDisplayManager

NewColorDisplayManagerStub creates a server-side IColorDisplayManager wrapping the given server implementation. The returned value satisfies IColorDisplayManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IColorDisplayManagerServer

type IColorDisplayManagerServer interface {
	IsDeviceColorManaged(ctx context.Context) (bool, error)
	SetSaturationLevel(ctx context.Context, saturationLevel int32) (bool, error)
	SetAppSaturationLevel(ctx context.Context, packageName string, saturationLevel int32) (bool, error)
	IsSaturationActivated(ctx context.Context) (bool, error)
	GetTransformCapabilities(ctx context.Context) (int32, error)
	IsNightDisplayActivated(ctx context.Context) (bool, error)
	SetNightDisplayActivated(ctx context.Context, activated bool) (bool, error)
	GetNightDisplayColorTemperature(ctx context.Context) (int32, error)
	SetNightDisplayColorTemperature(ctx context.Context, temperature int32) (bool, error)
	GetNightDisplayAutoMode(ctx context.Context) (int32, error)
	GetNightDisplayAutoModeRaw(ctx context.Context) (int32, error)
	SetNightDisplayAutoMode(ctx context.Context, autoMode int32) (bool, error)
	GetNightDisplayCustomStartTime(ctx context.Context) (Time, error)
	SetNightDisplayCustomStartTime(ctx context.Context, time Time) (bool, error)
	GetNightDisplayCustomEndTime(ctx context.Context) (Time, error)
	SetNightDisplayCustomEndTime(ctx context.Context, time Time) (bool, error)
	GetColorMode(ctx context.Context) (int32, error)
	SetColorMode(ctx context.Context, colorMode int32) error
	IsDisplayWhiteBalanceEnabled(ctx context.Context) (bool, error)
	SetDisplayWhiteBalanceEnabled(ctx context.Context, enabled bool) (bool, error)
	IsReduceBrightColorsActivated(ctx context.Context) (bool, error)
	SetReduceBrightColorsActivated(ctx context.Context, activated bool) (bool, error)
	GetReduceBrightColorsStrength(ctx context.Context) (int32, error)
	SetReduceBrightColorsStrength(ctx context.Context, strength int32) (bool, error)
	GetReduceBrightColorsOffsetFactor(ctx context.Context) (float32, error)
}

IColorDisplayManagerServer is the server-side interface that user implementations provide to NewColorDisplayManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IDeviceProductInfoConstants

type IDeviceProductInfoConstants interface {
	AsBinder() binder.IBinder
}

func NewDeviceProductInfoConstantsStub

func NewDeviceProductInfoConstantsStub(
	impl IDeviceProductInfoConstantsServer,
) IDeviceProductInfoConstants

NewDeviceProductInfoConstantsStub creates a server-side IDeviceProductInfoConstants wrapping the given server implementation. The returned value satisfies IDeviceProductInfoConstants and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDeviceProductInfoConstantsServer

type IDeviceProductInfoConstantsServer interface {
}

IDeviceProductInfoConstantsServer is the server-side interface that user implementations provide to NewDeviceProductInfoConstantsStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IDisplayManager

type IDisplayManager interface {
	AsBinder() binder.IBinder
	GetDisplayInfo(ctx context.Context, displayId int32) (gui.DisplayInfo, error)
	GetDisplayIds(ctx context.Context, includeDisabled bool) ([]int32, error)
	IsUidPresentOnDisplay(ctx context.Context, uid int32, displayId int32) (bool, error)
	RegisterCallback(ctx context.Context, callback IDisplayManagerCallback) error
	RegisterCallbackWithEventMask(ctx context.Context, callback IDisplayManagerCallback, eventsMask int64) error
	StartWifiDisplayScan(ctx context.Context) error
	StopWifiDisplayScan(ctx context.Context) error
	ConnectWifiDisplay(ctx context.Context, address string) error
	DisconnectWifiDisplay(ctx context.Context) error
	RenameWifiDisplay(ctx context.Context, address string, alias string) error
	ForgetWifiDisplay(ctx context.Context, address string) error
	PauseWifiDisplay(ctx context.Context) error
	ResumeWifiDisplay(ctx context.Context) error
	GetWifiDisplayStatus(ctx context.Context) (WifiDisplayStatus, error)
	SetUserDisabledHdrTypes(ctx context.Context, userDisabledTypes []int32) error
	SetAreUserDisabledHdrTypesAllowed(ctx context.Context, areUserDisabledHdrTypesAllowed bool) error
	AreUserDisabledHdrTypesAllowed(ctx context.Context) (bool, error)
	GetUserDisabledHdrTypes(ctx context.Context) ([]int32, error)
	OverrideHdrTypes(ctx context.Context, displayId int32, modes []int32) error
	RequestColorMode(ctx context.Context, displayId int32, colorMode int32) error
	CreateVirtualDisplay(ctx context.Context, virtualDisplayConfig VirtualDisplayConfig, callback IVirtualDisplayCallback, projectionToken projection.IMediaProjection, packageName string) (int32, error)
	ResizeVirtualDisplay(ctx context.Context, token IVirtualDisplayCallback, width int32, height int32, densityDpi int32) error
	SetVirtualDisplaySurface(ctx context.Context, token IVirtualDisplayCallback, surface view.Surface) error
	ReleaseVirtualDisplay(ctx context.Context, token IVirtualDisplayCallback) error
	SetVirtualDisplayState(ctx context.Context, token IVirtualDisplayCallback, isOn bool) error
	GetStableDisplaySize(ctx context.Context) (common.Point, error)
	GetBrightnessEvents(ctx context.Context) (pm.ParceledListSlice, error)
	GetAmbientBrightnessStats(ctx context.Context) (pm.ParceledListSlice, error)
	SetBrightnessConfigurationForUser(ctx context.Context, c BrightnessConfiguration, packageName string) error
	SetBrightnessConfigurationForDisplay(ctx context.Context, c BrightnessConfiguration, uniqueDisplayId string, packageName string) error
	GetBrightnessConfigurationForDisplay(ctx context.Context, uniqueDisplayId string) (BrightnessConfiguration, error)
	GetBrightnessConfigurationForUser(ctx context.Context) (BrightnessConfiguration, error)
	GetDefaultBrightnessConfiguration(ctx context.Context) (BrightnessConfiguration, error)
	IsMinimalPostProcessingRequested(ctx context.Context, displayId int32) (bool, error)
	SetTemporaryBrightness(ctx context.Context, displayId int32, brightness float32) error
	SetBrightness(ctx context.Context, displayId int32, brightness float32) error
	GetBrightness(ctx context.Context, displayId int32) (float32, error)
	SetTemporaryAutoBrightnessAdjustment(ctx context.Context, adjustment float32) error
	GetMinimumBrightnessCurve(ctx context.Context) (Curve, error)
	GetBrightnessInfo(ctx context.Context, displayId int32) (BrightnessInfo, error)
	GetPreferredWideGamutColorSpaceId(ctx context.Context) (int32, error)
	SetUserPreferredDisplayMode(ctx context.Context, displayId int32, mode drm.Mode) error
	GetUserPreferredDisplayMode(ctx context.Context, displayId int32) (drm.Mode, error)
	GetSystemPreferredDisplayMode(ctx context.Context, displayId int32) (drm.Mode, error)
	SetHdrConversionMode(ctx context.Context, hdrConversionMode HdrConversionMode) error
	GetHdrConversionModeSetting(ctx context.Context) (HdrConversionMode, error)
	GetHdrConversionMode(ctx context.Context) (HdrConversionMode, error)
	GetSupportedHdrOutputTypes(ctx context.Context) ([]int32, error)
	SetShouldAlwaysRespectAppRequestedMode(ctx context.Context, enabled bool) error
	ShouldAlwaysRespectAppRequestedMode(ctx context.Context) (bool, error)
	SetRefreshRateSwitchingType(ctx context.Context, newValue int32) error
	GetRefreshRateSwitchingType(ctx context.Context) (int32, error)
	GetDisplayDecorationSupport(ctx context.Context, displayId int32) (common.DisplayDecorationSupport, error)
	SetDisplayIdToMirror(ctx context.Context, token binder.IBinder, displayId int32) error
	GetOverlaySupport(ctx context.Context) (hardware.OverlayProperties, error)
	EnableConnectedDisplay(ctx context.Context, displayId int32) error
	DisableConnectedDisplay(ctx context.Context, displayId int32) error
}

func NewDisplayManagerStub

func NewDisplayManagerStub(
	impl IDisplayManagerServer,
) IDisplayManager

NewDisplayManagerStub creates a server-side IDisplayManager wrapping the given server implementation. The returned value satisfies IDisplayManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDisplayManagerCallback

type IDisplayManagerCallback interface {
	AsBinder() binder.IBinder
	OnDisplayEvent(ctx context.Context, displayId int32, event int32) error
}

func NewDisplayManagerCallbackStub

func NewDisplayManagerCallbackStub(
	impl IDisplayManagerCallbackServer,
) IDisplayManagerCallback

NewDisplayManagerCallbackStub creates a server-side IDisplayManagerCallback wrapping the given server implementation. The returned value satisfies IDisplayManagerCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDisplayManagerCallbackServer

type IDisplayManagerCallbackServer interface {
	OnDisplayEvent(ctx context.Context, displayId int32, event int32) error
}

IDisplayManagerCallbackServer is the server-side interface that user implementations provide to NewDisplayManagerCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IDisplayManagerServer

type IDisplayManagerServer interface {
	GetDisplayInfo(ctx context.Context, displayId int32) (gui.DisplayInfo, error)
	GetDisplayIds(ctx context.Context, includeDisabled bool) ([]int32, error)
	IsUidPresentOnDisplay(ctx context.Context, uid int32, displayId int32) (bool, error)
	RegisterCallback(ctx context.Context, callback IDisplayManagerCallback) error
	RegisterCallbackWithEventMask(ctx context.Context, callback IDisplayManagerCallback, eventsMask int64) error
	StartWifiDisplayScan(ctx context.Context) error
	StopWifiDisplayScan(ctx context.Context) error
	ConnectWifiDisplay(ctx context.Context, address string) error
	DisconnectWifiDisplay(ctx context.Context) error
	RenameWifiDisplay(ctx context.Context, address string, alias string) error
	ForgetWifiDisplay(ctx context.Context, address string) error
	PauseWifiDisplay(ctx context.Context) error
	ResumeWifiDisplay(ctx context.Context) error
	GetWifiDisplayStatus(ctx context.Context) (WifiDisplayStatus, error)
	SetUserDisabledHdrTypes(ctx context.Context, userDisabledTypes []int32) error
	SetAreUserDisabledHdrTypesAllowed(ctx context.Context, areUserDisabledHdrTypesAllowed bool) error
	AreUserDisabledHdrTypesAllowed(ctx context.Context) (bool, error)
	GetUserDisabledHdrTypes(ctx context.Context) ([]int32, error)
	OverrideHdrTypes(ctx context.Context, displayId int32, modes []int32) error
	RequestColorMode(ctx context.Context, displayId int32, colorMode int32) error
	CreateVirtualDisplay(ctx context.Context, virtualDisplayConfig VirtualDisplayConfig, callback IVirtualDisplayCallback, projectionToken projection.IMediaProjection, packageName string) (int32, error)
	ResizeVirtualDisplay(ctx context.Context, token IVirtualDisplayCallback, width int32, height int32, densityDpi int32) error
	SetVirtualDisplaySurface(ctx context.Context, token IVirtualDisplayCallback, surface view.Surface) error
	ReleaseVirtualDisplay(ctx context.Context, token IVirtualDisplayCallback) error
	SetVirtualDisplayState(ctx context.Context, token IVirtualDisplayCallback, isOn bool) error
	GetStableDisplaySize(ctx context.Context) (common.Point, error)
	GetBrightnessEvents(ctx context.Context) (pm.ParceledListSlice, error)
	GetAmbientBrightnessStats(ctx context.Context) (pm.ParceledListSlice, error)
	SetBrightnessConfigurationForUser(ctx context.Context, c BrightnessConfiguration, packageName string) error
	SetBrightnessConfigurationForDisplay(ctx context.Context, c BrightnessConfiguration, uniqueDisplayId string, packageName string) error
	GetBrightnessConfigurationForDisplay(ctx context.Context, uniqueDisplayId string) (BrightnessConfiguration, error)
	GetBrightnessConfigurationForUser(ctx context.Context) (BrightnessConfiguration, error)
	GetDefaultBrightnessConfiguration(ctx context.Context) (BrightnessConfiguration, error)
	IsMinimalPostProcessingRequested(ctx context.Context, displayId int32) (bool, error)
	SetTemporaryBrightness(ctx context.Context, displayId int32, brightness float32) error
	SetBrightness(ctx context.Context, displayId int32, brightness float32) error
	GetBrightness(ctx context.Context, displayId int32) (float32, error)
	SetTemporaryAutoBrightnessAdjustment(ctx context.Context, adjustment float32) error
	GetMinimumBrightnessCurve(ctx context.Context) (Curve, error)
	GetBrightnessInfo(ctx context.Context, displayId int32) (BrightnessInfo, error)
	GetPreferredWideGamutColorSpaceId(ctx context.Context) (int32, error)
	SetUserPreferredDisplayMode(ctx context.Context, displayId int32, mode drm.Mode) error
	GetUserPreferredDisplayMode(ctx context.Context, displayId int32) (drm.Mode, error)
	GetSystemPreferredDisplayMode(ctx context.Context, displayId int32) (drm.Mode, error)
	SetHdrConversionMode(ctx context.Context, hdrConversionMode HdrConversionMode) error
	GetHdrConversionModeSetting(ctx context.Context) (HdrConversionMode, error)
	GetHdrConversionMode(ctx context.Context) (HdrConversionMode, error)
	GetSupportedHdrOutputTypes(ctx context.Context) ([]int32, error)
	SetShouldAlwaysRespectAppRequestedMode(ctx context.Context, enabled bool) error
	ShouldAlwaysRespectAppRequestedMode(ctx context.Context) (bool, error)
	SetRefreshRateSwitchingType(ctx context.Context, newValue int32) error
	GetRefreshRateSwitchingType(ctx context.Context) (int32, error)
	GetDisplayDecorationSupport(ctx context.Context, displayId int32) (common.DisplayDecorationSupport, error)
	SetDisplayIdToMirror(ctx context.Context, token binder.IBinder, displayId int32) error
	GetOverlaySupport(ctx context.Context) (hardware.OverlayProperties, error)
	EnableConnectedDisplay(ctx context.Context, displayId int32) error
	DisableConnectedDisplay(ctx context.Context, displayId int32) error
}

IDisplayManagerServer is the server-side interface that user implementations provide to NewDisplayManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IVirtualDisplayCallback

type IVirtualDisplayCallback interface {
	AsBinder() binder.IBinder
	OnPaused(ctx context.Context) error
	OnResumed(ctx context.Context) error
	OnStopped(ctx context.Context) error
}

func NewVirtualDisplayCallbackStub

func NewVirtualDisplayCallbackStub(
	impl IVirtualDisplayCallbackServer,
) IVirtualDisplayCallback

NewVirtualDisplayCallbackStub creates a server-side IVirtualDisplayCallback wrapping the given server implementation. The returned value satisfies IVirtualDisplayCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IVirtualDisplayCallbackServer

type IVirtualDisplayCallbackServer interface {
	OnPaused(ctx context.Context) error
	OnResumed(ctx context.Context) error
	OnStopped(ctx context.Context) error
}

IVirtualDisplayCallbackServer is the server-side interface that user implementations provide to NewVirtualDisplayCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type Time

type Time struct {
	Hour   int32
	Minute int32
	Second int32
	Nano   int32
}

func (*Time) MarshalParcel

func (s *Time) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Time) UnmarshalParcel

func (s *Time) UnmarshalParcel(
	p *parcel.Parcel,
) error

type VirtualDisplayCallbackProxy

type VirtualDisplayCallbackProxy struct {
	Remote binder.IBinder
}

func NewVirtualDisplayCallbackProxy

func NewVirtualDisplayCallbackProxy(
	remote binder.IBinder,
) *VirtualDisplayCallbackProxy

func (*VirtualDisplayCallbackProxy) AsBinder

func (*VirtualDisplayCallbackProxy) OnPaused

func (p *VirtualDisplayCallbackProxy) OnPaused(
	ctx context.Context,
) error

func (*VirtualDisplayCallbackProxy) OnResumed

func (p *VirtualDisplayCallbackProxy) OnResumed(
	ctx context.Context,
) error

func (*VirtualDisplayCallbackProxy) OnStopped

func (p *VirtualDisplayCallbackProxy) OnStopped(
	ctx context.Context,
) error

type VirtualDisplayCallbackStub

type VirtualDisplayCallbackStub struct {
	Impl      IVirtualDisplayCallback
	Transport binder.VersionAwareTransport
}

VirtualDisplayCallbackStub dispatches incoming binder transactions to a typed IVirtualDisplayCallback implementation.

func (*VirtualDisplayCallbackStub) Descriptor

func (s *VirtualDisplayCallbackStub) Descriptor() string

func (*VirtualDisplayCallbackStub) OnTransaction

func (s *VirtualDisplayCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type VirtualDisplayConfig

type VirtualDisplayConfig struct {
	Name                          string
	Width                         int32
	Height                        int32
	DensityDpi                    int32
	Flags                         int32
	UniqueId                      string
	DisplayIdToMirror             int32
	WindowManagerMirroringEnabled bool
	RequestedRefreshRate          float32
	IsHomeSupported               bool
	Surface                       *view.Surface
}

func (*VirtualDisplayConfig) MarshalParcel

func (s *VirtualDisplayConfig) MarshalParcel(
	p *parcel.Parcel,
) error

func (*VirtualDisplayConfig) UnmarshalParcel

func (s *VirtualDisplayConfig) UnmarshalParcel(
	p *parcel.Parcel,
) error

type WifiDisplay

type WifiDisplay struct {
	DeviceAddress string
	DeviceName    string
	DeviceAlias   string
}

func (*WifiDisplay) MarshalParcel

func (s *WifiDisplay) MarshalParcel(
	p *parcel.Parcel,
) error

func (*WifiDisplay) UnmarshalParcel

func (s *WifiDisplay) UnmarshalParcel(
	p *parcel.Parcel,
) error

type WifiDisplayStatus

type WifiDisplayStatus struct {
	FeatureState       int32
	ScanState          int32
	ActiveDisplayState int32
}

func (*WifiDisplayStatus) MarshalParcel

func (s *WifiDisplayStatus) MarshalParcel(
	p *parcel.Parcel,
) error

func (*WifiDisplayStatus) UnmarshalParcel

func (s *WifiDisplayStatus) UnmarshalParcel(
	p *parcel.Parcel,
) error

Jump to