face

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIFaceServiceCreateTestSession                     = binder.FirstCallTransaction + 0
	TransactionIFaceServiceDumpSensorServiceStateProto           = binder.FirstCallTransaction + 1
	TransactionIFaceServiceGetSensorPropertiesInternal           = binder.FirstCallTransaction + 2
	TransactionIFaceServiceGetSensorProperties                   = binder.FirstCallTransaction + 3
	TransactionIFaceServiceAuthenticate                          = binder.FirstCallTransaction + 4
	TransactionIFaceServiceDetectFace                            = binder.FirstCallTransaction + 5
	TransactionIFaceServicePrepareForAuthentication              = binder.FirstCallTransaction + 6
	TransactionIFaceServiceStartPreparedClient                   = binder.FirstCallTransaction + 7
	TransactionIFaceServiceCancelAuthentication                  = binder.FirstCallTransaction + 8
	TransactionIFaceServiceCancelFaceDetect                      = binder.FirstCallTransaction + 9
	TransactionIFaceServiceCancelAuthenticationFromService       = binder.FirstCallTransaction + 10
	TransactionIFaceServiceEnroll                                = binder.FirstCallTransaction + 11
	TransactionIFaceServiceEnrollRemotely                        = binder.FirstCallTransaction + 12
	TransactionIFaceServiceCancelEnrollment                      = binder.FirstCallTransaction + 13
	TransactionIFaceServiceRemove                                = binder.FirstCallTransaction + 14
	TransactionIFaceServiceRemoveAll                             = binder.FirstCallTransaction + 15
	TransactionIFaceServiceGetEnrolledFaces                      = binder.FirstCallTransaction + 16
	TransactionIFaceServiceIsHardwareDetected                    = binder.FirstCallTransaction + 17
	TransactionIFaceServiceGenerateChallenge                     = binder.FirstCallTransaction + 18
	TransactionIFaceServiceRevokeChallenge                       = binder.FirstCallTransaction + 19
	TransactionIFaceServiceHasEnrolledFaces                      = binder.FirstCallTransaction + 20
	TransactionIFaceServiceGetLockoutModeForUser                 = binder.FirstCallTransaction + 21
	TransactionIFaceServiceInvalidateAuthenticatorId             = binder.FirstCallTransaction + 22
	TransactionIFaceServiceGetAuthenticatorId                    = binder.FirstCallTransaction + 23
	TransactionIFaceServiceResetLockout                          = binder.FirstCallTransaction + 24
	TransactionIFaceServiceAddLockoutResetCallback               = binder.FirstCallTransaction + 25
	TransactionIFaceServiceSetFeature                            = binder.FirstCallTransaction + 26
	TransactionIFaceServiceGetFeature                            = binder.FirstCallTransaction + 27
	TransactionIFaceServiceRegisterAuthenticators                = binder.FirstCallTransaction + 28
	TransactionIFaceServiceRegisterAuthenticatorsLegacy          = binder.FirstCallTransaction + 29
	TransactionIFaceServiceAddAuthenticatorsRegisteredCallback   = binder.FirstCallTransaction + 30
	TransactionIFaceServiceRegisterAuthenticationStateListener   = binder.FirstCallTransaction + 31
	TransactionIFaceServiceUnregisterAuthenticationStateListener = binder.FirstCallTransaction + 32
	TransactionIFaceServiceRegisterBiometricStateListener        = binder.FirstCallTransaction + 33
	TransactionIFaceServiceScheduleWatchdog                      = binder.FirstCallTransaction + 34
)
const (
	MethodIFaceServiceCreateTestSession                     = "createTestSession"
	MethodIFaceServiceDumpSensorServiceStateProto           = "dumpSensorServiceStateProto"
	MethodIFaceServiceGetSensorPropertiesInternal           = "getSensorPropertiesInternal"
	MethodIFaceServiceGetSensorProperties                   = "getSensorProperties"
	MethodIFaceServiceAuthenticate                          = "authenticate"
	MethodIFaceServiceDetectFace                            = "detectFace"
	MethodIFaceServicePrepareForAuthentication              = "prepareForAuthentication"
	MethodIFaceServiceStartPreparedClient                   = "startPreparedClient"
	MethodIFaceServiceCancelAuthentication                  = "cancelAuthentication"
	MethodIFaceServiceCancelFaceDetect                      = "cancelFaceDetect"
	MethodIFaceServiceCancelAuthenticationFromService       = "cancelAuthenticationFromService"
	MethodIFaceServiceEnroll                                = "enroll"
	MethodIFaceServiceEnrollRemotely                        = "enrollRemotely"
	MethodIFaceServiceCancelEnrollment                      = "cancelEnrollment"
	MethodIFaceServiceRemove                                = "remove"
	MethodIFaceServiceRemoveAll                             = "removeAll"
	MethodIFaceServiceGetEnrolledFaces                      = "getEnrolledFaces"
	MethodIFaceServiceIsHardwareDetected                    = "isHardwareDetected"
	MethodIFaceServiceGenerateChallenge                     = "generateChallenge"
	MethodIFaceServiceRevokeChallenge                       = "revokeChallenge"
	MethodIFaceServiceHasEnrolledFaces                      = "hasEnrolledFaces"
	MethodIFaceServiceGetLockoutModeForUser                 = "getLockoutModeForUser"
	MethodIFaceServiceInvalidateAuthenticatorId             = "invalidateAuthenticatorId"
	MethodIFaceServiceGetAuthenticatorId                    = "getAuthenticatorId"
	MethodIFaceServiceResetLockout                          = "resetLockout"
	MethodIFaceServiceAddLockoutResetCallback               = "addLockoutResetCallback"
	MethodIFaceServiceSetFeature                            = "setFeature"
	MethodIFaceServiceGetFeature                            = "getFeature"
	MethodIFaceServiceRegisterAuthenticators                = "registerAuthenticators"
	MethodIFaceServiceRegisterAuthenticatorsLegacy          = "registerAuthenticatorsLegacy"
	MethodIFaceServiceAddAuthenticatorsRegisteredCallback   = "addAuthenticatorsRegisteredCallback"
	MethodIFaceServiceRegisterAuthenticationStateListener   = "registerAuthenticationStateListener"
	MethodIFaceServiceUnregisterAuthenticationStateListener = "unregisterAuthenticationStateListener"
	MethodIFaceServiceRegisterBiometricStateListener        = "registerBiometricStateListener"
	MethodIFaceServiceScheduleWatchdog                      = "scheduleWatchdog"
)
const (
	TransactionIFaceServiceReceiverOnEnrollResult            = binder.FirstCallTransaction + 0
	TransactionIFaceServiceReceiverOnAcquired                = binder.FirstCallTransaction + 1
	TransactionIFaceServiceReceiverOnAuthenticationSucceeded = binder.FirstCallTransaction + 2
	TransactionIFaceServiceReceiverOnFaceDetected            = binder.FirstCallTransaction + 3
	TransactionIFaceServiceReceiverOnAuthenticationFailed    = binder.FirstCallTransaction + 4
	TransactionIFaceServiceReceiverOnError                   = binder.FirstCallTransaction + 5
	TransactionIFaceServiceReceiverOnRemoved                 = binder.FirstCallTransaction + 6
	TransactionIFaceServiceReceiverOnFeatureSet              = binder.FirstCallTransaction + 7
	TransactionIFaceServiceReceiverOnFeatureGet              = binder.FirstCallTransaction + 8
	TransactionIFaceServiceReceiverOnChallengeGenerated      = binder.FirstCallTransaction + 9
	TransactionIFaceServiceReceiverOnAuthenticationFrame     = binder.FirstCallTransaction + 10
	TransactionIFaceServiceReceiverOnEnrollmentFrame         = binder.FirstCallTransaction + 11
)
const (
	MethodIFaceServiceReceiverOnEnrollResult            = "onEnrollResult"
	MethodIFaceServiceReceiverOnAcquired                = "onAcquired"
	MethodIFaceServiceReceiverOnAuthenticationSucceeded = "onAuthenticationSucceeded"
	MethodIFaceServiceReceiverOnFaceDetected            = "onFaceDetected"
	MethodIFaceServiceReceiverOnAuthenticationFailed    = "onAuthenticationFailed"
	MethodIFaceServiceReceiverOnError                   = "onError"
	MethodIFaceServiceReceiverOnRemoved                 = "onRemoved"
	MethodIFaceServiceReceiverOnFeatureSet              = "onFeatureSet"
	MethodIFaceServiceReceiverOnFeatureGet              = "onFeatureGet"
	MethodIFaceServiceReceiverOnChallengeGenerated      = "onChallengeGenerated"
	MethodIFaceServiceReceiverOnAuthenticationFrame     = "onAuthenticationFrame"
	MethodIFaceServiceReceiverOnEnrollmentFrame         = "onEnrollmentFrame"
)
const DescriptorIFaceAuthenticatorsRegisteredCallback = "android.hardware.face.IFaceAuthenticatorsRegisteredCallback"
const DescriptorIFaceService = "android.hardware.face.IFaceService"
const DescriptorIFaceServiceReceiver = "android.hardware.face.IFaceServiceReceiver"
const (
	MethodIFaceAuthenticatorsRegisteredCallbackOnAllAuthenticatorsRegistered = "onAllAuthenticatorsRegistered"
)
const (
	TransactionIFaceAuthenticatorsRegisteredCallbackOnAllAuthenticatorsRegistered = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Face

type Face struct {
}

func (*Face) MarshalParcel

func (s *Face) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Face) UnmarshalParcel

func (s *Face) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FaceAuthenticateOptions

type FaceAuthenticateOptions struct {
	Flg                int32
	UserId             int32
	SensorId           int32
	DisplayState       int32
	AuthenticateReason int32
	WakeReason         int32
	OpPackageName      string
}

func (*FaceAuthenticateOptions) MarshalParcel

func (s *FaceAuthenticateOptions) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FaceAuthenticateOptions) UnmarshalParcel

func (s *FaceAuthenticateOptions) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FaceAuthenticationFrame

type FaceAuthenticationFrame struct {
}

func (*FaceAuthenticationFrame) MarshalParcel

func (s *FaceAuthenticationFrame) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FaceAuthenticationFrame) UnmarshalParcel

func (s *FaceAuthenticationFrame) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FaceAuthenticatorsRegisteredCallbackProxy

type FaceAuthenticatorsRegisteredCallbackProxy struct {
	Remote binder.IBinder
}

func NewFaceAuthenticatorsRegisteredCallbackProxy

func NewFaceAuthenticatorsRegisteredCallbackProxy(
	remote binder.IBinder,
) *FaceAuthenticatorsRegisteredCallbackProxy

func (*FaceAuthenticatorsRegisteredCallbackProxy) AsBinder

func (*FaceAuthenticatorsRegisteredCallbackProxy) OnAllAuthenticatorsRegistered

func (p *FaceAuthenticatorsRegisteredCallbackProxy) OnAllAuthenticatorsRegistered(
	ctx context.Context,
	sensors []FaceSensorPropertiesInternal,
) error

type FaceAuthenticatorsRegisteredCallbackStub

type FaceAuthenticatorsRegisteredCallbackStub struct {
	Impl      IFaceAuthenticatorsRegisteredCallback
	Transport binder.VersionAwareTransport
}

FaceAuthenticatorsRegisteredCallbackStub dispatches incoming binder transactions to a typed IFaceAuthenticatorsRegisteredCallback implementation.

func (*FaceAuthenticatorsRegisteredCallbackStub) Descriptor

func (*FaceAuthenticatorsRegisteredCallbackStub) OnTransaction

type FaceEnrollFrame

type FaceEnrollFrame struct {
	Stage int32
	Cell  *biometricsFace.Cell
}

func (*FaceEnrollFrame) MarshalParcel

func (s *FaceEnrollFrame) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FaceEnrollFrame) UnmarshalParcel

func (s *FaceEnrollFrame) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FaceEnrollOptions

type FaceEnrollOptions struct {
	EnrollReason int32
}

func (*FaceEnrollOptions) MarshalParcel

func (s *FaceEnrollOptions) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FaceEnrollOptions) UnmarshalParcel

func (s *FaceEnrollOptions) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FaceSensorConfigurations

type FaceSensorConfigurations struct {
}

func (*FaceSensorConfigurations) MarshalParcel

func (s *FaceSensorConfigurations) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FaceSensorConfigurations) UnmarshalParcel

func (s *FaceSensorConfigurations) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FaceSensorPropertiesInternal

type FaceSensorPropertiesInternal struct {
	SensorType               int32
	SupportsFaceDetection    bool
	SupportsSelfIllumination bool
}

func (*FaceSensorPropertiesInternal) MarshalParcel

func (s *FaceSensorPropertiesInternal) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FaceSensorPropertiesInternal) UnmarshalParcel

func (s *FaceSensorPropertiesInternal) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FaceServiceProxy

type FaceServiceProxy struct {
	Remote binder.IBinder
}

func GetFaceService

func GetFaceService(
	ctx context.Context,
	sm *servicemanager.ServiceManager,
) (*FaceServiceProxy, error)

GetFaceService retrieves the FaceService service and returns a typed proxy.

func NewFaceServiceProxy

func NewFaceServiceProxy(
	remote binder.IBinder,
) *FaceServiceProxy

func (*FaceServiceProxy) AddAuthenticatorsRegisteredCallback

func (p *FaceServiceProxy) AddAuthenticatorsRegisteredCallback(
	ctx context.Context,
	callback IFaceAuthenticatorsRegisteredCallback,
) error

func (*FaceServiceProxy) AddLockoutResetCallback

func (p *FaceServiceProxy) AddLockoutResetCallback(
	ctx context.Context,
	callback biometrics.IBiometricServiceLockoutResetCallback,
) error

func (*FaceServiceProxy) AsBinder

func (p *FaceServiceProxy) AsBinder() binder.IBinder

func (*FaceServiceProxy) Authenticate

func (p *FaceServiceProxy) Authenticate(
	ctx context.Context,
	token binder.IBinder,
	operationId int64,
	receiver IFaceServiceReceiver,
	options FaceAuthenticateOptions,
) (int64, error)

func (*FaceServiceProxy) CancelAuthentication

func (p *FaceServiceProxy) CancelAuthentication(
	ctx context.Context,
	token binder.IBinder,
	requestId int64,
) error

func (*FaceServiceProxy) CancelAuthenticationFromService

func (p *FaceServiceProxy) CancelAuthenticationFromService(
	ctx context.Context,
	sensorId int32,
	token binder.IBinder,
	requestId int64,
) error

func (*FaceServiceProxy) CancelEnrollment

func (p *FaceServiceProxy) CancelEnrollment(
	ctx context.Context,
	token binder.IBinder,
	requestId int64,
) error

func (*FaceServiceProxy) CancelFaceDetect

func (p *FaceServiceProxy) CancelFaceDetect(
	ctx context.Context,
	token binder.IBinder,
	requestId int64,
) error

func (*FaceServiceProxy) CreateTestSession

func (p *FaceServiceProxy) CreateTestSession(
	ctx context.Context,
	sensorId int32,
	callback biometrics.ITestSessionCallback,
) (biometrics.ITestSession, error)

func (*FaceServiceProxy) DetectFace

func (p *FaceServiceProxy) DetectFace(
	ctx context.Context,
	token binder.IBinder,
	receiver IFaceServiceReceiver,
	options FaceAuthenticateOptions,
) (int64, error)

func (*FaceServiceProxy) DumpSensorServiceStateProto

func (p *FaceServiceProxy) DumpSensorServiceStateProto(
	ctx context.Context,
	sensorId int32,
	clearSchedulerBuffer bool,
) ([]byte, error)

func (*FaceServiceProxy) Enroll

func (p *FaceServiceProxy) Enroll(
	ctx context.Context,
	token binder.IBinder,
	hardwareAuthToken []byte,
	receiver IFaceServiceReceiver,
	disabledFeatures []int32,
	previewSurface view.Surface,
	debugConsent bool,
	options FaceEnrollOptions,
) (int64, error)

func (*FaceServiceProxy) EnrollRemotely

func (p *FaceServiceProxy) EnrollRemotely(
	ctx context.Context,
	token binder.IBinder,
	hardwareAuthToken []byte,
	receiver IFaceServiceReceiver,
	disabledFeatures []int32,
) (int64, error)

func (*FaceServiceProxy) GenerateChallenge

func (p *FaceServiceProxy) GenerateChallenge(
	ctx context.Context,
	token binder.IBinder,
	sensorId int32,
	receiver IFaceServiceReceiver,
) error

func (*FaceServiceProxy) GetAuthenticatorId

func (p *FaceServiceProxy) GetAuthenticatorId(
	ctx context.Context,
	sensorId int32,
) (int64, error)

func (*FaceServiceProxy) GetEnrolledFaces

func (p *FaceServiceProxy) GetEnrolledFaces(
	ctx context.Context,
	sensorId int32,
) ([]Face, error)

func (*FaceServiceProxy) GetFeature

func (p *FaceServiceProxy) GetFeature(
	ctx context.Context,
	token binder.IBinder,
	feature int32,
	receiver IFaceServiceReceiver,
) error

func (*FaceServiceProxy) GetLockoutModeForUser

func (p *FaceServiceProxy) GetLockoutModeForUser(
	ctx context.Context,
	sensorId int32,
) (int32, error)

func (*FaceServiceProxy) GetSensorProperties

func (p *FaceServiceProxy) GetSensorProperties(
	ctx context.Context,
	sensorId int32,
) (FaceSensorPropertiesInternal, error)

func (*FaceServiceProxy) GetSensorPropertiesInternal

func (p *FaceServiceProxy) GetSensorPropertiesInternal(
	ctx context.Context,
) ([]FaceSensorPropertiesInternal, error)

func (*FaceServiceProxy) HasEnrolledFaces

func (p *FaceServiceProxy) HasEnrolledFaces(
	ctx context.Context,
	sensorId int32,
) (bool, error)

func (*FaceServiceProxy) InvalidateAuthenticatorId

func (p *FaceServiceProxy) InvalidateAuthenticatorId(
	ctx context.Context,
	sensorId int32,
	callback biometrics.IInvalidationCallback,
) error

func (*FaceServiceProxy) IsHardwareDetected

func (p *FaceServiceProxy) IsHardwareDetected(
	ctx context.Context,
	sensorId int32,
) (bool, error)

func (*FaceServiceProxy) PrepareForAuthentication

func (p *FaceServiceProxy) PrepareForAuthentication(
	ctx context.Context,
	requireConfirmation bool,
	token binder.IBinder,
	operationId int64,
	sensorReceiver biometrics.IBiometricSensorReceiver,
	options FaceAuthenticateOptions,
	requestId int64,
	cookie int32,
	allowBackgroundAuthentication bool,
) error

func (*FaceServiceProxy) RegisterAuthenticationStateListener

func (p *FaceServiceProxy) RegisterAuthenticationStateListener(
	ctx context.Context,
	listener biometrics.AuthenticationStateListener,
) error

func (*FaceServiceProxy) RegisterAuthenticators

func (p *FaceServiceProxy) RegisterAuthenticators(
	ctx context.Context,
	hidlSensors []FaceSensorPropertiesInternal,
) error

func (*FaceServiceProxy) RegisterAuthenticatorsLegacy

func (p *FaceServiceProxy) RegisterAuthenticatorsLegacy(
	ctx context.Context,
	faceSensorConfigurations FaceSensorConfigurations,
) error

func (*FaceServiceProxy) RegisterBiometricStateListener

func (p *FaceServiceProxy) RegisterBiometricStateListener(
	ctx context.Context,
	listener biometrics.IBiometricStateListener,
) error

func (*FaceServiceProxy) Remove

func (p *FaceServiceProxy) Remove(
	ctx context.Context,
	token binder.IBinder,
	faceId int32,
	receiver IFaceServiceReceiver,
) error

func (*FaceServiceProxy) RemoveAll

func (p *FaceServiceProxy) RemoveAll(
	ctx context.Context,
	token binder.IBinder,
	receiver IFaceServiceReceiver,
) error

func (*FaceServiceProxy) ResetLockout

func (p *FaceServiceProxy) ResetLockout(
	ctx context.Context,
	token binder.IBinder,
	sensorId int32,
	hardwareAuthToken []byte,
) error

func (*FaceServiceProxy) RevokeChallenge

func (p *FaceServiceProxy) RevokeChallenge(
	ctx context.Context,
	token binder.IBinder,
	sensorId int32,
	challenge int64,
) error

func (*FaceServiceProxy) ScheduleWatchdog

func (p *FaceServiceProxy) ScheduleWatchdog(
	ctx context.Context,
) error

func (*FaceServiceProxy) SetFeature

func (p *FaceServiceProxy) SetFeature(
	ctx context.Context,
	token binder.IBinder,
	feature int32,
	enabled bool,
	hardwareAuthToken []byte,
	receiver IFaceServiceReceiver,
) error

func (*FaceServiceProxy) StartPreparedClient

func (p *FaceServiceProxy) StartPreparedClient(
	ctx context.Context,
	sensorId int32,
	cookie int32,
) error

func (*FaceServiceProxy) UnregisterAuthenticationStateListener

func (p *FaceServiceProxy) UnregisterAuthenticationStateListener(
	ctx context.Context,
	listener biometrics.AuthenticationStateListener,
) error

type FaceServiceReceiverProxy

type FaceServiceReceiverProxy struct {
	Remote binder.IBinder
}

func NewFaceServiceReceiverProxy

func NewFaceServiceReceiverProxy(
	remote binder.IBinder,
) *FaceServiceReceiverProxy

func (*FaceServiceReceiverProxy) AsBinder

func (p *FaceServiceReceiverProxy) AsBinder() binder.IBinder

func (*FaceServiceReceiverProxy) OnAcquired

func (p *FaceServiceReceiverProxy) OnAcquired(
	ctx context.Context,
	acquiredInfo int32,
	vendorCode int32,
) error

func (*FaceServiceReceiverProxy) OnAuthenticationFailed

func (p *FaceServiceReceiverProxy) OnAuthenticationFailed(
	ctx context.Context,
) error

func (*FaceServiceReceiverProxy) OnAuthenticationFrame

func (p *FaceServiceReceiverProxy) OnAuthenticationFrame(
	ctx context.Context,
	frame FaceAuthenticationFrame,
) error

func (*FaceServiceReceiverProxy) OnAuthenticationSucceeded

func (p *FaceServiceReceiverProxy) OnAuthenticationSucceeded(
	ctx context.Context,
	face Face,
	isStrongBiometric bool,
) error

func (*FaceServiceReceiverProxy) OnChallengeGenerated

func (p *FaceServiceReceiverProxy) OnChallengeGenerated(
	ctx context.Context,
	sensorId int32,
	challenge int64,
) error

func (*FaceServiceReceiverProxy) OnEnrollResult

func (p *FaceServiceReceiverProxy) OnEnrollResult(
	ctx context.Context,
	face Face,
	remaining int32,
) error

func (*FaceServiceReceiverProxy) OnEnrollmentFrame

func (p *FaceServiceReceiverProxy) OnEnrollmentFrame(
	ctx context.Context,
	frame FaceEnrollFrame,
) error

func (*FaceServiceReceiverProxy) OnError

func (p *FaceServiceReceiverProxy) OnError(
	ctx context.Context,
	error_ int32,
	vendorCode int32,
) error

func (*FaceServiceReceiverProxy) OnFaceDetected

func (p *FaceServiceReceiverProxy) OnFaceDetected(
	ctx context.Context,
	sensorId int32,
	isStrongBiometric bool,
) error

func (*FaceServiceReceiverProxy) OnFeatureGet

func (p *FaceServiceReceiverProxy) OnFeatureGet(
	ctx context.Context,
	success bool,
	features []int32,
	featureState []bool,
) error

func (*FaceServiceReceiverProxy) OnFeatureSet

func (p *FaceServiceReceiverProxy) OnFeatureSet(
	ctx context.Context,
	success bool,
	feature int32,
) error

func (*FaceServiceReceiverProxy) OnRemoved

func (p *FaceServiceReceiverProxy) OnRemoved(
	ctx context.Context,
	face Face,
	remaining int32,
) error

type FaceServiceReceiverStub

type FaceServiceReceiverStub struct {
	Impl      IFaceServiceReceiver
	Transport binder.VersionAwareTransport
}

FaceServiceReceiverStub dispatches incoming binder transactions to a typed IFaceServiceReceiver implementation.

func (*FaceServiceReceiverStub) Descriptor

func (s *FaceServiceReceiverStub) Descriptor() string

func (*FaceServiceReceiverStub) OnTransaction

func (s *FaceServiceReceiverStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type FaceServiceStub

type FaceServiceStub struct {
	Impl      IFaceService
	Transport binder.VersionAwareTransport
}

FaceServiceStub dispatches incoming binder transactions to a typed IFaceService implementation.

func (*FaceServiceStub) Descriptor

func (s *FaceServiceStub) Descriptor() string

func (*FaceServiceStub) OnTransaction

func (s *FaceServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IFaceAuthenticatorsRegisteredCallback

type IFaceAuthenticatorsRegisteredCallback interface {
	AsBinder() binder.IBinder
	OnAllAuthenticatorsRegistered(ctx context.Context, sensors []FaceSensorPropertiesInternal) error
}

func NewFaceAuthenticatorsRegisteredCallbackStub

func NewFaceAuthenticatorsRegisteredCallbackStub(
	impl IFaceAuthenticatorsRegisteredCallbackServer,
) IFaceAuthenticatorsRegisteredCallback

NewFaceAuthenticatorsRegisteredCallbackStub creates a server-side IFaceAuthenticatorsRegisteredCallback wrapping the given server implementation. The returned value satisfies IFaceAuthenticatorsRegisteredCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IFaceAuthenticatorsRegisteredCallbackServer

type IFaceAuthenticatorsRegisteredCallbackServer interface {
	OnAllAuthenticatorsRegistered(ctx context.Context, sensors []FaceSensorPropertiesInternal) error
}

IFaceAuthenticatorsRegisteredCallbackServer is the server-side interface that user implementations provide to NewFaceAuthenticatorsRegisteredCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IFaceService

type IFaceService interface {
	AsBinder() binder.IBinder
	CreateTestSession(ctx context.Context, sensorId int32, callback biometrics.ITestSessionCallback) (biometrics.ITestSession, error)
	DumpSensorServiceStateProto(ctx context.Context, sensorId int32, clearSchedulerBuffer bool) ([]byte, error)
	GetSensorPropertiesInternal(ctx context.Context) ([]FaceSensorPropertiesInternal, error)
	GetSensorProperties(ctx context.Context, sensorId int32) (FaceSensorPropertiesInternal, error)
	Authenticate(ctx context.Context, token binder.IBinder, operationId int64, receiver IFaceServiceReceiver, options FaceAuthenticateOptions) (int64, error)
	DetectFace(ctx context.Context, token binder.IBinder, receiver IFaceServiceReceiver, options FaceAuthenticateOptions) (int64, error)
	PrepareForAuthentication(ctx context.Context, requireConfirmation bool, token binder.IBinder, operationId int64, sensorReceiver biometrics.IBiometricSensorReceiver, options FaceAuthenticateOptions, requestId int64, cookie int32, allowBackgroundAuthentication bool) error
	StartPreparedClient(ctx context.Context, sensorId int32, cookie int32) error
	CancelAuthentication(ctx context.Context, token binder.IBinder, requestId int64) error
	CancelFaceDetect(ctx context.Context, token binder.IBinder, requestId int64) error
	CancelAuthenticationFromService(ctx context.Context, sensorId int32, token binder.IBinder, requestId int64) error
	Enroll(ctx context.Context, token binder.IBinder, hardwareAuthToken []byte, receiver IFaceServiceReceiver, disabledFeatures []int32, previewSurface view.Surface, debugConsent bool, options FaceEnrollOptions) (int64, error)
	EnrollRemotely(ctx context.Context, token binder.IBinder, hardwareAuthToken []byte, receiver IFaceServiceReceiver, disabledFeatures []int32) (int64, error)
	CancelEnrollment(ctx context.Context, token binder.IBinder, requestId int64) error
	Remove(ctx context.Context, token binder.IBinder, faceId int32, receiver IFaceServiceReceiver) error
	RemoveAll(ctx context.Context, token binder.IBinder, receiver IFaceServiceReceiver) error
	GetEnrolledFaces(ctx context.Context, sensorId int32) ([]Face, error)
	IsHardwareDetected(ctx context.Context, sensorId int32) (bool, error)
	GenerateChallenge(ctx context.Context, token binder.IBinder, sensorId int32, receiver IFaceServiceReceiver) error
	RevokeChallenge(ctx context.Context, token binder.IBinder, sensorId int32, challenge int64) error
	HasEnrolledFaces(ctx context.Context, sensorId int32) (bool, error)
	GetLockoutModeForUser(ctx context.Context, sensorId int32) (int32, error)
	InvalidateAuthenticatorId(ctx context.Context, sensorId int32, callback biometrics.IInvalidationCallback) error
	GetAuthenticatorId(ctx context.Context, sensorId int32) (int64, error)
	ResetLockout(ctx context.Context, token binder.IBinder, sensorId int32, hardwareAuthToken []byte) error
	AddLockoutResetCallback(ctx context.Context, callback biometrics.IBiometricServiceLockoutResetCallback) error
	SetFeature(ctx context.Context, token binder.IBinder, feature int32, enabled bool, hardwareAuthToken []byte, receiver IFaceServiceReceiver) error
	GetFeature(ctx context.Context, token binder.IBinder, feature int32, receiver IFaceServiceReceiver) error
	RegisterAuthenticators(ctx context.Context, hidlSensors []FaceSensorPropertiesInternal) error
	RegisterAuthenticatorsLegacy(ctx context.Context, faceSensorConfigurations FaceSensorConfigurations) error
	AddAuthenticatorsRegisteredCallback(ctx context.Context, callback IFaceAuthenticatorsRegisteredCallback) error
	RegisterAuthenticationStateListener(ctx context.Context, listener biometrics.AuthenticationStateListener) error
	UnregisterAuthenticationStateListener(ctx context.Context, listener biometrics.AuthenticationStateListener) error
	RegisterBiometricStateListener(ctx context.Context, listener biometrics.IBiometricStateListener) error
	ScheduleWatchdog(ctx context.Context) error
}

func NewFaceServiceStub

func NewFaceServiceStub(
	impl IFaceServiceServer,
) IFaceService

NewFaceServiceStub creates a server-side IFaceService wrapping the given server implementation. The returned value satisfies IFaceService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IFaceServiceReceiver

type IFaceServiceReceiver interface {
	AsBinder() binder.IBinder
	OnEnrollResult(ctx context.Context, face Face, remaining int32) error
	OnAcquired(ctx context.Context, acquiredInfo int32, vendorCode int32) error
	OnAuthenticationSucceeded(ctx context.Context, face Face, isStrongBiometric bool) error
	OnFaceDetected(ctx context.Context, sensorId int32, isStrongBiometric bool) error
	OnAuthenticationFailed(ctx context.Context) error
	OnError(ctx context.Context, error_ int32, vendorCode int32) error
	OnRemoved(ctx context.Context, face Face, remaining int32) error
	OnFeatureSet(ctx context.Context, success bool, feature int32) error
	OnFeatureGet(ctx context.Context, success bool, features []int32, featureState []bool) error
	OnChallengeGenerated(ctx context.Context, sensorId int32, challenge int64) error
	OnAuthenticationFrame(ctx context.Context, frame FaceAuthenticationFrame) error
	OnEnrollmentFrame(ctx context.Context, frame FaceEnrollFrame) error
}

func NewFaceServiceReceiverStub

func NewFaceServiceReceiverStub(
	impl IFaceServiceReceiverServer,
) IFaceServiceReceiver

NewFaceServiceReceiverStub creates a server-side IFaceServiceReceiver wrapping the given server implementation. The returned value satisfies IFaceServiceReceiver and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IFaceServiceReceiverServer

type IFaceServiceReceiverServer interface {
	OnEnrollResult(ctx context.Context, face Face, remaining int32) error
	OnAcquired(ctx context.Context, acquiredInfo int32, vendorCode int32) error
	OnAuthenticationSucceeded(ctx context.Context, face Face, isStrongBiometric bool) error
	OnFaceDetected(ctx context.Context, sensorId int32, isStrongBiometric bool) error
	OnAuthenticationFailed(ctx context.Context) error
	OnError(ctx context.Context, error_ int32, vendorCode int32) error
	OnRemoved(ctx context.Context, face Face, remaining int32) error
	OnFeatureSet(ctx context.Context, success bool, feature int32) error
	OnFeatureGet(ctx context.Context, success bool, features []int32, featureState []bool) error
	OnChallengeGenerated(ctx context.Context, sensorId int32, challenge int64) error
	OnAuthenticationFrame(ctx context.Context, frame FaceAuthenticationFrame) error
	OnEnrollmentFrame(ctx context.Context, frame FaceEnrollFrame) error
}

IFaceServiceReceiverServer is the server-side interface that user implementations provide to NewFaceServiceReceiverStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IFaceServiceServer

type IFaceServiceServer interface {
	CreateTestSession(ctx context.Context, sensorId int32, callback biometrics.ITestSessionCallback) (biometrics.ITestSession, error)
	DumpSensorServiceStateProto(ctx context.Context, sensorId int32, clearSchedulerBuffer bool) ([]byte, error)
	GetSensorPropertiesInternal(ctx context.Context) ([]FaceSensorPropertiesInternal, error)
	GetSensorProperties(ctx context.Context, sensorId int32) (FaceSensorPropertiesInternal, error)
	Authenticate(ctx context.Context, token binder.IBinder, operationId int64, receiver IFaceServiceReceiver, options FaceAuthenticateOptions) (int64, error)
	DetectFace(ctx context.Context, token binder.IBinder, receiver IFaceServiceReceiver, options FaceAuthenticateOptions) (int64, error)
	PrepareForAuthentication(ctx context.Context, requireConfirmation bool, token binder.IBinder, operationId int64, sensorReceiver biometrics.IBiometricSensorReceiver, options FaceAuthenticateOptions, requestId int64, cookie int32, allowBackgroundAuthentication bool) error
	StartPreparedClient(ctx context.Context, sensorId int32, cookie int32) error
	CancelAuthentication(ctx context.Context, token binder.IBinder, requestId int64) error
	CancelFaceDetect(ctx context.Context, token binder.IBinder, requestId int64) error
	CancelAuthenticationFromService(ctx context.Context, sensorId int32, token binder.IBinder, requestId int64) error
	Enroll(ctx context.Context, token binder.IBinder, hardwareAuthToken []byte, receiver IFaceServiceReceiver, disabledFeatures []int32, previewSurface view.Surface, debugConsent bool, options FaceEnrollOptions) (int64, error)
	EnrollRemotely(ctx context.Context, token binder.IBinder, hardwareAuthToken []byte, receiver IFaceServiceReceiver, disabledFeatures []int32) (int64, error)
	CancelEnrollment(ctx context.Context, token binder.IBinder, requestId int64) error
	Remove(ctx context.Context, token binder.IBinder, faceId int32, receiver IFaceServiceReceiver) error
	RemoveAll(ctx context.Context, token binder.IBinder, receiver IFaceServiceReceiver) error
	GetEnrolledFaces(ctx context.Context, sensorId int32) ([]Face, error)
	IsHardwareDetected(ctx context.Context, sensorId int32) (bool, error)
	GenerateChallenge(ctx context.Context, token binder.IBinder, sensorId int32, receiver IFaceServiceReceiver) error
	RevokeChallenge(ctx context.Context, token binder.IBinder, sensorId int32, challenge int64) error
	HasEnrolledFaces(ctx context.Context, sensorId int32) (bool, error)
	GetLockoutModeForUser(ctx context.Context, sensorId int32) (int32, error)
	InvalidateAuthenticatorId(ctx context.Context, sensorId int32, callback biometrics.IInvalidationCallback) error
	GetAuthenticatorId(ctx context.Context, sensorId int32) (int64, error)
	ResetLockout(ctx context.Context, token binder.IBinder, sensorId int32, hardwareAuthToken []byte) error
	AddLockoutResetCallback(ctx context.Context, callback biometrics.IBiometricServiceLockoutResetCallback) error
	SetFeature(ctx context.Context, token binder.IBinder, feature int32, enabled bool, hardwareAuthToken []byte, receiver IFaceServiceReceiver) error
	GetFeature(ctx context.Context, token binder.IBinder, feature int32, receiver IFaceServiceReceiver) error
	RegisterAuthenticators(ctx context.Context, hidlSensors []FaceSensorPropertiesInternal) error
	RegisterAuthenticatorsLegacy(ctx context.Context, faceSensorConfigurations FaceSensorConfigurations) error
	AddAuthenticatorsRegisteredCallback(ctx context.Context, callback IFaceAuthenticatorsRegisteredCallback) error
	RegisterAuthenticationStateListener(ctx context.Context, listener biometrics.AuthenticationStateListener) error
	UnregisterAuthenticationStateListener(ctx context.Context, listener biometrics.AuthenticationStateListener) error
	RegisterBiometricStateListener(ctx context.Context, listener biometrics.IBiometricStateListener) error
	ScheduleWatchdog(ctx context.Context) error
}

IFaceServiceServer is the server-side interface that user implementations provide to NewFaceServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

Jump to