location

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIActivityRecognitionHardwareGetSupportedActivities = binder.FirstCallTransaction + 0
	TransactionIActivityRecognitionHardwareIsActivitySupported    = binder.FirstCallTransaction + 1
	TransactionIActivityRecognitionHardwareRegisterSink           = binder.FirstCallTransaction + 2
	TransactionIActivityRecognitionHardwareUnregisterSink         = binder.FirstCallTransaction + 3
	TransactionIActivityRecognitionHardwareEnableActivityEvent    = binder.FirstCallTransaction + 4
	TransactionIActivityRecognitionHardwareDisableActivityEvent   = binder.FirstCallTransaction + 5
	TransactionIActivityRecognitionHardwareFlush                  = binder.FirstCallTransaction + 6
)
const (
	MethodIActivityRecognitionHardwareGetSupportedActivities = "getSupportedActivities"
	MethodIActivityRecognitionHardwareIsActivitySupported    = "isActivitySupported"
	MethodIActivityRecognitionHardwareRegisterSink           = "registerSink"
	MethodIActivityRecognitionHardwareUnregisterSink         = "unregisterSink"
	MethodIActivityRecognitionHardwareEnableActivityEvent    = "enableActivityEvent"
	MethodIActivityRecognitionHardwareDisableActivityEvent   = "disableActivityEvent"
	MethodIActivityRecognitionHardwareFlush                  = "flush"
)
const (
	TransactionIContextHubClientSendMessageToNanoApp            = binder.FirstCallTransaction + 0
	TransactionIContextHubClientClose                           = binder.FirstCallTransaction + 1
	TransactionIContextHubClientGetId                           = binder.FirstCallTransaction + 2
	TransactionIContextHubClientCallbackFinished                = binder.FirstCallTransaction + 3
	TransactionIContextHubClientReliableMessageCallbackFinished = binder.FirstCallTransaction + 4
	TransactionIContextHubClientSendReliableMessageToNanoApp    = binder.FirstCallTransaction + 5
)
const (
	MethodIContextHubClientSendMessageToNanoApp            = "sendMessageToNanoApp"
	MethodIContextHubClientClose                           = "close"
	MethodIContextHubClientGetId                           = "getId"
	MethodIContextHubClientCallbackFinished                = "callbackFinished"
	MethodIContextHubClientReliableMessageCallbackFinished = "reliableMessageCallbackFinished"
	MethodIContextHubClientSendReliableMessageToNanoApp    = "sendReliableMessageToNanoApp"
)
const (
	TransactionIContextHubClientCallbackOnMessageFromNanoApp         = binder.FirstCallTransaction + 0
	TransactionIContextHubClientCallbackOnHubReset                   = binder.FirstCallTransaction + 1
	TransactionIContextHubClientCallbackOnNanoAppAborted             = binder.FirstCallTransaction + 2
	TransactionIContextHubClientCallbackOnNanoAppLoaded              = binder.FirstCallTransaction + 3
	TransactionIContextHubClientCallbackOnNanoAppUnloaded            = binder.FirstCallTransaction + 4
	TransactionIContextHubClientCallbackOnNanoAppEnabled             = binder.FirstCallTransaction + 5
	TransactionIContextHubClientCallbackOnNanoAppDisabled            = binder.FirstCallTransaction + 6
	TransactionIContextHubClientCallbackOnClientAuthorizationChanged = binder.FirstCallTransaction + 7
)
const (
	MethodIContextHubClientCallbackOnMessageFromNanoApp         = "onMessageFromNanoApp"
	MethodIContextHubClientCallbackOnHubReset                   = "onHubReset"
	MethodIContextHubClientCallbackOnNanoAppAborted             = "onNanoAppAborted"
	MethodIContextHubClientCallbackOnNanoAppLoaded              = "onNanoAppLoaded"
	MethodIContextHubClientCallbackOnNanoAppUnloaded            = "onNanoAppUnloaded"
	MethodIContextHubClientCallbackOnNanoAppEnabled             = "onNanoAppEnabled"
	MethodIContextHubClientCallbackOnNanoAppDisabled            = "onNanoAppDisabled"
	MethodIContextHubClientCallbackOnClientAuthorizationChanged = "onClientAuthorizationChanged"
)
const (
	TransactionIContextHubServiceRegisterCallback          = binder.FirstCallTransaction + 0
	TransactionIContextHubServiceGetContextHubHandles      = binder.FirstCallTransaction + 1
	TransactionIContextHubServiceGetContextHubInfo         = binder.FirstCallTransaction + 2
	TransactionIContextHubServiceLoadNanoApp               = binder.FirstCallTransaction + 3
	TransactionIContextHubServiceUnloadNanoApp             = binder.FirstCallTransaction + 4
	TransactionIContextHubServiceGetNanoAppInstanceInfo    = binder.FirstCallTransaction + 5
	TransactionIContextHubServiceFindNanoAppOnHub          = binder.FirstCallTransaction + 6
	TransactionIContextHubServiceSendMessage               = binder.FirstCallTransaction + 7
	TransactionIContextHubServiceCreateClient              = binder.FirstCallTransaction + 8
	TransactionIContextHubServiceCreatePendingIntentClient = binder.FirstCallTransaction + 9
	TransactionIContextHubServiceGetContextHubs            = binder.FirstCallTransaction + 10
	TransactionIContextHubServiceLoadNanoAppOnHub          = binder.FirstCallTransaction + 11
	TransactionIContextHubServiceUnloadNanoAppFromHub      = binder.FirstCallTransaction + 12
	TransactionIContextHubServiceEnableNanoApp             = binder.FirstCallTransaction + 13
	TransactionIContextHubServiceDisableNanoApp            = binder.FirstCallTransaction + 14
	TransactionIContextHubServiceQueryNanoApps             = binder.FirstCallTransaction + 15
	TransactionIContextHubServiceGetPreloadedNanoAppIds    = binder.FirstCallTransaction + 16
	TransactionIContextHubServiceSetTestMode               = binder.FirstCallTransaction + 17
)
const (
	MethodIContextHubServiceRegisterCallback          = "registerCallback"
	MethodIContextHubServiceGetContextHubHandles      = "getContextHubHandles"
	MethodIContextHubServiceGetContextHubInfo         = "getContextHubInfo"
	MethodIContextHubServiceLoadNanoApp               = "loadNanoApp"
	MethodIContextHubServiceUnloadNanoApp             = "unloadNanoApp"
	MethodIContextHubServiceGetNanoAppInstanceInfo    = "getNanoAppInstanceInfo"
	MethodIContextHubServiceFindNanoAppOnHub          = "findNanoAppOnHub"
	MethodIContextHubServiceSendMessage               = "sendMessage"
	MethodIContextHubServiceCreateClient              = "createClient"
	MethodIContextHubServiceCreatePendingIntentClient = "createPendingIntentClient"
	MethodIContextHubServiceGetContextHubs            = "getContextHubs"
	MethodIContextHubServiceLoadNanoAppOnHub          = "loadNanoAppOnHub"
	MethodIContextHubServiceUnloadNanoAppFromHub      = "unloadNanoAppFromHub"
	MethodIContextHubServiceEnableNanoApp             = "enableNanoApp"
	MethodIContextHubServiceDisableNanoApp            = "disableNanoApp"
	MethodIContextHubServiceQueryNanoApps             = "queryNanoApps"
	MethodIContextHubServiceGetPreloadedNanoAppIds    = "getPreloadedNanoAppIds"
	MethodIContextHubServiceSetTestMode               = "setTestMode"
)
const (
	TransactionIContextHubTransactionCallbackOnQueryResponse       = binder.FirstCallTransaction + 0
	TransactionIContextHubTransactionCallbackOnTransactionComplete = binder.FirstCallTransaction + 1
)
const (
	MethodIContextHubTransactionCallbackOnQueryResponse       = "onQueryResponse"
	MethodIContextHubTransactionCallbackOnTransactionComplete = "onTransactionComplete"
)
const (
	TransactionIGeofenceHardwareSetGpsGeofenceHardware                  = binder.FirstCallTransaction + 0
	TransactionIGeofenceHardwareSetFusedGeofenceHardware                = binder.FirstCallTransaction + 1
	TransactionIGeofenceHardwareGetMonitoringTypes                      = binder.FirstCallTransaction + 2
	TransactionIGeofenceHardwareGetStatusOfMonitoringType               = binder.FirstCallTransaction + 3
	TransactionIGeofenceHardwareAddCircularFence                        = binder.FirstCallTransaction + 4
	TransactionIGeofenceHardwareRemoveGeofence                          = binder.FirstCallTransaction + 5
	TransactionIGeofenceHardwarePauseGeofence                           = binder.FirstCallTransaction + 6
	TransactionIGeofenceHardwareResumeGeofence                          = binder.FirstCallTransaction + 7
	TransactionIGeofenceHardwareRegisterForMonitorStateChangeCallback   = binder.FirstCallTransaction + 8
	TransactionIGeofenceHardwareUnregisterForMonitorStateChangeCallback = binder.FirstCallTransaction + 9
)
const (
	MethodIGeofenceHardwareSetGpsGeofenceHardware                  = "setGpsGeofenceHardware"
	MethodIGeofenceHardwareSetFusedGeofenceHardware                = "setFusedGeofenceHardware"
	MethodIGeofenceHardwareGetMonitoringTypes                      = "getMonitoringTypes"
	MethodIGeofenceHardwareGetStatusOfMonitoringType               = "getStatusOfMonitoringType"
	MethodIGeofenceHardwareAddCircularFence                        = "addCircularFence"
	MethodIGeofenceHardwareRemoveGeofence                          = "removeGeofence"
	MethodIGeofenceHardwarePauseGeofence                           = "pauseGeofence"
	MethodIGeofenceHardwareResumeGeofence                          = "resumeGeofence"
	MethodIGeofenceHardwareRegisterForMonitorStateChangeCallback   = "registerForMonitorStateChangeCallback"
	MethodIGeofenceHardwareUnregisterForMonitorStateChangeCallback = "unregisterForMonitorStateChangeCallback"
)
const (
	TransactionIGeofenceHardwareCallbackOnGeofenceTransition = binder.FirstCallTransaction + 0
	TransactionIGeofenceHardwareCallbackOnGeofenceAdd        = binder.FirstCallTransaction + 1
	TransactionIGeofenceHardwareCallbackOnGeofenceRemove     = binder.FirstCallTransaction + 2
	TransactionIGeofenceHardwareCallbackOnGeofencePause      = binder.FirstCallTransaction + 3
	TransactionIGeofenceHardwareCallbackOnGeofenceResume     = binder.FirstCallTransaction + 4
)
const (
	MethodIGeofenceHardwareCallbackOnGeofenceTransition = "onGeofenceTransition"
	MethodIGeofenceHardwareCallbackOnGeofenceAdd        = "onGeofenceAdd"
	MethodIGeofenceHardwareCallbackOnGeofenceRemove     = "onGeofenceRemove"
	MethodIGeofenceHardwareCallbackOnGeofencePause      = "onGeofencePause"
	MethodIGeofenceHardwareCallbackOnGeofenceResume     = "onGeofenceResume"
)
const DescriptorIActivityRecognitionHardware = "android.hardware.location.IActivityRecognitionHardware"
const DescriptorIActivityRecognitionHardwareClient = "android.hardware.location.IActivityRecognitionHardwareClient"
const DescriptorIActivityRecognitionHardwareSink = "android.hardware.location.IActivityRecognitionHardwareSink"
const DescriptorIActivityRecognitionHardwareWatcher = "android.hardware.location.IActivityRecognitionHardwareWatcher"
const DescriptorIContextHubCallback = "android.hardware.location.IContextHubCallback"
const DescriptorIContextHubClient = "android.hardware.location.IContextHubClient"
const DescriptorIContextHubClientCallback = "android.hardware.location.IContextHubClientCallback"
const DescriptorIContextHubService = "android.hardware.location.IContextHubService"
const DescriptorIContextHubTransactionCallback = "android.hardware.location.IContextHubTransactionCallback"
const DescriptorIGeofenceHardware = "android.hardware.location.IGeofenceHardware"
const DescriptorIGeofenceHardwareCallback = "android.hardware.location.IGeofenceHardwareCallback"
const DescriptorIGeofenceHardwareMonitorCallback = "android.hardware.location.IGeofenceHardwareMonitorCallback"
const (
	MethodIActivityRecognitionHardwareClientOnAvailabilityChanged = "onAvailabilityChanged"
)
const (
	MethodIActivityRecognitionHardwareSinkOnActivityChanged = "onActivityChanged"
)
const (
	MethodIActivityRecognitionHardwareWatcherOnInstanceChanged = "onInstanceChanged"
)
const (
	MethodIContextHubCallbackOnMessageReceipt = "onMessageReceipt"
)
const (
	MethodIGeofenceHardwareMonitorCallbackOnMonitoringSystemChange = "onMonitoringSystemChange"
)
const (
	TransactionIActivityRecognitionHardwareClientOnAvailabilityChanged = binder.FirstCallTransaction + 0
)
const (
	TransactionIActivityRecognitionHardwareSinkOnActivityChanged = binder.FirstCallTransaction + 0
)
const (
	TransactionIActivityRecognitionHardwareWatcherOnInstanceChanged = binder.FirstCallTransaction + 0
)
const (
	TransactionIContextHubCallbackOnMessageReceipt = binder.FirstCallTransaction + 0
)
const (
	TransactionIGeofenceHardwareMonitorCallbackOnMonitoringSystemChange = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type ActivityChangedEvent

type ActivityChangedEvent struct {
}

func (*ActivityChangedEvent) MarshalParcel

func (s *ActivityChangedEvent) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ActivityChangedEvent) UnmarshalParcel

func (s *ActivityChangedEvent) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ActivityRecognitionHardwareClientProxy

type ActivityRecognitionHardwareClientProxy struct {
	Remote binder.IBinder
}

func NewActivityRecognitionHardwareClientProxy

func NewActivityRecognitionHardwareClientProxy(
	remote binder.IBinder,
) *ActivityRecognitionHardwareClientProxy

func (*ActivityRecognitionHardwareClientProxy) AsBinder

func (*ActivityRecognitionHardwareClientProxy) OnAvailabilityChanged

func (p *ActivityRecognitionHardwareClientProxy) OnAvailabilityChanged(
	ctx context.Context,
	isSupported bool,
	instance IActivityRecognitionHardware,
) error

type ActivityRecognitionHardwareClientStub

type ActivityRecognitionHardwareClientStub struct {
	Impl      IActivityRecognitionHardwareClient
	Transport binder.VersionAwareTransport
}

ActivityRecognitionHardwareClientStub dispatches incoming binder transactions to a typed IActivityRecognitionHardwareClient implementation.

func (*ActivityRecognitionHardwareClientStub) Descriptor

func (*ActivityRecognitionHardwareClientStub) OnTransaction

type ActivityRecognitionHardwareProxy

type ActivityRecognitionHardwareProxy struct {
	Remote binder.IBinder
}

func NewActivityRecognitionHardwareProxy

func NewActivityRecognitionHardwareProxy(
	remote binder.IBinder,
) *ActivityRecognitionHardwareProxy

func (*ActivityRecognitionHardwareProxy) AsBinder

func (*ActivityRecognitionHardwareProxy) DisableActivityEvent

func (p *ActivityRecognitionHardwareProxy) DisableActivityEvent(
	ctx context.Context,
	activityType string,
	eventType int32,
) (bool, error)

func (*ActivityRecognitionHardwareProxy) EnableActivityEvent

func (p *ActivityRecognitionHardwareProxy) EnableActivityEvent(
	ctx context.Context,
	activityType string,
	eventType int32,
	reportLatencyNs int64,
) (bool, error)

func (*ActivityRecognitionHardwareProxy) Flush

func (*ActivityRecognitionHardwareProxy) GetSupportedActivities

func (p *ActivityRecognitionHardwareProxy) GetSupportedActivities(
	ctx context.Context,
) ([]string, error)

func (*ActivityRecognitionHardwareProxy) IsActivitySupported

func (p *ActivityRecognitionHardwareProxy) IsActivitySupported(
	ctx context.Context,
	activityType string,
) (bool, error)

func (*ActivityRecognitionHardwareProxy) RegisterSink

func (*ActivityRecognitionHardwareProxy) UnregisterSink

type ActivityRecognitionHardwareSinkProxy

type ActivityRecognitionHardwareSinkProxy struct {
	Remote binder.IBinder
}

func NewActivityRecognitionHardwareSinkProxy

func NewActivityRecognitionHardwareSinkProxy(
	remote binder.IBinder,
) *ActivityRecognitionHardwareSinkProxy

func (*ActivityRecognitionHardwareSinkProxy) AsBinder

func (*ActivityRecognitionHardwareSinkProxy) OnActivityChanged

type ActivityRecognitionHardwareSinkStub

type ActivityRecognitionHardwareSinkStub struct {
	Impl      IActivityRecognitionHardwareSink
	Transport binder.VersionAwareTransport
}

ActivityRecognitionHardwareSinkStub dispatches incoming binder transactions to a typed IActivityRecognitionHardwareSink implementation.

func (*ActivityRecognitionHardwareSinkStub) Descriptor

func (*ActivityRecognitionHardwareSinkStub) OnTransaction

type ActivityRecognitionHardwareStub

type ActivityRecognitionHardwareStub struct {
	Impl      IActivityRecognitionHardware
	Transport binder.VersionAwareTransport
}

ActivityRecognitionHardwareStub dispatches incoming binder transactions to a typed IActivityRecognitionHardware implementation.

func (*ActivityRecognitionHardwareStub) Descriptor

func (s *ActivityRecognitionHardwareStub) Descriptor() string

func (*ActivityRecognitionHardwareStub) OnTransaction

type ActivityRecognitionHardwareWatcherProxy

type ActivityRecognitionHardwareWatcherProxy struct {
	Remote binder.IBinder
}

func NewActivityRecognitionHardwareWatcherProxy

func NewActivityRecognitionHardwareWatcherProxy(
	remote binder.IBinder,
) *ActivityRecognitionHardwareWatcherProxy

func (*ActivityRecognitionHardwareWatcherProxy) AsBinder

func (*ActivityRecognitionHardwareWatcherProxy) OnInstanceChanged

type ActivityRecognitionHardwareWatcherStub

type ActivityRecognitionHardwareWatcherStub struct {
	Impl      IActivityRecognitionHardwareWatcher
	Transport binder.VersionAwareTransport
}

ActivityRecognitionHardwareWatcherStub dispatches incoming binder transactions to a typed IActivityRecognitionHardwareWatcher implementation.

func (*ActivityRecognitionHardwareWatcherStub) Descriptor

func (*ActivityRecognitionHardwareWatcherStub) OnTransaction

type ContextHubCallbackProxy

type ContextHubCallbackProxy struct {
	Remote binder.IBinder
}

func NewContextHubCallbackProxy

func NewContextHubCallbackProxy(
	remote binder.IBinder,
) *ContextHubCallbackProxy

func (*ContextHubCallbackProxy) AsBinder

func (p *ContextHubCallbackProxy) AsBinder() binder.IBinder

func (*ContextHubCallbackProxy) OnMessageReceipt

func (p *ContextHubCallbackProxy) OnMessageReceipt(
	ctx context.Context,
	hubId int32,
	nanoAppId int32,
	msg ContextHubMessage,
) error

type ContextHubCallbackStub

type ContextHubCallbackStub struct {
	Impl      IContextHubCallback
	Transport binder.VersionAwareTransport
}

ContextHubCallbackStub dispatches incoming binder transactions to a typed IContextHubCallback implementation.

func (*ContextHubCallbackStub) Descriptor

func (s *ContextHubCallbackStub) Descriptor() string

func (*ContextHubCallbackStub) OnTransaction

func (s *ContextHubCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ContextHubClientCallbackProxy

type ContextHubClientCallbackProxy struct {
	Remote binder.IBinder
}

func NewContextHubClientCallbackProxy

func NewContextHubClientCallbackProxy(
	remote binder.IBinder,
) *ContextHubClientCallbackProxy

func (*ContextHubClientCallbackProxy) AsBinder

func (*ContextHubClientCallbackProxy) OnClientAuthorizationChanged

func (p *ContextHubClientCallbackProxy) OnClientAuthorizationChanged(
	ctx context.Context,
	nanoAppId int64,
	authorization int32,
) error

func (*ContextHubClientCallbackProxy) OnHubReset

func (p *ContextHubClientCallbackProxy) OnHubReset(
	ctx context.Context,
) error

func (*ContextHubClientCallbackProxy) OnMessageFromNanoApp

func (p *ContextHubClientCallbackProxy) OnMessageFromNanoApp(
	ctx context.Context,
	message NanoAppMessage,
) error

func (*ContextHubClientCallbackProxy) OnNanoAppAborted

func (p *ContextHubClientCallbackProxy) OnNanoAppAborted(
	ctx context.Context,
	nanoAppId int64,
	abortCode int32,
) error

func (*ContextHubClientCallbackProxy) OnNanoAppDisabled

func (p *ContextHubClientCallbackProxy) OnNanoAppDisabled(
	ctx context.Context,
	nanoAppId int64,
) error

func (*ContextHubClientCallbackProxy) OnNanoAppEnabled

func (p *ContextHubClientCallbackProxy) OnNanoAppEnabled(
	ctx context.Context,
	nanoAppId int64,
) error

func (*ContextHubClientCallbackProxy) OnNanoAppLoaded

func (p *ContextHubClientCallbackProxy) OnNanoAppLoaded(
	ctx context.Context,
	nanoAppId int64,
) error

func (*ContextHubClientCallbackProxy) OnNanoAppUnloaded

func (p *ContextHubClientCallbackProxy) OnNanoAppUnloaded(
	ctx context.Context,
	nanoAppId int64,
) error

type ContextHubClientCallbackStub

type ContextHubClientCallbackStub struct {
	Impl      IContextHubClientCallback
	Transport binder.VersionAwareTransport
}

ContextHubClientCallbackStub dispatches incoming binder transactions to a typed IContextHubClientCallback implementation.

func (*ContextHubClientCallbackStub) Descriptor

func (s *ContextHubClientCallbackStub) Descriptor() string

func (*ContextHubClientCallbackStub) OnTransaction

type ContextHubClientProxy

type ContextHubClientProxy struct {
	Remote binder.IBinder
}

func NewContextHubClientProxy

func NewContextHubClientProxy(
	remote binder.IBinder,
) *ContextHubClientProxy

func (*ContextHubClientProxy) AsBinder

func (p *ContextHubClientProxy) AsBinder() binder.IBinder

func (*ContextHubClientProxy) CallbackFinished

func (p *ContextHubClientProxy) CallbackFinished(
	ctx context.Context,
) error

func (*ContextHubClientProxy) Close

func (p *ContextHubClientProxy) Close(
	ctx context.Context,
) error

func (*ContextHubClientProxy) GetId

func (p *ContextHubClientProxy) GetId(
	ctx context.Context,
) (int32, error)

func (*ContextHubClientProxy) ReliableMessageCallbackFinished

func (p *ContextHubClientProxy) ReliableMessageCallbackFinished(
	ctx context.Context,
	messageSequenceNumber int32,
	errorCode byte,
) error

func (*ContextHubClientProxy) SendMessageToNanoApp

func (p *ContextHubClientProxy) SendMessageToNanoApp(
	ctx context.Context,
	message NanoAppMessage,
) (int32, error)

func (*ContextHubClientProxy) SendReliableMessageToNanoApp

func (p *ContextHubClientProxy) SendReliableMessageToNanoApp(
	ctx context.Context,
	message NanoAppMessage,
	transactionCallback IContextHubTransactionCallback,
) (int32, error)

type ContextHubClientStub

type ContextHubClientStub struct {
	Impl      IContextHubClient
	Transport binder.VersionAwareTransport
}

ContextHubClientStub dispatches incoming binder transactions to a typed IContextHubClient implementation.

func (*ContextHubClientStub) Descriptor

func (s *ContextHubClientStub) Descriptor() string

func (*ContextHubClientStub) OnTransaction

func (s *ContextHubClientStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ContextHubInfo

type ContextHubInfo struct {
	Id                       int32
	Name                     string
	Vendor                   string
	Toolchain                string
	PlatformVersion          int32
	ToolchainVersion         int32
	PeakMips                 float32
	StoppedPowerDrawMw       float32
	SleepPowerDrawMw         float32
	PeakPowerDrawMw          float32
	MaxPacketLengthBytes     int32
	ChrePlatformId           int64
	ChreApiMajorVersion      int32
	ChreApiMinorVersion      int32
	ChrePatchVersion         int32
	SupportsReliableMessages bool
}

func (*ContextHubInfo) MarshalParcel

func (s *ContextHubInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ContextHubInfo) UnmarshalParcel

func (s *ContextHubInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ContextHubMessage

type ContextHubMessage struct {
	Type    int32
	Version int32
}

func (*ContextHubMessage) MarshalParcel

func (s *ContextHubMessage) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ContextHubMessage) UnmarshalParcel

func (s *ContextHubMessage) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ContextHubServiceProxy

type ContextHubServiceProxy struct {
	Remote binder.IBinder
}

func GetContextHubService

func GetContextHubService(
	ctx context.Context,
	sm *servicemanager.ServiceManager,
) (*ContextHubServiceProxy, error)

GetContextHubService retrieves the ContexthubService service and returns a typed proxy.

func NewContextHubServiceProxy

func NewContextHubServiceProxy(
	remote binder.IBinder,
) *ContextHubServiceProxy

func (*ContextHubServiceProxy) AsBinder

func (p *ContextHubServiceProxy) AsBinder() binder.IBinder

func (*ContextHubServiceProxy) CreateClient

func (p *ContextHubServiceProxy) CreateClient(
	ctx context.Context,
	contextHubId int32,
	client IContextHubClientCallback,
	packageName string,
) (IContextHubClient, error)

func (*ContextHubServiceProxy) CreatePendingIntentClient

func (p *ContextHubServiceProxy) CreatePendingIntentClient(
	ctx context.Context,
	contextHubId int32,
	pendingIntent types.PendingIntent,
	nanoAppId int64,
) (IContextHubClient, error)

func (*ContextHubServiceProxy) DisableNanoApp

func (p *ContextHubServiceProxy) DisableNanoApp(
	ctx context.Context,
	contextHubId int32,
	transactionCallback IContextHubTransactionCallback,
	nanoAppId int64,
) error

func (*ContextHubServiceProxy) EnableNanoApp

func (p *ContextHubServiceProxy) EnableNanoApp(
	ctx context.Context,
	contextHubId int32,
	transactionCallback IContextHubTransactionCallback,
	nanoAppId int64,
) error

func (*ContextHubServiceProxy) FindNanoAppOnHub

func (p *ContextHubServiceProxy) FindNanoAppOnHub(
	ctx context.Context,
	contextHubHandle int32,
	filter NanoAppFilter,
) ([]int32, error)

func (*ContextHubServiceProxy) GetContextHubHandles

func (p *ContextHubServiceProxy) GetContextHubHandles(
	ctx context.Context,
) ([]int32, error)

func (*ContextHubServiceProxy) GetContextHubInfo

func (p *ContextHubServiceProxy) GetContextHubInfo(
	ctx context.Context,
	contextHubHandle int32,
) (ContextHubInfo, error)

func (*ContextHubServiceProxy) GetContextHubs

func (p *ContextHubServiceProxy) GetContextHubs(
	ctx context.Context,
) ([]ContextHubInfo, error)

func (*ContextHubServiceProxy) GetNanoAppInstanceInfo

func (p *ContextHubServiceProxy) GetNanoAppInstanceInfo(
	ctx context.Context,
	nanoAppHandle int32,
) (NanoAppInstanceInfo, error)

func (*ContextHubServiceProxy) GetPreloadedNanoAppIds

func (p *ContextHubServiceProxy) GetPreloadedNanoAppIds(
	ctx context.Context,
	hubInfo ContextHubInfo,
) ([]int64, error)

func (*ContextHubServiceProxy) LoadNanoApp

func (p *ContextHubServiceProxy) LoadNanoApp(
	ctx context.Context,
	contextHubHandle int32,
	nanoApp NanoApp,
) (int32, error)

func (*ContextHubServiceProxy) LoadNanoAppOnHub

func (p *ContextHubServiceProxy) LoadNanoAppOnHub(
	ctx context.Context,
	contextHubId int32,
	transactionCallback IContextHubTransactionCallback,
	nanoAppBinary NanoAppBinary,
) error

func (*ContextHubServiceProxy) QueryNanoApps

func (p *ContextHubServiceProxy) QueryNanoApps(
	ctx context.Context,
	contextHubId int32,
	transactionCallback IContextHubTransactionCallback,
) error

func (*ContextHubServiceProxy) RegisterCallback

func (p *ContextHubServiceProxy) RegisterCallback(
	ctx context.Context,
	callback IContextHubCallback,
) (int32, error)

func (*ContextHubServiceProxy) SendMessage

func (p *ContextHubServiceProxy) SendMessage(
	ctx context.Context,
	contextHubHandle int32,
	nanoAppHandle int32,
	msg ContextHubMessage,
) (int32, error)

func (*ContextHubServiceProxy) SetTestMode

func (p *ContextHubServiceProxy) SetTestMode(
	ctx context.Context,
	enable bool,
) (bool, error)

func (*ContextHubServiceProxy) UnloadNanoApp

func (p *ContextHubServiceProxy) UnloadNanoApp(
	ctx context.Context,
	nanoAppHandle int32,
) (int32, error)

func (*ContextHubServiceProxy) UnloadNanoAppFromHub

func (p *ContextHubServiceProxy) UnloadNanoAppFromHub(
	ctx context.Context,
	contextHubId int32,
	transactionCallback IContextHubTransactionCallback,
	nanoAppId int64,
) error

type ContextHubServiceStub

type ContextHubServiceStub struct {
	Impl      IContextHubService
	Transport binder.VersionAwareTransport
}

ContextHubServiceStub dispatches incoming binder transactions to a typed IContextHubService implementation.

func (*ContextHubServiceStub) Descriptor

func (s *ContextHubServiceStub) Descriptor() string

func (*ContextHubServiceStub) OnTransaction

func (s *ContextHubServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ContextHubTransactionCallbackProxy

type ContextHubTransactionCallbackProxy struct {
	Remote binder.IBinder
}

func NewContextHubTransactionCallbackProxy

func NewContextHubTransactionCallbackProxy(
	remote binder.IBinder,
) *ContextHubTransactionCallbackProxy

func (*ContextHubTransactionCallbackProxy) AsBinder

func (*ContextHubTransactionCallbackProxy) OnQueryResponse

func (p *ContextHubTransactionCallbackProxy) OnQueryResponse(
	ctx context.Context,
	result int32,
	nanoappList []NanoAppState,
) error

func (*ContextHubTransactionCallbackProxy) OnTransactionComplete

func (p *ContextHubTransactionCallbackProxy) OnTransactionComplete(
	ctx context.Context,
	result int32,
) error

type ContextHubTransactionCallbackStub

type ContextHubTransactionCallbackStub struct {
	Impl      IContextHubTransactionCallback
	Transport binder.VersionAwareTransport
}

ContextHubTransactionCallbackStub dispatches incoming binder transactions to a typed IContextHubTransactionCallback implementation.

func (*ContextHubTransactionCallbackStub) Descriptor

func (s *ContextHubTransactionCallbackStub) Descriptor() string

func (*ContextHubTransactionCallbackStub) OnTransaction

type GeofenceHardwareCallbackProxy

type GeofenceHardwareCallbackProxy struct {
	Remote binder.IBinder
}

func NewGeofenceHardwareCallbackProxy

func NewGeofenceHardwareCallbackProxy(
	remote binder.IBinder,
) *GeofenceHardwareCallbackProxy

func (*GeofenceHardwareCallbackProxy) AsBinder

func (*GeofenceHardwareCallbackProxy) OnGeofenceAdd

func (p *GeofenceHardwareCallbackProxy) OnGeofenceAdd(
	ctx context.Context,
	geofenceId int32,
	status int32,
) error

func (*GeofenceHardwareCallbackProxy) OnGeofencePause

func (p *GeofenceHardwareCallbackProxy) OnGeofencePause(
	ctx context.Context,
	geofenceId int32,
	status int32,
) error

func (*GeofenceHardwareCallbackProxy) OnGeofenceRemove

func (p *GeofenceHardwareCallbackProxy) OnGeofenceRemove(
	ctx context.Context,
	geofenceId int32,
	status int32,
) error

func (*GeofenceHardwareCallbackProxy) OnGeofenceResume

func (p *GeofenceHardwareCallbackProxy) OnGeofenceResume(
	ctx context.Context,
	geofenceId int32,
	status int32,
) error

func (*GeofenceHardwareCallbackProxy) OnGeofenceTransition

func (p *GeofenceHardwareCallbackProxy) OnGeofenceTransition(
	ctx context.Context,
	geofenceId int32,
	transition int32,
	location types.Location,
	timestamp int64,
	monitoringType int32,
) error

type GeofenceHardwareCallbackStub

type GeofenceHardwareCallbackStub struct {
	Impl      IGeofenceHardwareCallback
	Transport binder.VersionAwareTransport
}

GeofenceHardwareCallbackStub dispatches incoming binder transactions to a typed IGeofenceHardwareCallback implementation.

func (*GeofenceHardwareCallbackStub) Descriptor

func (s *GeofenceHardwareCallbackStub) Descriptor() string

func (*GeofenceHardwareCallbackStub) OnTransaction

type GeofenceHardwareMonitorCallbackProxy

type GeofenceHardwareMonitorCallbackProxy struct {
	Remote binder.IBinder
}

func NewGeofenceHardwareMonitorCallbackProxy

func NewGeofenceHardwareMonitorCallbackProxy(
	remote binder.IBinder,
) *GeofenceHardwareMonitorCallbackProxy

func (*GeofenceHardwareMonitorCallbackProxy) AsBinder

func (*GeofenceHardwareMonitorCallbackProxy) OnMonitoringSystemChange

func (p *GeofenceHardwareMonitorCallbackProxy) OnMonitoringSystemChange(
	ctx context.Context,
	event GeofenceHardwareMonitorEvent,
) error

type GeofenceHardwareMonitorCallbackStub

type GeofenceHardwareMonitorCallbackStub struct {
	Impl      IGeofenceHardwareMonitorCallback
	Transport binder.VersionAwareTransport
}

GeofenceHardwareMonitorCallbackStub dispatches incoming binder transactions to a typed IGeofenceHardwareMonitorCallback implementation.

func (*GeofenceHardwareMonitorCallbackStub) Descriptor

func (*GeofenceHardwareMonitorCallbackStub) OnTransaction

type GeofenceHardwareMonitorEvent

type GeofenceHardwareMonitorEvent struct {
	MonitoringType     int32
	MonitoringStatus   int32
	SourceTechnologies int32
	Location           *types.Location
}

func (*GeofenceHardwareMonitorEvent) MarshalParcel

func (s *GeofenceHardwareMonitorEvent) MarshalParcel(
	p *parcel.Parcel,
) error

func (*GeofenceHardwareMonitorEvent) UnmarshalParcel

func (s *GeofenceHardwareMonitorEvent) UnmarshalParcel(
	p *parcel.Parcel,
) error

type GeofenceHardwareProxy

type GeofenceHardwareProxy struct {
	Remote binder.IBinder
}

func NewGeofenceHardwareProxy

func NewGeofenceHardwareProxy(
	remote binder.IBinder,
) *GeofenceHardwareProxy

func (*GeofenceHardwareProxy) AddCircularFence

func (p *GeofenceHardwareProxy) AddCircularFence(
	ctx context.Context,
	monitoringType int32,
	request GeofenceHardwareRequestParcelable,
	callback IGeofenceHardwareCallback,
) (bool, error)

func (*GeofenceHardwareProxy) AsBinder

func (p *GeofenceHardwareProxy) AsBinder() binder.IBinder

func (*GeofenceHardwareProxy) GetMonitoringTypes

func (p *GeofenceHardwareProxy) GetMonitoringTypes(
	ctx context.Context,
) ([]int32, error)

func (*GeofenceHardwareProxy) GetStatusOfMonitoringType

func (p *GeofenceHardwareProxy) GetStatusOfMonitoringType(
	ctx context.Context,
	monitoringType int32,
) (int32, error)

func (*GeofenceHardwareProxy) PauseGeofence

func (p *GeofenceHardwareProxy) PauseGeofence(
	ctx context.Context,
	id int32,
	monitoringType int32,
) (bool, error)

func (*GeofenceHardwareProxy) RegisterForMonitorStateChangeCallback

func (p *GeofenceHardwareProxy) RegisterForMonitorStateChangeCallback(
	ctx context.Context,
	monitoringType int32,
	callback IGeofenceHardwareMonitorCallback,
) (bool, error)

func (*GeofenceHardwareProxy) RemoveGeofence

func (p *GeofenceHardwareProxy) RemoveGeofence(
	ctx context.Context,
	id int32,
	monitoringType int32,
) (bool, error)

func (*GeofenceHardwareProxy) ResumeGeofence

func (p *GeofenceHardwareProxy) ResumeGeofence(
	ctx context.Context,
	id int32,
	monitoringType int32,
	monitorTransitions int32,
) (bool, error)

func (*GeofenceHardwareProxy) SetFusedGeofenceHardware

func (p *GeofenceHardwareProxy) SetFusedGeofenceHardware(
	ctx context.Context,
	service types.IFusedGeofenceHardware,
) error

func (*GeofenceHardwareProxy) SetGpsGeofenceHardware

func (p *GeofenceHardwareProxy) SetGpsGeofenceHardware(
	ctx context.Context,
	service types.IGpsGeofenceHardware,
) error

func (*GeofenceHardwareProxy) UnregisterForMonitorStateChangeCallback

func (p *GeofenceHardwareProxy) UnregisterForMonitorStateChangeCallback(
	ctx context.Context,
	monitoringType int32,
	callback IGeofenceHardwareMonitorCallback,
) (bool, error)

type GeofenceHardwareRequestParcelable

type GeofenceHardwareRequestParcelable struct {
}

func (*GeofenceHardwareRequestParcelable) MarshalParcel

func (s *GeofenceHardwareRequestParcelable) MarshalParcel(
	p *parcel.Parcel,
) error

func (*GeofenceHardwareRequestParcelable) UnmarshalParcel

func (s *GeofenceHardwareRequestParcelable) UnmarshalParcel(
	p *parcel.Parcel,
) error

type GeofenceHardwareStub

type GeofenceHardwareStub struct {
	Impl      IGeofenceHardware
	Transport binder.VersionAwareTransport
}

GeofenceHardwareStub dispatches incoming binder transactions to a typed IGeofenceHardware implementation.

func (*GeofenceHardwareStub) Descriptor

func (s *GeofenceHardwareStub) Descriptor() string

func (*GeofenceHardwareStub) OnTransaction

func (s *GeofenceHardwareStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IActivityRecognitionHardware

type IActivityRecognitionHardware interface {
	AsBinder() binder.IBinder
	GetSupportedActivities(ctx context.Context) ([]string, error)
	IsActivitySupported(ctx context.Context, activityType string) (bool, error)
	RegisterSink(ctx context.Context, sink IActivityRecognitionHardwareSink) (bool, error)
	UnregisterSink(ctx context.Context, sink IActivityRecognitionHardwareSink) (bool, error)
	EnableActivityEvent(ctx context.Context, activityType string, eventType int32, reportLatencyNs int64) (bool, error)
	DisableActivityEvent(ctx context.Context, activityType string, eventType int32) (bool, error)
	Flush(ctx context.Context) (bool, error)
}

func NewActivityRecognitionHardwareStub

func NewActivityRecognitionHardwareStub(
	impl IActivityRecognitionHardwareServer,
) IActivityRecognitionHardware

NewActivityRecognitionHardwareStub creates a server-side IActivityRecognitionHardware wrapping the given server implementation. The returned value satisfies IActivityRecognitionHardware and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IActivityRecognitionHardwareClient

type IActivityRecognitionHardwareClient interface {
	AsBinder() binder.IBinder
	OnAvailabilityChanged(ctx context.Context, isSupported bool, instance IActivityRecognitionHardware) error
}

func NewActivityRecognitionHardwareClientStub

func NewActivityRecognitionHardwareClientStub(
	impl IActivityRecognitionHardwareClientServer,
) IActivityRecognitionHardwareClient

NewActivityRecognitionHardwareClientStub creates a server-side IActivityRecognitionHardwareClient wrapping the given server implementation. The returned value satisfies IActivityRecognitionHardwareClient and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IActivityRecognitionHardwareClientServer

type IActivityRecognitionHardwareClientServer interface {
	OnAvailabilityChanged(ctx context.Context, isSupported bool, instance IActivityRecognitionHardware) error
}

IActivityRecognitionHardwareClientServer is the server-side interface that user implementations provide to NewActivityRecognitionHardwareClientStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IActivityRecognitionHardwareServer

type IActivityRecognitionHardwareServer interface {
	GetSupportedActivities(ctx context.Context) ([]string, error)
	IsActivitySupported(ctx context.Context, activityType string) (bool, error)
	RegisterSink(ctx context.Context, sink IActivityRecognitionHardwareSink) (bool, error)
	UnregisterSink(ctx context.Context, sink IActivityRecognitionHardwareSink) (bool, error)
	EnableActivityEvent(ctx context.Context, activityType string, eventType int32, reportLatencyNs int64) (bool, error)
	DisableActivityEvent(ctx context.Context, activityType string, eventType int32) (bool, error)
	Flush(ctx context.Context) (bool, error)
}

IActivityRecognitionHardwareServer is the server-side interface that user implementations provide to NewActivityRecognitionHardwareStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IActivityRecognitionHardwareSink

type IActivityRecognitionHardwareSink interface {
	AsBinder() binder.IBinder
	OnActivityChanged(ctx context.Context, event ActivityChangedEvent) error
}

func NewActivityRecognitionHardwareSinkStub

func NewActivityRecognitionHardwareSinkStub(
	impl IActivityRecognitionHardwareSinkServer,
) IActivityRecognitionHardwareSink

NewActivityRecognitionHardwareSinkStub creates a server-side IActivityRecognitionHardwareSink wrapping the given server implementation. The returned value satisfies IActivityRecognitionHardwareSink and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IActivityRecognitionHardwareSinkServer

type IActivityRecognitionHardwareSinkServer interface {
	OnActivityChanged(ctx context.Context, event ActivityChangedEvent) error
}

IActivityRecognitionHardwareSinkServer is the server-side interface that user implementations provide to NewActivityRecognitionHardwareSinkStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IActivityRecognitionHardwareWatcher

type IActivityRecognitionHardwareWatcher interface {
	AsBinder() binder.IBinder
	OnInstanceChanged(ctx context.Context, instance IActivityRecognitionHardware) error
}

func NewActivityRecognitionHardwareWatcherStub

func NewActivityRecognitionHardwareWatcherStub(
	impl IActivityRecognitionHardwareWatcherServer,
) IActivityRecognitionHardwareWatcher

NewActivityRecognitionHardwareWatcherStub creates a server-side IActivityRecognitionHardwareWatcher wrapping the given server implementation. The returned value satisfies IActivityRecognitionHardwareWatcher and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IActivityRecognitionHardwareWatcherServer

type IActivityRecognitionHardwareWatcherServer interface {
	OnInstanceChanged(ctx context.Context, instance IActivityRecognitionHardware) error
}

IActivityRecognitionHardwareWatcherServer is the server-side interface that user implementations provide to NewActivityRecognitionHardwareWatcherStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IContextHubCallback

type IContextHubCallback interface {
	AsBinder() binder.IBinder
	OnMessageReceipt(ctx context.Context, hubId int32, nanoAppId int32, msg ContextHubMessage) error
}

func NewContextHubCallbackStub

func NewContextHubCallbackStub(
	impl IContextHubCallbackServer,
) IContextHubCallback

NewContextHubCallbackStub creates a server-side IContextHubCallback wrapping the given server implementation. The returned value satisfies IContextHubCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IContextHubCallbackServer

type IContextHubCallbackServer interface {
	OnMessageReceipt(ctx context.Context, hubId int32, nanoAppId int32, msg ContextHubMessage) error
}

IContextHubCallbackServer is the server-side interface that user implementations provide to NewContextHubCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IContextHubClient

type IContextHubClient interface {
	AsBinder() binder.IBinder
	SendMessageToNanoApp(ctx context.Context, message NanoAppMessage) (int32, error)
	Close(ctx context.Context) error
	GetId(ctx context.Context) (int32, error)
	CallbackFinished(ctx context.Context) error
	ReliableMessageCallbackFinished(ctx context.Context, messageSequenceNumber int32, errorCode byte) error
	SendReliableMessageToNanoApp(ctx context.Context, message NanoAppMessage, transactionCallback IContextHubTransactionCallback) (int32, error)
}

func NewContextHubClientStub

func NewContextHubClientStub(
	impl IContextHubClientServer,
) IContextHubClient

NewContextHubClientStub creates a server-side IContextHubClient wrapping the given server implementation. The returned value satisfies IContextHubClient and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IContextHubClientCallback

type IContextHubClientCallback interface {
	AsBinder() binder.IBinder
	OnMessageFromNanoApp(ctx context.Context, message NanoAppMessage) error
	OnHubReset(ctx context.Context) error
	OnNanoAppAborted(ctx context.Context, nanoAppId int64, abortCode int32) error
	OnNanoAppLoaded(ctx context.Context, nanoAppId int64) error
	OnNanoAppUnloaded(ctx context.Context, nanoAppId int64) error
	OnNanoAppEnabled(ctx context.Context, nanoAppId int64) error
	OnNanoAppDisabled(ctx context.Context, nanoAppId int64) error
	OnClientAuthorizationChanged(ctx context.Context, nanoAppId int64, authorization int32) error
}

func NewContextHubClientCallbackStub

func NewContextHubClientCallbackStub(
	impl IContextHubClientCallbackServer,
) IContextHubClientCallback

NewContextHubClientCallbackStub creates a server-side IContextHubClientCallback wrapping the given server implementation. The returned value satisfies IContextHubClientCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IContextHubClientCallbackServer

type IContextHubClientCallbackServer interface {
	OnMessageFromNanoApp(ctx context.Context, message NanoAppMessage) error
	OnHubReset(ctx context.Context) error
	OnNanoAppAborted(ctx context.Context, nanoAppId int64, abortCode int32) error
	OnNanoAppLoaded(ctx context.Context, nanoAppId int64) error
	OnNanoAppUnloaded(ctx context.Context, nanoAppId int64) error
	OnNanoAppEnabled(ctx context.Context, nanoAppId int64) error
	OnNanoAppDisabled(ctx context.Context, nanoAppId int64) error
	OnClientAuthorizationChanged(ctx context.Context, nanoAppId int64, authorization int32) error
}

IContextHubClientCallbackServer is the server-side interface that user implementations provide to NewContextHubClientCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IContextHubClientServer

type IContextHubClientServer interface {
	SendMessageToNanoApp(ctx context.Context, message NanoAppMessage) (int32, error)
	Close(ctx context.Context) error
	GetId(ctx context.Context) (int32, error)
	CallbackFinished(ctx context.Context) error
	ReliableMessageCallbackFinished(ctx context.Context, messageSequenceNumber int32, errorCode byte) error
	SendReliableMessageToNanoApp(ctx context.Context, message NanoAppMessage, transactionCallback IContextHubTransactionCallback) (int32, error)
}

IContextHubClientServer is the server-side interface that user implementations provide to NewContextHubClientStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IContextHubService

type IContextHubService interface {
	AsBinder() binder.IBinder
	RegisterCallback(ctx context.Context, callback IContextHubCallback) (int32, error)
	GetContextHubHandles(ctx context.Context) ([]int32, error)
	GetContextHubInfo(ctx context.Context, contextHubHandle int32) (ContextHubInfo, error)
	LoadNanoApp(ctx context.Context, contextHubHandle int32, nanoApp NanoApp) (int32, error)
	UnloadNanoApp(ctx context.Context, nanoAppHandle int32) (int32, error)
	GetNanoAppInstanceInfo(ctx context.Context, nanoAppHandle int32) (NanoAppInstanceInfo, error)
	FindNanoAppOnHub(ctx context.Context, contextHubHandle int32, filter NanoAppFilter) ([]int32, error)
	SendMessage(ctx context.Context, contextHubHandle int32, nanoAppHandle int32, msg ContextHubMessage) (int32, error)
	CreateClient(ctx context.Context, contextHubId int32, client IContextHubClientCallback, packageName string) (IContextHubClient, error)
	CreatePendingIntentClient(ctx context.Context, contextHubId int32, pendingIntent types.PendingIntent, nanoAppId int64) (IContextHubClient, error)
	GetContextHubs(ctx context.Context) ([]ContextHubInfo, error)
	LoadNanoAppOnHub(ctx context.Context, contextHubId int32, transactionCallback IContextHubTransactionCallback, nanoAppBinary NanoAppBinary) error
	UnloadNanoAppFromHub(ctx context.Context, contextHubId int32, transactionCallback IContextHubTransactionCallback, nanoAppId int64) error
	EnableNanoApp(ctx context.Context, contextHubId int32, transactionCallback IContextHubTransactionCallback, nanoAppId int64) error
	DisableNanoApp(ctx context.Context, contextHubId int32, transactionCallback IContextHubTransactionCallback, nanoAppId int64) error
	QueryNanoApps(ctx context.Context, contextHubId int32, transactionCallback IContextHubTransactionCallback) error
	GetPreloadedNanoAppIds(ctx context.Context, hubInfo ContextHubInfo) ([]int64, error)
	SetTestMode(ctx context.Context, enable bool) (bool, error)
}

func NewContextHubServiceStub

func NewContextHubServiceStub(
	impl IContextHubServiceServer,
) IContextHubService

NewContextHubServiceStub creates a server-side IContextHubService wrapping the given server implementation. The returned value satisfies IContextHubService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IContextHubServiceServer

type IContextHubServiceServer interface {
	RegisterCallback(ctx context.Context, callback IContextHubCallback) (int32, error)
	GetContextHubHandles(ctx context.Context) ([]int32, error)
	GetContextHubInfo(ctx context.Context, contextHubHandle int32) (ContextHubInfo, error)
	LoadNanoApp(ctx context.Context, contextHubHandle int32, nanoApp NanoApp) (int32, error)
	UnloadNanoApp(ctx context.Context, nanoAppHandle int32) (int32, error)
	GetNanoAppInstanceInfo(ctx context.Context, nanoAppHandle int32) (NanoAppInstanceInfo, error)
	FindNanoAppOnHub(ctx context.Context, contextHubHandle int32, filter NanoAppFilter) ([]int32, error)
	SendMessage(ctx context.Context, contextHubHandle int32, nanoAppHandle int32, msg ContextHubMessage) (int32, error)
	CreateClient(ctx context.Context, contextHubId int32, client IContextHubClientCallback, packageName string) (IContextHubClient, error)
	CreatePendingIntentClient(ctx context.Context, contextHubId int32, pendingIntent types.PendingIntent, nanoAppId int64) (IContextHubClient, error)
	GetContextHubs(ctx context.Context) ([]ContextHubInfo, error)
	LoadNanoAppOnHub(ctx context.Context, contextHubId int32, transactionCallback IContextHubTransactionCallback, nanoAppBinary NanoAppBinary) error
	UnloadNanoAppFromHub(ctx context.Context, contextHubId int32, transactionCallback IContextHubTransactionCallback, nanoAppId int64) error
	EnableNanoApp(ctx context.Context, contextHubId int32, transactionCallback IContextHubTransactionCallback, nanoAppId int64) error
	DisableNanoApp(ctx context.Context, contextHubId int32, transactionCallback IContextHubTransactionCallback, nanoAppId int64) error
	QueryNanoApps(ctx context.Context, contextHubId int32, transactionCallback IContextHubTransactionCallback) error
	GetPreloadedNanoAppIds(ctx context.Context, hubInfo ContextHubInfo) ([]int64, error)
	SetTestMode(ctx context.Context, enable bool) (bool, error)
}

IContextHubServiceServer is the server-side interface that user implementations provide to NewContextHubServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IContextHubTransactionCallback

type IContextHubTransactionCallback interface {
	AsBinder() binder.IBinder
	OnQueryResponse(ctx context.Context, result int32, nanoappList []NanoAppState) error
	OnTransactionComplete(ctx context.Context, result int32) error
}

func NewContextHubTransactionCallbackStub

func NewContextHubTransactionCallbackStub(
	impl IContextHubTransactionCallbackServer,
) IContextHubTransactionCallback

NewContextHubTransactionCallbackStub creates a server-side IContextHubTransactionCallback wrapping the given server implementation. The returned value satisfies IContextHubTransactionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IContextHubTransactionCallbackServer

type IContextHubTransactionCallbackServer interface {
	OnQueryResponse(ctx context.Context, result int32, nanoappList []NanoAppState) error
	OnTransactionComplete(ctx context.Context, result int32) error
}

IContextHubTransactionCallbackServer is the server-side interface that user implementations provide to NewContextHubTransactionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGeofenceHardware

type IGeofenceHardware interface {
	AsBinder() binder.IBinder
	SetGpsGeofenceHardware(ctx context.Context, service types.IGpsGeofenceHardware) error
	SetFusedGeofenceHardware(ctx context.Context, service types.IFusedGeofenceHardware) error
	GetMonitoringTypes(ctx context.Context) ([]int32, error)
	GetStatusOfMonitoringType(ctx context.Context, monitoringType int32) (int32, error)
	AddCircularFence(ctx context.Context, monitoringType int32, request GeofenceHardwareRequestParcelable, callback IGeofenceHardwareCallback) (bool, error)
	RemoveGeofence(ctx context.Context, id int32, monitoringType int32) (bool, error)
	PauseGeofence(ctx context.Context, id int32, monitoringType int32) (bool, error)
	ResumeGeofence(ctx context.Context, id int32, monitoringType int32, monitorTransitions int32) (bool, error)
	RegisterForMonitorStateChangeCallback(ctx context.Context, monitoringType int32, callback IGeofenceHardwareMonitorCallback) (bool, error)
	UnregisterForMonitorStateChangeCallback(ctx context.Context, monitoringType int32, callback IGeofenceHardwareMonitorCallback) (bool, error)
}

func NewGeofenceHardwareStub

func NewGeofenceHardwareStub(
	impl IGeofenceHardwareServer,
) IGeofenceHardware

NewGeofenceHardwareStub creates a server-side IGeofenceHardware wrapping the given server implementation. The returned value satisfies IGeofenceHardware and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGeofenceHardwareCallback

type IGeofenceHardwareCallback interface {
	AsBinder() binder.IBinder
	OnGeofenceTransition(ctx context.Context, geofenceId int32, transition int32, location types.Location, timestamp int64, monitoringType int32) error
	OnGeofenceAdd(ctx context.Context, geofenceId int32, status int32) error
	OnGeofenceRemove(ctx context.Context, geofenceId int32, status int32) error
	OnGeofencePause(ctx context.Context, geofenceId int32, status int32) error
	OnGeofenceResume(ctx context.Context, geofenceId int32, status int32) error
}

func NewGeofenceHardwareCallbackStub

func NewGeofenceHardwareCallbackStub(
	impl IGeofenceHardwareCallbackServer,
) IGeofenceHardwareCallback

NewGeofenceHardwareCallbackStub creates a server-side IGeofenceHardwareCallback wrapping the given server implementation. The returned value satisfies IGeofenceHardwareCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGeofenceHardwareCallbackServer

type IGeofenceHardwareCallbackServer interface {
	OnGeofenceTransition(ctx context.Context, geofenceId int32, transition int32, location types.Location, timestamp int64, monitoringType int32) error
	OnGeofenceAdd(ctx context.Context, geofenceId int32, status int32) error
	OnGeofenceRemove(ctx context.Context, geofenceId int32, status int32) error
	OnGeofencePause(ctx context.Context, geofenceId int32, status int32) error
	OnGeofenceResume(ctx context.Context, geofenceId int32, status int32) error
}

IGeofenceHardwareCallbackServer is the server-side interface that user implementations provide to NewGeofenceHardwareCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGeofenceHardwareMonitorCallback

type IGeofenceHardwareMonitorCallback interface {
	AsBinder() binder.IBinder
	OnMonitoringSystemChange(ctx context.Context, event GeofenceHardwareMonitorEvent) error
}

func NewGeofenceHardwareMonitorCallbackStub

func NewGeofenceHardwareMonitorCallbackStub(
	impl IGeofenceHardwareMonitorCallbackServer,
) IGeofenceHardwareMonitorCallback

NewGeofenceHardwareMonitorCallbackStub creates a server-side IGeofenceHardwareMonitorCallback wrapping the given server implementation. The returned value satisfies IGeofenceHardwareMonitorCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGeofenceHardwareMonitorCallbackServer

type IGeofenceHardwareMonitorCallbackServer interface {
	OnMonitoringSystemChange(ctx context.Context, event GeofenceHardwareMonitorEvent) error
}

IGeofenceHardwareMonitorCallbackServer is the server-side interface that user implementations provide to NewGeofenceHardwareMonitorCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGeofenceHardwareServer

type IGeofenceHardwareServer interface {
	SetGpsGeofenceHardware(ctx context.Context, service types.IGpsGeofenceHardware) error
	SetFusedGeofenceHardware(ctx context.Context, service types.IFusedGeofenceHardware) error
	GetMonitoringTypes(ctx context.Context) ([]int32, error)
	GetStatusOfMonitoringType(ctx context.Context, monitoringType int32) (int32, error)
	AddCircularFence(ctx context.Context, monitoringType int32, request GeofenceHardwareRequestParcelable, callback IGeofenceHardwareCallback) (bool, error)
	RemoveGeofence(ctx context.Context, id int32, monitoringType int32) (bool, error)
	PauseGeofence(ctx context.Context, id int32, monitoringType int32) (bool, error)
	ResumeGeofence(ctx context.Context, id int32, monitoringType int32, monitorTransitions int32) (bool, error)
	RegisterForMonitorStateChangeCallback(ctx context.Context, monitoringType int32, callback IGeofenceHardwareMonitorCallback) (bool, error)
	UnregisterForMonitorStateChangeCallback(ctx context.Context, monitoringType int32, callback IGeofenceHardwareMonitorCallback) (bool, error)
}

IGeofenceHardwareServer is the server-side interface that user implementations provide to NewGeofenceHardwareStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type NanoApp

type NanoApp struct {
	Publisher           string
	Name                string
	AppId               int64
	AppVersion          int32
	NeededReadMemBytes  int32
	NeededWriteMemBytes int32
	NeededExecMemBytes  int32
}

func (*NanoApp) MarshalParcel

func (s *NanoApp) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NanoApp) UnmarshalParcel

func (s *NanoApp) UnmarshalParcel(
	p *parcel.Parcel,
) error

type NanoAppBinary

type NanoAppBinary struct {
}

func (*NanoAppBinary) MarshalParcel

func (s *NanoAppBinary) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NanoAppBinary) UnmarshalParcel

func (s *NanoAppBinary) UnmarshalParcel(
	p *parcel.Parcel,
) error

type NanoAppFilter

type NanoAppFilter struct {
	AppId                  int64
	AppVersion             int32
	VersionRestrictionMask int32
	AppIdVendorMask        int64
}

func (*NanoAppFilter) MarshalParcel

func (s *NanoAppFilter) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NanoAppFilter) UnmarshalParcel

func (s *NanoAppFilter) UnmarshalParcel(
	p *parcel.Parcel,
) error

type NanoAppInstanceInfo

type NanoAppInstanceInfo struct {
	Publisher           string
	Name                string
	Handle              int32
	AppId               int64
	AppVersion          int32
	ContexthubId        int32
	NeededReadMemBytes  int32
	NeededWriteMemBytes int32
	NeededExecMemBytes  int32
}

func (*NanoAppInstanceInfo) MarshalParcel

func (s *NanoAppInstanceInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NanoAppInstanceInfo) UnmarshalParcel

func (s *NanoAppInstanceInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type NanoAppMessage

type NanoAppMessage struct {
	NanoAppId             int64
	MessageType           int32
	MessageSequenceNumber int32
}

func (*NanoAppMessage) MarshalParcel

func (s *NanoAppMessage) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NanoAppMessage) UnmarshalParcel

func (s *NanoAppMessage) UnmarshalParcel(
	p *parcel.Parcel,
) error

type NanoAppRpcService

type NanoAppRpcService struct {
	ServiceId      int64
	ServiceVersion int32
}

func (*NanoAppRpcService) MarshalParcel

func (s *NanoAppRpcService) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NanoAppRpcService) UnmarshalParcel

func (s *NanoAppRpcService) UnmarshalParcel(
	p *parcel.Parcel,
) error

type NanoAppState

type NanoAppState struct {
	NanoAppId      int64
	NanoAppVersion int32
}

func (*NanoAppState) MarshalParcel

func (s *NanoAppState) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NanoAppState) UnmarshalParcel

func (s *NanoAppState) UnmarshalParcel(
	p *parcel.Parcel,
) error

Jump to