c2

package
v0.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 28, 2026 License: CC0-1.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	BaseBlockTagNativeBlock int32 = 0
	BaseBlockTagHwbBlock    int32 = 1
	BaseBlockTagPooledBlock int32 = 2
)
const (
	FieldSupportedValuesTagEmpty  int32 = 0
	FieldSupportedValuesTagRange  int32 = 1
	FieldSupportedValuesTagValues int32 = 2
	FieldSupportedValuesTagFlags  int32 = 3
)
const (
	FrameDataDropFrame      int32 = (1 << 0)
	FrameDataEndOfStream    int32 = (1 << 1)
	FrameDataDiscardFrame   int32 = (1 << 2)
	FrameDataFlagIncomplete int32 = (1 << 3)
	FrameDataCodecConfig    int32 = -2147483648
)
const (
	TransactionIComponentConfigureVideoTunnel  = binder.FirstCallTransaction + 0
	TransactionIComponentCreateBlockPool       = binder.FirstCallTransaction + 1
	TransactionIComponentDestroyBlockPool      = binder.FirstCallTransaction + 2
	TransactionIComponentDrain                 = binder.FirstCallTransaction + 3
	TransactionIComponentFlush                 = binder.FirstCallTransaction + 4
	TransactionIComponentGetInterface          = binder.FirstCallTransaction + 5
	TransactionIComponentQueue                 = binder.FirstCallTransaction + 6
	TransactionIComponentRelease               = binder.FirstCallTransaction + 7
	TransactionIComponentReset                 = binder.FirstCallTransaction + 8
	TransactionIComponentStart                 = binder.FirstCallTransaction + 9
	TransactionIComponentStop                  = binder.FirstCallTransaction + 10
	TransactionIComponentConnectToInputSurface = binder.FirstCallTransaction + 11
	TransactionIComponentAsInputSink           = binder.FirstCallTransaction + 12
)
const (
	MethodIComponentConfigureVideoTunnel  = "configureVideoTunnel"
	MethodIComponentCreateBlockPool       = "createBlockPool"
	MethodIComponentDestroyBlockPool      = "destroyBlockPool"
	MethodIComponentDrain                 = "drain"
	MethodIComponentFlush                 = "flush"
	MethodIComponentGetInterface          = "getInterface"
	MethodIComponentQueue                 = "queue"
	MethodIComponentRelease               = "release"
	MethodIComponentReset                 = "reset"
	MethodIComponentStart                 = "start"
	MethodIComponentStop                  = "stop"
	MethodIComponentConnectToInputSurface = "connectToInputSurface"
	MethodIComponentAsInputSink           = "asInputSink"
)
const (
	TransactionIComponentListenerOnError                = binder.FirstCallTransaction + 0
	TransactionIComponentListenerOnFramesRendered       = binder.FirstCallTransaction + 1
	TransactionIComponentListenerOnInputBuffersReleased = binder.FirstCallTransaction + 2
	TransactionIComponentListenerOnTripped              = binder.FirstCallTransaction + 3
	TransactionIComponentListenerOnWorkDone             = binder.FirstCallTransaction + 4
)
const (
	MethodIComponentListenerOnError                = "onError"
	MethodIComponentListenerOnFramesRendered       = "onFramesRendered"
	MethodIComponentListenerOnInputBuffersReleased = "onInputBuffersReleased"
	MethodIComponentListenerOnTripped              = "onTripped"
	MethodIComponentListenerOnWorkDone             = "onWorkDone"
)
const (
	TransactionIComponentStoreCopyBuffer           = binder.FirstCallTransaction + 0
	TransactionIComponentStoreCreateComponent      = binder.FirstCallTransaction + 1
	TransactionIComponentStoreCreateInterface      = binder.FirstCallTransaction + 2
	TransactionIComponentStoreGetConfigurable      = binder.FirstCallTransaction + 3
	TransactionIComponentStoreGetPoolClientManager = binder.FirstCallTransaction + 4
	TransactionIComponentStoreGetStructDescriptors = binder.FirstCallTransaction + 5
	TransactionIComponentStoreListComponents       = binder.FirstCallTransaction + 6
	TransactionIComponentStoreCreateInputSurface   = binder.FirstCallTransaction + 7
)
const (
	MethodIComponentStoreCopyBuffer           = "copyBuffer"
	MethodIComponentStoreCreateComponent      = "createComponent"
	MethodIComponentStoreCreateInterface      = "createInterface"
	MethodIComponentStoreGetConfigurable      = "getConfigurable"
	MethodIComponentStoreGetPoolClientManager = "getPoolClientManager"
	MethodIComponentStoreGetStructDescriptors = "getStructDescriptors"
	MethodIComponentStoreListComponents       = "listComponents"
	MethodIComponentStoreCreateInputSurface   = "createInputSurface"
)
const (
	TransactionIConfigurableConfig               = binder.FirstCallTransaction + 0
	TransactionIConfigurableGetId                = binder.FirstCallTransaction + 1
	TransactionIConfigurableGetName              = binder.FirstCallTransaction + 2
	TransactionIConfigurableQuery                = binder.FirstCallTransaction + 3
	TransactionIConfigurableQuerySupportedParams = binder.FirstCallTransaction + 4
	TransactionIConfigurableQuerySupportedValues = binder.FirstCallTransaction + 5
)
const (
	MethodIConfigurableConfig               = "config"
	MethodIConfigurableGetId                = "getId"
	MethodIConfigurableGetName              = "getName"
	MethodIConfigurableQuery                = "query"
	MethodIConfigurableQuerySupportedParams = "querySupportedParams"
	MethodIConfigurableQuerySupportedValues = "querySupportedValues"
)
const (
	TransactionIGraphicBufferAllocatorAllocate      = binder.FirstCallTransaction + 0
	TransactionIGraphicBufferAllocatorDeallocate    = binder.FirstCallTransaction + 1
	TransactionIGraphicBufferAllocatorGetWaitableFd = binder.FirstCallTransaction + 2
)
const (
	MethodIGraphicBufferAllocatorAllocate      = "allocate"
	MethodIGraphicBufferAllocatorDeallocate    = "deallocate"
	MethodIGraphicBufferAllocatorGetWaitableFd = "getWaitableFd"
)
const (
	TransactionIInputSurfaceGetSurface      = binder.FirstCallTransaction + 0
	TransactionIInputSurfaceGetConfigurable = binder.FirstCallTransaction + 1
	TransactionIInputSurfaceConnect         = binder.FirstCallTransaction + 2
)
const (
	MethodIInputSurfaceGetSurface      = "getSurface"
	MethodIInputSurfaceGetConfigurable = "getConfigurable"
	MethodIInputSurfaceConnect         = "connect"
)
const (
	TransactionIInputSurfaceConnectionDisconnect        = binder.FirstCallTransaction + 0
	TransactionIInputSurfaceConnectionSignalEndOfStream = binder.FirstCallTransaction + 1
)
const (
	MethodIInputSurfaceConnectionDisconnect        = "disconnect"
	MethodIInputSurfaceConnectionSignalEndOfStream = "signalEndOfStream"
)
const (
	TransactionIPooledGraphicBufferAllocatorAllocate   = binder.FirstCallTransaction + 0
	TransactionIPooledGraphicBufferAllocatorDeallocate = binder.FirstCallTransaction + 1
)
const (
	MethodIPooledGraphicBufferAllocatorAllocate   = "allocate"
	MethodIPooledGraphicBufferAllocatorDeallocate = "deallocate"
)
const (
	ParamDescriptorAttributeRequired   int32 = (1 << 0)
	ParamDescriptorAttributePersistent int32 = (1 << 1)
	ParamDescriptorAttributeStrict     int32 = (1 << 2)
	ParamDescriptorAttributeReadOnly   int32 = (1 << 3)
	ParamDescriptorAttributeHidden     int32 = (1 << 4)
	ParamDescriptorAttributeInternal   int32 = (1 << 5)
	ParamDescriptorAttributeConst      int32 = (1 << 6)
)
const (
	StatusOK        int32 = 0
	StatusBadValue  int32 = -22
	StatusBadIndex  int32 = -75
	StatusCannotDo  int32 = -2147483646
	StatusDUPLICATE int32 = -17
	StatusNotFound  int32 = -2
	StatusBadState  int32 = -38
	StatusBLOCKING  int32 = -9930
	StatusNoMemory  int32 = -12
	StatusREFUSED   int32 = -1
	StatusTimedOut  int32 = -110
	StatusOMITTED   int32 = -74
	StatusCORRUPTED int32 = -2147483648
	StatusNoInit    int32 = -19
)
const DescriptorIComponent = "android.hardware.media.c2.IComponent"
const DescriptorIComponentInterface = "android.hardware.media.c2.IComponentInterface"
const DescriptorIComponentListener = "android.hardware.media.c2.IComponentListener"
const DescriptorIComponentStore = "android.hardware.media.c2.IComponentStore"
const DescriptorIConfigurable = "android.hardware.media.c2.IConfigurable"
const DescriptorIGraphicBufferAllocator = "android.hardware.media.c2.IGraphicBufferAllocator"
const DescriptorIInputSink = "android.hardware.media.c2.IInputSink"
const DescriptorIInputSurface = "android.hardware.media.c2.IInputSurface"
const DescriptorIInputSurfaceConnection = "android.hardware.media.c2.IInputSurfaceConnection"
const DescriptorIPooledGraphicBufferAllocator = "android.hardware.media.c2.IPooledGraphicBufferAllocator"
const (
	MethodIComponentInterfaceGetConfigurable = "getConfigurable"
)
const (
	MethodIInputSinkQueue = "queue"
)
const (
	TransactionIComponentInterfaceGetConfigurable = binder.FirstCallTransaction + 0
)
const (
	TransactionIInputSinkQueue = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type BaseBlock

type BaseBlock struct {
	Tag         int32
	NativeBlock common.NativeHandle
	HwbBlock    graphicsCommon.HardwareBuffer
	PooledBlock bufferpool2.BufferStatusMessage
}

func (*BaseBlock) GetHwbBlock

func (u *BaseBlock) GetHwbBlock() (graphicsCommon.HardwareBuffer, bool)

func (*BaseBlock) GetNativeBlock

func (u *BaseBlock) GetNativeBlock() (common.NativeHandle, bool)

func (*BaseBlock) GetPooledBlock

func (u *BaseBlock) GetPooledBlock() (bufferpool2.BufferStatusMessage, bool)

func (*BaseBlock) MarshalParcel

func (u *BaseBlock) MarshalParcel(
	p *parcel.Parcel,
) error

func (*BaseBlock) SetHwbBlock

func (u *BaseBlock) SetHwbBlock(
	v graphicsCommon.HardwareBuffer,
)

func (*BaseBlock) SetNativeBlock

func (u *BaseBlock) SetNativeBlock(
	v common.NativeHandle,
)

func (*BaseBlock) SetPooledBlock

func (u *BaseBlock) SetPooledBlock(
	v bufferpool2.BufferStatusMessage,
)

func (*BaseBlock) UnmarshalParcel

func (u *BaseBlock) UnmarshalParcel(
	p *parcel.Parcel,
) error

type Block

type Block struct {
	Index int32
	Meta  Params
	Fence common.NativeHandle
}

func (*Block) MarshalParcel

func (s *Block) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Block) UnmarshalParcel

func (s *Block) UnmarshalParcel(
	p *parcel.Parcel,
) error

type Buffer

type Buffer struct {
	Info   Params
	Blocks []Block
}

func (*Buffer) MarshalParcel

func (s *Buffer) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Buffer) UnmarshalParcel

func (s *Buffer) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ComponentInterfaceProxy

type ComponentInterfaceProxy struct {
	Remote binder.IBinder
}

func NewComponentInterfaceProxy

func NewComponentInterfaceProxy(
	remote binder.IBinder,
) *ComponentInterfaceProxy

func (*ComponentInterfaceProxy) AsBinder

func (p *ComponentInterfaceProxy) AsBinder() binder.IBinder

func (*ComponentInterfaceProxy) GetConfigurable

func (p *ComponentInterfaceProxy) GetConfigurable(
	ctx context.Context,
) (IConfigurable, error)

type ComponentInterfaceStub

type ComponentInterfaceStub struct {
	Impl      IComponentInterface
	Transport binder.VersionAwareTransport
}

ComponentInterfaceStub dispatches incoming binder transactions to a typed IComponentInterface implementation.

func (*ComponentInterfaceStub) Descriptor

func (s *ComponentInterfaceStub) Descriptor() string

func (*ComponentInterfaceStub) OnTransaction

func (s *ComponentInterfaceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ComponentListenerProxy

type ComponentListenerProxy struct {
	Remote binder.IBinder
}

func NewComponentListenerProxy

func NewComponentListenerProxy(
	remote binder.IBinder,
) *ComponentListenerProxy

func (*ComponentListenerProxy) AsBinder

func (p *ComponentListenerProxy) AsBinder() binder.IBinder

func (*ComponentListenerProxy) OnError

func (p *ComponentListenerProxy) OnError(
	ctx context.Context,
	status Status,
	errorCode int32,
) error

func (*ComponentListenerProxy) OnFramesRendered

func (p *ComponentListenerProxy) OnFramesRendered(
	ctx context.Context,
	renderedFrames []IComponentListenerRenderedFrame,
) error

func (*ComponentListenerProxy) OnInputBuffersReleased

func (p *ComponentListenerProxy) OnInputBuffersReleased(
	ctx context.Context,
	inputBuffers []IComponentListenerInputBuffer,
) error

func (*ComponentListenerProxy) OnTripped

func (p *ComponentListenerProxy) OnTripped(
	ctx context.Context,
	settingResults []SettingResult,
) error

func (*ComponentListenerProxy) OnWorkDone

func (p *ComponentListenerProxy) OnWorkDone(
	ctx context.Context,
	workBundle WorkBundle,
) error

type ComponentListenerStub

type ComponentListenerStub struct {
	Impl      IComponentListener
	Transport binder.VersionAwareTransport
}

ComponentListenerStub dispatches incoming binder transactions to a typed IComponentListener implementation.

func (*ComponentListenerStub) Descriptor

func (s *ComponentListenerStub) Descriptor() string

func (*ComponentListenerStub) OnTransaction

func (s *ComponentListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ComponentProxy

type ComponentProxy struct {
	Remote binder.IBinder
}

func NewComponentProxy

func NewComponentProxy(
	remote binder.IBinder,
) *ComponentProxy

func (*ComponentProxy) AsBinder

func (p *ComponentProxy) AsBinder() binder.IBinder

func (*ComponentProxy) AsInputSink

func (p *ComponentProxy) AsInputSink(
	ctx context.Context,
) (IInputSink, error)

func (*ComponentProxy) ConfigureVideoTunnel

func (p *ComponentProxy) ConfigureVideoTunnel(
	ctx context.Context,
	avSyncHwId int32,
) (common.NativeHandle, error)

func (*ComponentProxy) ConnectToInputSurface

func (p *ComponentProxy) ConnectToInputSurface(
	ctx context.Context,
	inputSurface IInputSurface,
) (IInputSurfaceConnection, error)

func (*ComponentProxy) CreateBlockPool

func (p *ComponentProxy) CreateBlockPool(
	ctx context.Context,
	allocator IComponentBlockPoolAllocator,
) (IComponentBlockPool, error)

func (*ComponentProxy) DestroyBlockPool

func (p *ComponentProxy) DestroyBlockPool(
	ctx context.Context,
	blockPoolId int64,
) error

func (*ComponentProxy) Drain

func (p *ComponentProxy) Drain(
	ctx context.Context,
	withEos bool,
) error

func (*ComponentProxy) Flush

func (p *ComponentProxy) Flush(
	ctx context.Context,
) (WorkBundle, error)

func (*ComponentProxy) GetInterface

func (p *ComponentProxy) GetInterface(
	ctx context.Context,
) (IComponentInterface, error)

func (*ComponentProxy) Queue

func (p *ComponentProxy) Queue(
	ctx context.Context,
	workBundle WorkBundle,
) error

func (*ComponentProxy) Release

func (p *ComponentProxy) Release(
	ctx context.Context,
) error

func (*ComponentProxy) Reset

func (p *ComponentProxy) Reset(
	ctx context.Context,
) error

func (*ComponentProxy) Start

func (p *ComponentProxy) Start(
	ctx context.Context,
) error

func (*ComponentProxy) Stop

func (p *ComponentProxy) Stop(
	ctx context.Context,
) error

type ComponentStoreProxy

type ComponentStoreProxy struct {
	Remote binder.IBinder
}

func NewComponentStoreProxy

func NewComponentStoreProxy(
	remote binder.IBinder,
) *ComponentStoreProxy

func (*ComponentStoreProxy) AsBinder

func (p *ComponentStoreProxy) AsBinder() binder.IBinder

func (*ComponentStoreProxy) CopyBuffer

func (p *ComponentStoreProxy) CopyBuffer(
	ctx context.Context,
	src Buffer,
	dst Buffer,
) error

func (*ComponentStoreProxy) CreateComponent

func (p *ComponentStoreProxy) CreateComponent(
	ctx context.Context,
	name string,
	listener IComponentListener,
	pool bufferpool2.IClientManager,
) (IComponent, error)

func (*ComponentStoreProxy) CreateInputSurface

func (p *ComponentStoreProxy) CreateInputSurface(
	ctx context.Context,
) (IInputSurface, error)

func (*ComponentStoreProxy) CreateInterface

func (p *ComponentStoreProxy) CreateInterface(
	ctx context.Context,
	name string,
) (IComponentInterface, error)

func (*ComponentStoreProxy) GetConfigurable

func (p *ComponentStoreProxy) GetConfigurable(
	ctx context.Context,
) (IConfigurable, error)

func (*ComponentStoreProxy) GetPoolClientManager

func (p *ComponentStoreProxy) GetPoolClientManager(
	ctx context.Context,
) (bufferpool2.IClientManager, error)

func (*ComponentStoreProxy) GetStructDescriptors

func (p *ComponentStoreProxy) GetStructDescriptors(
	ctx context.Context,
	indices []int32,
) ([]StructDescriptor, error)

func (*ComponentStoreProxy) ListComponents

type ComponentStoreStub

type ComponentStoreStub struct {
	Impl      IComponentStore
	Transport binder.VersionAwareTransport
}

ComponentStoreStub dispatches incoming binder transactions to a typed IComponentStore implementation.

func (*ComponentStoreStub) Descriptor

func (s *ComponentStoreStub) Descriptor() string

func (*ComponentStoreStub) OnTransaction

func (s *ComponentStoreStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ComponentStub

type ComponentStub struct {
	Impl      IComponent
	Transport binder.VersionAwareTransport
}

ComponentStub dispatches incoming binder transactions to a typed IComponent implementation.

func (*ComponentStub) Descriptor

func (s *ComponentStub) Descriptor() string

func (*ComponentStub) OnTransaction

func (s *ComponentStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ConfigurableProxy

type ConfigurableProxy struct {
	Remote binder.IBinder
}

func NewConfigurableProxy

func NewConfigurableProxy(
	remote binder.IBinder,
) *ConfigurableProxy

func (*ConfigurableProxy) AsBinder

func (p *ConfigurableProxy) AsBinder() binder.IBinder

func (*ConfigurableProxy) Config

func (p *ConfigurableProxy) Config(
	ctx context.Context,
	inParams Params,
	mayBlock bool,
) (IConfigurableConfigResult, error)

func (*ConfigurableProxy) GetId

func (p *ConfigurableProxy) GetId(
	ctx context.Context,
) (int32, error)

func (*ConfigurableProxy) GetName

func (p *ConfigurableProxy) GetName(
	ctx context.Context,
) (string, error)

func (*ConfigurableProxy) Query

func (p *ConfigurableProxy) Query(
	ctx context.Context,
	indices []int32,
	mayBlock bool,
) (IConfigurableQueryResult, error)

func (*ConfigurableProxy) QuerySupportedParams

func (p *ConfigurableProxy) QuerySupportedParams(
	ctx context.Context,
	start int32,
	count int32,
) ([]ParamDescriptor, error)

func (*ConfigurableProxy) QuerySupportedValues

func (p *ConfigurableProxy) QuerySupportedValues(
	ctx context.Context,
	inFields []FieldSupportedValuesQuery,
	mayBlock bool,
) (IConfigurableQuerySupportedValuesResult, error)

type ConfigurableStub

type ConfigurableStub struct {
	Impl      IConfigurable
	Transport binder.VersionAwareTransport
}

ConfigurableStub dispatches incoming binder transactions to a typed IConfigurable implementation.

func (*ConfigurableStub) Descriptor

func (s *ConfigurableStub) Descriptor() string

func (*ConfigurableStub) OnTransaction

func (s *ConfigurableStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type FieldDescriptor

type FieldDescriptor struct {
	FieldId     FieldId
	Type        FieldDescriptorType
	StructIndex int32
	Extent      int32
	Name        string
	NamedValues []FieldDescriptorNamedValue
}

func (*FieldDescriptor) MarshalParcel

func (s *FieldDescriptor) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FieldDescriptor) UnmarshalParcel

func (s *FieldDescriptor) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FieldDescriptorNamedValue

type FieldDescriptorNamedValue struct {
	Name  string
	Value int64
}

func (*FieldDescriptorNamedValue) MarshalParcel

func (s *FieldDescriptorNamedValue) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FieldDescriptorNamedValue) UnmarshalParcel

func (s *FieldDescriptorNamedValue) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FieldDescriptorType

type FieldDescriptorType int32
const (
	FieldDescriptorTypeNoInit FieldDescriptorType = 0
	FieldDescriptorTypeINT32  FieldDescriptorType = 1
	FieldDescriptorTypeUINT32 FieldDescriptorType = 2
	FieldDescriptorTypeCNTR32 FieldDescriptorType = 3
	FieldDescriptorTypeINT64  FieldDescriptorType = 4
	FieldDescriptorTypeUINT64 FieldDescriptorType = 5
	FieldDescriptorTypeCNTR64 FieldDescriptorType = 6
	FieldDescriptorTypeFLOAT  FieldDescriptorType = 7
	FieldDescriptorTypeSTRING FieldDescriptorType = 256
	FieldDescriptorTypeBLOB   FieldDescriptorType = 257
	FieldDescriptorTypeSTRUCT FieldDescriptorType = 131072
)

type FieldId

type FieldId struct {
	Offset    int32
	SizeBytes int32
}

func (*FieldId) MarshalParcel

func (s *FieldId) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FieldId) UnmarshalParcel

func (s *FieldId) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FieldSupportedValues

type FieldSupportedValues struct {
	Tag    int32
	Empty  bool
	Range  ValueRange
	Values []int64
	Flags  []int64
}

func (*FieldSupportedValues) GetEmpty

func (u *FieldSupportedValues) GetEmpty() (bool, bool)

func (*FieldSupportedValues) GetFlags

func (u *FieldSupportedValues) GetFlags() ([]int64, bool)

func (*FieldSupportedValues) GetRange

func (u *FieldSupportedValues) GetRange() (ValueRange, bool)

func (*FieldSupportedValues) GetValues

func (u *FieldSupportedValues) GetValues() ([]int64, bool)

func (*FieldSupportedValues) MarshalParcel

func (u *FieldSupportedValues) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FieldSupportedValues) SetEmpty

func (u *FieldSupportedValues) SetEmpty(
	v bool,
)

func (*FieldSupportedValues) SetFlags

func (u *FieldSupportedValues) SetFlags(
	v []int64,
)

func (*FieldSupportedValues) SetRange

func (u *FieldSupportedValues) SetRange(
	v ValueRange,
)

func (*FieldSupportedValues) SetValues

func (u *FieldSupportedValues) SetValues(
	v []int64,
)

func (*FieldSupportedValues) UnmarshalParcel

func (u *FieldSupportedValues) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FieldSupportedValuesQuery

type FieldSupportedValuesQuery struct {
	Field ParamField
	Type  FieldSupportedValuesQueryType
}

func (*FieldSupportedValuesQuery) MarshalParcel

func (s *FieldSupportedValuesQuery) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FieldSupportedValuesQuery) UnmarshalParcel

func (s *FieldSupportedValuesQuery) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FieldSupportedValuesQueryResult

type FieldSupportedValuesQueryResult struct {
	Status Status
	Values FieldSupportedValues
}

func (*FieldSupportedValuesQueryResult) MarshalParcel

func (s *FieldSupportedValuesQueryResult) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FieldSupportedValuesQueryResult) UnmarshalParcel

func (s *FieldSupportedValuesQueryResult) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FieldSupportedValuesQueryType

type FieldSupportedValuesQueryType int32
const (
	FieldSupportedValuesQueryTypePOSSIBLE FieldSupportedValuesQueryType = 0
	FieldSupportedValuesQueryTypeCURRENT  FieldSupportedValuesQueryType = 1
)

type FrameData

type FrameData struct {
	Flags        int32
	Ordinal      WorkOrdinal
	Buffers      []Buffer
	ConfigUpdate Params
	InfoBuffers  []InfoBuffer
}

func (*FrameData) MarshalParcel

func (s *FrameData) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FrameData) UnmarshalParcel

func (s *FrameData) UnmarshalParcel(
	p *parcel.Parcel,
) error

type GraphicBufferAllocatorProxy

type GraphicBufferAllocatorProxy struct {
	Remote binder.IBinder
}

func NewGraphicBufferAllocatorProxy

func NewGraphicBufferAllocatorProxy(
	remote binder.IBinder,
) *GraphicBufferAllocatorProxy

func (*GraphicBufferAllocatorProxy) AsBinder

func (*GraphicBufferAllocatorProxy) Deallocate

func (p *GraphicBufferAllocatorProxy) Deallocate(
	ctx context.Context,
	id int64,
) (bool, error)

func (*GraphicBufferAllocatorProxy) GetWaitableFd

func (p *GraphicBufferAllocatorProxy) GetWaitableFd(
	ctx context.Context,
) (int32, error)

type GraphicBufferAllocatorStub

type GraphicBufferAllocatorStub struct {
	Impl      IGraphicBufferAllocator
	Transport binder.VersionAwareTransport
}

GraphicBufferAllocatorStub dispatches incoming binder transactions to a typed IGraphicBufferAllocator implementation.

func (*GraphicBufferAllocatorStub) Descriptor

func (s *GraphicBufferAllocatorStub) Descriptor() string

func (*GraphicBufferAllocatorStub) OnTransaction

func (s *GraphicBufferAllocatorStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IComponent

type IComponent interface {
	AsBinder() binder.IBinder
	ConfigureVideoTunnel(ctx context.Context, avSyncHwId int32) (common.NativeHandle, error)
	CreateBlockPool(ctx context.Context, allocator IComponentBlockPoolAllocator) (IComponentBlockPool, error)
	DestroyBlockPool(ctx context.Context, blockPoolId int64) error
	Drain(ctx context.Context, withEos bool) error
	Flush(ctx context.Context) (WorkBundle, error)
	GetInterface(ctx context.Context) (IComponentInterface, error)
	Queue(ctx context.Context, workBundle WorkBundle) error
	Release(ctx context.Context) error
	Reset(ctx context.Context) error
	Start(ctx context.Context) error
	Stop(ctx context.Context) error
	ConnectToInputSurface(ctx context.Context, inputSurface IInputSurface) (IInputSurfaceConnection, error)
	AsInputSink(ctx context.Context) (IInputSink, error)
}

func NewComponentStub

func NewComponentStub(
	impl IComponentServer,
) IComponent

NewComponentStub creates a server-side IComponent wrapping the given server implementation. The returned value satisfies IComponent and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IComponentBlockPool

type IComponentBlockPool struct {
	BlockPoolId  int64
	Configurable IConfigurable
}

func (*IComponentBlockPool) MarshalParcel

func (s *IComponentBlockPool) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IComponentBlockPool) UnmarshalParcel

func (s *IComponentBlockPool) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IComponentBlockPoolAllocator

type IComponentBlockPoolAllocator struct {
	AllocatorId       int32
	GbAllocator       *IComponentGbAllocator
	PooledGbAllocator *IComponentPooledGbAllocator
}

func (*IComponentBlockPoolAllocator) MarshalParcel

func (s *IComponentBlockPoolAllocator) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IComponentBlockPoolAllocator) UnmarshalParcel

func (s *IComponentBlockPoolAllocator) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IComponentGbAllocator

type IComponentGbAllocator struct {
	WaitableFd int32
	Igba       IGraphicBufferAllocator
}

func (*IComponentGbAllocator) MarshalParcel

func (s *IComponentGbAllocator) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IComponentGbAllocator) UnmarshalParcel

func (s *IComponentGbAllocator) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IComponentInterface

type IComponentInterface interface {
	AsBinder() binder.IBinder
	GetConfigurable(ctx context.Context) (IConfigurable, error)
}

func NewComponentInterfaceStub

func NewComponentInterfaceStub(
	impl IComponentInterfaceServer,
) IComponentInterface

NewComponentInterfaceStub creates a server-side IComponentInterface wrapping the given server implementation. The returned value satisfies IComponentInterface and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IComponentInterfaceServer

type IComponentInterfaceServer interface {
	GetConfigurable(ctx context.Context) (IConfigurable, error)
}

IComponentInterfaceServer is the server-side interface that user implementations provide to NewComponentInterfaceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IComponentListener

type IComponentListener interface {
	AsBinder() binder.IBinder
	OnError(ctx context.Context, status Status, errorCode int32) error
	OnFramesRendered(ctx context.Context, renderedFrames []IComponentListenerRenderedFrame) error
	OnInputBuffersReleased(ctx context.Context, inputBuffers []IComponentListenerInputBuffer) error
	OnTripped(ctx context.Context, settingResults []SettingResult) error
	OnWorkDone(ctx context.Context, workBundle WorkBundle) error
}

func NewComponentListenerStub

func NewComponentListenerStub(
	impl IComponentListenerServer,
) IComponentListener

NewComponentListenerStub creates a server-side IComponentListener wrapping the given server implementation. The returned value satisfies IComponentListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IComponentListenerInputBuffer

type IComponentListenerInputBuffer struct {
	FrameIndex int64
	ArrayIndex int32
}

func (*IComponentListenerInputBuffer) MarshalParcel

func (s *IComponentListenerInputBuffer) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IComponentListenerInputBuffer) UnmarshalParcel

func (s *IComponentListenerInputBuffer) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IComponentListenerRenderedFrame

type IComponentListenerRenderedFrame struct {
	BufferQueueId int64
	SlotId        int32
	TimestampNs   int64
}

func (*IComponentListenerRenderedFrame) MarshalParcel

func (s *IComponentListenerRenderedFrame) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IComponentListenerRenderedFrame) UnmarshalParcel

func (s *IComponentListenerRenderedFrame) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IComponentListenerServer

type IComponentListenerServer interface {
	OnError(ctx context.Context, status Status, errorCode int32) error
	OnFramesRendered(ctx context.Context, renderedFrames []IComponentListenerRenderedFrame) error
	OnInputBuffersReleased(ctx context.Context, inputBuffers []IComponentListenerInputBuffer) error
	OnTripped(ctx context.Context, settingResults []SettingResult) error
	OnWorkDone(ctx context.Context, workBundle WorkBundle) error
}

IComponentListenerServer is the server-side interface that user implementations provide to NewComponentListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IComponentPooledGbAllocator

type IComponentPooledGbAllocator struct {
	WaitableFd int32
	ReceiverId int64
	Ipgba      IPooledGraphicBufferAllocator
}

func (*IComponentPooledGbAllocator) MarshalParcel

func (s *IComponentPooledGbAllocator) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IComponentPooledGbAllocator) UnmarshalParcel

func (s *IComponentPooledGbAllocator) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IComponentServer

type IComponentServer interface {
	ConfigureVideoTunnel(ctx context.Context, avSyncHwId int32) (common.NativeHandle, error)
	CreateBlockPool(ctx context.Context, allocator IComponentBlockPoolAllocator) (IComponentBlockPool, error)
	DestroyBlockPool(ctx context.Context, blockPoolId int64) error
	Drain(ctx context.Context, withEos bool) error
	Flush(ctx context.Context) (WorkBundle, error)
	GetInterface(ctx context.Context) (IComponentInterface, error)
	Queue(ctx context.Context, workBundle WorkBundle) error
	Release(ctx context.Context) error
	Reset(ctx context.Context) error
	Start(ctx context.Context) error
	Stop(ctx context.Context) error
	ConnectToInputSurface(ctx context.Context, inputSurface IInputSurface) (IInputSurfaceConnection, error)
	AsInputSink(ctx context.Context) (IInputSink, error)
}

IComponentServer is the server-side interface that user implementations provide to NewComponentStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IComponentStore

type IComponentStore interface {
	AsBinder() binder.IBinder
	CopyBuffer(ctx context.Context, src Buffer, dst Buffer) error
	CreateComponent(ctx context.Context, name string, listener IComponentListener, pool bufferpool2.IClientManager) (IComponent, error)
	CreateInterface(ctx context.Context, name string) (IComponentInterface, error)
	GetConfigurable(ctx context.Context) (IConfigurable, error)
	GetPoolClientManager(ctx context.Context) (bufferpool2.IClientManager, error)
	GetStructDescriptors(ctx context.Context, indices []int32) ([]StructDescriptor, error)
	ListComponents(ctx context.Context) ([]IComponentStoreComponentTraits, error)
	CreateInputSurface(ctx context.Context) (IInputSurface, error)
}

func NewComponentStoreStub

func NewComponentStoreStub(
	impl IComponentStoreServer,
) IComponentStore

NewComponentStoreStub creates a server-side IComponentStore wrapping the given server implementation. The returned value satisfies IComponentStore and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IComponentStoreComponentTraits

type IComponentStoreComponentTraits struct {
	Name      string
	Domain    IComponentStoreComponentTraitsDomain
	Kind      IComponentStoreComponentTraitsKind
	Rank      int32
	MediaType string
	Aliases   []string
}

func (*IComponentStoreComponentTraits) MarshalParcel

func (s *IComponentStoreComponentTraits) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IComponentStoreComponentTraits) UnmarshalParcel

func (s *IComponentStoreComponentTraits) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IComponentStoreComponentTraitsDomain

type IComponentStoreComponentTraitsDomain int32
const (
	IComponentStoreComponentTraitsDomainOTHER IComponentStoreComponentTraitsDomain = 0
	IComponentStoreComponentTraitsDomainVIDEO IComponentStoreComponentTraitsDomain = 1
	IComponentStoreComponentTraitsDomainAUDIO IComponentStoreComponentTraitsDomain = 2
	IComponentStoreComponentTraitsDomainIMAGE IComponentStoreComponentTraitsDomain = 3
)

type IComponentStoreComponentTraitsKind

type IComponentStoreComponentTraitsKind int32
const (
	IComponentStoreComponentTraitsKindOTHER   IComponentStoreComponentTraitsKind = 0
	IComponentStoreComponentTraitsKindDECODER IComponentStoreComponentTraitsKind = 1
	IComponentStoreComponentTraitsKindENCODER IComponentStoreComponentTraitsKind = 2
)

type IComponentStoreServer

type IComponentStoreServer interface {
	CopyBuffer(ctx context.Context, src Buffer, dst Buffer) error
	CreateComponent(ctx context.Context, name string, listener IComponentListener, pool bufferpool2.IClientManager) (IComponent, error)
	CreateInterface(ctx context.Context, name string) (IComponentInterface, error)
	GetConfigurable(ctx context.Context) (IConfigurable, error)
	GetPoolClientManager(ctx context.Context) (bufferpool2.IClientManager, error)
	GetStructDescriptors(ctx context.Context, indices []int32) ([]StructDescriptor, error)
	ListComponents(ctx context.Context) ([]IComponentStoreComponentTraits, error)
	CreateInputSurface(ctx context.Context) (IInputSurface, error)
}

IComponentStoreServer is the server-side interface that user implementations provide to NewComponentStoreStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IConfigurable

type IConfigurable interface {
	AsBinder() binder.IBinder
	Config(ctx context.Context, inParams Params, mayBlock bool) (IConfigurableConfigResult, error)
	GetId(ctx context.Context) (int32, error)
	GetName(ctx context.Context) (string, error)
	Query(ctx context.Context, indices []int32, mayBlock bool) (IConfigurableQueryResult, error)
	QuerySupportedParams(ctx context.Context, start int32, count int32) ([]ParamDescriptor, error)
	QuerySupportedValues(ctx context.Context, inFields []FieldSupportedValuesQuery, mayBlock bool) (IConfigurableQuerySupportedValuesResult, error)
}

func NewConfigurableStub

func NewConfigurableStub(
	impl IConfigurableServer,
) IConfigurable

NewConfigurableStub creates a server-side IConfigurable wrapping the given server implementation. The returned value satisfies IConfigurable and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IConfigurableConfigResult

type IConfigurableConfigResult struct {
	Params   Params
	Failures []SettingResult
	Status   Status
}

func (*IConfigurableConfigResult) MarshalParcel

func (s *IConfigurableConfigResult) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IConfigurableConfigResult) UnmarshalParcel

func (s *IConfigurableConfigResult) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IConfigurableQueryResult

type IConfigurableQueryResult struct {
	Params Params
	Status Status
}

func (*IConfigurableQueryResult) MarshalParcel

func (s *IConfigurableQueryResult) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IConfigurableQueryResult) UnmarshalParcel

func (s *IConfigurableQueryResult) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IConfigurableQuerySupportedValuesResult

type IConfigurableQuerySupportedValuesResult struct {
	Values []FieldSupportedValuesQueryResult
	Status Status
}

func (*IConfigurableQuerySupportedValuesResult) MarshalParcel

func (*IConfigurableQuerySupportedValuesResult) UnmarshalParcel

func (s *IConfigurableQuerySupportedValuesResult) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IConfigurableServer

type IConfigurableServer interface {
	Config(ctx context.Context, inParams Params, mayBlock bool) (IConfigurableConfigResult, error)
	GetId(ctx context.Context) (int32, error)
	GetName(ctx context.Context) (string, error)
	Query(ctx context.Context, indices []int32, mayBlock bool) (IConfigurableQueryResult, error)
	QuerySupportedParams(ctx context.Context, start int32, count int32) ([]ParamDescriptor, error)
	QuerySupportedValues(ctx context.Context, inFields []FieldSupportedValuesQuery, mayBlock bool) (IConfigurableQuerySupportedValuesResult, error)
}

IConfigurableServer is the server-side interface that user implementations provide to NewConfigurableStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGraphicBufferAllocator

type IGraphicBufferAllocator interface {
	AsBinder() binder.IBinder
	Allocate(ctx context.Context, desc IGraphicBufferAllocatorDescription) (IGraphicBufferAllocatorAllocation, error)
	Deallocate(ctx context.Context, id int64) (bool, error)
	GetWaitableFd(ctx context.Context) (int32, error)
}

func NewGraphicBufferAllocatorStub

func NewGraphicBufferAllocatorStub(
	impl IGraphicBufferAllocatorServer,
) IGraphicBufferAllocator

NewGraphicBufferAllocatorStub creates a server-side IGraphicBufferAllocator wrapping the given server implementation. The returned value satisfies IGraphicBufferAllocator and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGraphicBufferAllocatorAllocation

type IGraphicBufferAllocatorAllocation struct {
	Buffer common.HardwareBuffer
	Fence  int32
}

func (*IGraphicBufferAllocatorAllocation) MarshalParcel

func (s *IGraphicBufferAllocatorAllocation) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IGraphicBufferAllocatorAllocation) UnmarshalParcel

func (s *IGraphicBufferAllocatorAllocation) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IGraphicBufferAllocatorDescription

type IGraphicBufferAllocatorDescription struct {
	Width  int32
	Height int32
	Format int32
	Usage  int64
}

func (*IGraphicBufferAllocatorDescription) MarshalParcel

func (s *IGraphicBufferAllocatorDescription) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IGraphicBufferAllocatorDescription) UnmarshalParcel

func (s *IGraphicBufferAllocatorDescription) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IGraphicBufferAllocatorServer

type IGraphicBufferAllocatorServer interface {
	Allocate(ctx context.Context, desc IGraphicBufferAllocatorDescription) (IGraphicBufferAllocatorAllocation, error)
	Deallocate(ctx context.Context, id int64) (bool, error)
	GetWaitableFd(ctx context.Context) (int32, error)
}

IGraphicBufferAllocatorServer is the server-side interface that user implementations provide to NewGraphicBufferAllocatorStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IInputSink

type IInputSink interface {
	AsBinder() binder.IBinder
	Queue(ctx context.Context, workBundle WorkBundle) error
}

func NewInputSinkStub

func NewInputSinkStub(
	impl IInputSinkServer,
) IInputSink

NewInputSinkStub creates a server-side IInputSink wrapping the given server implementation. The returned value satisfies IInputSink and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IInputSinkServer

type IInputSinkServer interface {
	Queue(ctx context.Context, workBundle WorkBundle) error
}

IInputSinkServer is the server-side interface that user implementations provide to NewInputSinkStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IInputSurface

type IInputSurface interface {
	AsBinder() binder.IBinder
	GetSurface(ctx context.Context) (view.Surface, error)
	GetConfigurable(ctx context.Context) (IConfigurable, error)
	Connect(ctx context.Context, sink IInputSink) (IInputSurfaceConnection, error)
}

func NewInputSurfaceStub

func NewInputSurfaceStub(
	impl IInputSurfaceServer,
) IInputSurface

NewInputSurfaceStub creates a server-side IInputSurface wrapping the given server implementation. The returned value satisfies IInputSurface and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IInputSurfaceConnection

type IInputSurfaceConnection interface {
	AsBinder() binder.IBinder
	Disconnect(ctx context.Context) error
	SignalEndOfStream(ctx context.Context) error
}

func NewInputSurfaceConnectionStub

func NewInputSurfaceConnectionStub(
	impl IInputSurfaceConnectionServer,
) IInputSurfaceConnection

NewInputSurfaceConnectionStub creates a server-side IInputSurfaceConnection wrapping the given server implementation. The returned value satisfies IInputSurfaceConnection and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IInputSurfaceConnectionServer

type IInputSurfaceConnectionServer interface {
	Disconnect(ctx context.Context) error
	SignalEndOfStream(ctx context.Context) error
}

IInputSurfaceConnectionServer is the server-side interface that user implementations provide to NewInputSurfaceConnectionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IInputSurfaceServer

type IInputSurfaceServer interface {
	GetSurface(ctx context.Context) (view.Surface, error)
	GetConfigurable(ctx context.Context) (IConfigurable, error)
	Connect(ctx context.Context, sink IInputSink) (IInputSurfaceConnection, error)
}

IInputSurfaceServer is the server-side interface that user implementations provide to NewInputSurfaceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IPooledGraphicBufferAllocator

type IPooledGraphicBufferAllocator interface {
	AsBinder() binder.IBinder
	Allocate(ctx context.Context, desc IPooledGraphicBufferAllocatorDescription) (IPooledGraphicBufferAllocatorAllocation, error)
	Deallocate(ctx context.Context, id int32) (bool, error)
}

func NewPooledGraphicBufferAllocatorStub

func NewPooledGraphicBufferAllocatorStub(
	impl IPooledGraphicBufferAllocatorServer,
) IPooledGraphicBufferAllocator

NewPooledGraphicBufferAllocatorStub creates a server-side IPooledGraphicBufferAllocator wrapping the given server implementation. The returned value satisfies IPooledGraphicBufferAllocator and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IPooledGraphicBufferAllocatorAllocation

type IPooledGraphicBufferAllocatorAllocation struct {
	BufferId int32
	Fence    int32
}

func (*IPooledGraphicBufferAllocatorAllocation) MarshalParcel

func (*IPooledGraphicBufferAllocatorAllocation) UnmarshalParcel

func (s *IPooledGraphicBufferAllocatorAllocation) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IPooledGraphicBufferAllocatorDescription

type IPooledGraphicBufferAllocatorDescription struct {
	WidthPixels  int32
	HeightPixels int32
	Format       int32
	Usage        int64
}

func (*IPooledGraphicBufferAllocatorDescription) MarshalParcel

func (*IPooledGraphicBufferAllocatorDescription) UnmarshalParcel

func (s *IPooledGraphicBufferAllocatorDescription) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IPooledGraphicBufferAllocatorServer

type IPooledGraphicBufferAllocatorServer interface {
	Allocate(ctx context.Context, desc IPooledGraphicBufferAllocatorDescription) (IPooledGraphicBufferAllocatorAllocation, error)
	Deallocate(ctx context.Context, id int32) (bool, error)
}

IPooledGraphicBufferAllocatorServer is the server-side interface that user implementations provide to NewPooledGraphicBufferAllocatorStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type InfoBuffer

type InfoBuffer struct {
	Index  int32
	Buffer Buffer
}

func (*InfoBuffer) MarshalParcel

func (s *InfoBuffer) MarshalParcel(
	p *parcel.Parcel,
) error

func (*InfoBuffer) UnmarshalParcel

func (s *InfoBuffer) UnmarshalParcel(
	p *parcel.Parcel,
) error

type InputSinkProxy

type InputSinkProxy struct {
	Remote binder.IBinder
}

func NewInputSinkProxy

func NewInputSinkProxy(
	remote binder.IBinder,
) *InputSinkProxy

func (*InputSinkProxy) AsBinder

func (p *InputSinkProxy) AsBinder() binder.IBinder

func (*InputSinkProxy) Queue

func (p *InputSinkProxy) Queue(
	ctx context.Context,
	workBundle WorkBundle,
) error

type InputSinkStub

type InputSinkStub struct {
	Impl      IInputSink
	Transport binder.VersionAwareTransport
}

InputSinkStub dispatches incoming binder transactions to a typed IInputSink implementation.

func (*InputSinkStub) Descriptor

func (s *InputSinkStub) Descriptor() string

func (*InputSinkStub) OnTransaction

func (s *InputSinkStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type InputSurfaceConnectionProxy

type InputSurfaceConnectionProxy struct {
	Remote binder.IBinder
}

func NewInputSurfaceConnectionProxy

func NewInputSurfaceConnectionProxy(
	remote binder.IBinder,
) *InputSurfaceConnectionProxy

func (*InputSurfaceConnectionProxy) AsBinder

func (*InputSurfaceConnectionProxy) Disconnect

func (p *InputSurfaceConnectionProxy) Disconnect(
	ctx context.Context,
) error

func (*InputSurfaceConnectionProxy) SignalEndOfStream

func (p *InputSurfaceConnectionProxy) SignalEndOfStream(
	ctx context.Context,
) error

type InputSurfaceConnectionStub

type InputSurfaceConnectionStub struct {
	Impl      IInputSurfaceConnection
	Transport binder.VersionAwareTransport
}

InputSurfaceConnectionStub dispatches incoming binder transactions to a typed IInputSurfaceConnection implementation.

func (*InputSurfaceConnectionStub) Descriptor

func (s *InputSurfaceConnectionStub) Descriptor() string

func (*InputSurfaceConnectionStub) OnTransaction

func (s *InputSurfaceConnectionStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type InputSurfaceProxy

type InputSurfaceProxy struct {
	Remote binder.IBinder
}

func NewInputSurfaceProxy

func NewInputSurfaceProxy(
	remote binder.IBinder,
) *InputSurfaceProxy

func (*InputSurfaceProxy) AsBinder

func (p *InputSurfaceProxy) AsBinder() binder.IBinder

func (*InputSurfaceProxy) Connect

func (*InputSurfaceProxy) GetConfigurable

func (p *InputSurfaceProxy) GetConfigurable(
	ctx context.Context,
) (IConfigurable, error)

func (*InputSurfaceProxy) GetSurface

func (p *InputSurfaceProxy) GetSurface(
	ctx context.Context,
) (view.Surface, error)

type InputSurfaceStub

type InputSurfaceStub struct {
	Impl      IInputSurface
	Transport binder.VersionAwareTransport
}

InputSurfaceStub dispatches incoming binder transactions to a typed IInputSurface implementation.

func (*InputSurfaceStub) Descriptor

func (s *InputSurfaceStub) Descriptor() string

func (*InputSurfaceStub) OnTransaction

func (s *InputSurfaceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ParamDescriptor

type ParamDescriptor struct {
	Index        int32
	Attrib       int32
	Name         string
	Dependencies []int32
}

func (*ParamDescriptor) MarshalParcel

func (s *ParamDescriptor) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ParamDescriptor) UnmarshalParcel

func (s *ParamDescriptor) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ParamField

type ParamField struct {
	Index   int32
	FieldId FieldId
}

func (*ParamField) MarshalParcel

func (s *ParamField) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ParamField) UnmarshalParcel

func (s *ParamField) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ParamFieldValues

type ParamFieldValues struct {
	ParamOrField ParamField
	Values       []FieldSupportedValues
}

func (*ParamFieldValues) MarshalParcel

func (s *ParamFieldValues) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ParamFieldValues) UnmarshalParcel

func (s *ParamFieldValues) UnmarshalParcel(
	p *parcel.Parcel,
) error

type Params

type Params struct {
	Params []byte
}

func (*Params) MarshalParcel

func (s *Params) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Params) UnmarshalParcel

func (s *Params) UnmarshalParcel(
	p *parcel.Parcel,
) error

type PooledGraphicBufferAllocatorProxy

type PooledGraphicBufferAllocatorProxy struct {
	Remote binder.IBinder
}

func NewPooledGraphicBufferAllocatorProxy

func NewPooledGraphicBufferAllocatorProxy(
	remote binder.IBinder,
) *PooledGraphicBufferAllocatorProxy

func (*PooledGraphicBufferAllocatorProxy) AsBinder

func (*PooledGraphicBufferAllocatorProxy) Deallocate

func (p *PooledGraphicBufferAllocatorProxy) Deallocate(
	ctx context.Context,
	id int32,
) (bool, error)

type PooledGraphicBufferAllocatorStub

type PooledGraphicBufferAllocatorStub struct {
	Impl      IPooledGraphicBufferAllocator
	Transport binder.VersionAwareTransport
}

PooledGraphicBufferAllocatorStub dispatches incoming binder transactions to a typed IPooledGraphicBufferAllocator implementation.

func (*PooledGraphicBufferAllocatorStub) Descriptor

func (s *PooledGraphicBufferAllocatorStub) Descriptor() string

func (*PooledGraphicBufferAllocatorStub) OnTransaction

type SettingResult

type SettingResult struct {
	Failure   SettingResultFailure
	Field     ParamFieldValues
	Conflicts []ParamFieldValues
}

func (*SettingResult) MarshalParcel

func (s *SettingResult) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SettingResult) UnmarshalParcel

func (s *SettingResult) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SettingResultFailure

type SettingResultFailure int32
const (
	SettingResultFailureBadType      SettingResultFailure = 0
	SettingResultFailureBadPort      SettingResultFailure = 1
	SettingResultFailureBadIndex     SettingResultFailure = 2
	SettingResultFailureReadOnly     SettingResultFailure = 3
	SettingResultFailureMISMATCH     SettingResultFailure = 4
	SettingResultFailureBadValue     SettingResultFailure = 5
	SettingResultFailureCONFLICT     SettingResultFailure = 6
	SettingResultFailureUNSUPPORTED  SettingResultFailure = 7
	SettingResultFailureInfoBadValue SettingResultFailure = 8
	SettingResultFailureInfoConflict SettingResultFailure = 9
)

type Status

type Status struct {
	Status int32
}

func (*Status) MarshalParcel

func (s *Status) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Status) UnmarshalParcel

func (s *Status) UnmarshalParcel(
	p *parcel.Parcel,
) error

type StructDescriptor

type StructDescriptor struct {
	Type   int32
	Fields []FieldDescriptor
}

func (*StructDescriptor) MarshalParcel

func (s *StructDescriptor) MarshalParcel(
	p *parcel.Parcel,
) error

func (*StructDescriptor) UnmarshalParcel

func (s *StructDescriptor) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ValueRange

type ValueRange struct {
	Min   int64
	Max   int64
	Step  int64
	Num   int64
	Denom int64
}

func (*ValueRange) MarshalParcel

func (s *ValueRange) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ValueRange) UnmarshalParcel

func (s *ValueRange) UnmarshalParcel(
	p *parcel.Parcel,
) error

type Work

type Work struct {
	ChainInfo         []byte
	Input             FrameData
	Worklets          []Worklet
	WorkletsProcessed int32
	Result            Status
}

func (*Work) MarshalParcel

func (s *Work) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Work) UnmarshalParcel

func (s *Work) UnmarshalParcel(
	p *parcel.Parcel,
) error

type WorkBundle

type WorkBundle struct {
	Works      []Work
	BaseBlocks []BaseBlock
}

func (*WorkBundle) MarshalParcel

func (s *WorkBundle) MarshalParcel(
	p *parcel.Parcel,
) error

func (*WorkBundle) UnmarshalParcel

func (s *WorkBundle) UnmarshalParcel(
	p *parcel.Parcel,
) error

type WorkOrdinal

type WorkOrdinal struct {
	TimestampUs   int64
	FrameIndex    int64
	CustomOrdinal int64
}

func (*WorkOrdinal) MarshalParcel

func (s *WorkOrdinal) MarshalParcel(
	p *parcel.Parcel,
) error

func (*WorkOrdinal) UnmarshalParcel

func (s *WorkOrdinal) UnmarshalParcel(
	p *parcel.Parcel,
) error

type Worklet

type Worklet struct {
	ComponentId int32
	Tunings     []byte
	Failures    []SettingResult
	Output      FrameData
}

func (*Worklet) MarshalParcel

func (s *Worklet) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Worklet) UnmarshalParcel

func (s *Worklet) UnmarshalParcel(
	p *parcel.Parcel,
) error

Jump to