messaging

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	CdmaSmsAddressDigitModeFourBit                 int32 = 0
	CdmaSmsAddressDigitModeEightBit                int32 = 1
	CdmaSmsAddressNumberPlanUnknown                int32 = 0
	CdmaSmsAddressNumberPlanTelephony              int32 = 1
	CdmaSmsAddressNumberPlanReserved2              int32 = 2
	CdmaSmsAddressNumberPlanData                   int32 = 3
	CdmaSmsAddressNumberPlanTelex                  int32 = 4
	CdmaSmsAddressNumberPlanReserved5              int32 = 5
	CdmaSmsAddressNumberPlanReserved6              int32 = 6
	CdmaSmsAddressNumberPlanReserved7              int32 = 7
	CdmaSmsAddressNumberPlanReserved8              int32 = 8
	CdmaSmsAddressNumberPlanPrivate                int32 = 9
	CdmaSmsAddressNumberPlanReserved10             int32 = 10
	CdmaSmsAddressNumberPlanReserved11             int32 = 11
	CdmaSmsAddressNumberPlanReserved12             int32 = 12
	CdmaSmsAddressNumberPlanReserved13             int32 = 13
	CdmaSmsAddressNumberPlanReserved14             int32 = 14
	CdmaSmsAddressNumberPlanReserved15             int32 = 15
	CdmaSmsAddressNumberTypeUnknown                int32 = 0
	CdmaSmsAddressNumberTypeInternationalOrDataIp  int32 = 1
	CdmaSmsAddressNumberTypeNationalOrInternetMail int32 = 2
	CdmaSmsAddressNumberTypeNetwork                int32 = 3
	CdmaSmsAddressNumberTypeSubscriber             int32 = 4
	CdmaSmsAddressNumberTypeAlphanumeric           int32 = 5
	CdmaSmsAddressNumberTypeAbbreviated            int32 = 6
	CdmaSmsAddressNumberTypeReserved7              int32 = 7
)
const (
	CdmaSmsSubaddressSubaddressTypeNsap          int32 = 0
	CdmaSmsSubaddressSubaddressTypeUserSpecified int32 = 1
)
const (
	CdmaSmsWriteArgsStatusRecUnread int32 = 0
	CdmaSmsWriteArgsStatusRecRead   int32 = 1
	CdmaSmsWriteArgsStatusStoUnsent int32 = 2
	CdmaSmsWriteArgsStatusStoSent   int32 = 3
)
const (
	TransactionIRadioMessagingAcknowledgeIncomingGsmSmsWithPdu = binder.FirstCallTransaction + 0
	TransactionIRadioMessagingAcknowledgeLastIncomingCdmaSms   = binder.FirstCallTransaction + 1
	TransactionIRadioMessagingAcknowledgeLastIncomingGsmSms    = binder.FirstCallTransaction + 2
	TransactionIRadioMessagingDeleteSmsOnRuim                  = binder.FirstCallTransaction + 3
	TransactionIRadioMessagingDeleteSmsOnSim                   = binder.FirstCallTransaction + 4
	TransactionIRadioMessagingGetCdmaBroadcastConfig           = binder.FirstCallTransaction + 5
	TransactionIRadioMessagingGetGsmBroadcastConfig            = binder.FirstCallTransaction + 6
	TransactionIRadioMessagingGetSmscAddress                   = binder.FirstCallTransaction + 7
	TransactionIRadioMessagingReportSmsMemoryStatus            = binder.FirstCallTransaction + 8
	TransactionIRadioMessagingResponseAcknowledgement          = binder.FirstCallTransaction + 9
	TransactionIRadioMessagingSendCdmaSms                      = binder.FirstCallTransaction + 10
	TransactionIRadioMessagingSendCdmaSmsExpectMore            = binder.FirstCallTransaction + 11
	TransactionIRadioMessagingSendImsSms                       = binder.FirstCallTransaction + 12
	TransactionIRadioMessagingSendSms                          = binder.FirstCallTransaction + 13
	TransactionIRadioMessagingSendSmsExpectMore                = binder.FirstCallTransaction + 14
	TransactionIRadioMessagingSetCdmaBroadcastActivation       = binder.FirstCallTransaction + 15
	TransactionIRadioMessagingSetCdmaBroadcastConfig           = binder.FirstCallTransaction + 16
	TransactionIRadioMessagingSetGsmBroadcastActivation        = binder.FirstCallTransaction + 17
	TransactionIRadioMessagingSetGsmBroadcastConfig            = binder.FirstCallTransaction + 18
	TransactionIRadioMessagingSetResponseFunctions             = binder.FirstCallTransaction + 19
	TransactionIRadioMessagingSetSmscAddress                   = binder.FirstCallTransaction + 20
	TransactionIRadioMessagingWriteSmsToRuim                   = binder.FirstCallTransaction + 21
	TransactionIRadioMessagingWriteSmsToSim                    = binder.FirstCallTransaction + 22
)
const (
	MethodIRadioMessagingAcknowledgeIncomingGsmSmsWithPdu = "acknowledgeIncomingGsmSmsWithPdu"
	MethodIRadioMessagingAcknowledgeLastIncomingCdmaSms   = "acknowledgeLastIncomingCdmaSms"
	MethodIRadioMessagingAcknowledgeLastIncomingGsmSms    = "acknowledgeLastIncomingGsmSms"
	MethodIRadioMessagingDeleteSmsOnRuim                  = "deleteSmsOnRuim"
	MethodIRadioMessagingDeleteSmsOnSim                   = "deleteSmsOnSim"
	MethodIRadioMessagingGetCdmaBroadcastConfig           = "getCdmaBroadcastConfig"
	MethodIRadioMessagingGetGsmBroadcastConfig            = "getGsmBroadcastConfig"
	MethodIRadioMessagingGetSmscAddress                   = "getSmscAddress"
	MethodIRadioMessagingReportSmsMemoryStatus            = "reportSmsMemoryStatus"
	MethodIRadioMessagingResponseAcknowledgement          = "responseAcknowledgement"
	MethodIRadioMessagingSendCdmaSms                      = "sendCdmaSms"
	MethodIRadioMessagingSendCdmaSmsExpectMore            = "sendCdmaSmsExpectMore"
	MethodIRadioMessagingSendImsSms                       = "sendImsSms"
	MethodIRadioMessagingSendSms                          = "sendSms"
	MethodIRadioMessagingSendSmsExpectMore                = "sendSmsExpectMore"
	MethodIRadioMessagingSetCdmaBroadcastActivation       = "setCdmaBroadcastActivation"
	MethodIRadioMessagingSetCdmaBroadcastConfig           = "setCdmaBroadcastConfig"
	MethodIRadioMessagingSetGsmBroadcastActivation        = "setGsmBroadcastActivation"
	MethodIRadioMessagingSetGsmBroadcastConfig            = "setGsmBroadcastConfig"
	MethodIRadioMessagingSetResponseFunctions             = "setResponseFunctions"
	MethodIRadioMessagingSetSmscAddress                   = "setSmscAddress"
	MethodIRadioMessagingWriteSmsToRuim                   = "writeSmsToRuim"
	MethodIRadioMessagingWriteSmsToSim                    = "writeSmsToSim"
)
const (
	TransactionIRadioMessagingIndicationCdmaNewSms             = binder.FirstCallTransaction + 0
	TransactionIRadioMessagingIndicationCdmaRuimSmsStorageFull = binder.FirstCallTransaction + 1
	TransactionIRadioMessagingIndicationNewBroadcastSms        = binder.FirstCallTransaction + 2
	TransactionIRadioMessagingIndicationNewSms                 = binder.FirstCallTransaction + 3
	TransactionIRadioMessagingIndicationNewSmsOnSim            = binder.FirstCallTransaction + 4
	TransactionIRadioMessagingIndicationNewSmsStatusReport     = binder.FirstCallTransaction + 5
	TransactionIRadioMessagingIndicationSimSmsStorageFull      = binder.FirstCallTransaction + 6
)
const (
	MethodIRadioMessagingIndicationCdmaNewSms             = "cdmaNewSms"
	MethodIRadioMessagingIndicationCdmaRuimSmsStorageFull = "cdmaRuimSmsStorageFull"
	MethodIRadioMessagingIndicationNewBroadcastSms        = "newBroadcastSms"
	MethodIRadioMessagingIndicationNewSms                 = "newSms"
	MethodIRadioMessagingIndicationNewSmsOnSim            = "newSmsOnSim"
	MethodIRadioMessagingIndicationNewSmsStatusReport     = "newSmsStatusReport"
	MethodIRadioMessagingIndicationSimSmsStorageFull      = "simSmsStorageFull"
)
const (
	TransactionIRadioMessagingResponseAcknowledgeIncomingGsmSmsWithPduResponse = binder.FirstCallTransaction + 0
	TransactionIRadioMessagingResponseAcknowledgeLastIncomingCdmaSmsResponse   = binder.FirstCallTransaction + 1
	TransactionIRadioMessagingResponseAcknowledgeLastIncomingGsmSmsResponse    = binder.FirstCallTransaction + 2
	TransactionIRadioMessagingResponseAcknowledgeRequest                       = binder.FirstCallTransaction + 3
	TransactionIRadioMessagingResponseDeleteSmsOnRuimResponse                  = binder.FirstCallTransaction + 4
	TransactionIRadioMessagingResponseDeleteSmsOnSimResponse                   = binder.FirstCallTransaction + 5
	TransactionIRadioMessagingResponseGetCdmaBroadcastConfigResponse           = binder.FirstCallTransaction + 6
	TransactionIRadioMessagingResponseGetGsmBroadcastConfigResponse            = binder.FirstCallTransaction + 7
	TransactionIRadioMessagingResponseGetSmscAddressResponse                   = binder.FirstCallTransaction + 8
	TransactionIRadioMessagingResponseReportSmsMemoryStatusResponse            = binder.FirstCallTransaction + 9
	TransactionIRadioMessagingResponseSendCdmaSmsExpectMoreResponse            = binder.FirstCallTransaction + 10
	TransactionIRadioMessagingResponseSendCdmaSmsResponse                      = binder.FirstCallTransaction + 11
	TransactionIRadioMessagingResponseSendImsSmsResponse                       = binder.FirstCallTransaction + 12
	TransactionIRadioMessagingResponseSendSmsExpectMoreResponse                = binder.FirstCallTransaction + 13
	TransactionIRadioMessagingResponseSendSmsResponse                          = binder.FirstCallTransaction + 14
	TransactionIRadioMessagingResponseSetCdmaBroadcastActivationResponse       = binder.FirstCallTransaction + 15
	TransactionIRadioMessagingResponseSetCdmaBroadcastConfigResponse           = binder.FirstCallTransaction + 16
	TransactionIRadioMessagingResponseSetGsmBroadcastActivationResponse        = binder.FirstCallTransaction + 17
	TransactionIRadioMessagingResponseSetGsmBroadcastConfigResponse            = binder.FirstCallTransaction + 18
	TransactionIRadioMessagingResponseSetSmscAddressResponse                   = binder.FirstCallTransaction + 19
	TransactionIRadioMessagingResponseWriteSmsToRuimResponse                   = binder.FirstCallTransaction + 20
	TransactionIRadioMessagingResponseWriteSmsToSimResponse                    = binder.FirstCallTransaction + 21
)
const (
	MethodIRadioMessagingResponseAcknowledgeIncomingGsmSmsWithPduResponse = "acknowledgeIncomingGsmSmsWithPduResponse"
	MethodIRadioMessagingResponseAcknowledgeLastIncomingCdmaSmsResponse   = "acknowledgeLastIncomingCdmaSmsResponse"
	MethodIRadioMessagingResponseAcknowledgeLastIncomingGsmSmsResponse    = "acknowledgeLastIncomingGsmSmsResponse"
	MethodIRadioMessagingResponseAcknowledgeRequest                       = "acknowledgeRequest"
	MethodIRadioMessagingResponseDeleteSmsOnRuimResponse                  = "deleteSmsOnRuimResponse"
	MethodIRadioMessagingResponseDeleteSmsOnSimResponse                   = "deleteSmsOnSimResponse"
	MethodIRadioMessagingResponseGetCdmaBroadcastConfigResponse           = "getCdmaBroadcastConfigResponse"
	MethodIRadioMessagingResponseGetGsmBroadcastConfigResponse            = "getGsmBroadcastConfigResponse"
	MethodIRadioMessagingResponseGetSmscAddressResponse                   = "getSmscAddressResponse"
	MethodIRadioMessagingResponseReportSmsMemoryStatusResponse            = "reportSmsMemoryStatusResponse"
	MethodIRadioMessagingResponseSendCdmaSmsExpectMoreResponse            = "sendCdmaSmsExpectMoreResponse"
	MethodIRadioMessagingResponseSendCdmaSmsResponse                      = "sendCdmaSmsResponse"
	MethodIRadioMessagingResponseSendImsSmsResponse                       = "sendImsSmsResponse"
	MethodIRadioMessagingResponseSendSmsExpectMoreResponse                = "sendSmsExpectMoreResponse"
	MethodIRadioMessagingResponseSendSmsResponse                          = "sendSmsResponse"
	MethodIRadioMessagingResponseSetCdmaBroadcastActivationResponse       = "setCdmaBroadcastActivationResponse"
	MethodIRadioMessagingResponseSetCdmaBroadcastConfigResponse           = "setCdmaBroadcastConfigResponse"
	MethodIRadioMessagingResponseSetGsmBroadcastActivationResponse        = "setGsmBroadcastActivationResponse"
	MethodIRadioMessagingResponseSetGsmBroadcastConfigResponse            = "setGsmBroadcastConfigResponse"
	MethodIRadioMessagingResponseSetSmscAddressResponse                   = "setSmscAddressResponse"
	MethodIRadioMessagingResponseWriteSmsToRuimResponse                   = "writeSmsToRuimResponse"
	MethodIRadioMessagingResponseWriteSmsToSimResponse                    = "writeSmsToSimResponse"
)
const (
	SmsWriteArgsStatusRecUnread int32 = 0
	SmsWriteArgsStatusRecRead   int32 = 1
	SmsWriteArgsStatusStoUnsent int32 = 2
	SmsWriteArgsStatusStoSent   int32 = 3
)
const DescriptorIRadioMessaging = "android.hardware.radio.messaging.IRadioMessaging"
const DescriptorIRadioMessagingIndication = "android.hardware.radio.messaging.IRadioMessagingIndication"
const DescriptorIRadioMessagingResponse = "android.hardware.radio.messaging.IRadioMessagingResponse"

Variables

This section is empty.

Functions

This section is empty.

Types

type CdmaBroadcastSmsConfigInfo

type CdmaBroadcastSmsConfigInfo struct {
	ServiceCategory int32
	Language        int32
	Selected        bool
}

func (*CdmaBroadcastSmsConfigInfo) MarshalParcel

func (s *CdmaBroadcastSmsConfigInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CdmaBroadcastSmsConfigInfo) UnmarshalParcel

func (s *CdmaBroadcastSmsConfigInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CdmaSmsAck

type CdmaSmsAck struct {
	ErrorClass   bool
	SmsCauseCode int32
}

func (*CdmaSmsAck) MarshalParcel

func (s *CdmaSmsAck) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CdmaSmsAck) UnmarshalParcel

func (s *CdmaSmsAck) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CdmaSmsAddress

type CdmaSmsAddress struct {
	DigitMode               int32
	IsNumberModeDataNetwork bool
	NumberType              int32
	NumberPlan              int32
	Digits                  []byte
}

func (*CdmaSmsAddress) MarshalParcel

func (s *CdmaSmsAddress) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CdmaSmsAddress) UnmarshalParcel

func (s *CdmaSmsAddress) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CdmaSmsMessage

type CdmaSmsMessage struct {
	TeleserviceId    int32
	IsServicePresent bool
	ServiceCategory  int32
	Address          CdmaSmsAddress
	SubAddress       CdmaSmsSubaddress
	BearerData       []byte
}

func (*CdmaSmsMessage) MarshalParcel

func (s *CdmaSmsMessage) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CdmaSmsMessage) UnmarshalParcel

func (s *CdmaSmsMessage) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CdmaSmsSubaddress

type CdmaSmsSubaddress struct {
	SubaddressType int32
	Odd            bool
	Digits         []byte
}

func (*CdmaSmsSubaddress) MarshalParcel

func (s *CdmaSmsSubaddress) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CdmaSmsSubaddress) UnmarshalParcel

func (s *CdmaSmsSubaddress) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CdmaSmsWriteArgs

type CdmaSmsWriteArgs struct {
	Status  int32
	Message CdmaSmsMessage
}

func (*CdmaSmsWriteArgs) MarshalParcel

func (s *CdmaSmsWriteArgs) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CdmaSmsWriteArgs) UnmarshalParcel

func (s *CdmaSmsWriteArgs) UnmarshalParcel(
	p *parcel.Parcel,
) error

type GsmBroadcastSmsConfigInfo

type GsmBroadcastSmsConfigInfo struct {
	FromServiceId  int32
	ToServiceId    int32
	FromCodeScheme int32
	ToCodeScheme   int32
	Selected       bool
}

func (*GsmBroadcastSmsConfigInfo) MarshalParcel

func (s *GsmBroadcastSmsConfigInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*GsmBroadcastSmsConfigInfo) UnmarshalParcel

func (s *GsmBroadcastSmsConfigInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type GsmSmsMessage

type GsmSmsMessage struct {
	SmscPdu string
	Pdu     string
}

func (*GsmSmsMessage) MarshalParcel

func (s *GsmSmsMessage) MarshalParcel(
	p *parcel.Parcel,
) error

func (*GsmSmsMessage) UnmarshalParcel

func (s *GsmSmsMessage) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IRadioMessaging

type IRadioMessaging interface {
	AsBinder() binder.IBinder
	AcknowledgeIncomingGsmSmsWithPdu(ctx context.Context, serial int32, success bool, ackPdu string) error
	AcknowledgeLastIncomingCdmaSms(ctx context.Context, serial int32, smsAck CdmaSmsAck) error
	AcknowledgeLastIncomingGsmSms(ctx context.Context, serial int32, success bool, cause SmsAcknowledgeFailCause) error
	DeleteSmsOnRuim(ctx context.Context, serial int32, index int32) error
	DeleteSmsOnSim(ctx context.Context, serial int32, index int32) error
	GetCdmaBroadcastConfig(ctx context.Context, serial int32) error
	GetGsmBroadcastConfig(ctx context.Context, serial int32) error
	GetSmscAddress(ctx context.Context, serial int32) error
	ReportSmsMemoryStatus(ctx context.Context, serial int32, available bool) error
	ResponseAcknowledgement(ctx context.Context) error
	SendCdmaSms(ctx context.Context, serial int32, sms CdmaSmsMessage) error
	SendCdmaSmsExpectMore(ctx context.Context, serial int32, sms CdmaSmsMessage) error
	SendImsSms(ctx context.Context, serial int32, message ImsSmsMessage) error
	SendSms(ctx context.Context, serial int32, message GsmSmsMessage) error
	SendSmsExpectMore(ctx context.Context, serial int32, message GsmSmsMessage) error
	SetCdmaBroadcastActivation(ctx context.Context, serial int32, activate bool) error
	SetCdmaBroadcastConfig(ctx context.Context, serial int32, configInfo []CdmaBroadcastSmsConfigInfo) error
	SetGsmBroadcastActivation(ctx context.Context, serial int32, activate bool) error
	SetGsmBroadcastConfig(ctx context.Context, serial int32, configInfo []GsmBroadcastSmsConfigInfo) error
	SetResponseFunctions(ctx context.Context, radioMessagingResponse IRadioMessagingResponse, radioMessagingIndication IRadioMessagingIndication) error
	SetSmscAddress(ctx context.Context, serial int32, smsc string) error
	WriteSmsToRuim(ctx context.Context, serial int32, cdmaSms CdmaSmsWriteArgs) error
	WriteSmsToSim(ctx context.Context, serial int32, smsWriteArgs SmsWriteArgs) error
}

func NewRadioMessagingStub

func NewRadioMessagingStub(
	impl IRadioMessagingServer,
) IRadioMessaging

NewRadioMessagingStub creates a server-side IRadioMessaging wrapping the given server implementation. The returned value satisfies IRadioMessaging and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IRadioMessagingIndication

type IRadioMessagingIndication interface {
	AsBinder() binder.IBinder
	CdmaNewSms(ctx context.Context, type_ radio.RadioIndicationType, msg CdmaSmsMessage) error
	CdmaRuimSmsStorageFull(ctx context.Context, type_ radio.RadioIndicationType) error
	NewBroadcastSms(ctx context.Context, type_ radio.RadioIndicationType, data []byte) error
	NewSms(ctx context.Context, type_ radio.RadioIndicationType, pdu []byte) error
	NewSmsOnSim(ctx context.Context, type_ radio.RadioIndicationType, recordNumber int32) error
	NewSmsStatusReport(ctx context.Context, type_ radio.RadioIndicationType, pdu []byte) error
	SimSmsStorageFull(ctx context.Context, type_ radio.RadioIndicationType) error
}

func NewRadioMessagingIndicationStub

func NewRadioMessagingIndicationStub(
	impl IRadioMessagingIndicationServer,
) IRadioMessagingIndication

NewRadioMessagingIndicationStub creates a server-side IRadioMessagingIndication wrapping the given server implementation. The returned value satisfies IRadioMessagingIndication and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IRadioMessagingIndicationServer

type IRadioMessagingIndicationServer interface {
	CdmaNewSms(ctx context.Context, type_ radio.RadioIndicationType, msg CdmaSmsMessage) error
	CdmaRuimSmsStorageFull(ctx context.Context, type_ radio.RadioIndicationType) error
	NewBroadcastSms(ctx context.Context, type_ radio.RadioIndicationType, data []byte) error
	NewSms(ctx context.Context, type_ radio.RadioIndicationType, pdu []byte) error
	NewSmsOnSim(ctx context.Context, type_ radio.RadioIndicationType, recordNumber int32) error
	NewSmsStatusReport(ctx context.Context, type_ radio.RadioIndicationType, pdu []byte) error
	SimSmsStorageFull(ctx context.Context, type_ radio.RadioIndicationType) error
}

IRadioMessagingIndicationServer is the server-side interface that user implementations provide to NewRadioMessagingIndicationStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IRadioMessagingResponse

type IRadioMessagingResponse interface {
	AsBinder() binder.IBinder
	AcknowledgeIncomingGsmSmsWithPduResponse(ctx context.Context, info radio.RadioResponseInfo) error
	AcknowledgeLastIncomingCdmaSmsResponse(ctx context.Context, info radio.RadioResponseInfo) error
	AcknowledgeLastIncomingGsmSmsResponse(ctx context.Context, info radio.RadioResponseInfo) error
	AcknowledgeRequest(ctx context.Context, serial int32) error
	DeleteSmsOnRuimResponse(ctx context.Context, info radio.RadioResponseInfo) error
	DeleteSmsOnSimResponse(ctx context.Context, info radio.RadioResponseInfo) error
	GetCdmaBroadcastConfigResponse(ctx context.Context, info radio.RadioResponseInfo, configs []CdmaBroadcastSmsConfigInfo) error
	GetGsmBroadcastConfigResponse(ctx context.Context, info radio.RadioResponseInfo, configs []GsmBroadcastSmsConfigInfo) error
	GetSmscAddressResponse(ctx context.Context, info radio.RadioResponseInfo, smsc string) error
	ReportSmsMemoryStatusResponse(ctx context.Context, info radio.RadioResponseInfo) error
	SendCdmaSmsExpectMoreResponse(ctx context.Context, info radio.RadioResponseInfo, sms SendSmsResult) error
	SendCdmaSmsResponse(ctx context.Context, info radio.RadioResponseInfo, sms SendSmsResult) error
	SendImsSmsResponse(ctx context.Context, info radio.RadioResponseInfo, sms SendSmsResult) error
	SendSmsExpectMoreResponse(ctx context.Context, info radio.RadioResponseInfo, sms SendSmsResult) error
	SendSmsResponse(ctx context.Context, info radio.RadioResponseInfo, sms SendSmsResult) error
	SetCdmaBroadcastActivationResponse(ctx context.Context, info radio.RadioResponseInfo) error
	SetCdmaBroadcastConfigResponse(ctx context.Context, info radio.RadioResponseInfo) error
	SetGsmBroadcastActivationResponse(ctx context.Context, info radio.RadioResponseInfo) error
	SetGsmBroadcastConfigResponse(ctx context.Context, info radio.RadioResponseInfo) error
	SetSmscAddressResponse(ctx context.Context, info radio.RadioResponseInfo) error
	WriteSmsToRuimResponse(ctx context.Context, info radio.RadioResponseInfo, index int32) error
	WriteSmsToSimResponse(ctx context.Context, info radio.RadioResponseInfo, index int32) error
}

func NewRadioMessagingResponseStub

func NewRadioMessagingResponseStub(
	impl IRadioMessagingResponseServer,
) IRadioMessagingResponse

NewRadioMessagingResponseStub creates a server-side IRadioMessagingResponse wrapping the given server implementation. The returned value satisfies IRadioMessagingResponse and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IRadioMessagingResponseServer

type IRadioMessagingResponseServer interface {
	AcknowledgeIncomingGsmSmsWithPduResponse(ctx context.Context, info radio.RadioResponseInfo) error
	AcknowledgeLastIncomingCdmaSmsResponse(ctx context.Context, info radio.RadioResponseInfo) error
	AcknowledgeLastIncomingGsmSmsResponse(ctx context.Context, info radio.RadioResponseInfo) error
	AcknowledgeRequest(ctx context.Context, serial int32) error
	DeleteSmsOnRuimResponse(ctx context.Context, info radio.RadioResponseInfo) error
	DeleteSmsOnSimResponse(ctx context.Context, info radio.RadioResponseInfo) error
	GetCdmaBroadcastConfigResponse(ctx context.Context, info radio.RadioResponseInfo, configs []CdmaBroadcastSmsConfigInfo) error
	GetGsmBroadcastConfigResponse(ctx context.Context, info radio.RadioResponseInfo, configs []GsmBroadcastSmsConfigInfo) error
	GetSmscAddressResponse(ctx context.Context, info radio.RadioResponseInfo, smsc string) error
	ReportSmsMemoryStatusResponse(ctx context.Context, info radio.RadioResponseInfo) error
	SendCdmaSmsExpectMoreResponse(ctx context.Context, info radio.RadioResponseInfo, sms SendSmsResult) error
	SendCdmaSmsResponse(ctx context.Context, info radio.RadioResponseInfo, sms SendSmsResult) error
	SendImsSmsResponse(ctx context.Context, info radio.RadioResponseInfo, sms SendSmsResult) error
	SendSmsExpectMoreResponse(ctx context.Context, info radio.RadioResponseInfo, sms SendSmsResult) error
	SendSmsResponse(ctx context.Context, info radio.RadioResponseInfo, sms SendSmsResult) error
	SetCdmaBroadcastActivationResponse(ctx context.Context, info radio.RadioResponseInfo) error
	SetCdmaBroadcastConfigResponse(ctx context.Context, info radio.RadioResponseInfo) error
	SetGsmBroadcastActivationResponse(ctx context.Context, info radio.RadioResponseInfo) error
	SetGsmBroadcastConfigResponse(ctx context.Context, info radio.RadioResponseInfo) error
	SetSmscAddressResponse(ctx context.Context, info radio.RadioResponseInfo) error
	WriteSmsToRuimResponse(ctx context.Context, info radio.RadioResponseInfo, index int32) error
	WriteSmsToSimResponse(ctx context.Context, info radio.RadioResponseInfo, index int32) error
}

IRadioMessagingResponseServer is the server-side interface that user implementations provide to NewRadioMessagingResponseStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IRadioMessagingServer

type IRadioMessagingServer interface {
	AcknowledgeIncomingGsmSmsWithPdu(ctx context.Context, serial int32, success bool, ackPdu string) error
	AcknowledgeLastIncomingCdmaSms(ctx context.Context, serial int32, smsAck CdmaSmsAck) error
	AcknowledgeLastIncomingGsmSms(ctx context.Context, serial int32, success bool, cause SmsAcknowledgeFailCause) error
	DeleteSmsOnRuim(ctx context.Context, serial int32, index int32) error
	DeleteSmsOnSim(ctx context.Context, serial int32, index int32) error
	GetCdmaBroadcastConfig(ctx context.Context, serial int32) error
	GetGsmBroadcastConfig(ctx context.Context, serial int32) error
	GetSmscAddress(ctx context.Context, serial int32) error
	ReportSmsMemoryStatus(ctx context.Context, serial int32, available bool) error
	ResponseAcknowledgement(ctx context.Context) error
	SendCdmaSms(ctx context.Context, serial int32, sms CdmaSmsMessage) error
	SendCdmaSmsExpectMore(ctx context.Context, serial int32, sms CdmaSmsMessage) error
	SendImsSms(ctx context.Context, serial int32, message ImsSmsMessage) error
	SendSms(ctx context.Context, serial int32, message GsmSmsMessage) error
	SendSmsExpectMore(ctx context.Context, serial int32, message GsmSmsMessage) error
	SetCdmaBroadcastActivation(ctx context.Context, serial int32, activate bool) error
	SetCdmaBroadcastConfig(ctx context.Context, serial int32, configInfo []CdmaBroadcastSmsConfigInfo) error
	SetGsmBroadcastActivation(ctx context.Context, serial int32, activate bool) error
	SetGsmBroadcastConfig(ctx context.Context, serial int32, configInfo []GsmBroadcastSmsConfigInfo) error
	SetResponseFunctions(ctx context.Context, radioMessagingResponse IRadioMessagingResponse, radioMessagingIndication IRadioMessagingIndication) error
	SetSmscAddress(ctx context.Context, serial int32, smsc string) error
	WriteSmsToRuim(ctx context.Context, serial int32, cdmaSms CdmaSmsWriteArgs) error
	WriteSmsToSim(ctx context.Context, serial int32, smsWriteArgs SmsWriteArgs) error
}

IRadioMessagingServer is the server-side interface that user implementations provide to NewRadioMessagingStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ImsSmsMessage

type ImsSmsMessage struct {
	Tech        radio.RadioTechnologyFamily
	Retry       bool
	MessageRef  int32
	CdmaMessage []CdmaSmsMessage
	GsmMessage  []GsmSmsMessage
}

func (*ImsSmsMessage) MarshalParcel

func (s *ImsSmsMessage) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ImsSmsMessage) UnmarshalParcel

func (s *ImsSmsMessage) UnmarshalParcel(
	p *parcel.Parcel,
) error

type RadioMessagingIndicationProxy

type RadioMessagingIndicationProxy struct {
	Remote binder.IBinder
}

func NewRadioMessagingIndicationProxy

func NewRadioMessagingIndicationProxy(
	remote binder.IBinder,
) *RadioMessagingIndicationProxy

func (*RadioMessagingIndicationProxy) AsBinder

func (*RadioMessagingIndicationProxy) CdmaNewSms

func (*RadioMessagingIndicationProxy) CdmaRuimSmsStorageFull

func (p *RadioMessagingIndicationProxy) CdmaRuimSmsStorageFull(
	ctx context.Context,
	type_ radio.RadioIndicationType,
) error

func (*RadioMessagingIndicationProxy) NewBroadcastSms

func (p *RadioMessagingIndicationProxy) NewBroadcastSms(
	ctx context.Context,
	type_ radio.RadioIndicationType,
	data []byte,
) error

func (*RadioMessagingIndicationProxy) NewSms

func (*RadioMessagingIndicationProxy) NewSmsOnSim

func (p *RadioMessagingIndicationProxy) NewSmsOnSim(
	ctx context.Context,
	type_ radio.RadioIndicationType,
	recordNumber int32,
) error

func (*RadioMessagingIndicationProxy) NewSmsStatusReport

func (p *RadioMessagingIndicationProxy) NewSmsStatusReport(
	ctx context.Context,
	type_ radio.RadioIndicationType,
	pdu []byte,
) error

func (*RadioMessagingIndicationProxy) SimSmsStorageFull

func (p *RadioMessagingIndicationProxy) SimSmsStorageFull(
	ctx context.Context,
	type_ radio.RadioIndicationType,
) error

type RadioMessagingIndicationStub

type RadioMessagingIndicationStub struct {
	Impl      IRadioMessagingIndication
	Transport binder.VersionAwareTransport
}

RadioMessagingIndicationStub dispatches incoming binder transactions to a typed IRadioMessagingIndication implementation.

func (*RadioMessagingIndicationStub) Descriptor

func (s *RadioMessagingIndicationStub) Descriptor() string

func (*RadioMessagingIndicationStub) OnTransaction

type RadioMessagingProxy

type RadioMessagingProxy struct {
	Remote binder.IBinder
}

func NewRadioMessagingProxy

func NewRadioMessagingProxy(
	remote binder.IBinder,
) *RadioMessagingProxy

func (*RadioMessagingProxy) AcknowledgeIncomingGsmSmsWithPdu

func (p *RadioMessagingProxy) AcknowledgeIncomingGsmSmsWithPdu(
	ctx context.Context,
	serial int32,
	success bool,
	ackPdu string,
) error

func (*RadioMessagingProxy) AcknowledgeLastIncomingCdmaSms

func (p *RadioMessagingProxy) AcknowledgeLastIncomingCdmaSms(
	ctx context.Context,
	serial int32,
	smsAck CdmaSmsAck,
) error

func (*RadioMessagingProxy) AcknowledgeLastIncomingGsmSms

func (p *RadioMessagingProxy) AcknowledgeLastIncomingGsmSms(
	ctx context.Context,
	serial int32,
	success bool,
	cause SmsAcknowledgeFailCause,
) error

func (*RadioMessagingProxy) AsBinder

func (p *RadioMessagingProxy) AsBinder() binder.IBinder

func (*RadioMessagingProxy) DeleteSmsOnRuim

func (p *RadioMessagingProxy) DeleteSmsOnRuim(
	ctx context.Context,
	serial int32,
	index int32,
) error

func (*RadioMessagingProxy) DeleteSmsOnSim

func (p *RadioMessagingProxy) DeleteSmsOnSim(
	ctx context.Context,
	serial int32,
	index int32,
) error

func (*RadioMessagingProxy) GetCdmaBroadcastConfig

func (p *RadioMessagingProxy) GetCdmaBroadcastConfig(
	ctx context.Context,
	serial int32,
) error

func (*RadioMessagingProxy) GetGsmBroadcastConfig

func (p *RadioMessagingProxy) GetGsmBroadcastConfig(
	ctx context.Context,
	serial int32,
) error

func (*RadioMessagingProxy) GetSmscAddress

func (p *RadioMessagingProxy) GetSmscAddress(
	ctx context.Context,
	serial int32,
) error

func (*RadioMessagingProxy) ReportSmsMemoryStatus

func (p *RadioMessagingProxy) ReportSmsMemoryStatus(
	ctx context.Context,
	serial int32,
	available bool,
) error

func (*RadioMessagingProxy) ResponseAcknowledgement

func (p *RadioMessagingProxy) ResponseAcknowledgement(
	ctx context.Context,
) error

func (*RadioMessagingProxy) SendCdmaSms

func (p *RadioMessagingProxy) SendCdmaSms(
	ctx context.Context,
	serial int32,
	sms CdmaSmsMessage,
) error

func (*RadioMessagingProxy) SendCdmaSmsExpectMore

func (p *RadioMessagingProxy) SendCdmaSmsExpectMore(
	ctx context.Context,
	serial int32,
	sms CdmaSmsMessage,
) error

func (*RadioMessagingProxy) SendImsSms

func (p *RadioMessagingProxy) SendImsSms(
	ctx context.Context,
	serial int32,
	message ImsSmsMessage,
) error

func (*RadioMessagingProxy) SendSms

func (p *RadioMessagingProxy) SendSms(
	ctx context.Context,
	serial int32,
	message GsmSmsMessage,
) error

func (*RadioMessagingProxy) SendSmsExpectMore

func (p *RadioMessagingProxy) SendSmsExpectMore(
	ctx context.Context,
	serial int32,
	message GsmSmsMessage,
) error

func (*RadioMessagingProxy) SetCdmaBroadcastActivation

func (p *RadioMessagingProxy) SetCdmaBroadcastActivation(
	ctx context.Context,
	serial int32,
	activate bool,
) error

func (*RadioMessagingProxy) SetCdmaBroadcastConfig

func (p *RadioMessagingProxy) SetCdmaBroadcastConfig(
	ctx context.Context,
	serial int32,
	configInfo []CdmaBroadcastSmsConfigInfo,
) error

func (*RadioMessagingProxy) SetGsmBroadcastActivation

func (p *RadioMessagingProxy) SetGsmBroadcastActivation(
	ctx context.Context,
	serial int32,
	activate bool,
) error

func (*RadioMessagingProxy) SetGsmBroadcastConfig

func (p *RadioMessagingProxy) SetGsmBroadcastConfig(
	ctx context.Context,
	serial int32,
	configInfo []GsmBroadcastSmsConfigInfo,
) error

func (*RadioMessagingProxy) SetResponseFunctions

func (p *RadioMessagingProxy) SetResponseFunctions(
	ctx context.Context,
	radioMessagingResponse IRadioMessagingResponse,
	radioMessagingIndication IRadioMessagingIndication,
) error

func (*RadioMessagingProxy) SetSmscAddress

func (p *RadioMessagingProxy) SetSmscAddress(
	ctx context.Context,
	serial int32,
	smsc string,
) error

func (*RadioMessagingProxy) WriteSmsToRuim

func (p *RadioMessagingProxy) WriteSmsToRuim(
	ctx context.Context,
	serial int32,
	cdmaSms CdmaSmsWriteArgs,
) error

func (*RadioMessagingProxy) WriteSmsToSim

func (p *RadioMessagingProxy) WriteSmsToSim(
	ctx context.Context,
	serial int32,
	smsWriteArgs SmsWriteArgs,
) error

type RadioMessagingResponseProxy

type RadioMessagingResponseProxy struct {
	Remote binder.IBinder
}

func NewRadioMessagingResponseProxy

func NewRadioMessagingResponseProxy(
	remote binder.IBinder,
) *RadioMessagingResponseProxy

func (*RadioMessagingResponseProxy) AcknowledgeIncomingGsmSmsWithPduResponse

func (p *RadioMessagingResponseProxy) AcknowledgeIncomingGsmSmsWithPduResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
) error

func (*RadioMessagingResponseProxy) AcknowledgeLastIncomingCdmaSmsResponse

func (p *RadioMessagingResponseProxy) AcknowledgeLastIncomingCdmaSmsResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
) error

func (*RadioMessagingResponseProxy) AcknowledgeLastIncomingGsmSmsResponse

func (p *RadioMessagingResponseProxy) AcknowledgeLastIncomingGsmSmsResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
) error

func (*RadioMessagingResponseProxy) AcknowledgeRequest

func (p *RadioMessagingResponseProxy) AcknowledgeRequest(
	ctx context.Context,
	serial int32,
) error

func (*RadioMessagingResponseProxy) AsBinder

func (*RadioMessagingResponseProxy) DeleteSmsOnRuimResponse

func (p *RadioMessagingResponseProxy) DeleteSmsOnRuimResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
) error

func (*RadioMessagingResponseProxy) DeleteSmsOnSimResponse

func (p *RadioMessagingResponseProxy) DeleteSmsOnSimResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
) error

func (*RadioMessagingResponseProxy) GetCdmaBroadcastConfigResponse

func (p *RadioMessagingResponseProxy) GetCdmaBroadcastConfigResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
	configs []CdmaBroadcastSmsConfigInfo,
) error

func (*RadioMessagingResponseProxy) GetGsmBroadcastConfigResponse

func (p *RadioMessagingResponseProxy) GetGsmBroadcastConfigResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
	configs []GsmBroadcastSmsConfigInfo,
) error

func (*RadioMessagingResponseProxy) GetSmscAddressResponse

func (p *RadioMessagingResponseProxy) GetSmscAddressResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
	smsc string,
) error

func (*RadioMessagingResponseProxy) ReportSmsMemoryStatusResponse

func (p *RadioMessagingResponseProxy) ReportSmsMemoryStatusResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
) error

func (*RadioMessagingResponseProxy) SendCdmaSmsExpectMoreResponse

func (p *RadioMessagingResponseProxy) SendCdmaSmsExpectMoreResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
	sms SendSmsResult,
) error

func (*RadioMessagingResponseProxy) SendCdmaSmsResponse

func (p *RadioMessagingResponseProxy) SendCdmaSmsResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
	sms SendSmsResult,
) error

func (*RadioMessagingResponseProxy) SendImsSmsResponse

func (p *RadioMessagingResponseProxy) SendImsSmsResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
	sms SendSmsResult,
) error

func (*RadioMessagingResponseProxy) SendSmsExpectMoreResponse

func (p *RadioMessagingResponseProxy) SendSmsExpectMoreResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
	sms SendSmsResult,
) error

func (*RadioMessagingResponseProxy) SendSmsResponse

func (*RadioMessagingResponseProxy) SetCdmaBroadcastActivationResponse

func (p *RadioMessagingResponseProxy) SetCdmaBroadcastActivationResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
) error

func (*RadioMessagingResponseProxy) SetCdmaBroadcastConfigResponse

func (p *RadioMessagingResponseProxy) SetCdmaBroadcastConfigResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
) error

func (*RadioMessagingResponseProxy) SetGsmBroadcastActivationResponse

func (p *RadioMessagingResponseProxy) SetGsmBroadcastActivationResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
) error

func (*RadioMessagingResponseProxy) SetGsmBroadcastConfigResponse

func (p *RadioMessagingResponseProxy) SetGsmBroadcastConfigResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
) error

func (*RadioMessagingResponseProxy) SetSmscAddressResponse

func (p *RadioMessagingResponseProxy) SetSmscAddressResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
) error

func (*RadioMessagingResponseProxy) WriteSmsToRuimResponse

func (p *RadioMessagingResponseProxy) WriteSmsToRuimResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
	index int32,
) error

func (*RadioMessagingResponseProxy) WriteSmsToSimResponse

func (p *RadioMessagingResponseProxy) WriteSmsToSimResponse(
	ctx context.Context,
	info radio.RadioResponseInfo,
	index int32,
) error

type RadioMessagingResponseStub

type RadioMessagingResponseStub struct {
	Impl      IRadioMessagingResponse
	Transport binder.VersionAwareTransport
}

RadioMessagingResponseStub dispatches incoming binder transactions to a typed IRadioMessagingResponse implementation.

func (*RadioMessagingResponseStub) Descriptor

func (s *RadioMessagingResponseStub) Descriptor() string

func (*RadioMessagingResponseStub) OnTransaction

func (s *RadioMessagingResponseStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type RadioMessagingStub

type RadioMessagingStub struct {
	Impl      IRadioMessaging
	Transport binder.VersionAwareTransport
}

RadioMessagingStub dispatches incoming binder transactions to a typed IRadioMessaging implementation.

func (*RadioMessagingStub) Descriptor

func (s *RadioMessagingStub) Descriptor() string

func (*RadioMessagingStub) OnTransaction

func (s *RadioMessagingStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type SendSmsResult

type SendSmsResult struct {
	MessageRef int32
	AckPDU     string
	ErrorCode  int32
}

func (*SendSmsResult) MarshalParcel

func (s *SendSmsResult) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SendSmsResult) UnmarshalParcel

func (s *SendSmsResult) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SmsAcknowledgeFailCause

type SmsAcknowledgeFailCause int32
const (
	SmsAcknowledgeFailCauseMemoryCapacityExceeded SmsAcknowledgeFailCause = 211
	SmsAcknowledgeFailCauseUnspecifiedError       SmsAcknowledgeFailCause = 255
)

type SmsWriteArgs

type SmsWriteArgs struct {
	Status int32
	Pdu    string
	Smsc   string
}

func (*SmsWriteArgs) MarshalParcel

func (s *SmsWriteArgs) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SmsWriteArgs) UnmarshalParcel

func (s *SmsWriteArgs) UnmarshalParcel(
	p *parcel.Parcel,
) error

Jump to