soundtrigger3

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	TransactionISoundTriggerHwGetProperties          = binder.FirstCallTransaction + 0
	TransactionISoundTriggerHwRegisterGlobalCallback = binder.FirstCallTransaction + 1
	TransactionISoundTriggerHwLoadSoundModel         = binder.FirstCallTransaction + 2
	TransactionISoundTriggerHwLoadPhraseSoundModel   = binder.FirstCallTransaction + 3
	TransactionISoundTriggerHwUnloadSoundModel       = binder.FirstCallTransaction + 4
	TransactionISoundTriggerHwStartRecognition       = binder.FirstCallTransaction + 5
	TransactionISoundTriggerHwStopRecognition        = binder.FirstCallTransaction + 6
	TransactionISoundTriggerHwForceRecognitionEvent  = binder.FirstCallTransaction + 7
	TransactionISoundTriggerHwQueryParameter         = binder.FirstCallTransaction + 8
	TransactionISoundTriggerHwGetParameter           = binder.FirstCallTransaction + 9
	TransactionISoundTriggerHwSetParameter           = binder.FirstCallTransaction + 10
)
const (
	MethodISoundTriggerHwGetProperties          = "getProperties"
	MethodISoundTriggerHwRegisterGlobalCallback = "registerGlobalCallback"
	MethodISoundTriggerHwLoadSoundModel         = "loadSoundModel"
	MethodISoundTriggerHwLoadPhraseSoundModel   = "loadPhraseSoundModel"
	MethodISoundTriggerHwUnloadSoundModel       = "unloadSoundModel"
	MethodISoundTriggerHwStartRecognition       = "startRecognition"
	MethodISoundTriggerHwStopRecognition        = "stopRecognition"
	MethodISoundTriggerHwForceRecognitionEvent  = "forceRecognitionEvent"
	MethodISoundTriggerHwQueryParameter         = "queryParameter"
	MethodISoundTriggerHwGetParameter           = "getParameter"
	MethodISoundTriggerHwSetParameter           = "setParameter"
)
const (
	TransactionISoundTriggerHwCallbackModelUnloaded             = binder.FirstCallTransaction + 0
	TransactionISoundTriggerHwCallbackPhraseRecognitionCallback = binder.FirstCallTransaction + 1
	TransactionISoundTriggerHwCallbackRecognitionCallback       = binder.FirstCallTransaction + 2
)
const (
	MethodISoundTriggerHwCallbackModelUnloaded             = "modelUnloaded"
	MethodISoundTriggerHwCallbackPhraseRecognitionCallback = "phraseRecognitionCallback"
	MethodISoundTriggerHwCallbackRecognitionCallback       = "recognitionCallback"
)
const DescriptorISoundTriggerHw = "android.hardware.soundtrigger3.ISoundTriggerHw"
const DescriptorISoundTriggerHwCallback = "android.hardware.soundtrigger3.ISoundTriggerHwCallback"
const DescriptorISoundTriggerHwGlobalCallback = "android.hardware.soundtrigger3.ISoundTriggerHwGlobalCallback"
const (
	MethodISoundTriggerHwGlobalCallbackOnResourcesAvailable = "onResourcesAvailable"
)
const (
	TransactionISoundTriggerHwGlobalCallbackOnResourcesAvailable = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type ISoundTriggerHw

type ISoundTriggerHw interface {
	AsBinder() binder.IBinder
	GetProperties(ctx context.Context) (broadcastradio.Properties, error)
	RegisterGlobalCallback(ctx context.Context, callback ISoundTriggerHwGlobalCallback) error
	LoadSoundModel(ctx context.Context, soundModel soundtrigger.SoundModel, callback ISoundTriggerHwCallback) (int32, error)
	LoadPhraseSoundModel(ctx context.Context, soundModel soundtrigger.PhraseSoundModel, callback ISoundTriggerHwCallback) (int32, error)
	UnloadSoundModel(ctx context.Context, modelHandle int32) error
	StartRecognition(ctx context.Context, modelHandle int32, deviceHandle int32, ioHandle int32, config hardwareSoundtrigger.SoundTriggerRecognitionConfig) error
	StopRecognition(ctx context.Context, modelHandle int32) error
	ForceRecognitionEvent(ctx context.Context, modelHandle int32) error
	QueryParameter(ctx context.Context, modelHandle int32, modelParam soundtrigger.ModelParameter) (soundtrigger.ModelParameterRange, error)
	GetParameter(ctx context.Context, modelHandle int32, modelParam soundtrigger.ModelParameter) (int32, error)
	SetParameter(ctx context.Context, modelHandle int32, modelParam soundtrigger.ModelParameter, value int32) error
}

func NewSoundTriggerHwStub

func NewSoundTriggerHwStub(
	impl ISoundTriggerHwServer,
) ISoundTriggerHw

NewSoundTriggerHwStub creates a server-side ISoundTriggerHw wrapping the given server implementation. The returned value satisfies ISoundTriggerHw and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISoundTriggerHwCallback

type ISoundTriggerHwCallback interface {
	AsBinder() binder.IBinder
	ModelUnloaded(ctx context.Context, model int32) error
	PhraseRecognitionCallback(ctx context.Context, model int32, event soundtrigger.PhraseRecognitionEvent) error
	RecognitionCallback(ctx context.Context, model int32, event hardwareSoundtrigger.SoundTriggerRecognitionEvent) error
}

func NewSoundTriggerHwCallbackStub

func NewSoundTriggerHwCallbackStub(
	impl ISoundTriggerHwCallbackServer,
) ISoundTriggerHwCallback

NewSoundTriggerHwCallbackStub creates a server-side ISoundTriggerHwCallback wrapping the given server implementation. The returned value satisfies ISoundTriggerHwCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISoundTriggerHwCallbackServer

type ISoundTriggerHwCallbackServer interface {
	ModelUnloaded(ctx context.Context, model int32) error
	PhraseRecognitionCallback(ctx context.Context, model int32, event soundtrigger.PhraseRecognitionEvent) error
	RecognitionCallback(ctx context.Context, model int32, event hardwareSoundtrigger.SoundTriggerRecognitionEvent) error
}

ISoundTriggerHwCallbackServer is the server-side interface that user implementations provide to NewSoundTriggerHwCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISoundTriggerHwGlobalCallback

type ISoundTriggerHwGlobalCallback interface {
	AsBinder() binder.IBinder
	OnResourcesAvailable(ctx context.Context) error
}

func NewSoundTriggerHwGlobalCallbackStub

func NewSoundTriggerHwGlobalCallbackStub(
	impl ISoundTriggerHwGlobalCallbackServer,
) ISoundTriggerHwGlobalCallback

NewSoundTriggerHwGlobalCallbackStub creates a server-side ISoundTriggerHwGlobalCallback wrapping the given server implementation. The returned value satisfies ISoundTriggerHwGlobalCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISoundTriggerHwGlobalCallbackServer

type ISoundTriggerHwGlobalCallbackServer interface {
	OnResourcesAvailable(ctx context.Context) error
}

ISoundTriggerHwGlobalCallbackServer is the server-side interface that user implementations provide to NewSoundTriggerHwGlobalCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISoundTriggerHwServer

type ISoundTriggerHwServer interface {
	GetProperties(ctx context.Context) (broadcastradio.Properties, error)
	RegisterGlobalCallback(ctx context.Context, callback ISoundTriggerHwGlobalCallback) error
	LoadSoundModel(ctx context.Context, soundModel soundtrigger.SoundModel, callback ISoundTriggerHwCallback) (int32, error)
	LoadPhraseSoundModel(ctx context.Context, soundModel soundtrigger.PhraseSoundModel, callback ISoundTriggerHwCallback) (int32, error)
	UnloadSoundModel(ctx context.Context, modelHandle int32) error
	StartRecognition(ctx context.Context, modelHandle int32, deviceHandle int32, ioHandle int32, config hardwareSoundtrigger.SoundTriggerRecognitionConfig) error
	StopRecognition(ctx context.Context, modelHandle int32) error
	ForceRecognitionEvent(ctx context.Context, modelHandle int32) error
	QueryParameter(ctx context.Context, modelHandle int32, modelParam soundtrigger.ModelParameter) (soundtrigger.ModelParameterRange, error)
	GetParameter(ctx context.Context, modelHandle int32, modelParam soundtrigger.ModelParameter) (int32, error)
	SetParameter(ctx context.Context, modelHandle int32, modelParam soundtrigger.ModelParameter, value int32) error
}

ISoundTriggerHwServer is the server-side interface that user implementations provide to NewSoundTriggerHwStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type SoundTriggerHwCallbackProxy

type SoundTriggerHwCallbackProxy struct {
	Remote binder.IBinder
}

func NewSoundTriggerHwCallbackProxy

func NewSoundTriggerHwCallbackProxy(
	remote binder.IBinder,
) *SoundTriggerHwCallbackProxy

func (*SoundTriggerHwCallbackProxy) AsBinder

func (*SoundTriggerHwCallbackProxy) ModelUnloaded

func (p *SoundTriggerHwCallbackProxy) ModelUnloaded(
	ctx context.Context,
	model int32,
) error

func (*SoundTriggerHwCallbackProxy) PhraseRecognitionCallback

func (p *SoundTriggerHwCallbackProxy) PhraseRecognitionCallback(
	ctx context.Context,
	model int32,
	event soundtrigger.PhraseRecognitionEvent,
) error

func (*SoundTriggerHwCallbackProxy) RecognitionCallback

type SoundTriggerHwCallbackStub

type SoundTriggerHwCallbackStub struct {
	Impl      ISoundTriggerHwCallback
	Transport binder.VersionAwareTransport
}

SoundTriggerHwCallbackStub dispatches incoming binder transactions to a typed ISoundTriggerHwCallback implementation.

func (*SoundTriggerHwCallbackStub) Descriptor

func (s *SoundTriggerHwCallbackStub) Descriptor() string

func (*SoundTriggerHwCallbackStub) OnTransaction

func (s *SoundTriggerHwCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type SoundTriggerHwGlobalCallbackProxy

type SoundTriggerHwGlobalCallbackProxy struct {
	Remote binder.IBinder
}

func NewSoundTriggerHwGlobalCallbackProxy

func NewSoundTriggerHwGlobalCallbackProxy(
	remote binder.IBinder,
) *SoundTriggerHwGlobalCallbackProxy

func (*SoundTriggerHwGlobalCallbackProxy) AsBinder

func (*SoundTriggerHwGlobalCallbackProxy) OnResourcesAvailable

func (p *SoundTriggerHwGlobalCallbackProxy) OnResourcesAvailable(
	ctx context.Context,
) error

type SoundTriggerHwGlobalCallbackStub

type SoundTriggerHwGlobalCallbackStub struct {
	Impl      ISoundTriggerHwGlobalCallback
	Transport binder.VersionAwareTransport
}

SoundTriggerHwGlobalCallbackStub dispatches incoming binder transactions to a typed ISoundTriggerHwGlobalCallback implementation.

func (*SoundTriggerHwGlobalCallbackStub) Descriptor

func (s *SoundTriggerHwGlobalCallbackStub) Descriptor() string

func (*SoundTriggerHwGlobalCallbackStub) OnTransaction

type SoundTriggerHwProxy

type SoundTriggerHwProxy struct {
	Remote binder.IBinder
}

func NewSoundTriggerHwProxy

func NewSoundTriggerHwProxy(
	remote binder.IBinder,
) *SoundTriggerHwProxy

func (*SoundTriggerHwProxy) AsBinder

func (p *SoundTriggerHwProxy) AsBinder() binder.IBinder

func (*SoundTriggerHwProxy) ForceRecognitionEvent

func (p *SoundTriggerHwProxy) ForceRecognitionEvent(
	ctx context.Context,
	modelHandle int32,
) error

func (*SoundTriggerHwProxy) GetParameter

func (p *SoundTriggerHwProxy) GetParameter(
	ctx context.Context,
	modelHandle int32,
	modelParam soundtrigger.ModelParameter,
) (int32, error)

func (*SoundTriggerHwProxy) GetProperties

func (p *SoundTriggerHwProxy) GetProperties(
	ctx context.Context,
) (broadcastradio.Properties, error)

func (*SoundTriggerHwProxy) LoadPhraseSoundModel

func (p *SoundTriggerHwProxy) LoadPhraseSoundModel(
	ctx context.Context,
	soundModel soundtrigger.PhraseSoundModel,
	callback ISoundTriggerHwCallback,
) (int32, error)

func (*SoundTriggerHwProxy) LoadSoundModel

func (p *SoundTriggerHwProxy) LoadSoundModel(
	ctx context.Context,
	soundModel soundtrigger.SoundModel,
	callback ISoundTriggerHwCallback,
) (int32, error)

func (*SoundTriggerHwProxy) QueryParameter

func (p *SoundTriggerHwProxy) QueryParameter(
	ctx context.Context,
	modelHandle int32,
	modelParam soundtrigger.ModelParameter,
) (soundtrigger.ModelParameterRange, error)

func (*SoundTriggerHwProxy) RegisterGlobalCallback

func (p *SoundTriggerHwProxy) RegisterGlobalCallback(
	ctx context.Context,
	callback ISoundTriggerHwGlobalCallback,
) error

func (*SoundTriggerHwProxy) SetParameter

func (p *SoundTriggerHwProxy) SetParameter(
	ctx context.Context,
	modelHandle int32,
	modelParam soundtrigger.ModelParameter,
	value int32,
) error

func (*SoundTriggerHwProxy) StartRecognition

func (p *SoundTriggerHwProxy) StartRecognition(
	ctx context.Context,
	modelHandle int32,
	deviceHandle int32,
	ioHandle int32,
	config hardwareSoundtrigger.SoundTriggerRecognitionConfig,
) error

func (*SoundTriggerHwProxy) StopRecognition

func (p *SoundTriggerHwProxy) StopRecognition(
	ctx context.Context,
	modelHandle int32,
) error

func (*SoundTriggerHwProxy) UnloadSoundModel

func (p *SoundTriggerHwProxy) UnloadSoundModel(
	ctx context.Context,
	modelHandle int32,
) error

type SoundTriggerHwStub

type SoundTriggerHwStub struct {
	Impl      ISoundTriggerHw
	Transport binder.VersionAwareTransport
}

SoundTriggerHwStub dispatches incoming binder transactions to a typed ISoundTriggerHw implementation.

func (*SoundTriggerHwStub) Descriptor

func (s *SoundTriggerHwStub) Descriptor() string

func (*SoundTriggerHwStub) OnTransaction

func (s *SoundTriggerHwStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to