Documentation
¶
Index ¶
- Constants
- type IUwb
- type IUwbChip
- type IUwbChipServer
- type IUwbClientCallback
- type IUwbClientCallbackServer
- type IUwbServer
- type UwbChipProxy
- func (p *UwbChipProxy) AsBinder() binder.IBinder
- func (p *UwbChipProxy) Close(ctx context.Context) error
- func (p *UwbChipProxy) CoreInit(ctx context.Context) error
- func (p *UwbChipProxy) GetName(ctx context.Context) (string, error)
- func (p *UwbChipProxy) GetSupportedAndroidUciVersion(ctx context.Context) (int32, error)
- func (p *UwbChipProxy) Open(ctx context.Context, clientCallback IUwbClientCallback) error
- func (p *UwbChipProxy) SendUciMessage(ctx context.Context, data []byte) (int32, error)
- func (p *UwbChipProxy) SessionInit(ctx context.Context, sessionId int32) error
- type UwbChipStub
- type UwbClientCallbackProxy
- type UwbClientCallbackStub
- type UwbEvent
- type UwbProxy
- type UwbStatus
- type UwbStub
Constants ¶
const ( TransactionIUwbGetChips = binder.FirstCallTransaction + 0 TransactionIUwbGetChip = binder.FirstCallTransaction + 1 )
const ( MethodIUwbGetChips = "getChips" MethodIUwbGetChip = "getChip" )
const ( TransactionIUwbChipGetName = binder.FirstCallTransaction + 0 TransactionIUwbChipOpen = binder.FirstCallTransaction + 1 TransactionIUwbChipClose = binder.FirstCallTransaction + 2 TransactionIUwbChipCoreInit = binder.FirstCallTransaction + 3 TransactionIUwbChipSessionInit = binder.FirstCallTransaction + 4 TransactionIUwbChipGetSupportedAndroidUciVersion = binder.FirstCallTransaction + 5 TransactionIUwbChipSendUciMessage = binder.FirstCallTransaction + 6 )
const ( MethodIUwbChipGetName = "getName" MethodIUwbChipOpen = "open" MethodIUwbChipClose = "close" MethodIUwbChipCoreInit = "coreInit" MethodIUwbChipSessionInit = "sessionInit" MethodIUwbChipGetSupportedAndroidUciVersion = "getSupportedAndroidUciVersion" MethodIUwbChipSendUciMessage = "sendUciMessage" )
const ( TransactionIUwbClientCallbackOnUciMessage = binder.FirstCallTransaction + 0 TransactionIUwbClientCallbackOnHalEvent = binder.FirstCallTransaction + 1 )
const ( MethodIUwbClientCallbackOnUciMessage = "onUciMessage" MethodIUwbClientCallbackOnHalEvent = "onHalEvent" )
const DescriptorIUwb = "android.hardware.uwb.IUwb"
const DescriptorIUwbChip = "android.hardware.uwb.IUwbChip"
const DescriptorIUwbClientCallback = "android.hardware.uwb.IUwbClientCallback"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IUwb ¶
type IUwb interface {
AsBinder() binder.IBinder
GetChips(ctx context.Context) ([]string, error)
GetChip(ctx context.Context, name string) (IUwbChip, error)
}
func NewUwbStub ¶
func NewUwbStub( impl IUwbServer, ) IUwb
NewUwbStub creates a server-side IUwb wrapping the given server implementation. The returned value satisfies IUwb and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IUwbChip ¶
type IUwbChip interface {
AsBinder() binder.IBinder
GetName(ctx context.Context) (string, error)
Open(ctx context.Context, clientCallback IUwbClientCallback) error
Close(ctx context.Context) error
CoreInit(ctx context.Context) error
SessionInit(ctx context.Context, sessionId int32) error
GetSupportedAndroidUciVersion(ctx context.Context) (int32, error)
SendUciMessage(ctx context.Context, data []byte) (int32, error)
}
func NewUwbChipStub ¶
func NewUwbChipStub( impl IUwbChipServer, ) IUwbChip
NewUwbChipStub creates a server-side IUwbChip wrapping the given server implementation. The returned value satisfies IUwbChip and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IUwbChipServer ¶
type IUwbChipServer interface {
GetName(ctx context.Context) (string, error)
Open(ctx context.Context, clientCallback IUwbClientCallback) error
Close(ctx context.Context) error
CoreInit(ctx context.Context) error
SessionInit(ctx context.Context, sessionId int32) error
GetSupportedAndroidUciVersion(ctx context.Context) (int32, error)
SendUciMessage(ctx context.Context, data []byte) (int32, error)
}
IUwbChipServer is the server-side interface that user implementations provide to NewUwbChipStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IUwbClientCallback ¶
type IUwbClientCallback interface {
AsBinder() binder.IBinder
OnUciMessage(ctx context.Context, data []byte) error
OnHalEvent(ctx context.Context, event UwbEvent, status UwbStatus) error
}
func NewUwbClientCallbackStub ¶
func NewUwbClientCallbackStub( impl IUwbClientCallbackServer, ) IUwbClientCallback
NewUwbClientCallbackStub creates a server-side IUwbClientCallback wrapping the given server implementation. The returned value satisfies IUwbClientCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IUwbClientCallbackServer ¶
type IUwbClientCallbackServer interface {
OnUciMessage(ctx context.Context, data []byte) error
OnHalEvent(ctx context.Context, event UwbEvent, status UwbStatus) error
}
IUwbClientCallbackServer is the server-side interface that user implementations provide to NewUwbClientCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IUwbServer ¶
type IUwbServer interface {
GetChips(ctx context.Context) ([]string, error)
GetChip(ctx context.Context, name string) (IUwbChip, error)
}
IUwbServer is the server-side interface that user implementations provide to NewUwbStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type UwbChipProxy ¶
func NewUwbChipProxy ¶
func NewUwbChipProxy( remote binder.IBinder, ) *UwbChipProxy
func (*UwbChipProxy) AsBinder ¶
func (p *UwbChipProxy) AsBinder() binder.IBinder
func (*UwbChipProxy) GetName ¶
func (p *UwbChipProxy) GetName( ctx context.Context, ) (string, error)
func (*UwbChipProxy) GetSupportedAndroidUciVersion ¶
func (p *UwbChipProxy) GetSupportedAndroidUciVersion( ctx context.Context, ) (int32, error)
func (*UwbChipProxy) Open ¶
func (p *UwbChipProxy) Open( ctx context.Context, clientCallback IUwbClientCallback, ) error
func (*UwbChipProxy) SendUciMessage ¶
func (*UwbChipProxy) SessionInit ¶
func (p *UwbChipProxy) SessionInit( ctx context.Context, sessionId int32, ) error
type UwbChipStub ¶
type UwbChipStub struct {
Impl IUwbChip
Transport binder.VersionAwareTransport
}
UwbChipStub dispatches incoming binder transactions to a typed IUwbChip implementation.
func (*UwbChipStub) Descriptor ¶
func (s *UwbChipStub) Descriptor() string
func (*UwbChipStub) OnTransaction ¶
func (s *UwbChipStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type UwbClientCallbackProxy ¶
func NewUwbClientCallbackProxy ¶
func NewUwbClientCallbackProxy( remote binder.IBinder, ) *UwbClientCallbackProxy
func (*UwbClientCallbackProxy) AsBinder ¶
func (p *UwbClientCallbackProxy) AsBinder() binder.IBinder
func (*UwbClientCallbackProxy) OnHalEvent ¶
func (*UwbClientCallbackProxy) OnUciMessage ¶
func (p *UwbClientCallbackProxy) OnUciMessage( ctx context.Context, data []byte, ) error
type UwbClientCallbackStub ¶
type UwbClientCallbackStub struct {
Impl IUwbClientCallback
Transport binder.VersionAwareTransport
}
UwbClientCallbackStub dispatches incoming binder transactions to a typed IUwbClientCallback implementation.
func (*UwbClientCallbackStub) Descriptor ¶
func (s *UwbClientCallbackStub) Descriptor() string
func (*UwbClientCallbackStub) OnTransaction ¶
func (s *UwbClientCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type UwbStub ¶
type UwbStub struct {
Impl IUwb
Transport binder.VersionAwareTransport
}
UwbStub dispatches incoming binder transactions to a typed IUwb implementation.