provider

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIGeocodeCallbackOnError   = binder.FirstCallTransaction + 0
	TransactionIGeocodeCallbackOnResults = binder.FirstCallTransaction + 1
)
const (
	MethodIGeocodeCallbackOnError   = "onError"
	MethodIGeocodeCallbackOnResults = "onResults"
)
const (
	TransactionIGeocodeProviderForwardGeocode = binder.FirstCallTransaction + 0
	TransactionIGeocodeProviderReverseGeocode = binder.FirstCallTransaction + 1
)
const (
	MethodIGeocodeProviderForwardGeocode = "forwardGeocode"
	MethodIGeocodeProviderReverseGeocode = "reverseGeocode"
)
const (
	TransactionILocationProviderSetLocationProviderManager = binder.FirstCallTransaction + 0
	TransactionILocationProviderSetRequest                 = binder.FirstCallTransaction + 1
	TransactionILocationProviderFlush                      = binder.FirstCallTransaction + 2
	TransactionILocationProviderSendExtraCommand           = binder.FirstCallTransaction + 3
)
const (
	MethodILocationProviderSetLocationProviderManager = "setLocationProviderManager"
	MethodILocationProviderSetRequest                 = "setRequest"
	MethodILocationProviderFlush                      = "flush"
	MethodILocationProviderSendExtraCommand           = "sendExtraCommand"
)
const (
	TransactionILocationProviderManagerOnInitialize      = binder.FirstCallTransaction + 0
	TransactionILocationProviderManagerOnSetAllowed      = binder.FirstCallTransaction + 1
	TransactionILocationProviderManagerOnSetProperties   = binder.FirstCallTransaction + 2
	TransactionILocationProviderManagerOnReportLocation  = binder.FirstCallTransaction + 3
	TransactionILocationProviderManagerOnReportLocations = binder.FirstCallTransaction + 4
	TransactionILocationProviderManagerOnFlushComplete   = binder.FirstCallTransaction + 5
)
const (
	MethodILocationProviderManagerOnInitialize      = "onInitialize"
	MethodILocationProviderManagerOnSetAllowed      = "onSetAllowed"
	MethodILocationProviderManagerOnSetProperties   = "onSetProperties"
	MethodILocationProviderManagerOnReportLocation  = "onReportLocation"
	MethodILocationProviderManagerOnReportLocations = "onReportLocations"
	MethodILocationProviderManagerOnFlushComplete   = "onFlushComplete"
)
const DescriptorIGeocodeCallback = "android.location.provider.IGeocodeCallback"
const DescriptorIGeocodeProvider = "android.location.provider.IGeocodeProvider"
const DescriptorILocationProvider = "android.location.provider.ILocationProvider"
const DescriptorILocationProviderManager = "android.location.provider.ILocationProviderManager"
const DescriptorIProviderRequestListener = "android.location.provider.IProviderRequestListener"
const (
	MethodIProviderRequestListenerOnProviderRequestChanged = "onProviderRequestChanged"
)
const (
	TransactionIProviderRequestListenerOnProviderRequestChanged = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type ForwardGeocodeRequest

type ForwardGeocodeRequest struct {
	LocationName          string
	LowerLeftLatitude     float64
	LowerLeftLongitude    float64
	UpperRightLatitude    float64
	UpperRightLongitude   float64
	MaxResults            int32
	CallingUid            int32
	CallingPackage        string
	CallingAttributionTag string
}

func (*ForwardGeocodeRequest) MarshalParcel

func (s *ForwardGeocodeRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ForwardGeocodeRequest) UnmarshalParcel

func (s *ForwardGeocodeRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type GeocodeCallbackProxy

type GeocodeCallbackProxy struct {
	Remote binder.IBinder
}

func NewGeocodeCallbackProxy

func NewGeocodeCallbackProxy(
	remote binder.IBinder,
) *GeocodeCallbackProxy

func (*GeocodeCallbackProxy) AsBinder

func (p *GeocodeCallbackProxy) AsBinder() binder.IBinder

func (*GeocodeCallbackProxy) OnError

func (p *GeocodeCallbackProxy) OnError(
	ctx context.Context,
	error_ string,
) error

func (*GeocodeCallbackProxy) OnResults

func (p *GeocodeCallbackProxy) OnResults(
	ctx context.Context,
	results []types.Address,
) error

type GeocodeCallbackStub

type GeocodeCallbackStub struct {
	Impl      IGeocodeCallback
	Transport binder.VersionAwareTransport
}

GeocodeCallbackStub dispatches incoming binder transactions to a typed IGeocodeCallback implementation.

func (*GeocodeCallbackStub) Descriptor

func (s *GeocodeCallbackStub) Descriptor() string

func (*GeocodeCallbackStub) OnTransaction

func (s *GeocodeCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type GeocodeProviderProxy

type GeocodeProviderProxy struct {
	Remote binder.IBinder
}

func NewGeocodeProviderProxy

func NewGeocodeProviderProxy(
	remote binder.IBinder,
) *GeocodeProviderProxy

func (*GeocodeProviderProxy) AsBinder

func (p *GeocodeProviderProxy) AsBinder() binder.IBinder

func (*GeocodeProviderProxy) ForwardGeocode

func (p *GeocodeProviderProxy) ForwardGeocode(
	ctx context.Context,
	request ForwardGeocodeRequest,
	callback IGeocodeCallback,
) error

func (*GeocodeProviderProxy) ReverseGeocode

func (p *GeocodeProviderProxy) ReverseGeocode(
	ctx context.Context,
	request ReverseGeocodeRequest,
	callback IGeocodeCallback,
) error

type GeocodeProviderStub

type GeocodeProviderStub struct {
	Impl      IGeocodeProvider
	Transport binder.VersionAwareTransport
}

GeocodeProviderStub dispatches incoming binder transactions to a typed IGeocodeProvider implementation.

func (*GeocodeProviderStub) Descriptor

func (s *GeocodeProviderStub) Descriptor() string

func (*GeocodeProviderStub) OnTransaction

func (s *GeocodeProviderStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IGeocodeCallback

type IGeocodeCallback interface {
	AsBinder() binder.IBinder
	OnError(ctx context.Context, error_ string) error
	OnResults(ctx context.Context, results []types.Address) error
}

func NewGeocodeCallbackStub

func NewGeocodeCallbackStub(
	impl IGeocodeCallbackServer,
) IGeocodeCallback

NewGeocodeCallbackStub creates a server-side IGeocodeCallback wrapping the given server implementation. The returned value satisfies IGeocodeCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGeocodeCallbackServer

type IGeocodeCallbackServer interface {
	OnError(ctx context.Context, error_ string) error
	OnResults(ctx context.Context, results []types.Address) error
}

IGeocodeCallbackServer is the server-side interface that user implementations provide to NewGeocodeCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGeocodeProvider

type IGeocodeProvider interface {
	AsBinder() binder.IBinder
	ForwardGeocode(ctx context.Context, request ForwardGeocodeRequest, callback IGeocodeCallback) error
	ReverseGeocode(ctx context.Context, request ReverseGeocodeRequest, callback IGeocodeCallback) error
}

func NewGeocodeProviderStub

func NewGeocodeProviderStub(
	impl IGeocodeProviderServer,
) IGeocodeProvider

NewGeocodeProviderStub creates a server-side IGeocodeProvider wrapping the given server implementation. The returned value satisfies IGeocodeProvider and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGeocodeProviderServer

type IGeocodeProviderServer interface {
	ForwardGeocode(ctx context.Context, request ForwardGeocodeRequest, callback IGeocodeCallback) error
	ReverseGeocode(ctx context.Context, request ReverseGeocodeRequest, callback IGeocodeCallback) error
}

IGeocodeProviderServer is the server-side interface that user implementations provide to NewGeocodeProviderStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ILocationProvider

type ILocationProvider interface {
	AsBinder() binder.IBinder
	SetLocationProviderManager(ctx context.Context, manager ILocationProviderManager) error
	SetRequest(ctx context.Context, request ProviderRequest) error
	Flush(ctx context.Context) error
	SendExtraCommand(ctx context.Context, command string, extras os.Bundle) error
}

func NewLocationProviderStub

func NewLocationProviderStub(
	impl ILocationProviderServer,
) ILocationProvider

NewLocationProviderStub creates a server-side ILocationProvider wrapping the given server implementation. The returned value satisfies ILocationProvider and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ILocationProviderManager

type ILocationProviderManager interface {
	AsBinder() binder.IBinder
	OnInitialize(ctx context.Context, allowed bool, properties ProviderProperties) error
	OnSetAllowed(ctx context.Context, allowed bool) error
	OnSetProperties(ctx context.Context, properties ProviderProperties) error
	OnReportLocation(ctx context.Context, location types.Location) error
	OnReportLocations(ctx context.Context, locations []types.Location) error
	OnFlushComplete(ctx context.Context) error
}

func NewLocationProviderManagerStub

func NewLocationProviderManagerStub(
	impl ILocationProviderManagerServer,
) ILocationProviderManager

NewLocationProviderManagerStub creates a server-side ILocationProviderManager wrapping the given server implementation. The returned value satisfies ILocationProviderManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ILocationProviderManagerServer

type ILocationProviderManagerServer interface {
	OnInitialize(ctx context.Context, allowed bool, properties ProviderProperties) error
	OnSetAllowed(ctx context.Context, allowed bool) error
	OnSetProperties(ctx context.Context, properties ProviderProperties) error
	OnReportLocation(ctx context.Context, location types.Location) error
	OnReportLocations(ctx context.Context, locations []types.Location) error
	OnFlushComplete(ctx context.Context) error
}

ILocationProviderManagerServer is the server-side interface that user implementations provide to NewLocationProviderManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ILocationProviderServer

type ILocationProviderServer interface {
	SetLocationProviderManager(ctx context.Context, manager ILocationProviderManager) error
	SetRequest(ctx context.Context, request ProviderRequest) error
	Flush(ctx context.Context) error
	SendExtraCommand(ctx context.Context, command string, extras os.Bundle) error
}

ILocationProviderServer is the server-side interface that user implementations provide to NewLocationProviderStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IProviderRequestListener

type IProviderRequestListener interface {
	AsBinder() binder.IBinder
	OnProviderRequestChanged(ctx context.Context, provider string, request ProviderRequest) error
}

func NewProviderRequestListenerStub

func NewProviderRequestListenerStub(
	impl IProviderRequestListenerServer,
) IProviderRequestListener

NewProviderRequestListenerStub creates a server-side IProviderRequestListener wrapping the given server implementation. The returned value satisfies IProviderRequestListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IProviderRequestListenerServer

type IProviderRequestListenerServer interface {
	OnProviderRequestChanged(ctx context.Context, provider string, request ProviderRequest) error
}

IProviderRequestListenerServer is the server-side interface that user implementations provide to NewProviderRequestListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type LocationProviderManagerProxy

type LocationProviderManagerProxy struct {
	Remote binder.IBinder
}

func NewLocationProviderManagerProxy

func NewLocationProviderManagerProxy(
	remote binder.IBinder,
) *LocationProviderManagerProxy

func (*LocationProviderManagerProxy) AsBinder

func (*LocationProviderManagerProxy) OnFlushComplete

func (p *LocationProviderManagerProxy) OnFlushComplete(
	ctx context.Context,
) error

func (*LocationProviderManagerProxy) OnInitialize

func (p *LocationProviderManagerProxy) OnInitialize(
	ctx context.Context,
	allowed bool,
	properties ProviderProperties,
) error

func (*LocationProviderManagerProxy) OnReportLocation

func (p *LocationProviderManagerProxy) OnReportLocation(
	ctx context.Context,
	location types.Location,
) error

func (*LocationProviderManagerProxy) OnReportLocations

func (p *LocationProviderManagerProxy) OnReportLocations(
	ctx context.Context,
	locations []types.Location,
) error

func (*LocationProviderManagerProxy) OnSetAllowed

func (p *LocationProviderManagerProxy) OnSetAllowed(
	ctx context.Context,
	allowed bool,
) error

func (*LocationProviderManagerProxy) OnSetProperties

func (p *LocationProviderManagerProxy) OnSetProperties(
	ctx context.Context,
	properties ProviderProperties,
) error

type LocationProviderManagerStub

type LocationProviderManagerStub struct {
	Impl      ILocationProviderManager
	Transport binder.VersionAwareTransport
}

LocationProviderManagerStub dispatches incoming binder transactions to a typed ILocationProviderManager implementation.

func (*LocationProviderManagerStub) Descriptor

func (s *LocationProviderManagerStub) Descriptor() string

func (*LocationProviderManagerStub) OnTransaction

func (s *LocationProviderManagerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type LocationProviderProxy

type LocationProviderProxy struct {
	Remote binder.IBinder
}

func NewLocationProviderProxy

func NewLocationProviderProxy(
	remote binder.IBinder,
) *LocationProviderProxy

func (*LocationProviderProxy) AsBinder

func (p *LocationProviderProxy) AsBinder() binder.IBinder

func (*LocationProviderProxy) Flush

func (p *LocationProviderProxy) Flush(
	ctx context.Context,
) error

func (*LocationProviderProxy) SendExtraCommand

func (p *LocationProviderProxy) SendExtraCommand(
	ctx context.Context,
	command string,
	extras os.Bundle,
) error

func (*LocationProviderProxy) SetLocationProviderManager

func (p *LocationProviderProxy) SetLocationProviderManager(
	ctx context.Context,
	manager ILocationProviderManager,
) error

func (*LocationProviderProxy) SetRequest

func (p *LocationProviderProxy) SetRequest(
	ctx context.Context,
	request ProviderRequest,
) error

type LocationProviderStub

type LocationProviderStub struct {
	Impl      ILocationProvider
	Transport binder.VersionAwareTransport
}

LocationProviderStub dispatches incoming binder transactions to a typed ILocationProvider implementation.

func (*LocationProviderStub) Descriptor

func (s *LocationProviderStub) Descriptor() string

func (*LocationProviderStub) OnTransaction

func (s *LocationProviderStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ProviderProperties

type ProviderProperties struct {
	HasNetworkRequirement   bool
	HasSatelliteRequirement bool
	HasCellRequirement      bool
	HasMonetaryCost         bool
	HasAltitudeSupport      bool
	HasSpeedSupport         bool
	HasBearingSupport       bool
	PowerUsage              int32
	Accuracy                int32
}

func (*ProviderProperties) MarshalParcel

func (s *ProviderProperties) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ProviderProperties) UnmarshalParcel

func (s *ProviderProperties) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ProviderRequest

type ProviderRequest struct {
	IntervalMillis int64
	WorkSource     *types.WorkSource
}

func (*ProviderRequest) MarshalParcel

func (s *ProviderRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ProviderRequest) UnmarshalParcel

func (s *ProviderRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ProviderRequestListenerProxy

type ProviderRequestListenerProxy struct {
	Remote binder.IBinder
}

func NewProviderRequestListenerProxy

func NewProviderRequestListenerProxy(
	remote binder.IBinder,
) *ProviderRequestListenerProxy

func (*ProviderRequestListenerProxy) AsBinder

func (*ProviderRequestListenerProxy) OnProviderRequestChanged

func (p *ProviderRequestListenerProxy) OnProviderRequestChanged(
	ctx context.Context,
	provider string,
	request ProviderRequest,
) error

type ProviderRequestListenerStub

type ProviderRequestListenerStub struct {
	Impl      IProviderRequestListener
	Transport binder.VersionAwareTransport
}

ProviderRequestListenerStub dispatches incoming binder transactions to a typed IProviderRequestListener implementation.

func (*ProviderRequestListenerStub) Descriptor

func (s *ProviderRequestListenerStub) Descriptor() string

func (*ProviderRequestListenerStub) OnTransaction

func (s *ProviderRequestListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ReverseGeocodeRequest

type ReverseGeocodeRequest struct {
	Latitude              float64
	Longitude             float64
	MaxResults            int32
	CallingUid            int32
	CallingPackage        string
	CallingAttributionTag string
}

func (*ReverseGeocodeRequest) MarshalParcel

func (s *ReverseGeocodeRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ReverseGeocodeRequest) UnmarshalParcel

func (s *ReverseGeocodeRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

Jump to