soundtrigger_middleware

package
v0.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 28, 2026 License: CC0-1.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIInjectGlobalEventTriggerRestart              = binder.FirstCallTransaction + 0
	TransactionIInjectGlobalEventSetResourceContention       = binder.FirstCallTransaction + 1
	TransactionIInjectGlobalEventTriggerOnResourcesAvailable = binder.FirstCallTransaction + 2
)
const (
	MethodIInjectGlobalEventTriggerRestart              = "triggerRestart"
	MethodIInjectGlobalEventSetResourceContention       = "setResourceContention"
	MethodIInjectGlobalEventTriggerOnResourcesAvailable = "triggerOnResourcesAvailable"
)
const (
	TransactionIInjectRecognitionEventTriggerRecognitionEvent = binder.FirstCallTransaction + 0
	TransactionIInjectRecognitionEventTriggerAbortRecognition = binder.FirstCallTransaction + 1
)
const (
	MethodIInjectRecognitionEventTriggerRecognitionEvent = "triggerRecognitionEvent"
	MethodIInjectRecognitionEventTriggerAbortRecognition = "triggerAbortRecognition"
)
const (
	TransactionISoundTriggerCallbackOnRecognition        = binder.FirstCallTransaction + 0
	TransactionISoundTriggerCallbackOnPhraseRecognition  = binder.FirstCallTransaction + 1
	TransactionISoundTriggerCallbackOnResourcesAvailable = binder.FirstCallTransaction + 2
	TransactionISoundTriggerCallbackOnModelUnloaded      = binder.FirstCallTransaction + 3
	TransactionISoundTriggerCallbackOnModuleDied         = binder.FirstCallTransaction + 4
)
const (
	MethodISoundTriggerCallbackOnRecognition        = "onRecognition"
	MethodISoundTriggerCallbackOnPhraseRecognition  = "onPhraseRecognition"
	MethodISoundTriggerCallbackOnResourcesAvailable = "onResourcesAvailable"
	MethodISoundTriggerCallbackOnModelUnloaded      = "onModelUnloaded"
	MethodISoundTriggerCallbackOnModuleDied         = "onModuleDied"
)
const (
	TransactionISoundTriggerInjectionRegisterGlobalEventInjection = binder.FirstCallTransaction + 0
	TransactionISoundTriggerInjectionOnRestarted                  = binder.FirstCallTransaction + 1
	TransactionISoundTriggerInjectionOnFrameworkDetached          = binder.FirstCallTransaction + 2
	TransactionISoundTriggerInjectionOnClientAttached             = binder.FirstCallTransaction + 3
	TransactionISoundTriggerInjectionOnClientDetached             = binder.FirstCallTransaction + 4
	TransactionISoundTriggerInjectionOnSoundModelLoaded           = binder.FirstCallTransaction + 5
	TransactionISoundTriggerInjectionOnParamSet                   = binder.FirstCallTransaction + 6
	TransactionISoundTriggerInjectionOnRecognitionStarted         = binder.FirstCallTransaction + 7
	TransactionISoundTriggerInjectionOnRecognitionStopped         = binder.FirstCallTransaction + 8
	TransactionISoundTriggerInjectionOnSoundModelUnloaded         = binder.FirstCallTransaction + 9
	TransactionISoundTriggerInjectionOnPreempted                  = binder.FirstCallTransaction + 10
)
const (
	MethodISoundTriggerInjectionRegisterGlobalEventInjection = "registerGlobalEventInjection"
	MethodISoundTriggerInjectionOnRestarted                  = "onRestarted"
	MethodISoundTriggerInjectionOnFrameworkDetached          = "onFrameworkDetached"
	MethodISoundTriggerInjectionOnClientAttached             = "onClientAttached"
	MethodISoundTriggerInjectionOnClientDetached             = "onClientDetached"
	MethodISoundTriggerInjectionOnSoundModelLoaded           = "onSoundModelLoaded"
	MethodISoundTriggerInjectionOnParamSet                   = "onParamSet"
	MethodISoundTriggerInjectionOnRecognitionStarted         = "onRecognitionStarted"
	MethodISoundTriggerInjectionOnRecognitionStopped         = "onRecognitionStopped"
	MethodISoundTriggerInjectionOnSoundModelUnloaded         = "onSoundModelUnloaded"
	MethodISoundTriggerInjectionOnPreempted                  = "onPreempted"
)
const (
	TransactionISoundTriggerMiddlewareServiceListModulesAsOriginator = binder.FirstCallTransaction + 0
	TransactionISoundTriggerMiddlewareServiceListModulesAsMiddleman  = binder.FirstCallTransaction + 1
	TransactionISoundTriggerMiddlewareServiceAttachAsOriginator      = binder.FirstCallTransaction + 2
	TransactionISoundTriggerMiddlewareServiceAttachAsMiddleman       = binder.FirstCallTransaction + 3
	TransactionISoundTriggerMiddlewareServiceAttachFakeHalInjection  = binder.FirstCallTransaction + 4
)
const (
	MethodISoundTriggerMiddlewareServiceListModulesAsOriginator = "listModulesAsOriginator"
	MethodISoundTriggerMiddlewareServiceListModulesAsMiddleman  = "listModulesAsMiddleman"
	MethodISoundTriggerMiddlewareServiceAttachAsOriginator      = "attachAsOriginator"
	MethodISoundTriggerMiddlewareServiceAttachAsMiddleman       = "attachAsMiddleman"
	MethodISoundTriggerMiddlewareServiceAttachFakeHalInjection  = "attachFakeHalInjection"
)
const (
	TransactionISoundTriggerModuleLoadModel                  = binder.FirstCallTransaction + 0
	TransactionISoundTriggerModuleLoadPhraseModel            = binder.FirstCallTransaction + 1
	TransactionISoundTriggerModuleUnloadModel                = binder.FirstCallTransaction + 2
	TransactionISoundTriggerModuleStartRecognition           = binder.FirstCallTransaction + 3
	TransactionISoundTriggerModuleStopRecognition            = binder.FirstCallTransaction + 4
	TransactionISoundTriggerModuleForceRecognitionEvent      = binder.FirstCallTransaction + 5
	TransactionISoundTriggerModuleSetModelParameter          = binder.FirstCallTransaction + 6
	TransactionISoundTriggerModuleGetModelParameter          = binder.FirstCallTransaction + 7
	TransactionISoundTriggerModuleQueryModelParameterSupport = binder.FirstCallTransaction + 8
	TransactionISoundTriggerModuleDetach                     = binder.FirstCallTransaction + 9
)
const (
	MethodISoundTriggerModuleLoadModel                  = "loadModel"
	MethodISoundTriggerModuleLoadPhraseModel            = "loadPhraseModel"
	MethodISoundTriggerModuleUnloadModel                = "unloadModel"
	MethodISoundTriggerModuleStartRecognition           = "startRecognition"
	MethodISoundTriggerModuleStopRecognition            = "stopRecognition"
	MethodISoundTriggerModuleForceRecognitionEvent      = "forceRecognitionEvent"
	MethodISoundTriggerModuleSetModelParameter          = "setModelParameter"
	MethodISoundTriggerModuleGetModelParameter          = "getModelParameter"
	MethodISoundTriggerModuleQueryModelParameterSupport = "queryModelParameterSupport"
	MethodISoundTriggerModuleDetach                     = "detach"
)
const DescriptorIAcknowledgeEvent = "android.media.soundtrigger_middleware.IAcknowledgeEvent"
const DescriptorIInjectGlobalEvent = "android.media.soundtrigger_middleware.IInjectGlobalEvent"
const DescriptorIInjectModelEvent = "android.media.soundtrigger_middleware.IInjectModelEvent"
const DescriptorIInjectRecognitionEvent = "android.media.soundtrigger_middleware.IInjectRecognitionEvent"
const DescriptorISoundTriggerCallback = "android.media.soundtrigger_middleware.ISoundTriggerCallback"
const DescriptorISoundTriggerInjection = "android.media.soundtrigger_middleware.ISoundTriggerInjection"
const DescriptorISoundTriggerMiddlewareService = "android.media.soundtrigger_middleware.ISoundTriggerMiddlewareService"
const DescriptorISoundTriggerModule = "android.media.soundtrigger_middleware.ISoundTriggerModule"
const (
	ISoundTriggerInjectionFakeHalArch string = "injection"
)
const (
	MethodIAcknowledgeEventEventReceived = "eventReceived"
)
const (
	MethodIInjectModelEventTriggerUnloadModel = "triggerUnloadModel"
)
const (
	TransactionIAcknowledgeEventEventReceived = binder.FirstCallTransaction + 0
)
const (
	TransactionIInjectModelEventTriggerUnloadModel = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type AcknowledgeEventProxy

type AcknowledgeEventProxy struct {
	Remote binder.IBinder
}

func NewAcknowledgeEventProxy

func NewAcknowledgeEventProxy(
	remote binder.IBinder,
) *AcknowledgeEventProxy

func (*AcknowledgeEventProxy) AsBinder

func (p *AcknowledgeEventProxy) AsBinder() binder.IBinder

func (*AcknowledgeEventProxy) EventReceived

func (p *AcknowledgeEventProxy) EventReceived(
	ctx context.Context,
) error

type AcknowledgeEventStub

type AcknowledgeEventStub struct {
	Impl      IAcknowledgeEvent
	Transport binder.VersionAwareTransport
}

AcknowledgeEventStub dispatches incoming binder transactions to a typed IAcknowledgeEvent implementation.

func (*AcknowledgeEventStub) Descriptor

func (s *AcknowledgeEventStub) Descriptor() string

func (*AcknowledgeEventStub) OnTransaction

func (s *AcknowledgeEventStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IAcknowledgeEvent

type IAcknowledgeEvent interface {
	AsBinder() binder.IBinder
	EventReceived(ctx context.Context) error
}

func NewAcknowledgeEventStub

func NewAcknowledgeEventStub(
	impl IAcknowledgeEventServer,
) IAcknowledgeEvent

NewAcknowledgeEventStub creates a server-side IAcknowledgeEvent wrapping the given server implementation. The returned value satisfies IAcknowledgeEvent and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IAcknowledgeEventServer

type IAcknowledgeEventServer interface {
	EventReceived(ctx context.Context) error
}

IAcknowledgeEventServer is the server-side interface that user implementations provide to NewAcknowledgeEventStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IInjectGlobalEvent

type IInjectGlobalEvent interface {
	AsBinder() binder.IBinder
	TriggerRestart(ctx context.Context) error
	SetResourceContention(ctx context.Context, isContended bool, callback IAcknowledgeEvent) error
	TriggerOnResourcesAvailable(ctx context.Context) error
}

func NewInjectGlobalEventStub

func NewInjectGlobalEventStub(
	impl IInjectGlobalEventServer,
) IInjectGlobalEvent

NewInjectGlobalEventStub creates a server-side IInjectGlobalEvent wrapping the given server implementation. The returned value satisfies IInjectGlobalEvent and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IInjectGlobalEventServer

type IInjectGlobalEventServer interface {
	TriggerRestart(ctx context.Context) error
	SetResourceContention(ctx context.Context, isContended bool, callback IAcknowledgeEvent) error
	TriggerOnResourcesAvailable(ctx context.Context) error
}

IInjectGlobalEventServer is the server-side interface that user implementations provide to NewInjectGlobalEventStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IInjectModelEvent

type IInjectModelEvent interface {
	AsBinder() binder.IBinder
	TriggerUnloadModel(ctx context.Context) error
}

func NewInjectModelEventStub

func NewInjectModelEventStub(
	impl IInjectModelEventServer,
) IInjectModelEvent

NewInjectModelEventStub creates a server-side IInjectModelEvent wrapping the given server implementation. The returned value satisfies IInjectModelEvent and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IInjectModelEventServer

type IInjectModelEventServer interface {
	TriggerUnloadModel(ctx context.Context) error
}

IInjectModelEventServer is the server-side interface that user implementations provide to NewInjectModelEventStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IInjectRecognitionEvent

type IInjectRecognitionEvent interface {
	AsBinder() binder.IBinder
	TriggerRecognitionEvent(ctx context.Context, data []byte, phraseExtras []soundtrigger.PhraseRecognitionExtra) error
	TriggerAbortRecognition(ctx context.Context) error
}

func NewInjectRecognitionEventStub

func NewInjectRecognitionEventStub(
	impl IInjectRecognitionEventServer,
) IInjectRecognitionEvent

NewInjectRecognitionEventStub creates a server-side IInjectRecognitionEvent wrapping the given server implementation. The returned value satisfies IInjectRecognitionEvent and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IInjectRecognitionEventServer

type IInjectRecognitionEventServer interface {
	TriggerRecognitionEvent(ctx context.Context, data []byte, phraseExtras []soundtrigger.PhraseRecognitionExtra) error
	TriggerAbortRecognition(ctx context.Context) error
}

IInjectRecognitionEventServer is the server-side interface that user implementations provide to NewInjectRecognitionEventStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISoundTriggerCallback

type ISoundTriggerCallback interface {
	AsBinder() binder.IBinder
	OnRecognition(ctx context.Context, modelHandle int32, event RecognitionEventSys, captureSession int32) error
	OnPhraseRecognition(ctx context.Context, modelHandle int32, event PhraseRecognitionEventSys, captureSession int32) error
	OnResourcesAvailable(ctx context.Context) error
	OnModelUnloaded(ctx context.Context, modelHandle int32) error
	OnModuleDied(ctx context.Context) error
}

func NewSoundTriggerCallbackStub

func NewSoundTriggerCallbackStub(
	impl ISoundTriggerCallbackServer,
) ISoundTriggerCallback

NewSoundTriggerCallbackStub creates a server-side ISoundTriggerCallback wrapping the given server implementation. The returned value satisfies ISoundTriggerCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISoundTriggerCallbackServer

type ISoundTriggerCallbackServer interface {
	OnRecognition(ctx context.Context, modelHandle int32, event RecognitionEventSys, captureSession int32) error
	OnPhraseRecognition(ctx context.Context, modelHandle int32, event PhraseRecognitionEventSys, captureSession int32) error
	OnResourcesAvailable(ctx context.Context) error
	OnModelUnloaded(ctx context.Context, modelHandle int32) error
	OnModuleDied(ctx context.Context) error
}

ISoundTriggerCallbackServer is the server-side interface that user implementations provide to NewSoundTriggerCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISoundTriggerInjection

type ISoundTriggerInjection interface {
	AsBinder() binder.IBinder
	RegisterGlobalEventInjection(ctx context.Context, globalInjection IInjectGlobalEvent) error
	OnRestarted(ctx context.Context, globalSession IInjectGlobalEvent) error
	OnFrameworkDetached(ctx context.Context, globalSession IInjectGlobalEvent) error
	OnClientAttached(ctx context.Context, token binder.IBinder, globalSession IInjectGlobalEvent) error
	OnClientDetached(ctx context.Context, token binder.IBinder) error
	OnSoundModelLoaded(ctx context.Context, model soundtrigger.SoundModel, phrases []soundtrigger.Phrase, modelInjection IInjectModelEvent, globalSession IInjectGlobalEvent) error
	OnParamSet(ctx context.Context, modelParam int32, value int32, modelSession IInjectModelEvent) error
	OnRecognitionStarted(ctx context.Context, audioSessionToken int32, config soundtrigger.RecognitionConfig, recognitionInjection IInjectRecognitionEvent, modelSession IInjectModelEvent) error
	OnRecognitionStopped(ctx context.Context, recognitionSession IInjectRecognitionEvent) error
	OnSoundModelUnloaded(ctx context.Context, modelSession IInjectModelEvent) error
	OnPreempted(ctx context.Context) error
}

func NewSoundTriggerInjectionStub

func NewSoundTriggerInjectionStub(
	impl ISoundTriggerInjectionServer,
) ISoundTriggerInjection

NewSoundTriggerInjectionStub creates a server-side ISoundTriggerInjection wrapping the given server implementation. The returned value satisfies ISoundTriggerInjection and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISoundTriggerInjectionServer

type ISoundTriggerInjectionServer interface {
	RegisterGlobalEventInjection(ctx context.Context, globalInjection IInjectGlobalEvent) error
	OnRestarted(ctx context.Context, globalSession IInjectGlobalEvent) error
	OnFrameworkDetached(ctx context.Context, globalSession IInjectGlobalEvent) error
	OnClientAttached(ctx context.Context, token binder.IBinder, globalSession IInjectGlobalEvent) error
	OnClientDetached(ctx context.Context, token binder.IBinder) error
	OnSoundModelLoaded(ctx context.Context, model soundtrigger.SoundModel, phrases []soundtrigger.Phrase, modelInjection IInjectModelEvent, globalSession IInjectGlobalEvent) error
	OnParamSet(ctx context.Context, modelParam int32, value int32, modelSession IInjectModelEvent) error
	OnRecognitionStarted(ctx context.Context, audioSessionToken int32, config soundtrigger.RecognitionConfig, recognitionInjection IInjectRecognitionEvent, modelSession IInjectModelEvent) error
	OnRecognitionStopped(ctx context.Context, recognitionSession IInjectRecognitionEvent) error
	OnSoundModelUnloaded(ctx context.Context, modelSession IInjectModelEvent) error
	OnPreempted(ctx context.Context) error
}

ISoundTriggerInjectionServer is the server-side interface that user implementations provide to NewSoundTriggerInjectionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISoundTriggerMiddlewareService

type ISoundTriggerMiddlewareService interface {
	AsBinder() binder.IBinder
	ListModulesAsOriginator(ctx context.Context, identity permission.Identity) ([]SoundTriggerModuleDescriptor, error)
	ListModulesAsMiddleman(ctx context.Context, middlemanIdentity permission.Identity, originatorIdentity permission.Identity) ([]SoundTriggerModuleDescriptor, error)
	AttachAsOriginator(ctx context.Context, handle int32, identity permission.Identity, callback ISoundTriggerCallback) (ISoundTriggerModule, error)
	AttachAsMiddleman(ctx context.Context, handle int32, middlemanIdentity permission.Identity, originatorIdentity permission.Identity, callback ISoundTriggerCallback, isTrusted bool) (ISoundTriggerModule, error)
	AttachFakeHalInjection(ctx context.Context, injection ISoundTriggerInjection) error
}

func NewSoundTriggerMiddlewareServiceStub

func NewSoundTriggerMiddlewareServiceStub(
	impl ISoundTriggerMiddlewareServiceServer,
) ISoundTriggerMiddlewareService

NewSoundTriggerMiddlewareServiceStub creates a server-side ISoundTriggerMiddlewareService wrapping the given server implementation. The returned value satisfies ISoundTriggerMiddlewareService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISoundTriggerMiddlewareServiceServer

type ISoundTriggerMiddlewareServiceServer interface {
	ListModulesAsOriginator(ctx context.Context, identity permission.Identity) ([]SoundTriggerModuleDescriptor, error)
	ListModulesAsMiddleman(ctx context.Context, middlemanIdentity permission.Identity, originatorIdentity permission.Identity) ([]SoundTriggerModuleDescriptor, error)
	AttachAsOriginator(ctx context.Context, handle int32, identity permission.Identity, callback ISoundTriggerCallback) (ISoundTriggerModule, error)
	AttachAsMiddleman(ctx context.Context, handle int32, middlemanIdentity permission.Identity, originatorIdentity permission.Identity, callback ISoundTriggerCallback, isTrusted bool) (ISoundTriggerModule, error)
	AttachFakeHalInjection(ctx context.Context, injection ISoundTriggerInjection) error
}

ISoundTriggerMiddlewareServiceServer is the server-side interface that user implementations provide to NewSoundTriggerMiddlewareServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISoundTriggerModule

type ISoundTriggerModule interface {
	AsBinder() binder.IBinder
	LoadModel(ctx context.Context, model soundtrigger.SoundModel) (int32, error)
	LoadPhraseModel(ctx context.Context, model soundtrigger.PhraseSoundModel) (int32, error)
	UnloadModel(ctx context.Context, modelHandle int32) error
	StartRecognition(ctx context.Context, modelHandle int32, config soundtrigger.RecognitionConfig) (binder.IBinder, error)
	StopRecognition(ctx context.Context, modelHandle int32) error
	ForceRecognitionEvent(ctx context.Context, modelHandle int32) error
	SetModelParameter(ctx context.Context, modelHandle int32, modelParam soundtrigger.ModelParameter, value int32) error
	GetModelParameter(ctx context.Context, modelHandle int32, modelParam soundtrigger.ModelParameter) (int32, error)
	QueryModelParameterSupport(ctx context.Context, modelHandle int32, modelParam soundtrigger.ModelParameter) (soundtrigger.ModelParameterRange, error)
	Detach(ctx context.Context) error
}

func NewSoundTriggerModuleStub

func NewSoundTriggerModuleStub(
	impl ISoundTriggerModuleServer,
) ISoundTriggerModule

NewSoundTriggerModuleStub creates a server-side ISoundTriggerModule wrapping the given server implementation. The returned value satisfies ISoundTriggerModule and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISoundTriggerModuleServer

type ISoundTriggerModuleServer interface {
	LoadModel(ctx context.Context, model soundtrigger.SoundModel) (int32, error)
	LoadPhraseModel(ctx context.Context, model soundtrigger.PhraseSoundModel) (int32, error)
	UnloadModel(ctx context.Context, modelHandle int32) error
	StartRecognition(ctx context.Context, modelHandle int32, config soundtrigger.RecognitionConfig) (binder.IBinder, error)
	StopRecognition(ctx context.Context, modelHandle int32) error
	ForceRecognitionEvent(ctx context.Context, modelHandle int32) error
	SetModelParameter(ctx context.Context, modelHandle int32, modelParam soundtrigger.ModelParameter, value int32) error
	GetModelParameter(ctx context.Context, modelHandle int32, modelParam soundtrigger.ModelParameter) (int32, error)
	QueryModelParameterSupport(ctx context.Context, modelHandle int32, modelParam soundtrigger.ModelParameter) (soundtrigger.ModelParameterRange, error)
	Detach(ctx context.Context) error
}

ISoundTriggerModuleServer is the server-side interface that user implementations provide to NewSoundTriggerModuleStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type InjectGlobalEventProxy

type InjectGlobalEventProxy struct {
	Remote binder.IBinder
}

func NewInjectGlobalEventProxy

func NewInjectGlobalEventProxy(
	remote binder.IBinder,
) *InjectGlobalEventProxy

func (*InjectGlobalEventProxy) AsBinder

func (p *InjectGlobalEventProxy) AsBinder() binder.IBinder

func (*InjectGlobalEventProxy) SetResourceContention

func (p *InjectGlobalEventProxy) SetResourceContention(
	ctx context.Context,
	isContended bool,
	callback IAcknowledgeEvent,
) error

func (*InjectGlobalEventProxy) TriggerOnResourcesAvailable

func (p *InjectGlobalEventProxy) TriggerOnResourcesAvailable(
	ctx context.Context,
) error

func (*InjectGlobalEventProxy) TriggerRestart

func (p *InjectGlobalEventProxy) TriggerRestart(
	ctx context.Context,
) error

type InjectGlobalEventStub

type InjectGlobalEventStub struct {
	Impl      IInjectGlobalEvent
	Transport binder.VersionAwareTransport
}

InjectGlobalEventStub dispatches incoming binder transactions to a typed IInjectGlobalEvent implementation.

func (*InjectGlobalEventStub) Descriptor

func (s *InjectGlobalEventStub) Descriptor() string

func (*InjectGlobalEventStub) OnTransaction

func (s *InjectGlobalEventStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type InjectModelEventProxy

type InjectModelEventProxy struct {
	Remote binder.IBinder
}

func NewInjectModelEventProxy

func NewInjectModelEventProxy(
	remote binder.IBinder,
) *InjectModelEventProxy

func (*InjectModelEventProxy) AsBinder

func (p *InjectModelEventProxy) AsBinder() binder.IBinder

func (*InjectModelEventProxy) TriggerUnloadModel

func (p *InjectModelEventProxy) TriggerUnloadModel(
	ctx context.Context,
) error

type InjectModelEventStub

type InjectModelEventStub struct {
	Impl      IInjectModelEvent
	Transport binder.VersionAwareTransport
}

InjectModelEventStub dispatches incoming binder transactions to a typed IInjectModelEvent implementation.

func (*InjectModelEventStub) Descriptor

func (s *InjectModelEventStub) Descriptor() string

func (*InjectModelEventStub) OnTransaction

func (s *InjectModelEventStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type InjectRecognitionEventProxy

type InjectRecognitionEventProxy struct {
	Remote binder.IBinder
}

func NewInjectRecognitionEventProxy

func NewInjectRecognitionEventProxy(
	remote binder.IBinder,
) *InjectRecognitionEventProxy

func (*InjectRecognitionEventProxy) AsBinder

func (*InjectRecognitionEventProxy) TriggerAbortRecognition

func (p *InjectRecognitionEventProxy) TriggerAbortRecognition(
	ctx context.Context,
) error

func (*InjectRecognitionEventProxy) TriggerRecognitionEvent

func (p *InjectRecognitionEventProxy) TriggerRecognitionEvent(
	ctx context.Context,
	data []byte,
	phraseExtras []soundtrigger.PhraseRecognitionExtra,
) error

type InjectRecognitionEventStub

type InjectRecognitionEventStub struct {
	Impl      IInjectRecognitionEvent
	Transport binder.VersionAwareTransport
}

InjectRecognitionEventStub dispatches incoming binder transactions to a typed IInjectRecognitionEvent implementation.

func (*InjectRecognitionEventStub) Descriptor

func (s *InjectRecognitionEventStub) Descriptor() string

func (*InjectRecognitionEventStub) OnTransaction

func (s *InjectRecognitionEventStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type PhraseRecognitionEventSys

type PhraseRecognitionEventSys struct {
	PhraseRecognitionEvent soundtrigger.PhraseRecognitionEvent
	HalEventReceivedMillis int64
	Token                  binder.IBinder
}

func (*PhraseRecognitionEventSys) MarshalParcel

func (s *PhraseRecognitionEventSys) MarshalParcel(
	p *parcel.Parcel,
) error

func (*PhraseRecognitionEventSys) UnmarshalParcel

func (s *PhraseRecognitionEventSys) UnmarshalParcel(
	p *parcel.Parcel,
) error

type RecognitionEventSys

type RecognitionEventSys struct {
	RecognitionEvent       soundtrigger.RecognitionEvent
	HalEventReceivedMillis int64
	Token                  binder.IBinder
}

func (*RecognitionEventSys) MarshalParcel

func (s *RecognitionEventSys) MarshalParcel(
	p *parcel.Parcel,
) error

func (*RecognitionEventSys) UnmarshalParcel

func (s *RecognitionEventSys) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SoundTriggerCallbackProxy

type SoundTriggerCallbackProxy struct {
	Remote binder.IBinder
}

func NewSoundTriggerCallbackProxy

func NewSoundTriggerCallbackProxy(
	remote binder.IBinder,
) *SoundTriggerCallbackProxy

func (*SoundTriggerCallbackProxy) AsBinder

func (*SoundTriggerCallbackProxy) OnModelUnloaded

func (p *SoundTriggerCallbackProxy) OnModelUnloaded(
	ctx context.Context,
	modelHandle int32,
) error

func (*SoundTriggerCallbackProxy) OnModuleDied

func (p *SoundTriggerCallbackProxy) OnModuleDied(
	ctx context.Context,
) error

func (*SoundTriggerCallbackProxy) OnPhraseRecognition

func (p *SoundTriggerCallbackProxy) OnPhraseRecognition(
	ctx context.Context,
	modelHandle int32,
	event PhraseRecognitionEventSys,
	captureSession int32,
) error

func (*SoundTriggerCallbackProxy) OnRecognition

func (p *SoundTriggerCallbackProxy) OnRecognition(
	ctx context.Context,
	modelHandle int32,
	event RecognitionEventSys,
	captureSession int32,
) error

func (*SoundTriggerCallbackProxy) OnResourcesAvailable

func (p *SoundTriggerCallbackProxy) OnResourcesAvailable(
	ctx context.Context,
) error

type SoundTriggerCallbackStub

type SoundTriggerCallbackStub struct {
	Impl      ISoundTriggerCallback
	Transport binder.VersionAwareTransport
}

SoundTriggerCallbackStub dispatches incoming binder transactions to a typed ISoundTriggerCallback implementation.

func (*SoundTriggerCallbackStub) Descriptor

func (s *SoundTriggerCallbackStub) Descriptor() string

func (*SoundTriggerCallbackStub) OnTransaction

func (s *SoundTriggerCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type SoundTriggerInjectionProxy

type SoundTriggerInjectionProxy struct {
	Remote binder.IBinder
}

func NewSoundTriggerInjectionProxy

func NewSoundTriggerInjectionProxy(
	remote binder.IBinder,
) *SoundTriggerInjectionProxy

func (*SoundTriggerInjectionProxy) AsBinder

func (*SoundTriggerInjectionProxy) OnClientAttached

func (p *SoundTriggerInjectionProxy) OnClientAttached(
	ctx context.Context,
	token binder.IBinder,
	globalSession IInjectGlobalEvent,
) error

func (*SoundTriggerInjectionProxy) OnClientDetached

func (p *SoundTriggerInjectionProxy) OnClientDetached(
	ctx context.Context,
	token binder.IBinder,
) error

func (*SoundTriggerInjectionProxy) OnFrameworkDetached

func (p *SoundTriggerInjectionProxy) OnFrameworkDetached(
	ctx context.Context,
	globalSession IInjectGlobalEvent,
) error

func (*SoundTriggerInjectionProxy) OnParamSet

func (p *SoundTriggerInjectionProxy) OnParamSet(
	ctx context.Context,
	modelParam int32,
	value int32,
	modelSession IInjectModelEvent,
) error

func (*SoundTriggerInjectionProxy) OnPreempted

func (p *SoundTriggerInjectionProxy) OnPreempted(
	ctx context.Context,
) error

func (*SoundTriggerInjectionProxy) OnRecognitionStarted

func (p *SoundTriggerInjectionProxy) OnRecognitionStarted(
	ctx context.Context,
	audioSessionToken int32,
	config soundtrigger.RecognitionConfig,
	recognitionInjection IInjectRecognitionEvent,
	modelSession IInjectModelEvent,
) error

func (*SoundTriggerInjectionProxy) OnRecognitionStopped

func (p *SoundTriggerInjectionProxy) OnRecognitionStopped(
	ctx context.Context,
	recognitionSession IInjectRecognitionEvent,
) error

func (*SoundTriggerInjectionProxy) OnRestarted

func (p *SoundTriggerInjectionProxy) OnRestarted(
	ctx context.Context,
	globalSession IInjectGlobalEvent,
) error

func (*SoundTriggerInjectionProxy) OnSoundModelLoaded

func (p *SoundTriggerInjectionProxy) OnSoundModelLoaded(
	ctx context.Context,
	model soundtrigger.SoundModel,
	phrases []soundtrigger.Phrase,
	modelInjection IInjectModelEvent,
	globalSession IInjectGlobalEvent,
) error

func (*SoundTriggerInjectionProxy) OnSoundModelUnloaded

func (p *SoundTriggerInjectionProxy) OnSoundModelUnloaded(
	ctx context.Context,
	modelSession IInjectModelEvent,
) error

func (*SoundTriggerInjectionProxy) RegisterGlobalEventInjection

func (p *SoundTriggerInjectionProxy) RegisterGlobalEventInjection(
	ctx context.Context,
	globalInjection IInjectGlobalEvent,
) error

type SoundTriggerInjectionStub

type SoundTriggerInjectionStub struct {
	Impl      ISoundTriggerInjection
	Transport binder.VersionAwareTransport
}

SoundTriggerInjectionStub dispatches incoming binder transactions to a typed ISoundTriggerInjection implementation.

func (*SoundTriggerInjectionStub) Descriptor

func (s *SoundTriggerInjectionStub) Descriptor() string

func (*SoundTriggerInjectionStub) OnTransaction

func (s *SoundTriggerInjectionStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type SoundTriggerMiddlewareServiceProxy

type SoundTriggerMiddlewareServiceProxy struct {
	Remote binder.IBinder
}

func NewSoundTriggerMiddlewareServiceProxy

func NewSoundTriggerMiddlewareServiceProxy(
	remote binder.IBinder,
) *SoundTriggerMiddlewareServiceProxy

func (*SoundTriggerMiddlewareServiceProxy) AsBinder

func (*SoundTriggerMiddlewareServiceProxy) AttachAsMiddleman

func (p *SoundTriggerMiddlewareServiceProxy) AttachAsMiddleman(
	ctx context.Context,
	handle int32,
	middlemanIdentity permission.Identity,
	originatorIdentity permission.Identity,
	callback ISoundTriggerCallback,
	isTrusted bool,
) (ISoundTriggerModule, error)

func (*SoundTriggerMiddlewareServiceProxy) AttachAsOriginator

func (p *SoundTriggerMiddlewareServiceProxy) AttachAsOriginator(
	ctx context.Context,
	handle int32,
	identity permission.Identity,
	callback ISoundTriggerCallback,
) (ISoundTriggerModule, error)

func (*SoundTriggerMiddlewareServiceProxy) AttachFakeHalInjection

func (p *SoundTriggerMiddlewareServiceProxy) AttachFakeHalInjection(
	ctx context.Context,
	injection ISoundTriggerInjection,
) error

func (*SoundTriggerMiddlewareServiceProxy) ListModulesAsMiddleman

func (p *SoundTriggerMiddlewareServiceProxy) ListModulesAsMiddleman(
	ctx context.Context,
	middlemanIdentity permission.Identity,
	originatorIdentity permission.Identity,
) ([]SoundTriggerModuleDescriptor, error)

func (*SoundTriggerMiddlewareServiceProxy) ListModulesAsOriginator

type SoundTriggerMiddlewareServiceStub

type SoundTriggerMiddlewareServiceStub struct {
	Impl      ISoundTriggerMiddlewareService
	Transport binder.VersionAwareTransport
}

SoundTriggerMiddlewareServiceStub dispatches incoming binder transactions to a typed ISoundTriggerMiddlewareService implementation.

func (*SoundTriggerMiddlewareServiceStub) Descriptor

func (s *SoundTriggerMiddlewareServiceStub) Descriptor() string

func (*SoundTriggerMiddlewareServiceStub) OnTransaction

type SoundTriggerModuleDescriptor

type SoundTriggerModuleDescriptor struct {
	Handle     int32
	Properties soundtrigger.Properties
}

func (*SoundTriggerModuleDescriptor) MarshalParcel

func (s *SoundTriggerModuleDescriptor) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SoundTriggerModuleDescriptor) UnmarshalParcel

func (s *SoundTriggerModuleDescriptor) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SoundTriggerModuleProxy

type SoundTriggerModuleProxy struct {
	Remote binder.IBinder
}

func NewSoundTriggerModuleProxy

func NewSoundTriggerModuleProxy(
	remote binder.IBinder,
) *SoundTriggerModuleProxy

func (*SoundTriggerModuleProxy) AsBinder

func (p *SoundTriggerModuleProxy) AsBinder() binder.IBinder

func (*SoundTriggerModuleProxy) Detach

func (p *SoundTriggerModuleProxy) Detach(
	ctx context.Context,
) error

func (*SoundTriggerModuleProxy) ForceRecognitionEvent

func (p *SoundTriggerModuleProxy) ForceRecognitionEvent(
	ctx context.Context,
	modelHandle int32,
) error

func (*SoundTriggerModuleProxy) GetModelParameter

func (p *SoundTriggerModuleProxy) GetModelParameter(
	ctx context.Context,
	modelHandle int32,
	modelParam soundtrigger.ModelParameter,
) (int32, error)

func (*SoundTriggerModuleProxy) LoadModel

func (p *SoundTriggerModuleProxy) LoadModel(
	ctx context.Context,
	model soundtrigger.SoundModel,
) (int32, error)

func (*SoundTriggerModuleProxy) LoadPhraseModel

func (p *SoundTriggerModuleProxy) LoadPhraseModel(
	ctx context.Context,
	model soundtrigger.PhraseSoundModel,
) (int32, error)

func (*SoundTriggerModuleProxy) QueryModelParameterSupport

func (p *SoundTriggerModuleProxy) QueryModelParameterSupport(
	ctx context.Context,
	modelHandle int32,
	modelParam soundtrigger.ModelParameter,
) (soundtrigger.ModelParameterRange, error)

func (*SoundTriggerModuleProxy) SetModelParameter

func (p *SoundTriggerModuleProxy) SetModelParameter(
	ctx context.Context,
	modelHandle int32,
	modelParam soundtrigger.ModelParameter,
	value int32,
) error

func (*SoundTriggerModuleProxy) StartRecognition

func (p *SoundTriggerModuleProxy) StartRecognition(
	ctx context.Context,
	modelHandle int32,
	config soundtrigger.RecognitionConfig,
) (binder.IBinder, error)

func (*SoundTriggerModuleProxy) StopRecognition

func (p *SoundTriggerModuleProxy) StopRecognition(
	ctx context.Context,
	modelHandle int32,
) error

func (*SoundTriggerModuleProxy) UnloadModel

func (p *SoundTriggerModuleProxy) UnloadModel(
	ctx context.Context,
	modelHandle int32,
) error

type SoundTriggerModuleStub

type SoundTriggerModuleStub struct {
	Impl      ISoundTriggerModule
	Transport binder.VersionAwareTransport
}

SoundTriggerModuleStub dispatches incoming binder transactions to a typed ISoundTriggerModule implementation.

func (*SoundTriggerModuleStub) Descriptor

func (s *SoundTriggerModuleStub) Descriptor() string

func (*SoundTriggerModuleStub) OnTransaction

func (s *SoundTriggerModuleStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to