incremental

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIIncrementalServiceOpenStorage                       = binder.FirstCallTransaction + 0
	TransactionIIncrementalServiceCreateStorage                     = binder.FirstCallTransaction + 1
	TransactionIIncrementalServiceCreateLinkedStorage               = binder.FirstCallTransaction + 2
	TransactionIIncrementalServiceStartLoading                      = binder.FirstCallTransaction + 3
	TransactionIIncrementalServiceOnInstallationComplete            = binder.FirstCallTransaction + 4
	TransactionIIncrementalServiceMakeBindMount                     = binder.FirstCallTransaction + 5
	TransactionIIncrementalServiceDeleteBindMount                   = binder.FirstCallTransaction + 6
	TransactionIIncrementalServiceMakeDirectory                     = binder.FirstCallTransaction + 7
	TransactionIIncrementalServiceMakeDirectories                   = binder.FirstCallTransaction + 8
	TransactionIIncrementalServiceMakeFile                          = binder.FirstCallTransaction + 9
	TransactionIIncrementalServiceMakeFileFromRange                 = binder.FirstCallTransaction + 10
	TransactionIIncrementalServiceMakeLink                          = binder.FirstCallTransaction + 11
	TransactionIIncrementalServiceUnlink                            = binder.FirstCallTransaction + 12
	TransactionIIncrementalServiceIsFileFullyLoaded                 = binder.FirstCallTransaction + 13
	TransactionIIncrementalServiceIsFullyLoaded                     = binder.FirstCallTransaction + 14
	TransactionIIncrementalServiceGetLoadingProgress                = binder.FirstCallTransaction + 15
	TransactionIIncrementalServiceGetMetadataByPath                 = binder.FirstCallTransaction + 16
	TransactionIIncrementalServiceGetMetadataById                   = binder.FirstCallTransaction + 17
	TransactionIIncrementalServiceDeleteStorage                     = binder.FirstCallTransaction + 18
	TransactionIIncrementalServiceDisallowReadLogs                  = binder.FirstCallTransaction + 19
	TransactionIIncrementalServiceConfigureNativeBinaries           = binder.FirstCallTransaction + 20
	TransactionIIncrementalServiceWaitForNativeBinariesExtraction   = binder.FirstCallTransaction + 21
	TransactionIIncrementalServiceRegisterLoadingProgressListener   = binder.FirstCallTransaction + 22
	TransactionIIncrementalServiceUnregisterLoadingProgressListener = binder.FirstCallTransaction + 23
	TransactionIIncrementalServiceGetMetrics                        = binder.FirstCallTransaction + 24
)
const (
	MethodIIncrementalServiceOpenStorage                       = "openStorage"
	MethodIIncrementalServiceCreateStorage                     = "createStorage"
	MethodIIncrementalServiceCreateLinkedStorage               = "createLinkedStorage"
	MethodIIncrementalServiceStartLoading                      = "startLoading"
	MethodIIncrementalServiceOnInstallationComplete            = "onInstallationComplete"
	MethodIIncrementalServiceMakeBindMount                     = "makeBindMount"
	MethodIIncrementalServiceDeleteBindMount                   = "deleteBindMount"
	MethodIIncrementalServiceMakeDirectory                     = "makeDirectory"
	MethodIIncrementalServiceMakeDirectories                   = "makeDirectories"
	MethodIIncrementalServiceMakeFile                          = "makeFile"
	MethodIIncrementalServiceMakeFileFromRange                 = "makeFileFromRange"
	MethodIIncrementalServiceMakeLink                          = "makeLink"
	MethodIIncrementalServiceUnlink                            = "unlink"
	MethodIIncrementalServiceIsFileFullyLoaded                 = "isFileFullyLoaded"
	MethodIIncrementalServiceIsFullyLoaded                     = "isFullyLoaded"
	MethodIIncrementalServiceGetLoadingProgress                = "getLoadingProgress"
	MethodIIncrementalServiceGetMetadataByPath                 = "getMetadataByPath"
	MethodIIncrementalServiceGetMetadataById                   = "getMetadataById"
	MethodIIncrementalServiceDeleteStorage                     = "deleteStorage"
	MethodIIncrementalServiceDisallowReadLogs                  = "disallowReadLogs"
	MethodIIncrementalServiceConfigureNativeBinaries           = "configureNativeBinaries"
	MethodIIncrementalServiceWaitForNativeBinariesExtraction   = "waitForNativeBinariesExtraction"
	MethodIIncrementalServiceRegisterLoadingProgressListener   = "registerLoadingProgressListener"
	MethodIIncrementalServiceUnregisterLoadingProgressListener = "unregisterLoadingProgressListener"
	MethodIIncrementalServiceGetMetrics                        = "getMetrics"
)
const (
	IIncrementalServiceCreateModeTemporaryBind              int32  = 1
	IIncrementalServiceCreateModePermanentBind              int32  = 2
	IIncrementalServiceCreateModeCreate                     int32  = 4
	IIncrementalServiceCreateModeOpenExisting               int32  = 8
	IIncrementalServiceBindTemporary                        int32  = 0
	IIncrementalServiceBindPermanent                        int32  = 1
	IIncrementalServiceMetricsMillisSinceOldestPendingRead  string = "millisSinceOldestPendingRead"
	IIncrementalServiceMetricsReadLogsEnabled               string = "readLogsEnabled"
	IIncrementalServiceMetricsStorageHealthStatusCode       string = "storageHealthStatusCode"
	IIncrementalServiceMetricsDataLoaderStatusCode          string = "dataLoaderStatusCode"
	IIncrementalServiceMetricsMillisSinceLastDataLoaderBind string = "millisSinceLastDataLoaderBind"
	IIncrementalServiceMetricsDataLoaderBindDelayMillis     string = "dataLoaderBindDelayMillis"
	IIncrementalServiceMetricsTotalDelayedReads             string = "totalDelayedReads"
	IIncrementalServiceMetricsTotalDelayedReadsMillis       string = "totalDelayedReadsMillis"
	IIncrementalServiceMetricsTotalFailedReads              string = "totalFailedReads"
	IIncrementalServiceMetricsLastReadErrorUid              string = "lastReadErrorUid"
	IIncrementalServiceMetricsMillisSinceLastReadError      string = "millisSinceLastReadError"
	IIncrementalServiceMetricsLastReadErrorNumber           string = "lastReadErrorNo"
)
const (
	IStorageHealthListenerHealthStatusOk           int32 = 0
	IStorageHealthListenerHealthStatusReadsPending int32 = 1
	IStorageHealthListenerHealthStatusBlocked      int32 = 2
	IStorageHealthListenerHealthStatusUnhealthy    int32 = 3
)
const DescriptorIIncrementalService = "android.os.incremental.IIncrementalService"
const DescriptorIIncrementalServiceConnector = "android.os.incremental.IIncrementalServiceConnector"
const DescriptorIStorageHealthListener = "android.os.incremental.IStorageHealthListener"
const DescriptorIStorageLoadingProgressListener = "android.os.incremental.IStorageLoadingProgressListener"
const (
	MethodIIncrementalServiceConnectorSetStorageParams = "setStorageParams"
)
const (
	MethodIStorageHealthListenerOnHealthStatus = "onHealthStatus"
)
const (
	MethodIStorageLoadingProgressListenerOnStorageLoadingProgressChanged = "onStorageLoadingProgressChanged"
)
const (
	TransactionIIncrementalServiceConnectorSetStorageParams = binder.FirstCallTransaction + 0
)
const (
	TransactionIStorageHealthListenerOnHealthStatus = binder.FirstCallTransaction + 0
)
const (
	TransactionIStorageLoadingProgressListenerOnStorageLoadingProgressChanged = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type IIncrementalService

type IIncrementalService interface {
	AsBinder() binder.IBinder
	OpenStorage(ctx context.Context, path string) (int32, error)
	CreateStorage(ctx context.Context, path string, params types.DataLoaderParamsParcel, createMode int32) (int32, error)
	CreateLinkedStorage(ctx context.Context, path string, otherStorageId int32, createMode int32) (int32, error)
	StartLoading(ctx context.Context, storageId int32, params types.DataLoaderParamsParcel, statusListener types.IDataLoaderStatusListener, healthCheckParams StorageHealthCheckParams, healthListener IStorageHealthListener, perUidReadTimeouts []PerUidReadTimeouts) (bool, error)
	OnInstallationComplete(ctx context.Context, storageId int32) error
	MakeBindMount(ctx context.Context, storageId int32, sourcePath string, targetFullPath string, bindType int32) (int32, error)
	DeleteBindMount(ctx context.Context, storageId int32, targetFullPath string) (int32, error)
	MakeDirectory(ctx context.Context, storageId int32, path string) (int32, error)
	MakeDirectories(ctx context.Context, storageId int32, path string) (int32, error)
	MakeFile(ctx context.Context, storageId int32, path string, mode int32, params IncrementalNewFileParams, content []byte) (int32, error)
	MakeFileFromRange(ctx context.Context, storageId int32, targetPath string, sourcePath string, start int64, end int64) (int32, error)
	MakeLink(ctx context.Context, sourceStorageId int32, sourcePath string, destStorageId int32, destPath string) (int32, error)
	Unlink(ctx context.Context, storageId int32, path string) (int32, error)
	IsFileFullyLoaded(ctx context.Context, storageId int32, path string) (int32, error)
	IsFullyLoaded(ctx context.Context, storageId int32) (int32, error)
	GetLoadingProgress(ctx context.Context, storageId int32) (float32, error)
	GetMetadataByPath(ctx context.Context, storageId int32, path string) ([]byte, error)
	GetMetadataById(ctx context.Context, storageId int32, fileId []byte) ([]byte, error)
	DeleteStorage(ctx context.Context, storageId int32) error
	DisallowReadLogs(ctx context.Context, storageId int32) error
	ConfigureNativeBinaries(ctx context.Context, storageId int32, apkFullPath string, libDirRelativePath string, abi string, extractNativeLibs bool) (bool, error)
	WaitForNativeBinariesExtraction(ctx context.Context, storageId int32) (bool, error)
	RegisterLoadingProgressListener(ctx context.Context, storageId int32, listener IStorageLoadingProgressListener) (bool, error)
	UnregisterLoadingProgressListener(ctx context.Context, storageId int32) (bool, error)
	GetMetrics(ctx context.Context, storageId int32) (os.PersistableBundle, error)
}

func NewIncrementalServiceStub

func NewIncrementalServiceStub(
	impl IIncrementalServiceServer,
) IIncrementalService

NewIncrementalServiceStub creates a server-side IIncrementalService wrapping the given server implementation. The returned value satisfies IIncrementalService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IIncrementalServiceConnector

type IIncrementalServiceConnector interface {
	AsBinder() binder.IBinder
	SetStorageParams(ctx context.Context, enableReadLogs bool) (int32, error)
}

func NewIncrementalServiceConnectorStub

func NewIncrementalServiceConnectorStub(
	impl IIncrementalServiceConnectorServer,
) IIncrementalServiceConnector

NewIncrementalServiceConnectorStub creates a server-side IIncrementalServiceConnector wrapping the given server implementation. The returned value satisfies IIncrementalServiceConnector and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IIncrementalServiceConnectorServer

type IIncrementalServiceConnectorServer interface {
	SetStorageParams(ctx context.Context, enableReadLogs bool) (int32, error)
}

IIncrementalServiceConnectorServer is the server-side interface that user implementations provide to NewIncrementalServiceConnectorStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IIncrementalServiceServer

type IIncrementalServiceServer interface {
	OpenStorage(ctx context.Context, path string) (int32, error)
	CreateStorage(ctx context.Context, path string, params types.DataLoaderParamsParcel, createMode int32) (int32, error)
	CreateLinkedStorage(ctx context.Context, path string, otherStorageId int32, createMode int32) (int32, error)
	StartLoading(ctx context.Context, storageId int32, params types.DataLoaderParamsParcel, statusListener types.IDataLoaderStatusListener, healthCheckParams StorageHealthCheckParams, healthListener IStorageHealthListener, perUidReadTimeouts []PerUidReadTimeouts) (bool, error)
	OnInstallationComplete(ctx context.Context, storageId int32) error
	MakeBindMount(ctx context.Context, storageId int32, sourcePath string, targetFullPath string, bindType int32) (int32, error)
	DeleteBindMount(ctx context.Context, storageId int32, targetFullPath string) (int32, error)
	MakeDirectory(ctx context.Context, storageId int32, path string) (int32, error)
	MakeDirectories(ctx context.Context, storageId int32, path string) (int32, error)
	MakeFile(ctx context.Context, storageId int32, path string, mode int32, params IncrementalNewFileParams, content []byte) (int32, error)
	MakeFileFromRange(ctx context.Context, storageId int32, targetPath string, sourcePath string, start int64, end int64) (int32, error)
	MakeLink(ctx context.Context, sourceStorageId int32, sourcePath string, destStorageId int32, destPath string) (int32, error)
	Unlink(ctx context.Context, storageId int32, path string) (int32, error)
	IsFileFullyLoaded(ctx context.Context, storageId int32, path string) (int32, error)
	IsFullyLoaded(ctx context.Context, storageId int32) (int32, error)
	GetLoadingProgress(ctx context.Context, storageId int32) (float32, error)
	GetMetadataByPath(ctx context.Context, storageId int32, path string) ([]byte, error)
	GetMetadataById(ctx context.Context, storageId int32, fileId []byte) ([]byte, error)
	DeleteStorage(ctx context.Context, storageId int32) error
	DisallowReadLogs(ctx context.Context, storageId int32) error
	ConfigureNativeBinaries(ctx context.Context, storageId int32, apkFullPath string, libDirRelativePath string, abi string, extractNativeLibs bool) (bool, error)
	WaitForNativeBinariesExtraction(ctx context.Context, storageId int32) (bool, error)
	RegisterLoadingProgressListener(ctx context.Context, storageId int32, listener IStorageLoadingProgressListener) (bool, error)
	UnregisterLoadingProgressListener(ctx context.Context, storageId int32) (bool, error)
	GetMetrics(ctx context.Context, storageId int32) (os.PersistableBundle, error)
}

IIncrementalServiceServer is the server-side interface that user implementations provide to NewIncrementalServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IStorageHealthListener

type IStorageHealthListener interface {
	AsBinder() binder.IBinder
	OnHealthStatus(ctx context.Context, storageId int32, status int32) error
}

func NewStorageHealthListenerStub

func NewStorageHealthListenerStub(
	impl IStorageHealthListenerServer,
) IStorageHealthListener

NewStorageHealthListenerStub creates a server-side IStorageHealthListener wrapping the given server implementation. The returned value satisfies IStorageHealthListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IStorageHealthListenerServer

type IStorageHealthListenerServer interface {
	OnHealthStatus(ctx context.Context, storageId int32, status int32) error
}

IStorageHealthListenerServer is the server-side interface that user implementations provide to NewStorageHealthListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IStorageLoadingProgressListener

type IStorageLoadingProgressListener interface {
	AsBinder() binder.IBinder
	OnStorageLoadingProgressChanged(ctx context.Context, storageId int32, progress float32) error
}

func NewStorageLoadingProgressListenerStub

func NewStorageLoadingProgressListenerStub(
	impl IStorageLoadingProgressListenerServer,
) IStorageLoadingProgressListener

NewStorageLoadingProgressListenerStub creates a server-side IStorageLoadingProgressListener wrapping the given server implementation. The returned value satisfies IStorageLoadingProgressListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IStorageLoadingProgressListenerServer

type IStorageLoadingProgressListenerServer interface {
	OnStorageLoadingProgressChanged(ctx context.Context, storageId int32, progress float32) error
}

IStorageLoadingProgressListenerServer is the server-side interface that user implementations provide to NewStorageLoadingProgressListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IncrementalFileSystemControlParcel

type IncrementalFileSystemControlParcel struct {
	Cmd           int32
	PendingReads  int32
	Log           int32
	BlocksWritten int32
}

func (*IncrementalFileSystemControlParcel) MarshalParcel

func (s *IncrementalFileSystemControlParcel) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IncrementalFileSystemControlParcel) UnmarshalParcel

func (s *IncrementalFileSystemControlParcel) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IncrementalNewFileParams

type IncrementalNewFileParams struct {
	Size      int64
	FileId    []byte
	Metadata  []byte
	Signature []byte
}

func (*IncrementalNewFileParams) MarshalParcel

func (s *IncrementalNewFileParams) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IncrementalNewFileParams) UnmarshalParcel

func (s *IncrementalNewFileParams) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IncrementalServiceConnectorProxy

type IncrementalServiceConnectorProxy struct {
	Remote binder.IBinder
}

func NewIncrementalServiceConnectorProxy

func NewIncrementalServiceConnectorProxy(
	remote binder.IBinder,
) *IncrementalServiceConnectorProxy

func (*IncrementalServiceConnectorProxy) AsBinder

func (*IncrementalServiceConnectorProxy) SetStorageParams

func (p *IncrementalServiceConnectorProxy) SetStorageParams(
	ctx context.Context,
	enableReadLogs bool,
) (int32, error)

type IncrementalServiceConnectorStub

type IncrementalServiceConnectorStub struct {
	Impl      IIncrementalServiceConnector
	Transport binder.VersionAwareTransport
}

IncrementalServiceConnectorStub dispatches incoming binder transactions to a typed IIncrementalServiceConnector implementation.

func (*IncrementalServiceConnectorStub) Descriptor

func (s *IncrementalServiceConnectorStub) Descriptor() string

func (*IncrementalServiceConnectorStub) OnTransaction

type IncrementalServiceProxy

type IncrementalServiceProxy struct {
	Remote binder.IBinder
}

func GetIncrementalService

func GetIncrementalService(
	ctx context.Context,
	sm *servicemanager.ServiceManager,
) (*IncrementalServiceProxy, error)

GetIncrementalService retrieves the IncrementalService service and returns a typed proxy.

func NewIncrementalServiceProxy

func NewIncrementalServiceProxy(
	remote binder.IBinder,
) *IncrementalServiceProxy

func (*IncrementalServiceProxy) AsBinder

func (p *IncrementalServiceProxy) AsBinder() binder.IBinder

func (*IncrementalServiceProxy) ConfigureNativeBinaries

func (p *IncrementalServiceProxy) ConfigureNativeBinaries(
	ctx context.Context,
	storageId int32,
	apkFullPath string,
	libDirRelativePath string,
	abi string,
	extractNativeLibs bool,
) (bool, error)

func (*IncrementalServiceProxy) CreateLinkedStorage

func (p *IncrementalServiceProxy) CreateLinkedStorage(
	ctx context.Context,
	path string,
	otherStorageId int32,
	createMode int32,
) (int32, error)

func (*IncrementalServiceProxy) CreateStorage

func (p *IncrementalServiceProxy) CreateStorage(
	ctx context.Context,
	path string,
	params types.DataLoaderParamsParcel,
	createMode int32,
) (int32, error)

func (*IncrementalServiceProxy) DeleteBindMount

func (p *IncrementalServiceProxy) DeleteBindMount(
	ctx context.Context,
	storageId int32,
	targetFullPath string,
) (int32, error)

func (*IncrementalServiceProxy) DeleteStorage

func (p *IncrementalServiceProxy) DeleteStorage(
	ctx context.Context,
	storageId int32,
) error

func (*IncrementalServiceProxy) DisallowReadLogs

func (p *IncrementalServiceProxy) DisallowReadLogs(
	ctx context.Context,
	storageId int32,
) error

func (*IncrementalServiceProxy) GetLoadingProgress

func (p *IncrementalServiceProxy) GetLoadingProgress(
	ctx context.Context,
	storageId int32,
) (float32, error)

func (*IncrementalServiceProxy) GetMetadataById

func (p *IncrementalServiceProxy) GetMetadataById(
	ctx context.Context,
	storageId int32,
	fileId []byte,
) ([]byte, error)

func (*IncrementalServiceProxy) GetMetadataByPath

func (p *IncrementalServiceProxy) GetMetadataByPath(
	ctx context.Context,
	storageId int32,
	path string,
) ([]byte, error)

func (*IncrementalServiceProxy) GetMetrics

func (p *IncrementalServiceProxy) GetMetrics(
	ctx context.Context,
	storageId int32,
) (os.PersistableBundle, error)

func (*IncrementalServiceProxy) IsFileFullyLoaded

func (p *IncrementalServiceProxy) IsFileFullyLoaded(
	ctx context.Context,
	storageId int32,
	path string,
) (int32, error)

func (*IncrementalServiceProxy) IsFullyLoaded

func (p *IncrementalServiceProxy) IsFullyLoaded(
	ctx context.Context,
	storageId int32,
) (int32, error)

func (*IncrementalServiceProxy) MakeBindMount

func (p *IncrementalServiceProxy) MakeBindMount(
	ctx context.Context,
	storageId int32,
	sourcePath string,
	targetFullPath string,
	bindType int32,
) (int32, error)

func (*IncrementalServiceProxy) MakeDirectories

func (p *IncrementalServiceProxy) MakeDirectories(
	ctx context.Context,
	storageId int32,
	path string,
) (int32, error)

func (*IncrementalServiceProxy) MakeDirectory

func (p *IncrementalServiceProxy) MakeDirectory(
	ctx context.Context,
	storageId int32,
	path string,
) (int32, error)

func (*IncrementalServiceProxy) MakeFile

func (p *IncrementalServiceProxy) MakeFile(
	ctx context.Context,
	storageId int32,
	path string,
	mode int32,
	params IncrementalNewFileParams,
	content []byte,
) (int32, error)

func (*IncrementalServiceProxy) MakeFileFromRange

func (p *IncrementalServiceProxy) MakeFileFromRange(
	ctx context.Context,
	storageId int32,
	targetPath string,
	sourcePath string,
	start int64,
	end int64,
) (int32, error)
func (p *IncrementalServiceProxy) MakeLink(
	ctx context.Context,
	sourceStorageId int32,
	sourcePath string,
	destStorageId int32,
	destPath string,
) (int32, error)

func (*IncrementalServiceProxy) OnInstallationComplete

func (p *IncrementalServiceProxy) OnInstallationComplete(
	ctx context.Context,
	storageId int32,
) error

func (*IncrementalServiceProxy) OpenStorage

func (p *IncrementalServiceProxy) OpenStorage(
	ctx context.Context,
	path string,
) (int32, error)

func (*IncrementalServiceProxy) RegisterLoadingProgressListener

func (p *IncrementalServiceProxy) RegisterLoadingProgressListener(
	ctx context.Context,
	storageId int32,
	listener IStorageLoadingProgressListener,
) (bool, error)

func (*IncrementalServiceProxy) StartLoading

func (p *IncrementalServiceProxy) StartLoading(
	ctx context.Context,
	storageId int32,
	params types.DataLoaderParamsParcel,
	statusListener types.IDataLoaderStatusListener,
	healthCheckParams StorageHealthCheckParams,
	healthListener IStorageHealthListener,
	perUidReadTimeouts []PerUidReadTimeouts,
) (bool, error)
func (p *IncrementalServiceProxy) Unlink(
	ctx context.Context,
	storageId int32,
	path string,
) (int32, error)

func (*IncrementalServiceProxy) UnregisterLoadingProgressListener

func (p *IncrementalServiceProxy) UnregisterLoadingProgressListener(
	ctx context.Context,
	storageId int32,
) (bool, error)

func (*IncrementalServiceProxy) WaitForNativeBinariesExtraction

func (p *IncrementalServiceProxy) WaitForNativeBinariesExtraction(
	ctx context.Context,
	storageId int32,
) (bool, error)

type IncrementalServiceStub

type IncrementalServiceStub struct {
	Impl      IIncrementalService
	Transport binder.VersionAwareTransport
}

IncrementalServiceStub dispatches incoming binder transactions to a typed IIncrementalService implementation.

func (*IncrementalServiceStub) Descriptor

func (s *IncrementalServiceStub) Descriptor() string

func (*IncrementalServiceStub) OnTransaction

func (s *IncrementalServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type PerUidReadTimeouts

type PerUidReadTimeouts struct {
	Uid              int32
	MinTimeUs        int64
	MinPendingTimeUs int64
	MaxPendingTimeUs int64
}

func (*PerUidReadTimeouts) MarshalParcel

func (s *PerUidReadTimeouts) MarshalParcel(
	p *parcel.Parcel,
) error

func (*PerUidReadTimeouts) UnmarshalParcel

func (s *PerUidReadTimeouts) UnmarshalParcel(
	p *parcel.Parcel,
) error

type StorageHealthCheckParams

type StorageHealthCheckParams struct {
	BlockedTimeoutMs      int32
	UnhealthyTimeoutMs    int32
	UnhealthyMonitoringMs int32
}

func (*StorageHealthCheckParams) MarshalParcel

func (s *StorageHealthCheckParams) MarshalParcel(
	p *parcel.Parcel,
) error

func (*StorageHealthCheckParams) UnmarshalParcel

func (s *StorageHealthCheckParams) UnmarshalParcel(
	p *parcel.Parcel,
) error

type StorageHealthListenerProxy

type StorageHealthListenerProxy struct {
	Remote binder.IBinder
}

func NewStorageHealthListenerProxy

func NewStorageHealthListenerProxy(
	remote binder.IBinder,
) *StorageHealthListenerProxy

func (*StorageHealthListenerProxy) AsBinder

func (*StorageHealthListenerProxy) OnHealthStatus

func (p *StorageHealthListenerProxy) OnHealthStatus(
	ctx context.Context,
	storageId int32,
	status int32,
) error

type StorageHealthListenerStub

type StorageHealthListenerStub struct {
	Impl      IStorageHealthListener
	Transport binder.VersionAwareTransport
}

StorageHealthListenerStub dispatches incoming binder transactions to a typed IStorageHealthListener implementation.

func (*StorageHealthListenerStub) Descriptor

func (s *StorageHealthListenerStub) Descriptor() string

func (*StorageHealthListenerStub) OnTransaction

func (s *StorageHealthListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type StorageLoadingProgressListenerProxy

type StorageLoadingProgressListenerProxy struct {
	Remote binder.IBinder
}

func NewStorageLoadingProgressListenerProxy

func NewStorageLoadingProgressListenerProxy(
	remote binder.IBinder,
) *StorageLoadingProgressListenerProxy

func (*StorageLoadingProgressListenerProxy) AsBinder

func (*StorageLoadingProgressListenerProxy) OnStorageLoadingProgressChanged

func (p *StorageLoadingProgressListenerProxy) OnStorageLoadingProgressChanged(
	ctx context.Context,
	storageId int32,
	progress float32,
) error

type StorageLoadingProgressListenerStub

type StorageLoadingProgressListenerStub struct {
	Impl      IStorageLoadingProgressListener
	Transport binder.VersionAwareTransport
}

StorageLoadingProgressListenerStub dispatches incoming binder transactions to a typed IStorageLoadingProgressListener implementation.

func (*StorageLoadingProgressListenerStub) Descriptor

func (*StorageLoadingProgressListenerStub) OnTransaction

Jump to