omapi

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	TransactionISecureElementChannelClose             = binder.FirstCallTransaction + 0
	TransactionISecureElementChannelIsClosed          = binder.FirstCallTransaction + 1
	TransactionISecureElementChannelIsBasicChannel    = binder.FirstCallTransaction + 2
	TransactionISecureElementChannelGetSelectResponse = binder.FirstCallTransaction + 3
	TransactionISecureElementChannelTransmit          = binder.FirstCallTransaction + 4
	TransactionISecureElementChannelSelectNext        = binder.FirstCallTransaction + 5
)
const (
	MethodISecureElementChannelClose             = "close"
	MethodISecureElementChannelIsClosed          = "isClosed"
	MethodISecureElementChannelIsBasicChannel    = "isBasicChannel"
	MethodISecureElementChannelGetSelectResponse = "getSelectResponse"
	MethodISecureElementChannelTransmit          = "transmit"
	MethodISecureElementChannelSelectNext        = "selectNext"
)
const (
	TransactionISecureElementReaderIsSecureElementPresent = binder.FirstCallTransaction + 0
	TransactionISecureElementReaderOpenSession            = binder.FirstCallTransaction + 1
	TransactionISecureElementReaderCloseSessions          = binder.FirstCallTransaction + 2
	TransactionISecureElementReaderReset                  = binder.FirstCallTransaction + 3
)
const (
	MethodISecureElementReaderIsSecureElementPresent = "isSecureElementPresent"
	MethodISecureElementReaderOpenSession            = "openSession"
	MethodISecureElementReaderCloseSessions          = "closeSessions"
	MethodISecureElementReaderReset                  = "reset"
)
const (
	TransactionISecureElementServiceGetReaders        = binder.FirstCallTransaction + 0
	TransactionISecureElementServiceGetReader         = binder.FirstCallTransaction + 1
	TransactionISecureElementServiceIsNfcEventAllowed = binder.FirstCallTransaction + 2
)
const (
	MethodISecureElementServiceGetReaders        = "getReaders"
	MethodISecureElementServiceGetReader         = "getReader"
	MethodISecureElementServiceIsNfcEventAllowed = "isNfcEventAllowed"
)
const (
	TransactionISecureElementSessionGetAtr             = binder.FirstCallTransaction + 0
	TransactionISecureElementSessionClose              = binder.FirstCallTransaction + 1
	TransactionISecureElementSessionCloseChannels      = binder.FirstCallTransaction + 2
	TransactionISecureElementSessionIsClosed           = binder.FirstCallTransaction + 3
	TransactionISecureElementSessionOpenBasicChannel   = binder.FirstCallTransaction + 4
	TransactionISecureElementSessionOpenLogicalChannel = binder.FirstCallTransaction + 5
)
const (
	MethodISecureElementSessionGetAtr             = "getAtr"
	MethodISecureElementSessionClose              = "close"
	MethodISecureElementSessionCloseChannels      = "closeChannels"
	MethodISecureElementSessionIsClosed           = "isClosed"
	MethodISecureElementSessionOpenBasicChannel   = "openBasicChannel"
	MethodISecureElementSessionOpenLogicalChannel = "openLogicalChannel"
)
const DescriptorISecureElementChannel = "android.se.omapi.ISecureElementChannel"
const DescriptorISecureElementListener = "android.se.omapi.ISecureElementListener"
const DescriptorISecureElementReader = "android.se.omapi.ISecureElementReader"
const DescriptorISecureElementService = "android.se.omapi.ISecureElementService"
const DescriptorISecureElementSession = "android.se.omapi.ISecureElementSession"

Variables

This section is empty.

Functions

This section is empty.

Types

type ISecureElementChannel

type ISecureElementChannel interface {
	AsBinder() binder.IBinder
	Close(ctx context.Context) error
	IsClosed(ctx context.Context) (bool, error)
	IsBasicChannel(ctx context.Context) (bool, error)
	GetSelectResponse(ctx context.Context) ([]byte, error)
	Transmit(ctx context.Context, command []byte) ([]byte, error)
	SelectNext(ctx context.Context) (bool, error)
}

func NewSecureElementChannelStub

func NewSecureElementChannelStub(
	impl ISecureElementChannelServer,
) ISecureElementChannel

NewSecureElementChannelStub creates a server-side ISecureElementChannel wrapping the given server implementation. The returned value satisfies ISecureElementChannel and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISecureElementChannelServer

type ISecureElementChannelServer interface {
	Close(ctx context.Context) error
	IsClosed(ctx context.Context) (bool, error)
	IsBasicChannel(ctx context.Context) (bool, error)
	GetSelectResponse(ctx context.Context) ([]byte, error)
	Transmit(ctx context.Context, command []byte) ([]byte, error)
	SelectNext(ctx context.Context) (bool, error)
}

ISecureElementChannelServer is the server-side interface that user implementations provide to NewSecureElementChannelStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISecureElementListener

type ISecureElementListener interface {
	AsBinder() binder.IBinder
}

func NewSecureElementListenerStub

func NewSecureElementListenerStub(
	impl ISecureElementListenerServer,
) ISecureElementListener

NewSecureElementListenerStub creates a server-side ISecureElementListener wrapping the given server implementation. The returned value satisfies ISecureElementListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISecureElementListenerServer

type ISecureElementListenerServer interface {
}

ISecureElementListenerServer is the server-side interface that user implementations provide to NewSecureElementListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISecureElementReader

type ISecureElementReader interface {
	AsBinder() binder.IBinder
	IsSecureElementPresent(ctx context.Context) (bool, error)
	OpenSession(ctx context.Context) (ISecureElementSession, error)
	CloseSessions(ctx context.Context) error
	Reset(ctx context.Context) (bool, error)
}

func NewSecureElementReaderStub

func NewSecureElementReaderStub(
	impl ISecureElementReaderServer,
) ISecureElementReader

NewSecureElementReaderStub creates a server-side ISecureElementReader wrapping the given server implementation. The returned value satisfies ISecureElementReader and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISecureElementReaderServer

type ISecureElementReaderServer interface {
	IsSecureElementPresent(ctx context.Context) (bool, error)
	OpenSession(ctx context.Context) (ISecureElementSession, error)
	CloseSessions(ctx context.Context) error
	Reset(ctx context.Context) (bool, error)
}

ISecureElementReaderServer is the server-side interface that user implementations provide to NewSecureElementReaderStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISecureElementService

type ISecureElementService interface {
	AsBinder() binder.IBinder
	GetReaders(ctx context.Context) ([]string, error)
	GetReader(ctx context.Context, reader string) (ISecureElementReader, error)
	IsNfcEventAllowed(ctx context.Context, reader string, aid []byte, packageNames []string) ([]bool, error)
}

func NewSecureElementServiceStub

func NewSecureElementServiceStub(
	impl ISecureElementServiceServer,
) ISecureElementService

NewSecureElementServiceStub creates a server-side ISecureElementService wrapping the given server implementation. The returned value satisfies ISecureElementService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISecureElementServiceServer

type ISecureElementServiceServer interface {
	GetReaders(ctx context.Context) ([]string, error)
	GetReader(ctx context.Context, reader string) (ISecureElementReader, error)
	IsNfcEventAllowed(ctx context.Context, reader string, aid []byte, packageNames []string) ([]bool, error)
}

ISecureElementServiceServer is the server-side interface that user implementations provide to NewSecureElementServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISecureElementSession

type ISecureElementSession interface {
	AsBinder() binder.IBinder
	GetAtr(ctx context.Context) ([]byte, error)
	Close(ctx context.Context) error
	CloseChannels(ctx context.Context) error
	IsClosed(ctx context.Context) (bool, error)
	OpenBasicChannel(ctx context.Context, aid []byte, p2 byte, listener ISecureElementListener) (ISecureElementChannel, error)
	OpenLogicalChannel(ctx context.Context, aid []byte, p2 byte, listener ISecureElementListener) (ISecureElementChannel, error)
}

func NewSecureElementSessionStub

func NewSecureElementSessionStub(
	impl ISecureElementSessionServer,
) ISecureElementSession

NewSecureElementSessionStub creates a server-side ISecureElementSession wrapping the given server implementation. The returned value satisfies ISecureElementSession and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISecureElementSessionServer

type ISecureElementSessionServer interface {
	GetAtr(ctx context.Context) ([]byte, error)
	Close(ctx context.Context) error
	CloseChannels(ctx context.Context) error
	IsClosed(ctx context.Context) (bool, error)
	OpenBasicChannel(ctx context.Context, aid []byte, p2 byte, listener ISecureElementListener) (ISecureElementChannel, error)
	OpenLogicalChannel(ctx context.Context, aid []byte, p2 byte, listener ISecureElementListener) (ISecureElementChannel, error)
}

ISecureElementSessionServer is the server-side interface that user implementations provide to NewSecureElementSessionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type SecureElementChannelProxy

type SecureElementChannelProxy struct {
	Remote binder.IBinder
}

func NewSecureElementChannelProxy

func NewSecureElementChannelProxy(
	remote binder.IBinder,
) *SecureElementChannelProxy

func (*SecureElementChannelProxy) AsBinder

func (*SecureElementChannelProxy) Close

func (*SecureElementChannelProxy) GetSelectResponse

func (p *SecureElementChannelProxy) GetSelectResponse(
	ctx context.Context,
) ([]byte, error)

func (*SecureElementChannelProxy) IsBasicChannel

func (p *SecureElementChannelProxy) IsBasicChannel(
	ctx context.Context,
) (bool, error)

func (*SecureElementChannelProxy) IsClosed

func (p *SecureElementChannelProxy) IsClosed(
	ctx context.Context,
) (bool, error)

func (*SecureElementChannelProxy) SelectNext

func (p *SecureElementChannelProxy) SelectNext(
	ctx context.Context,
) (bool, error)

func (*SecureElementChannelProxy) Transmit

func (p *SecureElementChannelProxy) Transmit(
	ctx context.Context,
	command []byte,
) ([]byte, error)

type SecureElementChannelStub

type SecureElementChannelStub struct {
	Impl      ISecureElementChannel
	Transport binder.VersionAwareTransport
}

SecureElementChannelStub dispatches incoming binder transactions to a typed ISecureElementChannel implementation.

func (*SecureElementChannelStub) Descriptor

func (s *SecureElementChannelStub) Descriptor() string

func (*SecureElementChannelStub) OnTransaction

func (s *SecureElementChannelStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type SecureElementListenerProxy

type SecureElementListenerProxy struct {
	Remote binder.IBinder
}

func NewSecureElementListenerProxy

func NewSecureElementListenerProxy(
	remote binder.IBinder,
) *SecureElementListenerProxy

func (*SecureElementListenerProxy) AsBinder

type SecureElementListenerStub

type SecureElementListenerStub struct {
	Impl      ISecureElementListener
	Transport binder.VersionAwareTransport
}

SecureElementListenerStub dispatches incoming binder transactions to a typed ISecureElementListener implementation.

func (*SecureElementListenerStub) Descriptor

func (s *SecureElementListenerStub) Descriptor() string

func (*SecureElementListenerStub) OnTransaction

func (s *SecureElementListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type SecureElementReaderProxy

type SecureElementReaderProxy struct {
	Remote binder.IBinder
}

func NewSecureElementReaderProxy

func NewSecureElementReaderProxy(
	remote binder.IBinder,
) *SecureElementReaderProxy

func (*SecureElementReaderProxy) AsBinder

func (p *SecureElementReaderProxy) AsBinder() binder.IBinder

func (*SecureElementReaderProxy) CloseSessions

func (p *SecureElementReaderProxy) CloseSessions(
	ctx context.Context,
) error

func (*SecureElementReaderProxy) IsSecureElementPresent

func (p *SecureElementReaderProxy) IsSecureElementPresent(
	ctx context.Context,
) (bool, error)

func (*SecureElementReaderProxy) OpenSession

func (*SecureElementReaderProxy) Reset

func (p *SecureElementReaderProxy) Reset(
	ctx context.Context,
) (bool, error)

type SecureElementReaderStub

type SecureElementReaderStub struct {
	Impl      ISecureElementReader
	Transport binder.VersionAwareTransport
}

SecureElementReaderStub dispatches incoming binder transactions to a typed ISecureElementReader implementation.

func (*SecureElementReaderStub) Descriptor

func (s *SecureElementReaderStub) Descriptor() string

func (*SecureElementReaderStub) OnTransaction

func (s *SecureElementReaderStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type SecureElementServiceProxy

type SecureElementServiceProxy struct {
	Remote binder.IBinder
}

func NewSecureElementServiceProxy

func NewSecureElementServiceProxy(
	remote binder.IBinder,
) *SecureElementServiceProxy

func (*SecureElementServiceProxy) AsBinder

func (*SecureElementServiceProxy) GetReader

func (*SecureElementServiceProxy) GetReaders

func (p *SecureElementServiceProxy) GetReaders(
	ctx context.Context,
) ([]string, error)

func (*SecureElementServiceProxy) IsNfcEventAllowed

func (p *SecureElementServiceProxy) IsNfcEventAllowed(
	ctx context.Context,
	reader string,
	aid []byte,
	packageNames []string,
) ([]bool, error)

type SecureElementServiceStub

type SecureElementServiceStub struct {
	Impl      ISecureElementService
	Transport binder.VersionAwareTransport
}

SecureElementServiceStub dispatches incoming binder transactions to a typed ISecureElementService implementation.

func (*SecureElementServiceStub) Descriptor

func (s *SecureElementServiceStub) Descriptor() string

func (*SecureElementServiceStub) OnTransaction

func (s *SecureElementServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type SecureElementSessionProxy

type SecureElementSessionProxy struct {
	Remote binder.IBinder
}

func NewSecureElementSessionProxy

func NewSecureElementSessionProxy(
	remote binder.IBinder,
) *SecureElementSessionProxy

func (*SecureElementSessionProxy) AsBinder

func (*SecureElementSessionProxy) Close

func (*SecureElementSessionProxy) CloseChannels

func (p *SecureElementSessionProxy) CloseChannels(
	ctx context.Context,
) error

func (*SecureElementSessionProxy) GetAtr

func (p *SecureElementSessionProxy) GetAtr(
	ctx context.Context,
) ([]byte, error)

func (*SecureElementSessionProxy) IsClosed

func (p *SecureElementSessionProxy) IsClosed(
	ctx context.Context,
) (bool, error)

func (*SecureElementSessionProxy) OpenBasicChannel

func (p *SecureElementSessionProxy) OpenBasicChannel(
	ctx context.Context,
	aid []byte,
	p2 byte,
	listener ISecureElementListener,
) (ISecureElementChannel, error)

func (*SecureElementSessionProxy) OpenLogicalChannel

func (p *SecureElementSessionProxy) OpenLogicalChannel(
	ctx context.Context,
	aid []byte,
	p2 byte,
	listener ISecureElementListener,
) (ISecureElementChannel, error)

type SecureElementSessionStub

type SecureElementSessionStub struct {
	Impl      ISecureElementSession
	Transport binder.VersionAwareTransport
}

SecureElementSessionStub dispatches incoming binder transactions to a typed ISecureElementSession implementation.

func (*SecureElementSessionStub) Descriptor

func (s *SecureElementSessionStub) Descriptor() string

func (*SecureElementSessionStub) OnTransaction

func (s *SecureElementSessionStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to