rkp

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIGetKeyCallbackOnSuccess = binder.FirstCallTransaction + 0
	TransactionIGetKeyCallbackOnCancel  = binder.FirstCallTransaction + 1
	TransactionIGetKeyCallbackOnError   = binder.FirstCallTransaction + 2
)
const (
	MethodIGetKeyCallbackOnSuccess = "onSuccess"
	MethodIGetKeyCallbackOnCancel  = "onCancel"
	MethodIGetKeyCallbackOnError   = "onError"
)
const (
	TransactionIGetRegistrationCallbackOnSuccess = binder.FirstCallTransaction + 0
	TransactionIGetRegistrationCallbackOnCancel  = binder.FirstCallTransaction + 1
	TransactionIGetRegistrationCallbackOnError   = binder.FirstCallTransaction + 2
)
const (
	MethodIGetRegistrationCallbackOnSuccess = "onSuccess"
	MethodIGetRegistrationCallbackOnCancel  = "onCancel"
	MethodIGetRegistrationCallbackOnError   = "onError"
)
const (
	TransactionIRegistrationGetKey                = binder.FirstCallTransaction + 0
	TransactionIRegistrationCancelGetKey          = binder.FirstCallTransaction + 1
	TransactionIRegistrationStoreUpgradedKeyAsync = binder.FirstCallTransaction + 2
)
const (
	MethodIRegistrationGetKey                = "getKey"
	MethodIRegistrationCancelGetKey          = "cancelGetKey"
	MethodIRegistrationStoreUpgradedKeyAsync = "storeUpgradedKeyAsync"
)
const (
	TransactionIStoreUpgradedKeyCallbackOnSuccess = binder.FirstCallTransaction + 0
	TransactionIStoreUpgradedKeyCallbackOnError   = binder.FirstCallTransaction + 1
)
const (
	MethodIStoreUpgradedKeyCallbackOnSuccess = "onSuccess"
	MethodIStoreUpgradedKeyCallbackOnError   = "onError"
)
const DescriptorIGetKeyCallback = "android.security.rkp.IGetKeyCallback"
const DescriptorIGetRegistrationCallback = "android.security.rkp.IGetRegistrationCallback"
const DescriptorIRegistration = "android.security.rkp.IRegistration"
const DescriptorIRemoteProvisioning = "android.security.rkp.IRemoteProvisioning"
const DescriptorIStoreUpgradedKeyCallback = "android.security.rkp.IStoreUpgradedKeyCallback"
const (
	MethodIRemoteProvisioningGetRegistration = "getRegistration"
)
const (
	TransactionIRemoteProvisioningGetRegistration = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type GetKeyCallbackProxy

type GetKeyCallbackProxy struct {
	Remote binder.IBinder
}

func NewGetKeyCallbackProxy

func NewGetKeyCallbackProxy(
	remote binder.IBinder,
) *GetKeyCallbackProxy

func (*GetKeyCallbackProxy) AsBinder

func (p *GetKeyCallbackProxy) AsBinder() binder.IBinder

func (*GetKeyCallbackProxy) OnCancel

func (p *GetKeyCallbackProxy) OnCancel(
	ctx context.Context,
) error

func (*GetKeyCallbackProxy) OnError

func (p *GetKeyCallbackProxy) OnError(
	ctx context.Context,
	error_ IGetKeyCallbackErrorCode,
	description string,
) error

func (*GetKeyCallbackProxy) OnSuccess

type GetKeyCallbackStub

type GetKeyCallbackStub struct {
	Impl      IGetKeyCallback
	Transport binder.VersionAwareTransport
}

GetKeyCallbackStub dispatches incoming binder transactions to a typed IGetKeyCallback implementation.

func (*GetKeyCallbackStub) Descriptor

func (s *GetKeyCallbackStub) Descriptor() string

func (*GetKeyCallbackStub) OnTransaction

func (s *GetKeyCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type GetRegistrationCallbackProxy

type GetRegistrationCallbackProxy struct {
	Remote binder.IBinder
}

func NewGetRegistrationCallbackProxy

func NewGetRegistrationCallbackProxy(
	remote binder.IBinder,
) *GetRegistrationCallbackProxy

func (*GetRegistrationCallbackProxy) AsBinder

func (*GetRegistrationCallbackProxy) OnCancel

func (p *GetRegistrationCallbackProxy) OnCancel(
	ctx context.Context,
) error

func (*GetRegistrationCallbackProxy) OnError

func (p *GetRegistrationCallbackProxy) OnError(
	ctx context.Context,
	error_ string,
) error

func (*GetRegistrationCallbackProxy) OnSuccess

func (p *GetRegistrationCallbackProxy) OnSuccess(
	ctx context.Context,
	registration IRegistration,
) error

type GetRegistrationCallbackStub

type GetRegistrationCallbackStub struct {
	Impl      IGetRegistrationCallback
	Transport binder.VersionAwareTransport
}

GetRegistrationCallbackStub dispatches incoming binder transactions to a typed IGetRegistrationCallback implementation.

func (*GetRegistrationCallbackStub) Descriptor

func (s *GetRegistrationCallbackStub) Descriptor() string

func (*GetRegistrationCallbackStub) OnTransaction

func (s *GetRegistrationCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IGetKeyCallback

type IGetKeyCallback interface {
	AsBinder() binder.IBinder
	OnSuccess(ctx context.Context, key RemotelyProvisionedKey) error
	OnCancel(ctx context.Context) error
	OnError(ctx context.Context, error_ IGetKeyCallbackErrorCode, description string) error
}

func NewGetKeyCallbackStub

func NewGetKeyCallbackStub(
	impl IGetKeyCallbackServer,
) IGetKeyCallback

NewGetKeyCallbackStub creates a server-side IGetKeyCallback wrapping the given server implementation. The returned value satisfies IGetKeyCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGetKeyCallbackErrorCode

type IGetKeyCallbackErrorCode int32
const (
	IGetKeyCallbackErrorCodeErrorUnknown                     IGetKeyCallbackErrorCode = 1
	IGetKeyCallbackErrorCodeErrorRequiresSecurityPatch       IGetKeyCallbackErrorCode = 2
	IGetKeyCallbackErrorCodeErrorPendingInternetConnectivity IGetKeyCallbackErrorCode = 3
	IGetKeyCallbackErrorCodeErrorPermanent                   IGetKeyCallbackErrorCode = 5
)

type IGetKeyCallbackServer

type IGetKeyCallbackServer interface {
	OnSuccess(ctx context.Context, key RemotelyProvisionedKey) error
	OnCancel(ctx context.Context) error
	OnError(ctx context.Context, error_ IGetKeyCallbackErrorCode, description string) error
}

IGetKeyCallbackServer is the server-side interface that user implementations provide to NewGetKeyCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGetRegistrationCallback

type IGetRegistrationCallback interface {
	AsBinder() binder.IBinder
	OnSuccess(ctx context.Context, registration IRegistration) error
	OnCancel(ctx context.Context) error
	OnError(ctx context.Context, error_ string) error
}

func NewGetRegistrationCallbackStub

func NewGetRegistrationCallbackStub(
	impl IGetRegistrationCallbackServer,
) IGetRegistrationCallback

NewGetRegistrationCallbackStub creates a server-side IGetRegistrationCallback wrapping the given server implementation. The returned value satisfies IGetRegistrationCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGetRegistrationCallbackServer

type IGetRegistrationCallbackServer interface {
	OnSuccess(ctx context.Context, registration IRegistration) error
	OnCancel(ctx context.Context) error
	OnError(ctx context.Context, error_ string) error
}

IGetRegistrationCallbackServer is the server-side interface that user implementations provide to NewGetRegistrationCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IRegistration

type IRegistration interface {
	AsBinder() binder.IBinder
	GetKey(ctx context.Context, keyId int32, callback IGetKeyCallback) error
	CancelGetKey(ctx context.Context, callback IGetKeyCallback) error
	StoreUpgradedKeyAsync(ctx context.Context, oldKeyBlob []byte, newKeyBlob []byte, callback IStoreUpgradedKeyCallback) error
}

func NewRegistrationStub

func NewRegistrationStub(
	impl IRegistrationServer,
) IRegistration

NewRegistrationStub creates a server-side IRegistration wrapping the given server implementation. The returned value satisfies IRegistration and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IRegistrationServer

type IRegistrationServer interface {
	GetKey(ctx context.Context, keyId int32, callback IGetKeyCallback) error
	CancelGetKey(ctx context.Context, callback IGetKeyCallback) error
	StoreUpgradedKeyAsync(ctx context.Context, oldKeyBlob []byte, newKeyBlob []byte, callback IStoreUpgradedKeyCallback) error
}

IRegistrationServer is the server-side interface that user implementations provide to NewRegistrationStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IRemoteProvisioning

type IRemoteProvisioning interface {
	AsBinder() binder.IBinder
	GetRegistration(ctx context.Context, irpcName string, callback IGetRegistrationCallback) error
}

func NewRemoteProvisioningStub

func NewRemoteProvisioningStub(
	impl IRemoteProvisioningServer,
) IRemoteProvisioning

NewRemoteProvisioningStub creates a server-side IRemoteProvisioning wrapping the given server implementation. The returned value satisfies IRemoteProvisioning and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IRemoteProvisioningServer

type IRemoteProvisioningServer interface {
	GetRegistration(ctx context.Context, irpcName string, callback IGetRegistrationCallback) error
}

IRemoteProvisioningServer is the server-side interface that user implementations provide to NewRemoteProvisioningStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IStoreUpgradedKeyCallback

type IStoreUpgradedKeyCallback interface {
	AsBinder() binder.IBinder
	OnSuccess(ctx context.Context) error
	OnError(ctx context.Context, error_ string) error
}

func NewStoreUpgradedKeyCallbackStub

func NewStoreUpgradedKeyCallbackStub(
	impl IStoreUpgradedKeyCallbackServer,
) IStoreUpgradedKeyCallback

NewStoreUpgradedKeyCallbackStub creates a server-side IStoreUpgradedKeyCallback wrapping the given server implementation. The returned value satisfies IStoreUpgradedKeyCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IStoreUpgradedKeyCallbackServer

type IStoreUpgradedKeyCallbackServer interface {
	OnSuccess(ctx context.Context) error
	OnError(ctx context.Context, error_ string) error
}

IStoreUpgradedKeyCallbackServer is the server-side interface that user implementations provide to NewStoreUpgradedKeyCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type RegistrationProxy

type RegistrationProxy struct {
	Remote binder.IBinder
}

func NewRegistrationProxy

func NewRegistrationProxy(
	remote binder.IBinder,
) *RegistrationProxy

func (*RegistrationProxy) AsBinder

func (p *RegistrationProxy) AsBinder() binder.IBinder

func (*RegistrationProxy) CancelGetKey

func (p *RegistrationProxy) CancelGetKey(
	ctx context.Context,
	callback IGetKeyCallback,
) error

func (*RegistrationProxy) GetKey

func (p *RegistrationProxy) GetKey(
	ctx context.Context,
	keyId int32,
	callback IGetKeyCallback,
) error

func (*RegistrationProxy) StoreUpgradedKeyAsync

func (p *RegistrationProxy) StoreUpgradedKeyAsync(
	ctx context.Context,
	oldKeyBlob []byte,
	newKeyBlob []byte,
	callback IStoreUpgradedKeyCallback,
) error

type RegistrationStub

type RegistrationStub struct {
	Impl      IRegistration
	Transport binder.VersionAwareTransport
}

RegistrationStub dispatches incoming binder transactions to a typed IRegistration implementation.

func (*RegistrationStub) Descriptor

func (s *RegistrationStub) Descriptor() string

func (*RegistrationStub) OnTransaction

func (s *RegistrationStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type RemoteProvisioningProxy

type RemoteProvisioningProxy struct {
	Remote binder.IBinder
}

func NewRemoteProvisioningProxy

func NewRemoteProvisioningProxy(
	remote binder.IBinder,
) *RemoteProvisioningProxy

func (*RemoteProvisioningProxy) AsBinder

func (p *RemoteProvisioningProxy) AsBinder() binder.IBinder

func (*RemoteProvisioningProxy) GetRegistration

func (p *RemoteProvisioningProxy) GetRegistration(
	ctx context.Context,
	irpcName string,
	callback IGetRegistrationCallback,
) error

type RemoteProvisioningStub

type RemoteProvisioningStub struct {
	Impl      IRemoteProvisioning
	Transport binder.VersionAwareTransport
}

RemoteProvisioningStub dispatches incoming binder transactions to a typed IRemoteProvisioning implementation.

func (*RemoteProvisioningStub) Descriptor

func (s *RemoteProvisioningStub) Descriptor() string

func (*RemoteProvisioningStub) OnTransaction

func (s *RemoteProvisioningStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type RemotelyProvisionedKey

type RemotelyProvisionedKey struct {
	KeyBlob          []byte
	EncodedCertChain []byte
}

func (*RemotelyProvisionedKey) MarshalParcel

func (s *RemotelyProvisionedKey) MarshalParcel(
	p *parcel.Parcel,
) error

func (*RemotelyProvisionedKey) UnmarshalParcel

func (s *RemotelyProvisionedKey) UnmarshalParcel(
	p *parcel.Parcel,
) error

type StoreUpgradedKeyCallbackProxy

type StoreUpgradedKeyCallbackProxy struct {
	Remote binder.IBinder
}

func NewStoreUpgradedKeyCallbackProxy

func NewStoreUpgradedKeyCallbackProxy(
	remote binder.IBinder,
) *StoreUpgradedKeyCallbackProxy

func (*StoreUpgradedKeyCallbackProxy) AsBinder

func (*StoreUpgradedKeyCallbackProxy) OnError

func (p *StoreUpgradedKeyCallbackProxy) OnError(
	ctx context.Context,
	error_ string,
) error

func (*StoreUpgradedKeyCallbackProxy) OnSuccess

func (p *StoreUpgradedKeyCallbackProxy) OnSuccess(
	ctx context.Context,
) error

type StoreUpgradedKeyCallbackStub

type StoreUpgradedKeyCallbackStub struct {
	Impl      IStoreUpgradedKeyCallback
	Transport binder.VersionAwareTransport
}

StoreUpgradedKeyCallbackStub dispatches incoming binder transactions to a typed IStoreUpgradedKeyCallback implementation.

func (*StoreUpgradedKeyCallbackStub) Descriptor

func (s *StoreUpgradedKeyCallbackStub) Descriptor() string

func (*StoreUpgradedKeyCallbackStub) OnTransaction

Jump to