classification

package
v0.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 28, 2026 License: CC0-1.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIFieldClassificationCallbackOnCancellable = binder.FirstCallTransaction + 0
	TransactionIFieldClassificationCallbackOnSuccess     = binder.FirstCallTransaction + 1
	TransactionIFieldClassificationCallbackOnFailure     = binder.FirstCallTransaction + 2
	TransactionIFieldClassificationCallbackIsCompleted   = binder.FirstCallTransaction + 3
	TransactionIFieldClassificationCallbackCancel        = binder.FirstCallTransaction + 4
)
const (
	MethodIFieldClassificationCallbackOnCancellable = "onCancellable"
	MethodIFieldClassificationCallbackOnSuccess     = "onSuccess"
	MethodIFieldClassificationCallbackOnFailure     = "onFailure"
	MethodIFieldClassificationCallbackIsCompleted   = "isCompleted"
	MethodIFieldClassificationCallbackCancel        = "cancel"
)
const (
	TransactionIFieldClassificationServiceOnConnected                  = binder.FirstCallTransaction + 0
	TransactionIFieldClassificationServiceOnDisconnected               = binder.FirstCallTransaction + 1
	TransactionIFieldClassificationServiceOnFieldClassificationRequest = binder.FirstCallTransaction + 2
)
const (
	MethodIFieldClassificationServiceOnConnected                  = "onConnected"
	MethodIFieldClassificationServiceOnDisconnected               = "onDisconnected"
	MethodIFieldClassificationServiceOnFieldClassificationRequest = "onFieldClassificationRequest"
)
const DescriptorIFieldClassificationCallback = "android.service.assist.classification.IFieldClassificationCallback"
const DescriptorIFieldClassificationService = "android.service.assist.classification.IFieldClassificationService"

Variables

This section is empty.

Functions

This section is empty.

Types

type FieldClassification

type FieldClassification struct {
	AutofillId *autofill.AutofillId
}

func (*FieldClassification) MarshalParcel

func (s *FieldClassification) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FieldClassification) UnmarshalParcel

func (s *FieldClassification) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FieldClassificationCallbackProxy

type FieldClassificationCallbackProxy struct {
	Remote binder.IBinder
}

func NewFieldClassificationCallbackProxy

func NewFieldClassificationCallbackProxy(
	remote binder.IBinder,
) *FieldClassificationCallbackProxy

func (*FieldClassificationCallbackProxy) AsBinder

func (*FieldClassificationCallbackProxy) Cancel

func (*FieldClassificationCallbackProxy) IsCompleted

func (p *FieldClassificationCallbackProxy) IsCompleted(
	ctx context.Context,
) (bool, error)

func (*FieldClassificationCallbackProxy) OnCancellable

func (p *FieldClassificationCallbackProxy) OnCancellable(
	ctx context.Context,
	cancellation os.ICancellationSignal,
) error

func (*FieldClassificationCallbackProxy) OnFailure

func (*FieldClassificationCallbackProxy) OnSuccess

type FieldClassificationCallbackStub

type FieldClassificationCallbackStub struct {
	Impl      IFieldClassificationCallback
	Transport binder.VersionAwareTransport
}

FieldClassificationCallbackStub dispatches incoming binder transactions to a typed IFieldClassificationCallback implementation.

func (*FieldClassificationCallbackStub) Descriptor

func (s *FieldClassificationCallbackStub) Descriptor() string

func (*FieldClassificationCallbackStub) OnTransaction

type FieldClassificationRequest

type FieldClassificationRequest struct {
	AssistStructure *assist.AssistStructure
}

func (*FieldClassificationRequest) MarshalParcel

func (s *FieldClassificationRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FieldClassificationRequest) UnmarshalParcel

func (s *FieldClassificationRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FieldClassificationResponse

type FieldClassificationResponse struct {
}

func (*FieldClassificationResponse) MarshalParcel

func (s *FieldClassificationResponse) MarshalParcel(
	p *parcel.Parcel,
) error

func (*FieldClassificationResponse) UnmarshalParcel

func (s *FieldClassificationResponse) UnmarshalParcel(
	p *parcel.Parcel,
) error

type FieldClassificationServiceProxy

type FieldClassificationServiceProxy struct {
	Remote binder.IBinder
}

func NewFieldClassificationServiceProxy

func NewFieldClassificationServiceProxy(
	remote binder.IBinder,
) *FieldClassificationServiceProxy

func (*FieldClassificationServiceProxy) AsBinder

func (*FieldClassificationServiceProxy) OnConnected

func (p *FieldClassificationServiceProxy) OnConnected(
	ctx context.Context,
	debug bool,
	verbose bool,
) error

func (*FieldClassificationServiceProxy) OnDisconnected

func (p *FieldClassificationServiceProxy) OnDisconnected(
	ctx context.Context,
) error

func (*FieldClassificationServiceProxy) OnFieldClassificationRequest

func (p *FieldClassificationServiceProxy) OnFieldClassificationRequest(
	ctx context.Context,
	request FieldClassificationRequest,
	callback IFieldClassificationCallback,
) error

type FieldClassificationServiceStub

type FieldClassificationServiceStub struct {
	Impl      IFieldClassificationService
	Transport binder.VersionAwareTransport
}

FieldClassificationServiceStub dispatches incoming binder transactions to a typed IFieldClassificationService implementation.

func (*FieldClassificationServiceStub) Descriptor

func (s *FieldClassificationServiceStub) Descriptor() string

func (*FieldClassificationServiceStub) OnTransaction

type IFieldClassificationCallback

type IFieldClassificationCallback interface {
	AsBinder() binder.IBinder
	OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
	OnSuccess(ctx context.Context, response FieldClassificationResponse) error
	OnFailure(ctx context.Context) error
	IsCompleted(ctx context.Context) (bool, error)
	Cancel(ctx context.Context) error
}

func NewFieldClassificationCallbackStub

func NewFieldClassificationCallbackStub(
	impl IFieldClassificationCallbackServer,
) IFieldClassificationCallback

NewFieldClassificationCallbackStub creates a server-side IFieldClassificationCallback wrapping the given server implementation. The returned value satisfies IFieldClassificationCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IFieldClassificationCallbackServer

type IFieldClassificationCallbackServer interface {
	OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
	OnSuccess(ctx context.Context, response FieldClassificationResponse) error
	OnFailure(ctx context.Context) error
	IsCompleted(ctx context.Context) (bool, error)
	Cancel(ctx context.Context) error
}

IFieldClassificationCallbackServer is the server-side interface that user implementations provide to NewFieldClassificationCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IFieldClassificationService

type IFieldClassificationService interface {
	AsBinder() binder.IBinder
	OnConnected(ctx context.Context, debug bool, verbose bool) error
	OnDisconnected(ctx context.Context) error
	OnFieldClassificationRequest(ctx context.Context, request FieldClassificationRequest, callback IFieldClassificationCallback) error
}

func NewFieldClassificationServiceStub

func NewFieldClassificationServiceStub(
	impl IFieldClassificationServiceServer,
) IFieldClassificationService

NewFieldClassificationServiceStub creates a server-side IFieldClassificationService wrapping the given server implementation. The returned value satisfies IFieldClassificationService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IFieldClassificationServiceServer

type IFieldClassificationServiceServer interface {
	OnConnected(ctx context.Context, debug bool, verbose bool) error
	OnDisconnected(ctx context.Context) error
	OnFieldClassificationRequest(ctx context.Context, request FieldClassificationRequest, callback IFieldClassificationCallback) error
}

IFieldClassificationServiceServer is the server-side interface that user implementations provide to NewFieldClassificationServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

Jump to