carrier

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	TransactionICarrierMessagingCallbackOnFilterComplete           = binder.FirstCallTransaction + 0
	TransactionICarrierMessagingCallbackOnSendSmsComplete          = binder.FirstCallTransaction + 1
	TransactionICarrierMessagingCallbackOnSendMultipartSmsComplete = binder.FirstCallTransaction + 2
	TransactionICarrierMessagingCallbackOnSendMmsComplete          = binder.FirstCallTransaction + 3
	TransactionICarrierMessagingCallbackOnDownloadMmsComplete      = binder.FirstCallTransaction + 4
)
const (
	MethodICarrierMessagingCallbackOnFilterComplete           = "onFilterComplete"
	MethodICarrierMessagingCallbackOnSendSmsComplete          = "onSendSmsComplete"
	MethodICarrierMessagingCallbackOnSendMultipartSmsComplete = "onSendMultipartSmsComplete"
	MethodICarrierMessagingCallbackOnSendMmsComplete          = "onSendMmsComplete"
	MethodICarrierMessagingCallbackOnDownloadMmsComplete      = "onDownloadMmsComplete"
)
const (
	TransactionICarrierMessagingServiceFilterSms            = binder.FirstCallTransaction + 0
	TransactionICarrierMessagingServiceSendTextSms          = binder.FirstCallTransaction + 1
	TransactionICarrierMessagingServiceSendDataSms          = binder.FirstCallTransaction + 2
	TransactionICarrierMessagingServiceSendMultipartTextSms = binder.FirstCallTransaction + 3
	TransactionICarrierMessagingServiceSendMms              = binder.FirstCallTransaction + 4
	TransactionICarrierMessagingServiceDownloadMms          = binder.FirstCallTransaction + 5
)
const (
	MethodICarrierMessagingServiceFilterSms            = "filterSms"
	MethodICarrierMessagingServiceSendTextSms          = "sendTextSms"
	MethodICarrierMessagingServiceSendDataSms          = "sendDataSms"
	MethodICarrierMessagingServiceSendMultipartTextSms = "sendMultipartTextSms"
	MethodICarrierMessagingServiceSendMms              = "sendMms"
	MethodICarrierMessagingServiceDownloadMms          = "downloadMms"
)
const DescriptorIApnSourceService = "android.service.carrier.IApnSourceService"
const DescriptorICarrierMessagingCallback = "android.service.carrier.ICarrierMessagingCallback"
const DescriptorICarrierMessagingClientService = "android.service.carrier.ICarrierMessagingClientService"
const DescriptorICarrierMessagingService = "android.service.carrier.ICarrierMessagingService"
const DescriptorICarrierService = "android.service.carrier.ICarrierService"
const (
	MethodIApnSourceServiceGetApns = "getApns"
)
const (
	MethodICarrierServiceGetCarrierConfig = "getCarrierConfig"
)
const (
	TransactionIApnSourceServiceGetApns = binder.FirstCallTransaction + 0
)
const (
	TransactionICarrierServiceGetCarrierConfig = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type ApnSourceServiceProxy

type ApnSourceServiceProxy struct {
	Remote binder.IBinder
}

func NewApnSourceServiceProxy

func NewApnSourceServiceProxy(
	remote binder.IBinder,
) *ApnSourceServiceProxy

func (*ApnSourceServiceProxy) AsBinder

func (p *ApnSourceServiceProxy) AsBinder() binder.IBinder

func (*ApnSourceServiceProxy) GetApns

func (p *ApnSourceServiceProxy) GetApns(
	ctx context.Context,
	subId int32,
) ([]content.ContentValues, error)

type ApnSourceServiceStub

type ApnSourceServiceStub struct {
	Impl      IApnSourceService
	Transport binder.VersionAwareTransport
}

ApnSourceServiceStub dispatches incoming binder transactions to a typed IApnSourceService implementation.

func (*ApnSourceServiceStub) Descriptor

func (s *ApnSourceServiceStub) Descriptor() string

func (*ApnSourceServiceStub) OnTransaction

func (s *ApnSourceServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type CarrierIdentifier

type CarrierIdentifier struct {
	Mcc               string
	Mnc               string
	Spn               string
	Imsi              string
	Gid1              string
	Gid2              string
	CarrierId         int32
	SpecificCarrierId int32
}

func (*CarrierIdentifier) MarshalParcel

func (s *CarrierIdentifier) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CarrierIdentifier) UnmarshalParcel

func (s *CarrierIdentifier) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CarrierMessagingCallbackProxy

type CarrierMessagingCallbackProxy struct {
	Remote binder.IBinder
}

func NewCarrierMessagingCallbackProxy

func NewCarrierMessagingCallbackProxy(
	remote binder.IBinder,
) *CarrierMessagingCallbackProxy

func (*CarrierMessagingCallbackProxy) AsBinder

func (*CarrierMessagingCallbackProxy) OnDownloadMmsComplete

func (p *CarrierMessagingCallbackProxy) OnDownloadMmsComplete(
	ctx context.Context,
	result int32,
) error

func (*CarrierMessagingCallbackProxy) OnFilterComplete

func (p *CarrierMessagingCallbackProxy) OnFilterComplete(
	ctx context.Context,
	result int32,
) error

func (*CarrierMessagingCallbackProxy) OnSendMmsComplete

func (p *CarrierMessagingCallbackProxy) OnSendMmsComplete(
	ctx context.Context,
	result int32,
	sendConfPdu []byte,
) error

func (*CarrierMessagingCallbackProxy) OnSendMultipartSmsComplete

func (p *CarrierMessagingCallbackProxy) OnSendMultipartSmsComplete(
	ctx context.Context,
	result int32,
	messageRefs []int32,
) error

func (*CarrierMessagingCallbackProxy) OnSendSmsComplete

func (p *CarrierMessagingCallbackProxy) OnSendSmsComplete(
	ctx context.Context,
	result int32,
	messageRef int32,
) error

type CarrierMessagingCallbackStub

type CarrierMessagingCallbackStub struct {
	Impl      ICarrierMessagingCallback
	Transport binder.VersionAwareTransport
}

CarrierMessagingCallbackStub dispatches incoming binder transactions to a typed ICarrierMessagingCallback implementation.

func (*CarrierMessagingCallbackStub) Descriptor

func (s *CarrierMessagingCallbackStub) Descriptor() string

func (*CarrierMessagingCallbackStub) OnTransaction

type CarrierMessagingClientServiceProxy

type CarrierMessagingClientServiceProxy struct {
	Remote binder.IBinder
}

func NewCarrierMessagingClientServiceProxy

func NewCarrierMessagingClientServiceProxy(
	remote binder.IBinder,
) *CarrierMessagingClientServiceProxy

func (*CarrierMessagingClientServiceProxy) AsBinder

type CarrierMessagingClientServiceStub

type CarrierMessagingClientServiceStub struct {
	Impl      ICarrierMessagingClientService
	Transport binder.VersionAwareTransport
}

CarrierMessagingClientServiceStub dispatches incoming binder transactions to a typed ICarrierMessagingClientService implementation.

func (*CarrierMessagingClientServiceStub) Descriptor

func (s *CarrierMessagingClientServiceStub) Descriptor() string

func (*CarrierMessagingClientServiceStub) OnTransaction

type CarrierMessagingServiceProxy

type CarrierMessagingServiceProxy struct {
	Remote binder.IBinder
}

func NewCarrierMessagingServiceProxy

func NewCarrierMessagingServiceProxy(
	remote binder.IBinder,
) *CarrierMessagingServiceProxy

func (*CarrierMessagingServiceProxy) AsBinder

func (*CarrierMessagingServiceProxy) DownloadMms

func (p *CarrierMessagingServiceProxy) DownloadMms(
	ctx context.Context,
	pduUri net.Uri,
	subId int32,
	location net.Uri,
	callback ICarrierMessagingCallback,
) error

func (*CarrierMessagingServiceProxy) FilterSms

func (p *CarrierMessagingServiceProxy) FilterSms(
	ctx context.Context,
	pdu MessagePdu,
	format string,
	destPort int32,
	subId int32,
	callback ICarrierMessagingCallback,
) error

func (*CarrierMessagingServiceProxy) SendDataSms

func (p *CarrierMessagingServiceProxy) SendDataSms(
	ctx context.Context,
	data []byte,
	subId int32,
	destAddress string,
	destPort int32,
	sendSmsFlag int32,
	callback ICarrierMessagingCallback,
) error

func (*CarrierMessagingServiceProxy) SendMms

func (p *CarrierMessagingServiceProxy) SendMms(
	ctx context.Context,
	pduUri net.Uri,
	subId int32,
	location net.Uri,
	callback ICarrierMessagingCallback,
) error

func (*CarrierMessagingServiceProxy) SendMultipartTextSms

func (p *CarrierMessagingServiceProxy) SendMultipartTextSms(
	ctx context.Context,
	parts []string,
	subId int32,
	destAddress string,
	sendSmsFlag int32,
	callback ICarrierMessagingCallback,
) error

func (*CarrierMessagingServiceProxy) SendTextSms

func (p *CarrierMessagingServiceProxy) SendTextSms(
	ctx context.Context,
	text string,
	subId int32,
	destAddress string,
	sendSmsFlag int32,
	callback ICarrierMessagingCallback,
) error

type CarrierMessagingServiceStub

type CarrierMessagingServiceStub struct {
	Impl      ICarrierMessagingService
	Transport binder.VersionAwareTransport
}

CarrierMessagingServiceStub dispatches incoming binder transactions to a typed ICarrierMessagingService implementation.

func (*CarrierMessagingServiceStub) Descriptor

func (s *CarrierMessagingServiceStub) Descriptor() string

func (*CarrierMessagingServiceStub) OnTransaction

func (s *CarrierMessagingServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type CarrierServiceProxy

type CarrierServiceProxy struct {
	Remote binder.IBinder
}

func NewCarrierServiceProxy

func NewCarrierServiceProxy(
	remote binder.IBinder,
) *CarrierServiceProxy

func (*CarrierServiceProxy) AsBinder

func (p *CarrierServiceProxy) AsBinder() binder.IBinder

func (*CarrierServiceProxy) GetCarrierConfig

func (p *CarrierServiceProxy) GetCarrierConfig(
	ctx context.Context,
	phoneId int32,
	id CarrierIdentifier,
	result os.ResultReceiver,
) error

type CarrierServiceStub

type CarrierServiceStub struct {
	Impl      ICarrierService
	Transport binder.VersionAwareTransport
}

CarrierServiceStub dispatches incoming binder transactions to a typed ICarrierService implementation.

func (*CarrierServiceStub) Descriptor

func (s *CarrierServiceStub) Descriptor() string

func (*CarrierServiceStub) OnTransaction

func (s *CarrierServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IApnSourceService

type IApnSourceService interface {
	AsBinder() binder.IBinder
	GetApns(ctx context.Context, subId int32) ([]content.ContentValues, error)
}

func NewApnSourceServiceStub

func NewApnSourceServiceStub(
	impl IApnSourceServiceServer,
) IApnSourceService

NewApnSourceServiceStub creates a server-side IApnSourceService wrapping the given server implementation. The returned value satisfies IApnSourceService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IApnSourceServiceServer

type IApnSourceServiceServer interface {
	GetApns(ctx context.Context, subId int32) ([]content.ContentValues, error)
}

IApnSourceServiceServer is the server-side interface that user implementations provide to NewApnSourceServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ICarrierMessagingCallback

type ICarrierMessagingCallback interface {
	AsBinder() binder.IBinder
	OnFilterComplete(ctx context.Context, result int32) error
	OnSendSmsComplete(ctx context.Context, result int32, messageRef int32) error
	OnSendMultipartSmsComplete(ctx context.Context, result int32, messageRefs []int32) error
	OnSendMmsComplete(ctx context.Context, result int32, sendConfPdu []byte) error
	OnDownloadMmsComplete(ctx context.Context, result int32) error
}

func NewCarrierMessagingCallbackStub

func NewCarrierMessagingCallbackStub(
	impl ICarrierMessagingCallbackServer,
) ICarrierMessagingCallback

NewCarrierMessagingCallbackStub creates a server-side ICarrierMessagingCallback wrapping the given server implementation. The returned value satisfies ICarrierMessagingCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ICarrierMessagingCallbackServer

type ICarrierMessagingCallbackServer interface {
	OnFilterComplete(ctx context.Context, result int32) error
	OnSendSmsComplete(ctx context.Context, result int32, messageRef int32) error
	OnSendMultipartSmsComplete(ctx context.Context, result int32, messageRefs []int32) error
	OnSendMmsComplete(ctx context.Context, result int32, sendConfPdu []byte) error
	OnDownloadMmsComplete(ctx context.Context, result int32) error
}

ICarrierMessagingCallbackServer is the server-side interface that user implementations provide to NewCarrierMessagingCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ICarrierMessagingClientService

type ICarrierMessagingClientService interface {
	AsBinder() binder.IBinder
}

func NewCarrierMessagingClientServiceStub

func NewCarrierMessagingClientServiceStub(
	impl ICarrierMessagingClientServiceServer,
) ICarrierMessagingClientService

NewCarrierMessagingClientServiceStub creates a server-side ICarrierMessagingClientService wrapping the given server implementation. The returned value satisfies ICarrierMessagingClientService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ICarrierMessagingClientServiceServer

type ICarrierMessagingClientServiceServer interface {
}

ICarrierMessagingClientServiceServer is the server-side interface that user implementations provide to NewCarrierMessagingClientServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ICarrierMessagingService

type ICarrierMessagingService interface {
	AsBinder() binder.IBinder
	FilterSms(ctx context.Context, pdu MessagePdu, format string, destPort int32, subId int32, callback ICarrierMessagingCallback) error
	SendTextSms(ctx context.Context, text string, subId int32, destAddress string, sendSmsFlag int32, callback ICarrierMessagingCallback) error
	SendDataSms(ctx context.Context, data []byte, subId int32, destAddress string, destPort int32, sendSmsFlag int32, callback ICarrierMessagingCallback) error
	SendMultipartTextSms(ctx context.Context, parts []string, subId int32, destAddress string, sendSmsFlag int32, callback ICarrierMessagingCallback) error
	SendMms(ctx context.Context, pduUri net.Uri, subId int32, location net.Uri, callback ICarrierMessagingCallback) error
	DownloadMms(ctx context.Context, pduUri net.Uri, subId int32, location net.Uri, callback ICarrierMessagingCallback) error
}

func NewCarrierMessagingServiceStub

func NewCarrierMessagingServiceStub(
	impl ICarrierMessagingServiceServer,
) ICarrierMessagingService

NewCarrierMessagingServiceStub creates a server-side ICarrierMessagingService wrapping the given server implementation. The returned value satisfies ICarrierMessagingService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ICarrierMessagingServiceServer

type ICarrierMessagingServiceServer interface {
	FilterSms(ctx context.Context, pdu MessagePdu, format string, destPort int32, subId int32, callback ICarrierMessagingCallback) error
	SendTextSms(ctx context.Context, text string, subId int32, destAddress string, sendSmsFlag int32, callback ICarrierMessagingCallback) error
	SendDataSms(ctx context.Context, data []byte, subId int32, destAddress string, destPort int32, sendSmsFlag int32, callback ICarrierMessagingCallback) error
	SendMultipartTextSms(ctx context.Context, parts []string, subId int32, destAddress string, sendSmsFlag int32, callback ICarrierMessagingCallback) error
	SendMms(ctx context.Context, pduUri net.Uri, subId int32, location net.Uri, callback ICarrierMessagingCallback) error
	DownloadMms(ctx context.Context, pduUri net.Uri, subId int32, location net.Uri, callback ICarrierMessagingCallback) error
}

ICarrierMessagingServiceServer is the server-side interface that user implementations provide to NewCarrierMessagingServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ICarrierService

type ICarrierService interface {
	AsBinder() binder.IBinder
	GetCarrierConfig(ctx context.Context, phoneId int32, id CarrierIdentifier, result os.ResultReceiver) error
}

func NewCarrierServiceStub

func NewCarrierServiceStub(
	impl ICarrierServiceServer,
) ICarrierService

NewCarrierServiceStub creates a server-side ICarrierService wrapping the given server implementation. The returned value satisfies ICarrierService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ICarrierServiceServer

type ICarrierServiceServer interface {
	GetCarrierConfig(ctx context.Context, phoneId int32, id CarrierIdentifier, result os.ResultReceiver) error
}

ICarrierServiceServer is the server-side interface that user implementations provide to NewCarrierServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type MessagePdu

type MessagePdu struct {
}

func (*MessagePdu) MarshalParcel

func (s *MessagePdu) MarshalParcel(
	p *parcel.Parcel,
) error

func (*MessagePdu) UnmarshalParcel

func (s *MessagePdu) UnmarshalParcel(
	p *parcel.Parcel,
) error

Jump to