credentials

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIBeginCreateCredentialCallbackOnSuccess     = binder.FirstCallTransaction + 0
	TransactionIBeginCreateCredentialCallbackOnFailure     = binder.FirstCallTransaction + 1
	TransactionIBeginCreateCredentialCallbackOnCancellable = binder.FirstCallTransaction + 2
)
const (
	MethodIBeginCreateCredentialCallbackOnSuccess     = "onSuccess"
	MethodIBeginCreateCredentialCallbackOnFailure     = "onFailure"
	MethodIBeginCreateCredentialCallbackOnCancellable = "onCancellable"
)
const (
	TransactionIBeginGetCredentialCallbackOnSuccess     = binder.FirstCallTransaction + 0
	TransactionIBeginGetCredentialCallbackOnFailure     = binder.FirstCallTransaction + 1
	TransactionIBeginGetCredentialCallbackOnCancellable = binder.FirstCallTransaction + 2
)
const (
	MethodIBeginGetCredentialCallbackOnSuccess     = "onSuccess"
	MethodIBeginGetCredentialCallbackOnFailure     = "onFailure"
	MethodIBeginGetCredentialCallbackOnCancellable = "onCancellable"
)
const (
	TransactionIClearCredentialStateCallbackOnSuccess     = binder.FirstCallTransaction + 0
	TransactionIClearCredentialStateCallbackOnFailure     = binder.FirstCallTransaction + 1
	TransactionIClearCredentialStateCallbackOnCancellable = binder.FirstCallTransaction + 2
)
const (
	MethodIClearCredentialStateCallbackOnSuccess     = "onSuccess"
	MethodIClearCredentialStateCallbackOnFailure     = "onFailure"
	MethodIClearCredentialStateCallbackOnCancellable = "onCancellable"
)
const (
	TransactionICredentialProviderServiceOnBeginGetCredential    = binder.FirstCallTransaction + 0
	TransactionICredentialProviderServiceOnBeginCreateCredential = binder.FirstCallTransaction + 1
	TransactionICredentialProviderServiceOnClearCredentialState  = binder.FirstCallTransaction + 2
)
const (
	MethodICredentialProviderServiceOnBeginGetCredential    = "onBeginGetCredential"
	MethodICredentialProviderServiceOnBeginCreateCredential = "onBeginCreateCredential"
	MethodICredentialProviderServiceOnClearCredentialState  = "onClearCredentialState"
)
const DescriptorIBeginCreateCredentialCallback = "android.service.credentials.IBeginCreateCredentialCallback"
const DescriptorIBeginGetCredentialCallback = "android.service.credentials.IBeginGetCredentialCallback"
const DescriptorIClearCredentialStateCallback = "android.service.credentials.IClearCredentialStateCallback"
const DescriptorICredentialProviderService = "android.service.credentials.ICredentialProviderService"

Variables

This section is empty.

Functions

This section is empty.

Types

type BeginCreateCredentialCallbackProxy

type BeginCreateCredentialCallbackProxy struct {
	Remote binder.IBinder
}

func NewBeginCreateCredentialCallbackProxy

func NewBeginCreateCredentialCallbackProxy(
	remote binder.IBinder,
) *BeginCreateCredentialCallbackProxy

func (*BeginCreateCredentialCallbackProxy) AsBinder

func (*BeginCreateCredentialCallbackProxy) OnCancellable

func (p *BeginCreateCredentialCallbackProxy) OnCancellable(
	ctx context.Context,
	cancellation os.ICancellationSignal,
) error

func (*BeginCreateCredentialCallbackProxy) OnFailure

func (p *BeginCreateCredentialCallbackProxy) OnFailure(
	ctx context.Context,
	errorType string,
	message string,
) error

func (*BeginCreateCredentialCallbackProxy) OnSuccess

type BeginCreateCredentialCallbackStub

type BeginCreateCredentialCallbackStub struct {
	Impl      IBeginCreateCredentialCallback
	Transport binder.VersionAwareTransport
}

BeginCreateCredentialCallbackStub dispatches incoming binder transactions to a typed IBeginCreateCredentialCallback implementation.

func (*BeginCreateCredentialCallbackStub) Descriptor

func (s *BeginCreateCredentialCallbackStub) Descriptor() string

func (*BeginCreateCredentialCallbackStub) OnTransaction

type BeginCreateCredentialRequest

type BeginCreateCredentialRequest struct {
	Type string
}

func (*BeginCreateCredentialRequest) MarshalParcel

func (s *BeginCreateCredentialRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*BeginCreateCredentialRequest) UnmarshalParcel

func (s *BeginCreateCredentialRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type BeginCreateCredentialResponse

type BeginCreateCredentialResponse struct {
}

func (*BeginCreateCredentialResponse) MarshalParcel

func (s *BeginCreateCredentialResponse) MarshalParcel(
	p *parcel.Parcel,
) error

func (*BeginCreateCredentialResponse) UnmarshalParcel

func (s *BeginCreateCredentialResponse) UnmarshalParcel(
	p *parcel.Parcel,
) error

type BeginGetCredentialCallbackProxy

type BeginGetCredentialCallbackProxy struct {
	Remote binder.IBinder
}

func NewBeginGetCredentialCallbackProxy

func NewBeginGetCredentialCallbackProxy(
	remote binder.IBinder,
) *BeginGetCredentialCallbackProxy

func (*BeginGetCredentialCallbackProxy) AsBinder

func (*BeginGetCredentialCallbackProxy) OnCancellable

func (p *BeginGetCredentialCallbackProxy) OnCancellable(
	ctx context.Context,
	cancellation os.ICancellationSignal,
) error

func (*BeginGetCredentialCallbackProxy) OnFailure

func (p *BeginGetCredentialCallbackProxy) OnFailure(
	ctx context.Context,
	errorType string,
	message string,
) error

func (*BeginGetCredentialCallbackProxy) OnSuccess

type BeginGetCredentialCallbackStub

type BeginGetCredentialCallbackStub struct {
	Impl      IBeginGetCredentialCallback
	Transport binder.VersionAwareTransport
}

BeginGetCredentialCallbackStub dispatches incoming binder transactions to a typed IBeginGetCredentialCallback implementation.

func (*BeginGetCredentialCallbackStub) Descriptor

func (s *BeginGetCredentialCallbackStub) Descriptor() string

func (*BeginGetCredentialCallbackStub) OnTransaction

type BeginGetCredentialRequest

type BeginGetCredentialRequest struct {
}

func (*BeginGetCredentialRequest) MarshalParcel

func (s *BeginGetCredentialRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*BeginGetCredentialRequest) UnmarshalParcel

func (s *BeginGetCredentialRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type BeginGetCredentialResponse

type BeginGetCredentialResponse struct {
}

func (*BeginGetCredentialResponse) MarshalParcel

func (s *BeginGetCredentialResponse) MarshalParcel(
	p *parcel.Parcel,
) error

func (*BeginGetCredentialResponse) UnmarshalParcel

func (s *BeginGetCredentialResponse) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ClearCredentialStateCallbackProxy

type ClearCredentialStateCallbackProxy struct {
	Remote binder.IBinder
}

func NewClearCredentialStateCallbackProxy

func NewClearCredentialStateCallbackProxy(
	remote binder.IBinder,
) *ClearCredentialStateCallbackProxy

func (*ClearCredentialStateCallbackProxy) AsBinder

func (*ClearCredentialStateCallbackProxy) OnCancellable

func (p *ClearCredentialStateCallbackProxy) OnCancellable(
	ctx context.Context,
	cancellation os.ICancellationSignal,
) error

func (*ClearCredentialStateCallbackProxy) OnFailure

func (p *ClearCredentialStateCallbackProxy) OnFailure(
	ctx context.Context,
	errorType string,
	message string,
) error

func (*ClearCredentialStateCallbackProxy) OnSuccess

type ClearCredentialStateCallbackStub

type ClearCredentialStateCallbackStub struct {
	Impl      IClearCredentialStateCallback
	Transport binder.VersionAwareTransport
}

ClearCredentialStateCallbackStub dispatches incoming binder transactions to a typed IClearCredentialStateCallback implementation.

func (*ClearCredentialStateCallbackStub) Descriptor

func (s *ClearCredentialStateCallbackStub) Descriptor() string

func (*ClearCredentialStateCallbackStub) OnTransaction

type ClearCredentialStateRequest

type ClearCredentialStateRequest struct {
}

func (*ClearCredentialStateRequest) MarshalParcel

func (s *ClearCredentialStateRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ClearCredentialStateRequest) UnmarshalParcel

func (s *ClearCredentialStateRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CredentialProviderServiceProxy

type CredentialProviderServiceProxy struct {
	Remote binder.IBinder
}

func NewCredentialProviderServiceProxy

func NewCredentialProviderServiceProxy(
	remote binder.IBinder,
) *CredentialProviderServiceProxy

func (*CredentialProviderServiceProxy) AsBinder

func (*CredentialProviderServiceProxy) OnBeginCreateCredential

func (*CredentialProviderServiceProxy) OnBeginGetCredential

func (*CredentialProviderServiceProxy) OnClearCredentialState

type CredentialProviderServiceStub

type CredentialProviderServiceStub struct {
	Impl      ICredentialProviderService
	Transport binder.VersionAwareTransport
}

CredentialProviderServiceStub dispatches incoming binder transactions to a typed ICredentialProviderService implementation.

func (*CredentialProviderServiceStub) Descriptor

func (s *CredentialProviderServiceStub) Descriptor() string

func (*CredentialProviderServiceStub) OnTransaction

type IBeginCreateCredentialCallback

type IBeginCreateCredentialCallback interface {
	AsBinder() binder.IBinder
	OnSuccess(ctx context.Context, request BeginCreateCredentialResponse) error
	OnFailure(ctx context.Context, errorType string, message string) error
	OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
}

func NewBeginCreateCredentialCallbackStub

func NewBeginCreateCredentialCallbackStub(
	impl IBeginCreateCredentialCallbackServer,
) IBeginCreateCredentialCallback

NewBeginCreateCredentialCallbackStub creates a server-side IBeginCreateCredentialCallback wrapping the given server implementation. The returned value satisfies IBeginCreateCredentialCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBeginCreateCredentialCallbackServer

type IBeginCreateCredentialCallbackServer interface {
	OnSuccess(ctx context.Context, request BeginCreateCredentialResponse) error
	OnFailure(ctx context.Context, errorType string, message string) error
	OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
}

IBeginCreateCredentialCallbackServer is the server-side interface that user implementations provide to NewBeginCreateCredentialCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IBeginGetCredentialCallback

type IBeginGetCredentialCallback interface {
	AsBinder() binder.IBinder
	OnSuccess(ctx context.Context, response BeginGetCredentialResponse) error
	OnFailure(ctx context.Context, errorType string, message string) error
	OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
}

func NewBeginGetCredentialCallbackStub

func NewBeginGetCredentialCallbackStub(
	impl IBeginGetCredentialCallbackServer,
) IBeginGetCredentialCallback

NewBeginGetCredentialCallbackStub creates a server-side IBeginGetCredentialCallback wrapping the given server implementation. The returned value satisfies IBeginGetCredentialCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBeginGetCredentialCallbackServer

type IBeginGetCredentialCallbackServer interface {
	OnSuccess(ctx context.Context, response BeginGetCredentialResponse) error
	OnFailure(ctx context.Context, errorType string, message string) error
	OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
}

IBeginGetCredentialCallbackServer is the server-side interface that user implementations provide to NewBeginGetCredentialCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IClearCredentialStateCallback

type IClearCredentialStateCallback interface {
	AsBinder() binder.IBinder
	OnSuccess(ctx context.Context) error
	OnFailure(ctx context.Context, errorType string, message string) error
	OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
}

func NewClearCredentialStateCallbackStub

func NewClearCredentialStateCallbackStub(
	impl IClearCredentialStateCallbackServer,
) IClearCredentialStateCallback

NewClearCredentialStateCallbackStub creates a server-side IClearCredentialStateCallback wrapping the given server implementation. The returned value satisfies IClearCredentialStateCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IClearCredentialStateCallbackServer

type IClearCredentialStateCallbackServer interface {
	OnSuccess(ctx context.Context) error
	OnFailure(ctx context.Context, errorType string, message string) error
	OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
}

IClearCredentialStateCallbackServer is the server-side interface that user implementations provide to NewClearCredentialStateCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ICredentialProviderService

type ICredentialProviderService interface {
	AsBinder() binder.IBinder
	OnBeginGetCredential(ctx context.Context, request BeginGetCredentialRequest, callback IBeginGetCredentialCallback) error
	OnBeginCreateCredential(ctx context.Context, request BeginCreateCredentialRequest, callback IBeginCreateCredentialCallback) error
	OnClearCredentialState(ctx context.Context, request ClearCredentialStateRequest, callback IClearCredentialStateCallback) error
}

func NewCredentialProviderServiceStub

func NewCredentialProviderServiceStub(
	impl ICredentialProviderServiceServer,
) ICredentialProviderService

NewCredentialProviderServiceStub creates a server-side ICredentialProviderService wrapping the given server implementation. The returned value satisfies ICredentialProviderService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ICredentialProviderServiceServer

type ICredentialProviderServiceServer interface {
	OnBeginGetCredential(ctx context.Context, request BeginGetCredentialRequest, callback IBeginGetCredentialCallback) error
	OnBeginCreateCredential(ctx context.Context, request BeginCreateCredentialRequest, callback IBeginCreateCredentialCallback) error
	OnClearCredentialState(ctx context.Context, request ClearCredentialStateRequest, callback IClearCredentialStateCallback) error
}

ICredentialProviderServiceServer is the server-side interface that user implementations provide to NewCredentialProviderServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

Jump to