dreams

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIDreamManagerDream                           = binder.FirstCallTransaction + 0
	TransactionIDreamManagerAwaken                          = binder.FirstCallTransaction + 1
	TransactionIDreamManagerSetDreamComponents              = binder.FirstCallTransaction + 2
	TransactionIDreamManagerGetDreamComponents              = binder.FirstCallTransaction + 3
	TransactionIDreamManagerGetDefaultDreamComponentForUser = binder.FirstCallTransaction + 4
	TransactionIDreamManagerTestDream                       = binder.FirstCallTransaction + 5
	TransactionIDreamManagerIsDreaming                      = binder.FirstCallTransaction + 6
	TransactionIDreamManagerIsDreamingOrInPreview           = binder.FirstCallTransaction + 7
	TransactionIDreamManagerFinishSelf                      = binder.FirstCallTransaction + 8
	TransactionIDreamManagerStartDozing                     = binder.FirstCallTransaction + 9
	TransactionIDreamManagerStopDozing                      = binder.FirstCallTransaction + 10
	TransactionIDreamManagerForceAmbientDisplayEnabled      = binder.FirstCallTransaction + 11
	TransactionIDreamManagerGetDreamComponentsForUser       = binder.FirstCallTransaction + 12
	TransactionIDreamManagerSetDreamComponentsForUser       = binder.FirstCallTransaction + 13
	TransactionIDreamManagerSetSystemDreamComponent         = binder.FirstCallTransaction + 14
	TransactionIDreamManagerRegisterDreamOverlayService     = binder.FirstCallTransaction + 15
	TransactionIDreamManagerStartDreamActivity              = binder.FirstCallTransaction + 16
)
const (
	MethodIDreamManagerDream                           = "dream"
	MethodIDreamManagerAwaken                          = "awaken"
	MethodIDreamManagerSetDreamComponents              = "setDreamComponents"
	MethodIDreamManagerGetDreamComponents              = "getDreamComponents"
	MethodIDreamManagerGetDefaultDreamComponentForUser = "getDefaultDreamComponentForUser"
	MethodIDreamManagerTestDream                       = "testDream"
	MethodIDreamManagerIsDreaming                      = "isDreaming"
	MethodIDreamManagerIsDreamingOrInPreview           = "isDreamingOrInPreview"
	MethodIDreamManagerFinishSelf                      = "finishSelf"
	MethodIDreamManagerStartDozing                     = "startDozing"
	MethodIDreamManagerStopDozing                      = "stopDozing"
	MethodIDreamManagerForceAmbientDisplayEnabled      = "forceAmbientDisplayEnabled"
	MethodIDreamManagerGetDreamComponentsForUser       = "getDreamComponentsForUser"
	MethodIDreamManagerSetDreamComponentsForUser       = "setDreamComponentsForUser"
	MethodIDreamManagerSetSystemDreamComponent         = "setSystemDreamComponent"
	MethodIDreamManagerRegisterDreamOverlayService     = "registerDreamOverlayService"
	MethodIDreamManagerStartDreamActivity              = "startDreamActivity"
)
const (
	TransactionIDreamOverlayClientStartDream = binder.FirstCallTransaction + 0
	TransactionIDreamOverlayClientWakeUp     = binder.FirstCallTransaction + 1
	TransactionIDreamOverlayClientEndDream   = binder.FirstCallTransaction + 2
)
const (
	MethodIDreamOverlayClientStartDream = "startDream"
	MethodIDreamOverlayClientWakeUp     = "wakeUp"
	MethodIDreamOverlayClientEndDream   = "endDream"
)
const (
	TransactionIDreamServiceAttach = binder.FirstCallTransaction + 0
	TransactionIDreamServiceDetach = binder.FirstCallTransaction + 1
	TransactionIDreamServiceWakeUp = binder.FirstCallTransaction + 2
)
const (
	MethodIDreamServiceAttach = "attach"
	MethodIDreamServiceDetach = "detach"
	MethodIDreamServiceWakeUp = "wakeUp"
)
const DescriptorIDreamManager = "android.service.dreams.IDreamManager"
const DescriptorIDreamOverlay = "android.service.dreams.IDreamOverlay"
const DescriptorIDreamOverlayCallback = "android.service.dreams.IDreamOverlayCallback"
const DescriptorIDreamOverlayClient = "android.service.dreams.IDreamOverlayClient"
const DescriptorIDreamOverlayClientCallback = "android.service.dreams.IDreamOverlayClientCallback"
const DescriptorIDreamService = "android.service.dreams.IDreamService"
const (
	MethodIDreamOverlayCallbackOnExitRequested = "onExitRequested"
)
const (
	MethodIDreamOverlayClientCallbackOnDreamOverlayClient = "onDreamOverlayClient"
)
const (
	MethodIDreamOverlayGetClient = "getClient"
)
const (
	TransactionIDreamOverlayCallbackOnExitRequested = binder.FirstCallTransaction + 0
)
const (
	TransactionIDreamOverlayClientCallbackOnDreamOverlayClient = binder.FirstCallTransaction + 0
)
const (
	TransactionIDreamOverlayGetClient = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type DreamManagerProxy

type DreamManagerProxy struct {
	Remote binder.IBinder
}

func NewDreamManagerProxy

func NewDreamManagerProxy(
	remote binder.IBinder,
) *DreamManagerProxy

func (*DreamManagerProxy) AsBinder

func (p *DreamManagerProxy) AsBinder() binder.IBinder

func (*DreamManagerProxy) Awaken

func (p *DreamManagerProxy) Awaken(
	ctx context.Context,
) error

func (*DreamManagerProxy) Dream

func (p *DreamManagerProxy) Dream(
	ctx context.Context,
) error

func (*DreamManagerProxy) FinishSelf

func (p *DreamManagerProxy) FinishSelf(
	ctx context.Context,
	token binder.IBinder,
	immediate bool,
) error

func (*DreamManagerProxy) ForceAmbientDisplayEnabled

func (p *DreamManagerProxy) ForceAmbientDisplayEnabled(
	ctx context.Context,
	enabled bool,
) error

func (*DreamManagerProxy) GetDefaultDreamComponentForUser

func (p *DreamManagerProxy) GetDefaultDreamComponentForUser(
	ctx context.Context,
) (content.ComponentName, error)

func (*DreamManagerProxy) GetDreamComponents

func (p *DreamManagerProxy) GetDreamComponents(
	ctx context.Context,
) ([]content.ComponentName, error)

func (*DreamManagerProxy) GetDreamComponentsForUser

func (p *DreamManagerProxy) GetDreamComponentsForUser(
	ctx context.Context,
) ([]content.ComponentName, error)

func (*DreamManagerProxy) IsDreaming

func (p *DreamManagerProxy) IsDreaming(
	ctx context.Context,
) (bool, error)

func (*DreamManagerProxy) IsDreamingOrInPreview

func (p *DreamManagerProxy) IsDreamingOrInPreview(
	ctx context.Context,
) (bool, error)

func (*DreamManagerProxy) RegisterDreamOverlayService

func (p *DreamManagerProxy) RegisterDreamOverlayService(
	ctx context.Context,
	componentName content.ComponentName,
) error

func (*DreamManagerProxy) SetDreamComponents

func (p *DreamManagerProxy) SetDreamComponents(
	ctx context.Context,
	componentNames []content.ComponentName,
) error

func (*DreamManagerProxy) SetDreamComponentsForUser

func (p *DreamManagerProxy) SetDreamComponentsForUser(
	ctx context.Context,
	componentNames []content.ComponentName,
) error

func (*DreamManagerProxy) SetSystemDreamComponent

func (p *DreamManagerProxy) SetSystemDreamComponent(
	ctx context.Context,
	componentName content.ComponentName,
) error

func (*DreamManagerProxy) StartDozing

func (p *DreamManagerProxy) StartDozing(
	ctx context.Context,
	token binder.IBinder,
	screenState int32,
	screenBrightness int32,
) error

func (*DreamManagerProxy) StartDreamActivity

func (p *DreamManagerProxy) StartDreamActivity(
	ctx context.Context,
	intent content.Intent,
) error

func (*DreamManagerProxy) StopDozing

func (p *DreamManagerProxy) StopDozing(
	ctx context.Context,
	token binder.IBinder,
) error

func (*DreamManagerProxy) TestDream

func (p *DreamManagerProxy) TestDream(
	ctx context.Context,
	componentName content.ComponentName,
) error

type DreamManagerStub

type DreamManagerStub struct {
	Impl      IDreamManager
	Transport binder.VersionAwareTransport
}

DreamManagerStub dispatches incoming binder transactions to a typed IDreamManager implementation.

func (*DreamManagerStub) Descriptor

func (s *DreamManagerStub) Descriptor() string

func (*DreamManagerStub) OnTransaction

func (s *DreamManagerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type DreamOverlayCallbackProxy

type DreamOverlayCallbackProxy struct {
	Remote binder.IBinder
}

func NewDreamOverlayCallbackProxy

func NewDreamOverlayCallbackProxy(
	remote binder.IBinder,
) *DreamOverlayCallbackProxy

func (*DreamOverlayCallbackProxy) AsBinder

func (*DreamOverlayCallbackProxy) OnExitRequested

func (p *DreamOverlayCallbackProxy) OnExitRequested(
	ctx context.Context,
) error

type DreamOverlayCallbackStub

type DreamOverlayCallbackStub struct {
	Impl      IDreamOverlayCallback
	Transport binder.VersionAwareTransport
}

DreamOverlayCallbackStub dispatches incoming binder transactions to a typed IDreamOverlayCallback implementation.

func (*DreamOverlayCallbackStub) Descriptor

func (s *DreamOverlayCallbackStub) Descriptor() string

func (*DreamOverlayCallbackStub) OnTransaction

func (s *DreamOverlayCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type DreamOverlayClientCallbackProxy

type DreamOverlayClientCallbackProxy struct {
	Remote binder.IBinder
}

func NewDreamOverlayClientCallbackProxy

func NewDreamOverlayClientCallbackProxy(
	remote binder.IBinder,
) *DreamOverlayClientCallbackProxy

func (*DreamOverlayClientCallbackProxy) AsBinder

func (*DreamOverlayClientCallbackProxy) OnDreamOverlayClient

func (p *DreamOverlayClientCallbackProxy) OnDreamOverlayClient(
	ctx context.Context,
	client IDreamOverlayClient,
) error

type DreamOverlayClientCallbackStub

type DreamOverlayClientCallbackStub struct {
	Impl      IDreamOverlayClientCallback
	Transport binder.VersionAwareTransport
}

DreamOverlayClientCallbackStub dispatches incoming binder transactions to a typed IDreamOverlayClientCallback implementation.

func (*DreamOverlayClientCallbackStub) Descriptor

func (s *DreamOverlayClientCallbackStub) Descriptor() string

func (*DreamOverlayClientCallbackStub) OnTransaction

type DreamOverlayClientProxy

type DreamOverlayClientProxy struct {
	Remote binder.IBinder
}

func NewDreamOverlayClientProxy

func NewDreamOverlayClientProxy(
	remote binder.IBinder,
) *DreamOverlayClientProxy

func (*DreamOverlayClientProxy) AsBinder

func (p *DreamOverlayClientProxy) AsBinder() binder.IBinder

func (*DreamOverlayClientProxy) EndDream

func (p *DreamOverlayClientProxy) EndDream(
	ctx context.Context,
) error

func (*DreamOverlayClientProxy) StartDream

func (p *DreamOverlayClientProxy) StartDream(
	ctx context.Context,
	params view.WindowManagerLayoutParams,
	callback IDreamOverlayCallback,
	dreamComponent string,
	shouldShowComplications bool,
) error

func (*DreamOverlayClientProxy) WakeUp

func (p *DreamOverlayClientProxy) WakeUp(
	ctx context.Context,
) error

type DreamOverlayClientStub

type DreamOverlayClientStub struct {
	Impl      IDreamOverlayClient
	Transport binder.VersionAwareTransport
}

DreamOverlayClientStub dispatches incoming binder transactions to a typed IDreamOverlayClient implementation.

func (*DreamOverlayClientStub) Descriptor

func (s *DreamOverlayClientStub) Descriptor() string

func (*DreamOverlayClientStub) OnTransaction

func (s *DreamOverlayClientStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type DreamOverlayProxy

type DreamOverlayProxy struct {
	Remote binder.IBinder
}

func NewDreamOverlayProxy

func NewDreamOverlayProxy(
	remote binder.IBinder,
) *DreamOverlayProxy

func (*DreamOverlayProxy) AsBinder

func (p *DreamOverlayProxy) AsBinder() binder.IBinder

func (*DreamOverlayProxy) GetClient

func (p *DreamOverlayProxy) GetClient(
	ctx context.Context,
	callback IDreamOverlayClientCallback,
) error

type DreamOverlayStub

type DreamOverlayStub struct {
	Impl      IDreamOverlay
	Transport binder.VersionAwareTransport
}

DreamOverlayStub dispatches incoming binder transactions to a typed IDreamOverlay implementation.

func (*DreamOverlayStub) Descriptor

func (s *DreamOverlayStub) Descriptor() string

func (*DreamOverlayStub) OnTransaction

func (s *DreamOverlayStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type DreamServiceProxy

type DreamServiceProxy struct {
	Remote binder.IBinder
}

func NewDreamServiceProxy

func NewDreamServiceProxy(
	remote binder.IBinder,
) *DreamServiceProxy

func (*DreamServiceProxy) AsBinder

func (p *DreamServiceProxy) AsBinder() binder.IBinder

func (*DreamServiceProxy) Attach

func (p *DreamServiceProxy) Attach(
	ctx context.Context,
	windowToken binder.IBinder,
	canDoze bool,
	isPreviewMode bool,
	started os.IRemoteCallback,
) error

func (*DreamServiceProxy) Detach

func (p *DreamServiceProxy) Detach(
	ctx context.Context,
) error

func (*DreamServiceProxy) WakeUp

func (p *DreamServiceProxy) WakeUp(
	ctx context.Context,
) error

type DreamServiceStub

type DreamServiceStub struct {
	Impl      IDreamService
	Transport binder.VersionAwareTransport
}

DreamServiceStub dispatches incoming binder transactions to a typed IDreamService implementation.

func (*DreamServiceStub) Descriptor

func (s *DreamServiceStub) Descriptor() string

func (*DreamServiceStub) OnTransaction

func (s *DreamServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IDreamManager

type IDreamManager interface {
	AsBinder() binder.IBinder
	Dream(ctx context.Context) error
	Awaken(ctx context.Context) error
	SetDreamComponents(ctx context.Context, componentNames []content.ComponentName) error
	GetDreamComponents(ctx context.Context) ([]content.ComponentName, error)
	GetDefaultDreamComponentForUser(ctx context.Context) (content.ComponentName, error)
	TestDream(ctx context.Context, componentName content.ComponentName) error
	IsDreaming(ctx context.Context) (bool, error)
	IsDreamingOrInPreview(ctx context.Context) (bool, error)
	FinishSelf(ctx context.Context, token binder.IBinder, immediate bool) error
	StartDozing(ctx context.Context, token binder.IBinder, screenState int32, screenBrightness int32) error
	StopDozing(ctx context.Context, token binder.IBinder) error
	ForceAmbientDisplayEnabled(ctx context.Context, enabled bool) error
	GetDreamComponentsForUser(ctx context.Context) ([]content.ComponentName, error)
	SetDreamComponentsForUser(ctx context.Context, componentNames []content.ComponentName) error
	SetSystemDreamComponent(ctx context.Context, componentName content.ComponentName) error
	RegisterDreamOverlayService(ctx context.Context, componentName content.ComponentName) error
	StartDreamActivity(ctx context.Context, intent content.Intent) error
}

func NewDreamManagerStub

func NewDreamManagerStub(
	impl IDreamManagerServer,
) IDreamManager

NewDreamManagerStub creates a server-side IDreamManager wrapping the given server implementation. The returned value satisfies IDreamManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDreamManagerServer

type IDreamManagerServer interface {
	Dream(ctx context.Context) error
	Awaken(ctx context.Context) error
	SetDreamComponents(ctx context.Context, componentNames []content.ComponentName) error
	GetDreamComponents(ctx context.Context) ([]content.ComponentName, error)
	GetDefaultDreamComponentForUser(ctx context.Context) (content.ComponentName, error)
	TestDream(ctx context.Context, componentName content.ComponentName) error
	IsDreaming(ctx context.Context) (bool, error)
	IsDreamingOrInPreview(ctx context.Context) (bool, error)
	FinishSelf(ctx context.Context, token binder.IBinder, immediate bool) error
	StartDozing(ctx context.Context, token binder.IBinder, screenState int32, screenBrightness int32) error
	StopDozing(ctx context.Context, token binder.IBinder) error
	ForceAmbientDisplayEnabled(ctx context.Context, enabled bool) error
	GetDreamComponentsForUser(ctx context.Context) ([]content.ComponentName, error)
	SetDreamComponentsForUser(ctx context.Context, componentNames []content.ComponentName) error
	SetSystemDreamComponent(ctx context.Context, componentName content.ComponentName) error
	RegisterDreamOverlayService(ctx context.Context, componentName content.ComponentName) error
	StartDreamActivity(ctx context.Context, intent content.Intent) error
}

IDreamManagerServer is the server-side interface that user implementations provide to NewDreamManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IDreamOverlay

type IDreamOverlay interface {
	AsBinder() binder.IBinder
	GetClient(ctx context.Context, callback IDreamOverlayClientCallback) error
}

func NewDreamOverlayStub

func NewDreamOverlayStub(
	impl IDreamOverlayServer,
) IDreamOverlay

NewDreamOverlayStub creates a server-side IDreamOverlay wrapping the given server implementation. The returned value satisfies IDreamOverlay and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDreamOverlayCallback

type IDreamOverlayCallback interface {
	AsBinder() binder.IBinder
	OnExitRequested(ctx context.Context) error
}

func NewDreamOverlayCallbackStub

func NewDreamOverlayCallbackStub(
	impl IDreamOverlayCallbackServer,
) IDreamOverlayCallback

NewDreamOverlayCallbackStub creates a server-side IDreamOverlayCallback wrapping the given server implementation. The returned value satisfies IDreamOverlayCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDreamOverlayCallbackServer

type IDreamOverlayCallbackServer interface {
	OnExitRequested(ctx context.Context) error
}

IDreamOverlayCallbackServer is the server-side interface that user implementations provide to NewDreamOverlayCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IDreamOverlayClient

type IDreamOverlayClient interface {
	AsBinder() binder.IBinder
	StartDream(ctx context.Context, params view.WindowManagerLayoutParams, callback IDreamOverlayCallback, dreamComponent string, shouldShowComplications bool) error
	WakeUp(ctx context.Context) error
	EndDream(ctx context.Context) error
}

func NewDreamOverlayClientStub

func NewDreamOverlayClientStub(
	impl IDreamOverlayClientServer,
) IDreamOverlayClient

NewDreamOverlayClientStub creates a server-side IDreamOverlayClient wrapping the given server implementation. The returned value satisfies IDreamOverlayClient and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDreamOverlayClientCallback

type IDreamOverlayClientCallback interface {
	AsBinder() binder.IBinder
	OnDreamOverlayClient(ctx context.Context, client IDreamOverlayClient) error
}

func NewDreamOverlayClientCallbackStub

func NewDreamOverlayClientCallbackStub(
	impl IDreamOverlayClientCallbackServer,
) IDreamOverlayClientCallback

NewDreamOverlayClientCallbackStub creates a server-side IDreamOverlayClientCallback wrapping the given server implementation. The returned value satisfies IDreamOverlayClientCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDreamOverlayClientCallbackServer

type IDreamOverlayClientCallbackServer interface {
	OnDreamOverlayClient(ctx context.Context, client IDreamOverlayClient) error
}

IDreamOverlayClientCallbackServer is the server-side interface that user implementations provide to NewDreamOverlayClientCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IDreamOverlayClientServer

type IDreamOverlayClientServer interface {
	StartDream(ctx context.Context, params view.WindowManagerLayoutParams, callback IDreamOverlayCallback, dreamComponent string, shouldShowComplications bool) error
	WakeUp(ctx context.Context) error
	EndDream(ctx context.Context) error
}

IDreamOverlayClientServer is the server-side interface that user implementations provide to NewDreamOverlayClientStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IDreamOverlayServer

type IDreamOverlayServer interface {
	GetClient(ctx context.Context, callback IDreamOverlayClientCallback) error
}

IDreamOverlayServer is the server-side interface that user implementations provide to NewDreamOverlayStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IDreamService

type IDreamService interface {
	AsBinder() binder.IBinder
	Attach(ctx context.Context, windowToken binder.IBinder, canDoze bool, isPreviewMode bool, started os.IRemoteCallback) error
	Detach(ctx context.Context) error
	WakeUp(ctx context.Context) error
}

func NewDreamServiceStub

func NewDreamServiceStub(
	impl IDreamServiceServer,
) IDreamService

NewDreamServiceStub creates a server-side IDreamService wrapping the given server implementation. The returned value satisfies IDreamService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDreamServiceServer

type IDreamServiceServer interface {
	Attach(ctx context.Context, windowToken binder.IBinder, canDoze bool, isPreviewMode bool, started os.IRemoteCallback) error
	Detach(ctx context.Context) error
	WakeUp(ctx context.Context) error
}

IDreamServiceServer is the server-side interface that user implementations provide to NewDreamServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

Jump to