euicc

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIEuiccServiceDownloadSubscription                   = binder.FirstCallTransaction + 0
	TransactionIEuiccServiceGetDownloadableSubscriptionMetadata    = binder.FirstCallTransaction + 1
	TransactionIEuiccServiceGetEid                                 = binder.FirstCallTransaction + 2
	TransactionIEuiccServiceGetOtaStatus                           = binder.FirstCallTransaction + 3
	TransactionIEuiccServiceStartOtaIfNecessary                    = binder.FirstCallTransaction + 4
	TransactionIEuiccServiceGetEuiccProfileInfoList                = binder.FirstCallTransaction + 5
	TransactionIEuiccServiceGetDefaultDownloadableSubscriptionList = binder.FirstCallTransaction + 6
	TransactionIEuiccServiceGetEuiccInfo                           = binder.FirstCallTransaction + 7
	TransactionIEuiccServiceDeleteSubscription                     = binder.FirstCallTransaction + 8
	TransactionIEuiccServiceSwitchToSubscription                   = binder.FirstCallTransaction + 9
	TransactionIEuiccServiceUpdateSubscriptionNickname             = binder.FirstCallTransaction + 10
	TransactionIEuiccServiceEraseSubscriptions                     = binder.FirstCallTransaction + 11
	TransactionIEuiccServiceEraseSubscriptionsWithOptions          = binder.FirstCallTransaction + 12
	TransactionIEuiccServiceRetainSubscriptionsForFactoryReset     = binder.FirstCallTransaction + 13
	TransactionIEuiccServiceDump                                   = binder.FirstCallTransaction + 14
	TransactionIEuiccServiceGetAvailableMemoryInBytes              = binder.FirstCallTransaction + 15
)
const (
	MethodIEuiccServiceDownloadSubscription                   = "downloadSubscription"
	MethodIEuiccServiceGetDownloadableSubscriptionMetadata    = "getDownloadableSubscriptionMetadata"
	MethodIEuiccServiceGetEid                                 = "getEid"
	MethodIEuiccServiceGetOtaStatus                           = "getOtaStatus"
	MethodIEuiccServiceStartOtaIfNecessary                    = "startOtaIfNecessary"
	MethodIEuiccServiceGetEuiccProfileInfoList                = "getEuiccProfileInfoList"
	MethodIEuiccServiceGetDefaultDownloadableSubscriptionList = "getDefaultDownloadableSubscriptionList"
	MethodIEuiccServiceGetEuiccInfo                           = "getEuiccInfo"
	MethodIEuiccServiceDeleteSubscription                     = "deleteSubscription"
	MethodIEuiccServiceSwitchToSubscription                   = "switchToSubscription"
	MethodIEuiccServiceUpdateSubscriptionNickname             = "updateSubscriptionNickname"
	MethodIEuiccServiceEraseSubscriptions                     = "eraseSubscriptions"
	MethodIEuiccServiceEraseSubscriptionsWithOptions          = "eraseSubscriptionsWithOptions"
	MethodIEuiccServiceRetainSubscriptionsForFactoryReset     = "retainSubscriptionsForFactoryReset"
	MethodIEuiccServiceDump                                   = "dump"
	MethodIEuiccServiceGetAvailableMemoryInBytes              = "getAvailableMemoryInBytes"
)
const (
	TransactionIGetAvailableMemoryInBytesCallbackOnSuccess                       = binder.FirstCallTransaction + 0
	TransactionIGetAvailableMemoryInBytesCallbackOnUnsupportedOperationException = binder.FirstCallTransaction + 1
)
const (
	MethodIGetAvailableMemoryInBytesCallbackOnSuccess                       = "onSuccess"
	MethodIGetAvailableMemoryInBytesCallbackOnUnsupportedOperationException = "onUnsupportedOperationException"
)
const DescriptorIDeleteSubscriptionCallback = "android.service.euicc.IDeleteSubscriptionCallback"
const DescriptorIDownloadSubscriptionCallback = "android.service.euicc.IDownloadSubscriptionCallback"
const DescriptorIEraseSubscriptionsCallback = "android.service.euicc.IEraseSubscriptionsCallback"
const DescriptorIEuiccService = "android.service.euicc.IEuiccService"
const DescriptorIEuiccServiceDumpResultCallback = "android.service.euicc.IEuiccServiceDumpResultCallback"
const DescriptorIGetAvailableMemoryInBytesCallback = "android.service.euicc.IGetAvailableMemoryInBytesCallback"
const DescriptorIGetDefaultDownloadableSubscriptionListCallback = "android.service.euicc.IGetDefaultDownloadableSubscriptionListCallback"
const DescriptorIGetDownloadableSubscriptionMetadataCallback = "android.service.euicc.IGetDownloadableSubscriptionMetadataCallback"
const DescriptorIGetEidCallback = "android.service.euicc.IGetEidCallback"
const DescriptorIGetEuiccInfoCallback = "android.service.euicc.IGetEuiccInfoCallback"
const DescriptorIGetEuiccProfileInfoListCallback = "android.service.euicc.IGetEuiccProfileInfoListCallback"
const DescriptorIGetOtaStatusCallback = "android.service.euicc.IGetOtaStatusCallback"
const DescriptorIOtaStatusChangedCallback = "android.service.euicc.IOtaStatusChangedCallback"
const DescriptorIRetainSubscriptionsForFactoryResetCallback = "android.service.euicc.IRetainSubscriptionsForFactoryResetCallback"
const DescriptorISwitchToSubscriptionCallback = "android.service.euicc.ISwitchToSubscriptionCallback"
const DescriptorIUpdateSubscriptionNicknameCallback = "android.service.euicc.IUpdateSubscriptionNicknameCallback"
const (
	MethodIDeleteSubscriptionCallbackOnComplete = "onComplete"
)
const (
	MethodIDownloadSubscriptionCallbackOnComplete = "onComplete"
)
const (
	MethodIEraseSubscriptionsCallbackOnComplete = "onComplete"
)
const (
	MethodIEuiccServiceDumpResultCallbackOnComplete = "onComplete"
)
const (
	MethodIGetDefaultDownloadableSubscriptionListCallbackOnComplete = "onComplete"
)
const (
	MethodIGetDownloadableSubscriptionMetadataCallbackOnComplete = "onComplete"
)
const (
	MethodIGetEidCallbackOnSuccess = "onSuccess"
)
const (
	MethodIGetEuiccInfoCallbackOnSuccess = "onSuccess"
)
const (
	MethodIGetEuiccProfileInfoListCallbackOnComplete = "onComplete"
)
const (
	MethodIGetOtaStatusCallbackOnSuccess = "onSuccess"
)
const (
	MethodIOtaStatusChangedCallbackOnOtaStatusChanged = "onOtaStatusChanged"
)
const (
	MethodIRetainSubscriptionsForFactoryResetCallbackOnComplete = "onComplete"
)
const (
	MethodISwitchToSubscriptionCallbackOnComplete = "onComplete"
)
const (
	MethodIUpdateSubscriptionNicknameCallbackOnComplete = "onComplete"
)
const (
	TransactionIDeleteSubscriptionCallbackOnComplete = binder.FirstCallTransaction + 0
)
const (
	TransactionIDownloadSubscriptionCallbackOnComplete = binder.FirstCallTransaction + 0
)
const (
	TransactionIEraseSubscriptionsCallbackOnComplete = binder.FirstCallTransaction + 0
)
const (
	TransactionIEuiccServiceDumpResultCallbackOnComplete = binder.FirstCallTransaction + 0
)
const (
	TransactionIGetDefaultDownloadableSubscriptionListCallbackOnComplete = binder.FirstCallTransaction + 0
)
const (
	TransactionIGetDownloadableSubscriptionMetadataCallbackOnComplete = binder.FirstCallTransaction + 0
)
const (
	TransactionIGetEidCallbackOnSuccess = binder.FirstCallTransaction + 0
)
const (
	TransactionIGetEuiccInfoCallbackOnSuccess = binder.FirstCallTransaction + 0
)
const (
	TransactionIGetEuiccProfileInfoListCallbackOnComplete = binder.FirstCallTransaction + 0
)
const (
	TransactionIGetOtaStatusCallbackOnSuccess = binder.FirstCallTransaction + 0
)
const (
	TransactionIOtaStatusChangedCallbackOnOtaStatusChanged = binder.FirstCallTransaction + 0
)
const (
	TransactionIRetainSubscriptionsForFactoryResetCallbackOnComplete = binder.FirstCallTransaction + 0
)
const (
	TransactionISwitchToSubscriptionCallbackOnComplete = binder.FirstCallTransaction + 0
)
const (
	TransactionIUpdateSubscriptionNicknameCallbackOnComplete = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type DeleteSubscriptionCallbackProxy

type DeleteSubscriptionCallbackProxy struct {
	Remote binder.IBinder
}

func NewDeleteSubscriptionCallbackProxy

func NewDeleteSubscriptionCallbackProxy(
	remote binder.IBinder,
) *DeleteSubscriptionCallbackProxy

func (*DeleteSubscriptionCallbackProxy) AsBinder

func (*DeleteSubscriptionCallbackProxy) OnComplete

func (p *DeleteSubscriptionCallbackProxy) OnComplete(
	ctx context.Context,
	result int32,
) error

type DeleteSubscriptionCallbackStub

type DeleteSubscriptionCallbackStub struct {
	Impl      IDeleteSubscriptionCallback
	Transport binder.VersionAwareTransport
}

DeleteSubscriptionCallbackStub dispatches incoming binder transactions to a typed IDeleteSubscriptionCallback implementation.

func (*DeleteSubscriptionCallbackStub) Descriptor

func (s *DeleteSubscriptionCallbackStub) Descriptor() string

func (*DeleteSubscriptionCallbackStub) OnTransaction

type DownloadSubscriptionCallbackProxy

type DownloadSubscriptionCallbackProxy struct {
	Remote binder.IBinder
}

func NewDownloadSubscriptionCallbackProxy

func NewDownloadSubscriptionCallbackProxy(
	remote binder.IBinder,
) *DownloadSubscriptionCallbackProxy

func (*DownloadSubscriptionCallbackProxy) AsBinder

func (*DownloadSubscriptionCallbackProxy) OnComplete

type DownloadSubscriptionCallbackStub

type DownloadSubscriptionCallbackStub struct {
	Impl      IDownloadSubscriptionCallback
	Transport binder.VersionAwareTransport
}

DownloadSubscriptionCallbackStub dispatches incoming binder transactions to a typed IDownloadSubscriptionCallback implementation.

func (*DownloadSubscriptionCallbackStub) Descriptor

func (s *DownloadSubscriptionCallbackStub) Descriptor() string

func (*DownloadSubscriptionCallbackStub) OnTransaction

type DownloadSubscriptionResult

type DownloadSubscriptionResult struct {
	Result           int32
	ResolvableErrors int32
	CardId           int32
}

func (*DownloadSubscriptionResult) MarshalParcel

func (s *DownloadSubscriptionResult) MarshalParcel(
	p *parcel.Parcel,
) error

func (*DownloadSubscriptionResult) UnmarshalParcel

func (s *DownloadSubscriptionResult) UnmarshalParcel(
	p *parcel.Parcel,
) error

type EraseSubscriptionsCallbackProxy

type EraseSubscriptionsCallbackProxy struct {
	Remote binder.IBinder
}

func NewEraseSubscriptionsCallbackProxy

func NewEraseSubscriptionsCallbackProxy(
	remote binder.IBinder,
) *EraseSubscriptionsCallbackProxy

func (*EraseSubscriptionsCallbackProxy) AsBinder

func (*EraseSubscriptionsCallbackProxy) OnComplete

func (p *EraseSubscriptionsCallbackProxy) OnComplete(
	ctx context.Context,
	result int32,
) error

type EraseSubscriptionsCallbackStub

type EraseSubscriptionsCallbackStub struct {
	Impl      IEraseSubscriptionsCallback
	Transport binder.VersionAwareTransport
}

EraseSubscriptionsCallbackStub dispatches incoming binder transactions to a typed IEraseSubscriptionsCallback implementation.

func (*EraseSubscriptionsCallbackStub) Descriptor

func (s *EraseSubscriptionsCallbackStub) Descriptor() string

func (*EraseSubscriptionsCallbackStub) OnTransaction

type EuiccProfileInfo

type EuiccProfileInfo struct {
	Iccid               string
	Nickname            string
	ServiceProviderName string
	ProfileName         string
	ProfileClass        int32
	State               int32
	PolicyRules         int32
}

func (*EuiccProfileInfo) MarshalParcel

func (s *EuiccProfileInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*EuiccProfileInfo) UnmarshalParcel

func (s *EuiccProfileInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type EuiccServiceDumpResultCallbackProxy

type EuiccServiceDumpResultCallbackProxy struct {
	Remote binder.IBinder
}

func NewEuiccServiceDumpResultCallbackProxy

func NewEuiccServiceDumpResultCallbackProxy(
	remote binder.IBinder,
) *EuiccServiceDumpResultCallbackProxy

func (*EuiccServiceDumpResultCallbackProxy) AsBinder

func (*EuiccServiceDumpResultCallbackProxy) OnComplete

func (p *EuiccServiceDumpResultCallbackProxy) OnComplete(
	ctx context.Context,
	logs string,
) error

type EuiccServiceDumpResultCallbackStub

type EuiccServiceDumpResultCallbackStub struct {
	Impl      IEuiccServiceDumpResultCallback
	Transport binder.VersionAwareTransport
}

EuiccServiceDumpResultCallbackStub dispatches incoming binder transactions to a typed IEuiccServiceDumpResultCallback implementation.

func (*EuiccServiceDumpResultCallbackStub) Descriptor

func (*EuiccServiceDumpResultCallbackStub) OnTransaction

type EuiccServiceProxy

type EuiccServiceProxy struct {
	Remote binder.IBinder
}

func NewEuiccServiceProxy

func NewEuiccServiceProxy(
	remote binder.IBinder,
) *EuiccServiceProxy

func (*EuiccServiceProxy) AsBinder

func (p *EuiccServiceProxy) AsBinder() binder.IBinder

func (*EuiccServiceProxy) DeleteSubscription

func (p *EuiccServiceProxy) DeleteSubscription(
	ctx context.Context,
	slotId int32,
	iccid string,
	callback IDeleteSubscriptionCallback,
) error

func (*EuiccServiceProxy) DownloadSubscription

func (p *EuiccServiceProxy) DownloadSubscription(
	ctx context.Context,
	slotId int32,
	portIndex int32,
	subscription telephonyEuicc.DownloadableSubscription,
	switchAfterDownload bool,
	forceDeactivateSim bool,
	resolvedBundle os.Bundle,
	callback IDownloadSubscriptionCallback,
) error

func (*EuiccServiceProxy) Dump

func (*EuiccServiceProxy) EraseSubscriptions

func (p *EuiccServiceProxy) EraseSubscriptions(
	ctx context.Context,
	slotId int32,
	callback IEraseSubscriptionsCallback,
) error

func (*EuiccServiceProxy) EraseSubscriptionsWithOptions

func (p *EuiccServiceProxy) EraseSubscriptionsWithOptions(
	ctx context.Context,
	slotIndex int32,
	options int32,
	callback IEraseSubscriptionsCallback,
) error

func (*EuiccServiceProxy) GetAvailableMemoryInBytes

func (p *EuiccServiceProxy) GetAvailableMemoryInBytes(
	ctx context.Context,
	slotId int32,
	callback IGetAvailableMemoryInBytesCallback,
) error

func (*EuiccServiceProxy) GetDefaultDownloadableSubscriptionList

func (p *EuiccServiceProxy) GetDefaultDownloadableSubscriptionList(
	ctx context.Context,
	slotId int32,
	forceDeactivateSim bool,
	callback IGetDefaultDownloadableSubscriptionListCallback,
) error

func (*EuiccServiceProxy) GetDownloadableSubscriptionMetadata

func (p *EuiccServiceProxy) GetDownloadableSubscriptionMetadata(
	ctx context.Context,
	slotId int32,
	portIndex int32,
	subscription telephonyEuicc.DownloadableSubscription,
	switchAfterDownload bool,
	forceDeactivateSim bool,
	callback IGetDownloadableSubscriptionMetadataCallback,
) error

func (*EuiccServiceProxy) GetEid

func (p *EuiccServiceProxy) GetEid(
	ctx context.Context,
	slotId int32,
	callback IGetEidCallback,
) error

func (*EuiccServiceProxy) GetEuiccInfo

func (p *EuiccServiceProxy) GetEuiccInfo(
	ctx context.Context,
	slotId int32,
	callback IGetEuiccInfoCallback,
) error

func (*EuiccServiceProxy) GetEuiccProfileInfoList

func (p *EuiccServiceProxy) GetEuiccProfileInfoList(
	ctx context.Context,
	slotId int32,
	callback IGetEuiccProfileInfoListCallback,
) error

func (*EuiccServiceProxy) GetOtaStatus

func (p *EuiccServiceProxy) GetOtaStatus(
	ctx context.Context,
	slotId int32,
	callback IGetOtaStatusCallback,
) error

func (*EuiccServiceProxy) RetainSubscriptionsForFactoryReset

func (p *EuiccServiceProxy) RetainSubscriptionsForFactoryReset(
	ctx context.Context,
	slotId int32,
	callback IRetainSubscriptionsForFactoryResetCallback,
) error

func (*EuiccServiceProxy) StartOtaIfNecessary

func (p *EuiccServiceProxy) StartOtaIfNecessary(
	ctx context.Context,
	slotId int32,
	statusChangedCallback IOtaStatusChangedCallback,
) error

func (*EuiccServiceProxy) SwitchToSubscription

func (p *EuiccServiceProxy) SwitchToSubscription(
	ctx context.Context,
	slotId int32,
	portIndex int32,
	iccid string,
	forceDeactivateSim bool,
	callback ISwitchToSubscriptionCallback,
	useLegacyApi bool,
) error

func (*EuiccServiceProxy) UpdateSubscriptionNickname

func (p *EuiccServiceProxy) UpdateSubscriptionNickname(
	ctx context.Context,
	slotId int32,
	iccid string,
	nickname string,
	callback IUpdateSubscriptionNicknameCallback,
) error

type EuiccServiceStub

type EuiccServiceStub struct {
	Impl      IEuiccService
	Transport binder.VersionAwareTransport
}

EuiccServiceStub dispatches incoming binder transactions to a typed IEuiccService implementation.

func (*EuiccServiceStub) Descriptor

func (s *EuiccServiceStub) Descriptor() string

func (*EuiccServiceStub) OnTransaction

func (s *EuiccServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type GetAvailableMemoryInBytesCallbackProxy

type GetAvailableMemoryInBytesCallbackProxy struct {
	Remote binder.IBinder
}

func NewGetAvailableMemoryInBytesCallbackProxy

func NewGetAvailableMemoryInBytesCallbackProxy(
	remote binder.IBinder,
) *GetAvailableMemoryInBytesCallbackProxy

func (*GetAvailableMemoryInBytesCallbackProxy) AsBinder

func (*GetAvailableMemoryInBytesCallbackProxy) OnSuccess

func (p *GetAvailableMemoryInBytesCallbackProxy) OnSuccess(
	ctx context.Context,
	availableMemoryInBytes int64,
) error

func (*GetAvailableMemoryInBytesCallbackProxy) OnUnsupportedOperationException

func (p *GetAvailableMemoryInBytesCallbackProxy) OnUnsupportedOperationException(
	ctx context.Context,
	message string,
) error

type GetAvailableMemoryInBytesCallbackStub

type GetAvailableMemoryInBytesCallbackStub struct {
	Impl      IGetAvailableMemoryInBytesCallback
	Transport binder.VersionAwareTransport
}

GetAvailableMemoryInBytesCallbackStub dispatches incoming binder transactions to a typed IGetAvailableMemoryInBytesCallback implementation.

func (*GetAvailableMemoryInBytesCallbackStub) Descriptor

func (*GetAvailableMemoryInBytesCallbackStub) OnTransaction

type GetDefaultDownloadableSubscriptionListCallbackProxy

type GetDefaultDownloadableSubscriptionListCallbackProxy struct {
	Remote binder.IBinder
}

func NewGetDefaultDownloadableSubscriptionListCallbackProxy

func NewGetDefaultDownloadableSubscriptionListCallbackProxy(
	remote binder.IBinder,
) *GetDefaultDownloadableSubscriptionListCallbackProxy

func (*GetDefaultDownloadableSubscriptionListCallbackProxy) AsBinder

func (*GetDefaultDownloadableSubscriptionListCallbackProxy) OnComplete

type GetDefaultDownloadableSubscriptionListCallbackStub

type GetDefaultDownloadableSubscriptionListCallbackStub struct {
	Impl      IGetDefaultDownloadableSubscriptionListCallback
	Transport binder.VersionAwareTransport
}

GetDefaultDownloadableSubscriptionListCallbackStub dispatches incoming binder transactions to a typed IGetDefaultDownloadableSubscriptionListCallback implementation.

func (*GetDefaultDownloadableSubscriptionListCallbackStub) Descriptor

func (*GetDefaultDownloadableSubscriptionListCallbackStub) OnTransaction

type GetDefaultDownloadableSubscriptionListResult

type GetDefaultDownloadableSubscriptionListResult struct {
	Result int32
}

func (*GetDefaultDownloadableSubscriptionListResult) MarshalParcel

func (*GetDefaultDownloadableSubscriptionListResult) UnmarshalParcel

type GetDownloadableSubscriptionMetadataCallbackProxy

type GetDownloadableSubscriptionMetadataCallbackProxy struct {
	Remote binder.IBinder
}

func NewGetDownloadableSubscriptionMetadataCallbackProxy

func NewGetDownloadableSubscriptionMetadataCallbackProxy(
	remote binder.IBinder,
) *GetDownloadableSubscriptionMetadataCallbackProxy

func (*GetDownloadableSubscriptionMetadataCallbackProxy) AsBinder

func (*GetDownloadableSubscriptionMetadataCallbackProxy) OnComplete

type GetDownloadableSubscriptionMetadataCallbackStub

type GetDownloadableSubscriptionMetadataCallbackStub struct {
	Impl      IGetDownloadableSubscriptionMetadataCallback
	Transport binder.VersionAwareTransport
}

GetDownloadableSubscriptionMetadataCallbackStub dispatches incoming binder transactions to a typed IGetDownloadableSubscriptionMetadataCallback implementation.

func (*GetDownloadableSubscriptionMetadataCallbackStub) Descriptor

func (*GetDownloadableSubscriptionMetadataCallbackStub) OnTransaction

type GetDownloadableSubscriptionMetadataResult

type GetDownloadableSubscriptionMetadataResult struct {
	Result int32
}

func (*GetDownloadableSubscriptionMetadataResult) MarshalParcel

func (*GetDownloadableSubscriptionMetadataResult) UnmarshalParcel

type GetEidCallbackProxy

type GetEidCallbackProxy struct {
	Remote binder.IBinder
}

func NewGetEidCallbackProxy

func NewGetEidCallbackProxy(
	remote binder.IBinder,
) *GetEidCallbackProxy

func (*GetEidCallbackProxy) AsBinder

func (p *GetEidCallbackProxy) AsBinder() binder.IBinder

func (*GetEidCallbackProxy) OnSuccess

func (p *GetEidCallbackProxy) OnSuccess(
	ctx context.Context,
	eid string,
) error

type GetEidCallbackStub

type GetEidCallbackStub struct {
	Impl      IGetEidCallback
	Transport binder.VersionAwareTransport
}

GetEidCallbackStub dispatches incoming binder transactions to a typed IGetEidCallback implementation.

func (*GetEidCallbackStub) Descriptor

func (s *GetEidCallbackStub) Descriptor() string

func (*GetEidCallbackStub) OnTransaction

func (s *GetEidCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type GetEuiccInfoCallbackProxy

type GetEuiccInfoCallbackProxy struct {
	Remote binder.IBinder
}

func NewGetEuiccInfoCallbackProxy

func NewGetEuiccInfoCallbackProxy(
	remote binder.IBinder,
) *GetEuiccInfoCallbackProxy

func (*GetEuiccInfoCallbackProxy) AsBinder

func (*GetEuiccInfoCallbackProxy) OnSuccess

func (p *GetEuiccInfoCallbackProxy) OnSuccess(
	ctx context.Context,
	euiccInfo telephonyEuicc.EuiccInfo,
) error

type GetEuiccInfoCallbackStub

type GetEuiccInfoCallbackStub struct {
	Impl      IGetEuiccInfoCallback
	Transport binder.VersionAwareTransport
}

GetEuiccInfoCallbackStub dispatches incoming binder transactions to a typed IGetEuiccInfoCallback implementation.

func (*GetEuiccInfoCallbackStub) Descriptor

func (s *GetEuiccInfoCallbackStub) Descriptor() string

func (*GetEuiccInfoCallbackStub) OnTransaction

func (s *GetEuiccInfoCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type GetEuiccProfileInfoListCallbackProxy

type GetEuiccProfileInfoListCallbackProxy struct {
	Remote binder.IBinder
}

func NewGetEuiccProfileInfoListCallbackProxy

func NewGetEuiccProfileInfoListCallbackProxy(
	remote binder.IBinder,
) *GetEuiccProfileInfoListCallbackProxy

func (*GetEuiccProfileInfoListCallbackProxy) AsBinder

func (*GetEuiccProfileInfoListCallbackProxy) OnComplete

type GetEuiccProfileInfoListCallbackStub

type GetEuiccProfileInfoListCallbackStub struct {
	Impl      IGetEuiccProfileInfoListCallback
	Transport binder.VersionAwareTransport
}

GetEuiccProfileInfoListCallbackStub dispatches incoming binder transactions to a typed IGetEuiccProfileInfoListCallback implementation.

func (*GetEuiccProfileInfoListCallbackStub) Descriptor

func (*GetEuiccProfileInfoListCallbackStub) OnTransaction

type GetEuiccProfileInfoListResult

type GetEuiccProfileInfoListResult struct {
	Result      int32
	IsRemovable bool
}

func (*GetEuiccProfileInfoListResult) MarshalParcel

func (s *GetEuiccProfileInfoListResult) MarshalParcel(
	p *parcel.Parcel,
) error

func (*GetEuiccProfileInfoListResult) UnmarshalParcel

func (s *GetEuiccProfileInfoListResult) UnmarshalParcel(
	p *parcel.Parcel,
) error

type GetOtaStatusCallbackProxy

type GetOtaStatusCallbackProxy struct {
	Remote binder.IBinder
}

func NewGetOtaStatusCallbackProxy

func NewGetOtaStatusCallbackProxy(
	remote binder.IBinder,
) *GetOtaStatusCallbackProxy

func (*GetOtaStatusCallbackProxy) AsBinder

func (*GetOtaStatusCallbackProxy) OnSuccess

func (p *GetOtaStatusCallbackProxy) OnSuccess(
	ctx context.Context,
	status int32,
) error

type GetOtaStatusCallbackStub

type GetOtaStatusCallbackStub struct {
	Impl      IGetOtaStatusCallback
	Transport binder.VersionAwareTransport
}

GetOtaStatusCallbackStub dispatches incoming binder transactions to a typed IGetOtaStatusCallback implementation.

func (*GetOtaStatusCallbackStub) Descriptor

func (s *GetOtaStatusCallbackStub) Descriptor() string

func (*GetOtaStatusCallbackStub) OnTransaction

func (s *GetOtaStatusCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IDeleteSubscriptionCallback

type IDeleteSubscriptionCallback interface {
	AsBinder() binder.IBinder
	OnComplete(ctx context.Context, result int32) error
}

func NewDeleteSubscriptionCallbackStub

func NewDeleteSubscriptionCallbackStub(
	impl IDeleteSubscriptionCallbackServer,
) IDeleteSubscriptionCallback

NewDeleteSubscriptionCallbackStub creates a server-side IDeleteSubscriptionCallback wrapping the given server implementation. The returned value satisfies IDeleteSubscriptionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDeleteSubscriptionCallbackServer

type IDeleteSubscriptionCallbackServer interface {
	OnComplete(ctx context.Context, result int32) error
}

IDeleteSubscriptionCallbackServer is the server-side interface that user implementations provide to NewDeleteSubscriptionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IDownloadSubscriptionCallback

type IDownloadSubscriptionCallback interface {
	AsBinder() binder.IBinder
	OnComplete(ctx context.Context, result DownloadSubscriptionResult) error
}

func NewDownloadSubscriptionCallbackStub

func NewDownloadSubscriptionCallbackStub(
	impl IDownloadSubscriptionCallbackServer,
) IDownloadSubscriptionCallback

NewDownloadSubscriptionCallbackStub creates a server-side IDownloadSubscriptionCallback wrapping the given server implementation. The returned value satisfies IDownloadSubscriptionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDownloadSubscriptionCallbackServer

type IDownloadSubscriptionCallbackServer interface {
	OnComplete(ctx context.Context, result DownloadSubscriptionResult) error
}

IDownloadSubscriptionCallbackServer is the server-side interface that user implementations provide to NewDownloadSubscriptionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IEraseSubscriptionsCallback

type IEraseSubscriptionsCallback interface {
	AsBinder() binder.IBinder
	OnComplete(ctx context.Context, result int32) error
}

func NewEraseSubscriptionsCallbackStub

func NewEraseSubscriptionsCallbackStub(
	impl IEraseSubscriptionsCallbackServer,
) IEraseSubscriptionsCallback

NewEraseSubscriptionsCallbackStub creates a server-side IEraseSubscriptionsCallback wrapping the given server implementation. The returned value satisfies IEraseSubscriptionsCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IEraseSubscriptionsCallbackServer

type IEraseSubscriptionsCallbackServer interface {
	OnComplete(ctx context.Context, result int32) error
}

IEraseSubscriptionsCallbackServer is the server-side interface that user implementations provide to NewEraseSubscriptionsCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IEuiccService

type IEuiccService interface {
	AsBinder() binder.IBinder
	DownloadSubscription(ctx context.Context, slotId int32, portIndex int32, subscription telephonyEuicc.DownloadableSubscription, switchAfterDownload bool, forceDeactivateSim bool, resolvedBundle os.Bundle, callback IDownloadSubscriptionCallback) error
	GetDownloadableSubscriptionMetadata(ctx context.Context, slotId int32, portIndex int32, subscription telephonyEuicc.DownloadableSubscription, switchAfterDownload bool, forceDeactivateSim bool, callback IGetDownloadableSubscriptionMetadataCallback) error
	GetEid(ctx context.Context, slotId int32, callback IGetEidCallback) error
	GetOtaStatus(ctx context.Context, slotId int32, callback IGetOtaStatusCallback) error
	StartOtaIfNecessary(ctx context.Context, slotId int32, statusChangedCallback IOtaStatusChangedCallback) error
	GetEuiccProfileInfoList(ctx context.Context, slotId int32, callback IGetEuiccProfileInfoListCallback) error
	GetDefaultDownloadableSubscriptionList(ctx context.Context, slotId int32, forceDeactivateSim bool, callback IGetDefaultDownloadableSubscriptionListCallback) error
	GetEuiccInfo(ctx context.Context, slotId int32, callback IGetEuiccInfoCallback) error
	DeleteSubscription(ctx context.Context, slotId int32, iccid string, callback IDeleteSubscriptionCallback) error
	SwitchToSubscription(ctx context.Context, slotId int32, portIndex int32, iccid string, forceDeactivateSim bool, callback ISwitchToSubscriptionCallback, useLegacyApi bool) error
	UpdateSubscriptionNickname(ctx context.Context, slotId int32, iccid string, nickname string, callback IUpdateSubscriptionNicknameCallback) error
	EraseSubscriptions(ctx context.Context, slotId int32, callback IEraseSubscriptionsCallback) error
	EraseSubscriptionsWithOptions(ctx context.Context, slotIndex int32, options int32, callback IEraseSubscriptionsCallback) error
	RetainSubscriptionsForFactoryReset(ctx context.Context, slotId int32, callback IRetainSubscriptionsForFactoryResetCallback) error
	Dump(ctx context.Context, callback IEuiccServiceDumpResultCallback) error
	GetAvailableMemoryInBytes(ctx context.Context, slotId int32, callback IGetAvailableMemoryInBytesCallback) error
}

func NewEuiccServiceStub

func NewEuiccServiceStub(
	impl IEuiccServiceServer,
) IEuiccService

NewEuiccServiceStub creates a server-side IEuiccService wrapping the given server implementation. The returned value satisfies IEuiccService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IEuiccServiceDumpResultCallback

type IEuiccServiceDumpResultCallback interface {
	AsBinder() binder.IBinder
	OnComplete(ctx context.Context, logs string) error
}

func NewEuiccServiceDumpResultCallbackStub

func NewEuiccServiceDumpResultCallbackStub(
	impl IEuiccServiceDumpResultCallbackServer,
) IEuiccServiceDumpResultCallback

NewEuiccServiceDumpResultCallbackStub creates a server-side IEuiccServiceDumpResultCallback wrapping the given server implementation. The returned value satisfies IEuiccServiceDumpResultCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IEuiccServiceDumpResultCallbackServer

type IEuiccServiceDumpResultCallbackServer interface {
	OnComplete(ctx context.Context, logs string) error
}

IEuiccServiceDumpResultCallbackServer is the server-side interface that user implementations provide to NewEuiccServiceDumpResultCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IEuiccServiceServer

type IEuiccServiceServer interface {
	DownloadSubscription(ctx context.Context, slotId int32, portIndex int32, subscription telephonyEuicc.DownloadableSubscription, switchAfterDownload bool, forceDeactivateSim bool, resolvedBundle os.Bundle, callback IDownloadSubscriptionCallback) error
	GetDownloadableSubscriptionMetadata(ctx context.Context, slotId int32, portIndex int32, subscription telephonyEuicc.DownloadableSubscription, switchAfterDownload bool, forceDeactivateSim bool, callback IGetDownloadableSubscriptionMetadataCallback) error
	GetEid(ctx context.Context, slotId int32, callback IGetEidCallback) error
	GetOtaStatus(ctx context.Context, slotId int32, callback IGetOtaStatusCallback) error
	StartOtaIfNecessary(ctx context.Context, slotId int32, statusChangedCallback IOtaStatusChangedCallback) error
	GetEuiccProfileInfoList(ctx context.Context, slotId int32, callback IGetEuiccProfileInfoListCallback) error
	GetDefaultDownloadableSubscriptionList(ctx context.Context, slotId int32, forceDeactivateSim bool, callback IGetDefaultDownloadableSubscriptionListCallback) error
	GetEuiccInfo(ctx context.Context, slotId int32, callback IGetEuiccInfoCallback) error
	DeleteSubscription(ctx context.Context, slotId int32, iccid string, callback IDeleteSubscriptionCallback) error
	SwitchToSubscription(ctx context.Context, slotId int32, portIndex int32, iccid string, forceDeactivateSim bool, callback ISwitchToSubscriptionCallback, useLegacyApi bool) error
	UpdateSubscriptionNickname(ctx context.Context, slotId int32, iccid string, nickname string, callback IUpdateSubscriptionNicknameCallback) error
	EraseSubscriptions(ctx context.Context, slotId int32, callback IEraseSubscriptionsCallback) error
	EraseSubscriptionsWithOptions(ctx context.Context, slotIndex int32, options int32, callback IEraseSubscriptionsCallback) error
	RetainSubscriptionsForFactoryReset(ctx context.Context, slotId int32, callback IRetainSubscriptionsForFactoryResetCallback) error
	Dump(ctx context.Context, callback IEuiccServiceDumpResultCallback) error
	GetAvailableMemoryInBytes(ctx context.Context, slotId int32, callback IGetAvailableMemoryInBytesCallback) error
}

IEuiccServiceServer is the server-side interface that user implementations provide to NewEuiccServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGetAvailableMemoryInBytesCallback

type IGetAvailableMemoryInBytesCallback interface {
	AsBinder() binder.IBinder
	OnSuccess(ctx context.Context, availableMemoryInBytes int64) error
	OnUnsupportedOperationException(ctx context.Context, message string) error
}

func NewGetAvailableMemoryInBytesCallbackStub

func NewGetAvailableMemoryInBytesCallbackStub(
	impl IGetAvailableMemoryInBytesCallbackServer,
) IGetAvailableMemoryInBytesCallback

NewGetAvailableMemoryInBytesCallbackStub creates a server-side IGetAvailableMemoryInBytesCallback wrapping the given server implementation. The returned value satisfies IGetAvailableMemoryInBytesCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGetAvailableMemoryInBytesCallbackServer

type IGetAvailableMemoryInBytesCallbackServer interface {
	OnSuccess(ctx context.Context, availableMemoryInBytes int64) error
	OnUnsupportedOperationException(ctx context.Context, message string) error
}

IGetAvailableMemoryInBytesCallbackServer is the server-side interface that user implementations provide to NewGetAvailableMemoryInBytesCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGetDefaultDownloadableSubscriptionListCallback

type IGetDefaultDownloadableSubscriptionListCallback interface {
	AsBinder() binder.IBinder
	OnComplete(ctx context.Context, result GetDefaultDownloadableSubscriptionListResult) error
}

func NewGetDefaultDownloadableSubscriptionListCallbackStub

func NewGetDefaultDownloadableSubscriptionListCallbackStub(
	impl IGetDefaultDownloadableSubscriptionListCallbackServer,
) IGetDefaultDownloadableSubscriptionListCallback

NewGetDefaultDownloadableSubscriptionListCallbackStub creates a server-side IGetDefaultDownloadableSubscriptionListCallback wrapping the given server implementation. The returned value satisfies IGetDefaultDownloadableSubscriptionListCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGetDefaultDownloadableSubscriptionListCallbackServer

type IGetDefaultDownloadableSubscriptionListCallbackServer interface {
	OnComplete(ctx context.Context, result GetDefaultDownloadableSubscriptionListResult) error
}

IGetDefaultDownloadableSubscriptionListCallbackServer is the server-side interface that user implementations provide to NewGetDefaultDownloadableSubscriptionListCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGetDownloadableSubscriptionMetadataCallback

type IGetDownloadableSubscriptionMetadataCallback interface {
	AsBinder() binder.IBinder
	OnComplete(ctx context.Context, result GetDownloadableSubscriptionMetadataResult) error
}

func NewGetDownloadableSubscriptionMetadataCallbackStub

func NewGetDownloadableSubscriptionMetadataCallbackStub(
	impl IGetDownloadableSubscriptionMetadataCallbackServer,
) IGetDownloadableSubscriptionMetadataCallback

NewGetDownloadableSubscriptionMetadataCallbackStub creates a server-side IGetDownloadableSubscriptionMetadataCallback wrapping the given server implementation. The returned value satisfies IGetDownloadableSubscriptionMetadataCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGetDownloadableSubscriptionMetadataCallbackServer

type IGetDownloadableSubscriptionMetadataCallbackServer interface {
	OnComplete(ctx context.Context, result GetDownloadableSubscriptionMetadataResult) error
}

IGetDownloadableSubscriptionMetadataCallbackServer is the server-side interface that user implementations provide to NewGetDownloadableSubscriptionMetadataCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGetEidCallback

type IGetEidCallback interface {
	AsBinder() binder.IBinder
	OnSuccess(ctx context.Context, eid string) error
}

func NewGetEidCallbackStub

func NewGetEidCallbackStub(
	impl IGetEidCallbackServer,
) IGetEidCallback

NewGetEidCallbackStub creates a server-side IGetEidCallback wrapping the given server implementation. The returned value satisfies IGetEidCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGetEidCallbackServer

type IGetEidCallbackServer interface {
	OnSuccess(ctx context.Context, eid string) error
}

IGetEidCallbackServer is the server-side interface that user implementations provide to NewGetEidCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGetEuiccInfoCallback

type IGetEuiccInfoCallback interface {
	AsBinder() binder.IBinder
	OnSuccess(ctx context.Context, euiccInfo telephonyEuicc.EuiccInfo) error
}

func NewGetEuiccInfoCallbackStub

func NewGetEuiccInfoCallbackStub(
	impl IGetEuiccInfoCallbackServer,
) IGetEuiccInfoCallback

NewGetEuiccInfoCallbackStub creates a server-side IGetEuiccInfoCallback wrapping the given server implementation. The returned value satisfies IGetEuiccInfoCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGetEuiccInfoCallbackServer

type IGetEuiccInfoCallbackServer interface {
	OnSuccess(ctx context.Context, euiccInfo telephonyEuicc.EuiccInfo) error
}

IGetEuiccInfoCallbackServer is the server-side interface that user implementations provide to NewGetEuiccInfoCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGetEuiccProfileInfoListCallback

type IGetEuiccProfileInfoListCallback interface {
	AsBinder() binder.IBinder
	OnComplete(ctx context.Context, result GetEuiccProfileInfoListResult) error
}

func NewGetEuiccProfileInfoListCallbackStub

func NewGetEuiccProfileInfoListCallbackStub(
	impl IGetEuiccProfileInfoListCallbackServer,
) IGetEuiccProfileInfoListCallback

NewGetEuiccProfileInfoListCallbackStub creates a server-side IGetEuiccProfileInfoListCallback wrapping the given server implementation. The returned value satisfies IGetEuiccProfileInfoListCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGetEuiccProfileInfoListCallbackServer

type IGetEuiccProfileInfoListCallbackServer interface {
	OnComplete(ctx context.Context, result GetEuiccProfileInfoListResult) error
}

IGetEuiccProfileInfoListCallbackServer is the server-side interface that user implementations provide to NewGetEuiccProfileInfoListCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGetOtaStatusCallback

type IGetOtaStatusCallback interface {
	AsBinder() binder.IBinder
	OnSuccess(ctx context.Context, status int32) error
}

func NewGetOtaStatusCallbackStub

func NewGetOtaStatusCallbackStub(
	impl IGetOtaStatusCallbackServer,
) IGetOtaStatusCallback

NewGetOtaStatusCallbackStub creates a server-side IGetOtaStatusCallback wrapping the given server implementation. The returned value satisfies IGetOtaStatusCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGetOtaStatusCallbackServer

type IGetOtaStatusCallbackServer interface {
	OnSuccess(ctx context.Context, status int32) error
}

IGetOtaStatusCallbackServer is the server-side interface that user implementations provide to NewGetOtaStatusCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IOtaStatusChangedCallback

type IOtaStatusChangedCallback interface {
	AsBinder() binder.IBinder
	OnOtaStatusChanged(ctx context.Context, status int32) error
}

func NewOtaStatusChangedCallbackStub

func NewOtaStatusChangedCallbackStub(
	impl IOtaStatusChangedCallbackServer,
) IOtaStatusChangedCallback

NewOtaStatusChangedCallbackStub creates a server-side IOtaStatusChangedCallback wrapping the given server implementation. The returned value satisfies IOtaStatusChangedCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IOtaStatusChangedCallbackServer

type IOtaStatusChangedCallbackServer interface {
	OnOtaStatusChanged(ctx context.Context, status int32) error
}

IOtaStatusChangedCallbackServer is the server-side interface that user implementations provide to NewOtaStatusChangedCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IRetainSubscriptionsForFactoryResetCallback

type IRetainSubscriptionsForFactoryResetCallback interface {
	AsBinder() binder.IBinder
	OnComplete(ctx context.Context, result int32) error
}

func NewRetainSubscriptionsForFactoryResetCallbackStub

func NewRetainSubscriptionsForFactoryResetCallbackStub(
	impl IRetainSubscriptionsForFactoryResetCallbackServer,
) IRetainSubscriptionsForFactoryResetCallback

NewRetainSubscriptionsForFactoryResetCallbackStub creates a server-side IRetainSubscriptionsForFactoryResetCallback wrapping the given server implementation. The returned value satisfies IRetainSubscriptionsForFactoryResetCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IRetainSubscriptionsForFactoryResetCallbackServer

type IRetainSubscriptionsForFactoryResetCallbackServer interface {
	OnComplete(ctx context.Context, result int32) error
}

IRetainSubscriptionsForFactoryResetCallbackServer is the server-side interface that user implementations provide to NewRetainSubscriptionsForFactoryResetCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISwitchToSubscriptionCallback

type ISwitchToSubscriptionCallback interface {
	AsBinder() binder.IBinder
	OnComplete(ctx context.Context, result int32) error
}

func NewSwitchToSubscriptionCallbackStub

func NewSwitchToSubscriptionCallbackStub(
	impl ISwitchToSubscriptionCallbackServer,
) ISwitchToSubscriptionCallback

NewSwitchToSubscriptionCallbackStub creates a server-side ISwitchToSubscriptionCallback wrapping the given server implementation. The returned value satisfies ISwitchToSubscriptionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISwitchToSubscriptionCallbackServer

type ISwitchToSubscriptionCallbackServer interface {
	OnComplete(ctx context.Context, result int32) error
}

ISwitchToSubscriptionCallbackServer is the server-side interface that user implementations provide to NewSwitchToSubscriptionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IUpdateSubscriptionNicknameCallback

type IUpdateSubscriptionNicknameCallback interface {
	AsBinder() binder.IBinder
	OnComplete(ctx context.Context, result int32) error
}

func NewUpdateSubscriptionNicknameCallbackStub

func NewUpdateSubscriptionNicknameCallbackStub(
	impl IUpdateSubscriptionNicknameCallbackServer,
) IUpdateSubscriptionNicknameCallback

NewUpdateSubscriptionNicknameCallbackStub creates a server-side IUpdateSubscriptionNicknameCallback wrapping the given server implementation. The returned value satisfies IUpdateSubscriptionNicknameCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IUpdateSubscriptionNicknameCallbackServer

type IUpdateSubscriptionNicknameCallbackServer interface {
	OnComplete(ctx context.Context, result int32) error
}

IUpdateSubscriptionNicknameCallbackServer is the server-side interface that user implementations provide to NewUpdateSubscriptionNicknameCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type OtaStatusChangedCallbackProxy

type OtaStatusChangedCallbackProxy struct {
	Remote binder.IBinder
}

func NewOtaStatusChangedCallbackProxy

func NewOtaStatusChangedCallbackProxy(
	remote binder.IBinder,
) *OtaStatusChangedCallbackProxy

func (*OtaStatusChangedCallbackProxy) AsBinder

func (*OtaStatusChangedCallbackProxy) OnOtaStatusChanged

func (p *OtaStatusChangedCallbackProxy) OnOtaStatusChanged(
	ctx context.Context,
	status int32,
) error

type OtaStatusChangedCallbackStub

type OtaStatusChangedCallbackStub struct {
	Impl      IOtaStatusChangedCallback
	Transport binder.VersionAwareTransport
}

OtaStatusChangedCallbackStub dispatches incoming binder transactions to a typed IOtaStatusChangedCallback implementation.

func (*OtaStatusChangedCallbackStub) Descriptor

func (s *OtaStatusChangedCallbackStub) Descriptor() string

func (*OtaStatusChangedCallbackStub) OnTransaction

type RetainSubscriptionsForFactoryResetCallbackProxy

type RetainSubscriptionsForFactoryResetCallbackProxy struct {
	Remote binder.IBinder
}

func NewRetainSubscriptionsForFactoryResetCallbackProxy

func NewRetainSubscriptionsForFactoryResetCallbackProxy(
	remote binder.IBinder,
) *RetainSubscriptionsForFactoryResetCallbackProxy

func (*RetainSubscriptionsForFactoryResetCallbackProxy) AsBinder

func (*RetainSubscriptionsForFactoryResetCallbackProxy) OnComplete

type RetainSubscriptionsForFactoryResetCallbackStub

type RetainSubscriptionsForFactoryResetCallbackStub struct {
	Impl      IRetainSubscriptionsForFactoryResetCallback
	Transport binder.VersionAwareTransport
}

RetainSubscriptionsForFactoryResetCallbackStub dispatches incoming binder transactions to a typed IRetainSubscriptionsForFactoryResetCallback implementation.

func (*RetainSubscriptionsForFactoryResetCallbackStub) Descriptor

func (*RetainSubscriptionsForFactoryResetCallbackStub) OnTransaction

type SwitchToSubscriptionCallbackProxy

type SwitchToSubscriptionCallbackProxy struct {
	Remote binder.IBinder
}

func NewSwitchToSubscriptionCallbackProxy

func NewSwitchToSubscriptionCallbackProxy(
	remote binder.IBinder,
) *SwitchToSubscriptionCallbackProxy

func (*SwitchToSubscriptionCallbackProxy) AsBinder

func (*SwitchToSubscriptionCallbackProxy) OnComplete

func (p *SwitchToSubscriptionCallbackProxy) OnComplete(
	ctx context.Context,
	result int32,
) error

type SwitchToSubscriptionCallbackStub

type SwitchToSubscriptionCallbackStub struct {
	Impl      ISwitchToSubscriptionCallback
	Transport binder.VersionAwareTransport
}

SwitchToSubscriptionCallbackStub dispatches incoming binder transactions to a typed ISwitchToSubscriptionCallback implementation.

func (*SwitchToSubscriptionCallbackStub) Descriptor

func (s *SwitchToSubscriptionCallbackStub) Descriptor() string

func (*SwitchToSubscriptionCallbackStub) OnTransaction

type UpdateSubscriptionNicknameCallbackProxy

type UpdateSubscriptionNicknameCallbackProxy struct {
	Remote binder.IBinder
}

func NewUpdateSubscriptionNicknameCallbackProxy

func NewUpdateSubscriptionNicknameCallbackProxy(
	remote binder.IBinder,
) *UpdateSubscriptionNicknameCallbackProxy

func (*UpdateSubscriptionNicknameCallbackProxy) AsBinder

func (*UpdateSubscriptionNicknameCallbackProxy) OnComplete

func (p *UpdateSubscriptionNicknameCallbackProxy) OnComplete(
	ctx context.Context,
	result int32,
) error

type UpdateSubscriptionNicknameCallbackStub

type UpdateSubscriptionNicknameCallbackStub struct {
	Impl      IUpdateSubscriptionNicknameCallback
	Transport binder.VersionAwareTransport
}

UpdateSubscriptionNicknameCallbackStub dispatches incoming binder transactions to a typed IUpdateSubscriptionNicknameCallback implementation.

func (*UpdateSubscriptionNicknameCallbackStub) Descriptor

func (*UpdateSubscriptionNicknameCallbackStub) OnTransaction

Jump to