ondeviceintelligence

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIOnDeviceIntelligenceServiceGetVersion                          = binder.FirstCallTransaction + 0
	TransactionIOnDeviceIntelligenceServiceGetFeature                          = binder.FirstCallTransaction + 1
	TransactionIOnDeviceIntelligenceServiceListFeatures                        = binder.FirstCallTransaction + 2
	TransactionIOnDeviceIntelligenceServiceGetFeatureDetails                   = binder.FirstCallTransaction + 3
	TransactionIOnDeviceIntelligenceServiceGetReadOnlyFileDescriptor           = binder.FirstCallTransaction + 4
	TransactionIOnDeviceIntelligenceServiceGetReadOnlyFeatureFileDescriptorMap = binder.FirstCallTransaction + 5
	TransactionIOnDeviceIntelligenceServiceRequestFeatureDownload              = binder.FirstCallTransaction + 6
	TransactionIOnDeviceIntelligenceServiceRegisterRemoteServices              = binder.FirstCallTransaction + 7
)
const (
	MethodIOnDeviceIntelligenceServiceGetVersion                          = "getVersion"
	MethodIOnDeviceIntelligenceServiceGetFeature                          = "getFeature"
	MethodIOnDeviceIntelligenceServiceListFeatures                        = "listFeatures"
	MethodIOnDeviceIntelligenceServiceGetFeatureDetails                   = "getFeatureDetails"
	MethodIOnDeviceIntelligenceServiceGetReadOnlyFileDescriptor           = "getReadOnlyFileDescriptor"
	MethodIOnDeviceIntelligenceServiceGetReadOnlyFeatureFileDescriptorMap = "getReadOnlyFeatureFileDescriptorMap"
	MethodIOnDeviceIntelligenceServiceRequestFeatureDownload              = "requestFeatureDownload"
	MethodIOnDeviceIntelligenceServiceRegisterRemoteServices              = "registerRemoteServices"
)
const (
	TransactionIOnDeviceTrustedInferenceServiceRegisterRemoteStorageService = binder.FirstCallTransaction + 0
	TransactionIOnDeviceTrustedInferenceServiceRequestTokenCount            = binder.FirstCallTransaction + 1
	TransactionIOnDeviceTrustedInferenceServiceProcessRequest               = binder.FirstCallTransaction + 2
	TransactionIOnDeviceTrustedInferenceServiceProcessRequestStreaming      = binder.FirstCallTransaction + 3
	TransactionIOnDeviceTrustedInferenceServiceUpdateProcessingState        = binder.FirstCallTransaction + 4
)
const (
	MethodIOnDeviceTrustedInferenceServiceRegisterRemoteStorageService = "registerRemoteStorageService"
	MethodIOnDeviceTrustedInferenceServiceRequestTokenCount            = "requestTokenCount"
	MethodIOnDeviceTrustedInferenceServiceProcessRequest               = "processRequest"
	MethodIOnDeviceTrustedInferenceServiceProcessRequestStreaming      = "processRequestStreaming"
	MethodIOnDeviceTrustedInferenceServiceUpdateProcessingState        = "updateProcessingState"
)
const (
	TransactionIProcessingUpdateStatusCallbackOnSuccess = binder.FirstCallTransaction + 0
	TransactionIProcessingUpdateStatusCallbackOnFailure = binder.FirstCallTransaction + 1
)
const (
	MethodIProcessingUpdateStatusCallbackOnSuccess = "onSuccess"
	MethodIProcessingUpdateStatusCallbackOnFailure = "onFailure"
)
const (
	TransactionIRemoteStorageServiceGetReadOnlyFileDescriptor           = binder.FirstCallTransaction + 0
	TransactionIRemoteStorageServiceGetReadOnlyFeatureFileDescriptorMap = binder.FirstCallTransaction + 1
)
const (
	MethodIRemoteStorageServiceGetReadOnlyFileDescriptor           = "getReadOnlyFileDescriptor"
	MethodIRemoteStorageServiceGetReadOnlyFeatureFileDescriptorMap = "getReadOnlyFeatureFileDescriptorMap"
)
const DescriptorIOnDeviceIntelligenceService = "android.service.ondeviceintelligence.IOnDeviceIntelligenceService"
const DescriptorIOnDeviceTrustedInferenceService = "android.service.ondeviceintelligence.IOnDeviceTrustedInferenceService"
const DescriptorIProcessingUpdateStatusCallback = "android.service.ondeviceintelligence.IProcessingUpdateStatusCallback"
const DescriptorIRemoteProcessingService = "android.service.ondeviceintelligence.IRemoteProcessingService"
const DescriptorIRemoteStorageService = "android.service.ondeviceintelligence.IRemoteStorageService"
const (
	MethodIRemoteProcessingServiceUpdateProcessingState = "updateProcessingState"
)
const (
	TransactionIRemoteProcessingServiceUpdateProcessingState = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type IOnDeviceIntelligenceService

type IOnDeviceIntelligenceService interface {
	AsBinder() binder.IBinder
	GetVersion(ctx context.Context, remoteCallback os.RemoteCallback) error
	GetFeature(ctx context.Context, featureId int32, featureCallback appOndeviceintelligence.IFeatureCallback) error
	ListFeatures(ctx context.Context, listFeaturesCallback appOndeviceintelligence.IListFeaturesCallback) error
	GetFeatureDetails(ctx context.Context, feature appOndeviceintelligence.Feature, featureDetailsCallback appOndeviceintelligence.IFeatureDetailsCallback) error
	GetReadOnlyFileDescriptor(ctx context.Context, fileName string, future infra.AndroidFuture) error
	GetReadOnlyFeatureFileDescriptorMap(ctx context.Context, feature appOndeviceintelligence.Feature, remoteCallback os.RemoteCallback) error
	RequestFeatureDownload(ctx context.Context, feature appOndeviceintelligence.Feature, cancellationSignal os.ICancellationSignal, downloadCallback appOndeviceintelligence.IDownloadCallback) error
	RegisterRemoteServices(ctx context.Context, remoteProcessingService IRemoteProcessingService) error
}

func NewOnDeviceIntelligenceServiceStub

func NewOnDeviceIntelligenceServiceStub(
	impl IOnDeviceIntelligenceServiceServer,
) IOnDeviceIntelligenceService

NewOnDeviceIntelligenceServiceStub creates a server-side IOnDeviceIntelligenceService wrapping the given server implementation. The returned value satisfies IOnDeviceIntelligenceService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IOnDeviceIntelligenceServiceServer

type IOnDeviceIntelligenceServiceServer interface {
	GetVersion(ctx context.Context, remoteCallback os.RemoteCallback) error
	GetFeature(ctx context.Context, featureId int32, featureCallback appOndeviceintelligence.IFeatureCallback) error
	ListFeatures(ctx context.Context, listFeaturesCallback appOndeviceintelligence.IListFeaturesCallback) error
	GetFeatureDetails(ctx context.Context, feature appOndeviceintelligence.Feature, featureDetailsCallback appOndeviceintelligence.IFeatureDetailsCallback) error
	GetReadOnlyFileDescriptor(ctx context.Context, fileName string, future infra.AndroidFuture) error
	GetReadOnlyFeatureFileDescriptorMap(ctx context.Context, feature appOndeviceintelligence.Feature, remoteCallback os.RemoteCallback) error
	RequestFeatureDownload(ctx context.Context, feature appOndeviceintelligence.Feature, cancellationSignal os.ICancellationSignal, downloadCallback appOndeviceintelligence.IDownloadCallback) error
	RegisterRemoteServices(ctx context.Context, remoteProcessingService IRemoteProcessingService) error
}

IOnDeviceIntelligenceServiceServer is the server-side interface that user implementations provide to NewOnDeviceIntelligenceServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IOnDeviceTrustedInferenceService

type IOnDeviceTrustedInferenceService interface {
	AsBinder() binder.IBinder
	RegisterRemoteStorageService(ctx context.Context, storageService IRemoteStorageService) error
	RequestTokenCount(ctx context.Context, feature appOndeviceintelligence.Feature, request appOndeviceintelligence.Content, cancellationSignal os.ICancellationSignal, tokenCountCallback appOndeviceintelligence.ITokenCountCallback) error
	ProcessRequest(ctx context.Context, feature appOndeviceintelligence.Feature, request appOndeviceintelligence.Content, requestType int32, cancellationSignal os.ICancellationSignal, processingSignal appOndeviceintelligence.IProcessingSignal, callback appOndeviceintelligence.IResponseCallback) error
	ProcessRequestStreaming(ctx context.Context, feature appOndeviceintelligence.Feature, request appOndeviceintelligence.Content, requestType int32, cancellationSignal os.ICancellationSignal, processingSignal appOndeviceintelligence.IProcessingSignal, callback appOndeviceintelligence.IStreamingResponseCallback) error
	UpdateProcessingState(ctx context.Context, processingState os.Bundle, callback IProcessingUpdateStatusCallback) error
}

func NewOnDeviceTrustedInferenceServiceStub

func NewOnDeviceTrustedInferenceServiceStub(
	impl IOnDeviceTrustedInferenceServiceServer,
) IOnDeviceTrustedInferenceService

NewOnDeviceTrustedInferenceServiceStub creates a server-side IOnDeviceTrustedInferenceService wrapping the given server implementation. The returned value satisfies IOnDeviceTrustedInferenceService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IOnDeviceTrustedInferenceServiceServer

type IOnDeviceTrustedInferenceServiceServer interface {
	RegisterRemoteStorageService(ctx context.Context, storageService IRemoteStorageService) error
	RequestTokenCount(ctx context.Context, feature appOndeviceintelligence.Feature, request appOndeviceintelligence.Content, cancellationSignal os.ICancellationSignal, tokenCountCallback appOndeviceintelligence.ITokenCountCallback) error
	ProcessRequest(ctx context.Context, feature appOndeviceintelligence.Feature, request appOndeviceintelligence.Content, requestType int32, cancellationSignal os.ICancellationSignal, processingSignal appOndeviceintelligence.IProcessingSignal, callback appOndeviceintelligence.IResponseCallback) error
	ProcessRequestStreaming(ctx context.Context, feature appOndeviceintelligence.Feature, request appOndeviceintelligence.Content, requestType int32, cancellationSignal os.ICancellationSignal, processingSignal appOndeviceintelligence.IProcessingSignal, callback appOndeviceintelligence.IStreamingResponseCallback) error
	UpdateProcessingState(ctx context.Context, processingState os.Bundle, callback IProcessingUpdateStatusCallback) error
}

IOnDeviceTrustedInferenceServiceServer is the server-side interface that user implementations provide to NewOnDeviceTrustedInferenceServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IProcessingUpdateStatusCallback

type IProcessingUpdateStatusCallback interface {
	AsBinder() binder.IBinder
	OnSuccess(ctx context.Context, statusParams os.PersistableBundle) error
	OnFailure(ctx context.Context, errorCode int32, errorMessage string) error
}

func NewProcessingUpdateStatusCallbackStub

func NewProcessingUpdateStatusCallbackStub(
	impl IProcessingUpdateStatusCallbackServer,
) IProcessingUpdateStatusCallback

NewProcessingUpdateStatusCallbackStub creates a server-side IProcessingUpdateStatusCallback wrapping the given server implementation. The returned value satisfies IProcessingUpdateStatusCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IProcessingUpdateStatusCallbackServer

type IProcessingUpdateStatusCallbackServer interface {
	OnSuccess(ctx context.Context, statusParams os.PersistableBundle) error
	OnFailure(ctx context.Context, errorCode int32, errorMessage string) error
}

IProcessingUpdateStatusCallbackServer is the server-side interface that user implementations provide to NewProcessingUpdateStatusCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IRemoteProcessingService

type IRemoteProcessingService interface {
	AsBinder() binder.IBinder
	UpdateProcessingState(ctx context.Context, processingState os.Bundle, callback IProcessingUpdateStatusCallback) error
}

func NewRemoteProcessingServiceStub

func NewRemoteProcessingServiceStub(
	impl IRemoteProcessingServiceServer,
) IRemoteProcessingService

NewRemoteProcessingServiceStub creates a server-side IRemoteProcessingService wrapping the given server implementation. The returned value satisfies IRemoteProcessingService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IRemoteProcessingServiceServer

type IRemoteProcessingServiceServer interface {
	UpdateProcessingState(ctx context.Context, processingState os.Bundle, callback IProcessingUpdateStatusCallback) error
}

IRemoteProcessingServiceServer is the server-side interface that user implementations provide to NewRemoteProcessingServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IRemoteStorageService

type IRemoteStorageService interface {
	AsBinder() binder.IBinder
	GetReadOnlyFileDescriptor(ctx context.Context, filePath string, future infra.AndroidFuture) error
	GetReadOnlyFeatureFileDescriptorMap(ctx context.Context, feature appOndeviceintelligence.Feature, remoteCallback os.RemoteCallback) error
}

func NewRemoteStorageServiceStub

func NewRemoteStorageServiceStub(
	impl IRemoteStorageServiceServer,
) IRemoteStorageService

NewRemoteStorageServiceStub creates a server-side IRemoteStorageService wrapping the given server implementation. The returned value satisfies IRemoteStorageService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IRemoteStorageServiceServer

type IRemoteStorageServiceServer interface {
	GetReadOnlyFileDescriptor(ctx context.Context, filePath string, future infra.AndroidFuture) error
	GetReadOnlyFeatureFileDescriptorMap(ctx context.Context, feature appOndeviceintelligence.Feature, remoteCallback os.RemoteCallback) error
}

IRemoteStorageServiceServer is the server-side interface that user implementations provide to NewRemoteStorageServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type OnDeviceIntelligenceServiceProxy

type OnDeviceIntelligenceServiceProxy struct {
	Remote binder.IBinder
}

func NewOnDeviceIntelligenceServiceProxy

func NewOnDeviceIntelligenceServiceProxy(
	remote binder.IBinder,
) *OnDeviceIntelligenceServiceProxy

func (*OnDeviceIntelligenceServiceProxy) AsBinder

func (*OnDeviceIntelligenceServiceProxy) GetFeature

func (p *OnDeviceIntelligenceServiceProxy) GetFeature(
	ctx context.Context,
	featureId int32,
	featureCallback appOndeviceintelligence.IFeatureCallback,
) error

func (*OnDeviceIntelligenceServiceProxy) GetFeatureDetails

func (*OnDeviceIntelligenceServiceProxy) GetReadOnlyFeatureFileDescriptorMap

func (p *OnDeviceIntelligenceServiceProxy) GetReadOnlyFeatureFileDescriptorMap(
	ctx context.Context,
	feature appOndeviceintelligence.Feature,
	remoteCallback os.RemoteCallback,
) error

func (*OnDeviceIntelligenceServiceProxy) GetReadOnlyFileDescriptor

func (p *OnDeviceIntelligenceServiceProxy) GetReadOnlyFileDescriptor(
	ctx context.Context,
	fileName string,
	future infra.AndroidFuture,
) error

func (*OnDeviceIntelligenceServiceProxy) GetVersion

func (p *OnDeviceIntelligenceServiceProxy) GetVersion(
	ctx context.Context,
	remoteCallback os.RemoteCallback,
) error

func (*OnDeviceIntelligenceServiceProxy) ListFeatures

func (*OnDeviceIntelligenceServiceProxy) RegisterRemoteServices

func (p *OnDeviceIntelligenceServiceProxy) RegisterRemoteServices(
	ctx context.Context,
	remoteProcessingService IRemoteProcessingService,
) error

func (*OnDeviceIntelligenceServiceProxy) RequestFeatureDownload

func (p *OnDeviceIntelligenceServiceProxy) RequestFeatureDownload(
	ctx context.Context,
	feature appOndeviceintelligence.Feature,
	cancellationSignal os.ICancellationSignal,
	downloadCallback appOndeviceintelligence.IDownloadCallback,
) error

type OnDeviceIntelligenceServiceStub

type OnDeviceIntelligenceServiceStub struct {
	Impl      IOnDeviceIntelligenceService
	Transport binder.VersionAwareTransport
}

OnDeviceIntelligenceServiceStub dispatches incoming binder transactions to a typed IOnDeviceIntelligenceService implementation.

func (*OnDeviceIntelligenceServiceStub) Descriptor

func (s *OnDeviceIntelligenceServiceStub) Descriptor() string

func (*OnDeviceIntelligenceServiceStub) OnTransaction

type OnDeviceTrustedInferenceServiceProxy

type OnDeviceTrustedInferenceServiceProxy struct {
	Remote binder.IBinder
}

func NewOnDeviceTrustedInferenceServiceProxy

func NewOnDeviceTrustedInferenceServiceProxy(
	remote binder.IBinder,
) *OnDeviceTrustedInferenceServiceProxy

func (*OnDeviceTrustedInferenceServiceProxy) AsBinder

func (*OnDeviceTrustedInferenceServiceProxy) ProcessRequest

func (*OnDeviceTrustedInferenceServiceProxy) ProcessRequestStreaming

func (*OnDeviceTrustedInferenceServiceProxy) RegisterRemoteStorageService

func (p *OnDeviceTrustedInferenceServiceProxy) RegisterRemoteStorageService(
	ctx context.Context,
	storageService IRemoteStorageService,
) error

func (*OnDeviceTrustedInferenceServiceProxy) RequestTokenCount

func (*OnDeviceTrustedInferenceServiceProxy) UpdateProcessingState

func (p *OnDeviceTrustedInferenceServiceProxy) UpdateProcessingState(
	ctx context.Context,
	processingState os.Bundle,
	callback IProcessingUpdateStatusCallback,
) error

type OnDeviceTrustedInferenceServiceStub

type OnDeviceTrustedInferenceServiceStub struct {
	Impl      IOnDeviceTrustedInferenceService
	Transport binder.VersionAwareTransport
}

OnDeviceTrustedInferenceServiceStub dispatches incoming binder transactions to a typed IOnDeviceTrustedInferenceService implementation.

func (*OnDeviceTrustedInferenceServiceStub) Descriptor

func (*OnDeviceTrustedInferenceServiceStub) OnTransaction

type ProcessingUpdateStatusCallbackProxy

type ProcessingUpdateStatusCallbackProxy struct {
	Remote binder.IBinder
}

func NewProcessingUpdateStatusCallbackProxy

func NewProcessingUpdateStatusCallbackProxy(
	remote binder.IBinder,
) *ProcessingUpdateStatusCallbackProxy

func (*ProcessingUpdateStatusCallbackProxy) AsBinder

func (*ProcessingUpdateStatusCallbackProxy) OnFailure

func (p *ProcessingUpdateStatusCallbackProxy) OnFailure(
	ctx context.Context,
	errorCode int32,
	errorMessage string,
) error

func (*ProcessingUpdateStatusCallbackProxy) OnSuccess

func (p *ProcessingUpdateStatusCallbackProxy) OnSuccess(
	ctx context.Context,
	statusParams os.PersistableBundle,
) error

type ProcessingUpdateStatusCallbackStub

type ProcessingUpdateStatusCallbackStub struct {
	Impl      IProcessingUpdateStatusCallback
	Transport binder.VersionAwareTransport
}

ProcessingUpdateStatusCallbackStub dispatches incoming binder transactions to a typed IProcessingUpdateStatusCallback implementation.

func (*ProcessingUpdateStatusCallbackStub) Descriptor

func (*ProcessingUpdateStatusCallbackStub) OnTransaction

type RemoteProcessingServiceProxy

type RemoteProcessingServiceProxy struct {
	Remote binder.IBinder
}

func NewRemoteProcessingServiceProxy

func NewRemoteProcessingServiceProxy(
	remote binder.IBinder,
) *RemoteProcessingServiceProxy

func (*RemoteProcessingServiceProxy) AsBinder

func (*RemoteProcessingServiceProxy) UpdateProcessingState

func (p *RemoteProcessingServiceProxy) UpdateProcessingState(
	ctx context.Context,
	processingState os.Bundle,
	callback IProcessingUpdateStatusCallback,
) error

type RemoteProcessingServiceStub

type RemoteProcessingServiceStub struct {
	Impl      IRemoteProcessingService
	Transport binder.VersionAwareTransport
}

RemoteProcessingServiceStub dispatches incoming binder transactions to a typed IRemoteProcessingService implementation.

func (*RemoteProcessingServiceStub) Descriptor

func (s *RemoteProcessingServiceStub) Descriptor() string

func (*RemoteProcessingServiceStub) OnTransaction

func (s *RemoteProcessingServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type RemoteStorageServiceProxy

type RemoteStorageServiceProxy struct {
	Remote binder.IBinder
}

func NewRemoteStorageServiceProxy

func NewRemoteStorageServiceProxy(
	remote binder.IBinder,
) *RemoteStorageServiceProxy

func (*RemoteStorageServiceProxy) AsBinder

func (*RemoteStorageServiceProxy) GetReadOnlyFeatureFileDescriptorMap

func (p *RemoteStorageServiceProxy) GetReadOnlyFeatureFileDescriptorMap(
	ctx context.Context,
	feature appOndeviceintelligence.Feature,
	remoteCallback os.RemoteCallback,
) error

func (*RemoteStorageServiceProxy) GetReadOnlyFileDescriptor

func (p *RemoteStorageServiceProxy) GetReadOnlyFileDescriptor(
	ctx context.Context,
	filePath string,
	future infra.AndroidFuture,
) error

type RemoteStorageServiceStub

type RemoteStorageServiceStub struct {
	Impl      IRemoteStorageService
	Transport binder.VersionAwareTransport
}

RemoteStorageServiceStub dispatches incoming binder transactions to a typed IRemoteStorageService implementation.

func (*RemoteStorageServiceStub) Descriptor

func (s *RemoteStorageServiceStub) Descriptor() string

func (*RemoteStorageServiceStub) OnTransaction

func (s *RemoteStorageServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to