rotationresolver

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIRotationResolverCallbackOnCancellable = binder.FirstCallTransaction + 0
	TransactionIRotationResolverCallbackOnSuccess     = binder.FirstCallTransaction + 1
	TransactionIRotationResolverCallbackOnFailure     = binder.FirstCallTransaction + 2
)
const (
	MethodIRotationResolverCallbackOnCancellable = "onCancellable"
	MethodIRotationResolverCallbackOnSuccess     = "onSuccess"
	MethodIRotationResolverCallbackOnFailure     = "onFailure"
)
const DescriptorIRotationResolverCallback = "android.service.rotationresolver.IRotationResolverCallback"
const DescriptorIRotationResolverService = "android.service.rotationresolver.IRotationResolverService"
const (
	MethodIRotationResolverServiceResolveRotation = "resolveRotation"
)
const (
	TransactionIRotationResolverServiceResolveRotation = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type IRotationResolverCallback

type IRotationResolverCallback interface {
	AsBinder() binder.IBinder
	OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
	OnSuccess(ctx context.Context, recommendedRotation int32) error
	OnFailure(ctx context.Context, error_ int32) error
}

func NewRotationResolverCallbackStub

func NewRotationResolverCallbackStub(
	impl IRotationResolverCallbackServer,
) IRotationResolverCallback

NewRotationResolverCallbackStub creates a server-side IRotationResolverCallback wrapping the given server implementation. The returned value satisfies IRotationResolverCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IRotationResolverCallbackServer

type IRotationResolverCallbackServer interface {
	OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
	OnSuccess(ctx context.Context, recommendedRotation int32) error
	OnFailure(ctx context.Context, error_ int32) error
}

IRotationResolverCallbackServer is the server-side interface that user implementations provide to NewRotationResolverCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IRotationResolverService

type IRotationResolverService interface {
	AsBinder() binder.IBinder
	ResolveRotation(ctx context.Context, callback IRotationResolverCallback, request RotationResolutionRequest) error
}

func NewRotationResolverServiceStub

func NewRotationResolverServiceStub(
	impl IRotationResolverServiceServer,
) IRotationResolverService

NewRotationResolverServiceStub creates a server-side IRotationResolverService wrapping the given server implementation. The returned value satisfies IRotationResolverService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IRotationResolverServiceServer

type IRotationResolverServiceServer interface {
	ResolveRotation(ctx context.Context, callback IRotationResolverCallback, request RotationResolutionRequest) error
}

IRotationResolverServiceServer is the server-side interface that user implementations provide to NewRotationResolverServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type RotationResolutionRequest

type RotationResolutionRequest struct {
	Flg                   int32
	ForegroundPackageName string
	CurrentRotation       int32
	ProposedRotation      int32
	TimeoutMillis         int64
}

func (*RotationResolutionRequest) MarshalParcel

func (s *RotationResolutionRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*RotationResolutionRequest) UnmarshalParcel

func (s *RotationResolutionRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type RotationResolverCallbackProxy

type RotationResolverCallbackProxy struct {
	Remote binder.IBinder
}

func NewRotationResolverCallbackProxy

func NewRotationResolverCallbackProxy(
	remote binder.IBinder,
) *RotationResolverCallbackProxy

func (*RotationResolverCallbackProxy) AsBinder

func (*RotationResolverCallbackProxy) OnCancellable

func (p *RotationResolverCallbackProxy) OnCancellable(
	ctx context.Context,
	cancellation os.ICancellationSignal,
) error

func (*RotationResolverCallbackProxy) OnFailure

func (p *RotationResolverCallbackProxy) OnFailure(
	ctx context.Context,
	error_ int32,
) error

func (*RotationResolverCallbackProxy) OnSuccess

func (p *RotationResolverCallbackProxy) OnSuccess(
	ctx context.Context,
	recommendedRotation int32,
) error

type RotationResolverCallbackStub

type RotationResolverCallbackStub struct {
	Impl      IRotationResolverCallback
	Transport binder.VersionAwareTransport
}

RotationResolverCallbackStub dispatches incoming binder transactions to a typed IRotationResolverCallback implementation.

func (*RotationResolverCallbackStub) Descriptor

func (s *RotationResolverCallbackStub) Descriptor() string

func (*RotationResolverCallbackStub) OnTransaction

type RotationResolverServiceProxy

type RotationResolverServiceProxy struct {
	Remote binder.IBinder
}

func NewRotationResolverServiceProxy

func NewRotationResolverServiceProxy(
	remote binder.IBinder,
) *RotationResolverServiceProxy

func (*RotationResolverServiceProxy) AsBinder

func (*RotationResolverServiceProxy) ResolveRotation

type RotationResolverServiceStub

type RotationResolverServiceStub struct {
	Impl      IRotationResolverService
	Transport binder.VersionAwareTransport
}

RotationResolverServiceStub dispatches incoming binder transactions to a typed IRotationResolverService implementation.

func (*RotationResolverServiceStub) Descriptor

func (s *RotationResolverServiceStub) Descriptor() string

func (*RotationResolverServiceStub) OnTransaction

func (s *RotationResolverServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to