wallpaper

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIWallpaperConnectionAttachEngine                  = binder.FirstCallTransaction + 0
	TransactionIWallpaperConnectionEngineShown                   = binder.FirstCallTransaction + 1
	TransactionIWallpaperConnectionSetWallpaper                  = binder.FirstCallTransaction + 2
	TransactionIWallpaperConnectionOnWallpaperColorsChanged      = binder.FirstCallTransaction + 3
	TransactionIWallpaperConnectionOnLocalWallpaperColorsChanged = binder.FirstCallTransaction + 4
)
const (
	MethodIWallpaperConnectionAttachEngine                  = "attachEngine"
	MethodIWallpaperConnectionEngineShown                   = "engineShown"
	MethodIWallpaperConnectionSetWallpaper                  = "setWallpaper"
	MethodIWallpaperConnectionOnWallpaperColorsChanged      = "onWallpaperColorsChanged"
	MethodIWallpaperConnectionOnLocalWallpaperColorsChanged = "onLocalWallpaperColorsChanged"
)
const (
	TransactionIWallpaperEngineSetDesiredSize           = binder.FirstCallTransaction + 0
	TransactionIWallpaperEngineSetDisplayPadding        = binder.FirstCallTransaction + 1
	TransactionIWallpaperEngineSetVisibility            = binder.FirstCallTransaction + 2
	TransactionIWallpaperEngineOnScreenTurningOn        = binder.FirstCallTransaction + 3
	TransactionIWallpaperEngineOnScreenTurnedOn         = binder.FirstCallTransaction + 4
	TransactionIWallpaperEngineSetInAmbientMode         = binder.FirstCallTransaction + 5
	TransactionIWallpaperEngineDispatchPointer          = binder.FirstCallTransaction + 6
	TransactionIWallpaperEngineDispatchWallpaperCommand = binder.FirstCallTransaction + 7
	TransactionIWallpaperEngineRequestWallpaperColors   = binder.FirstCallTransaction + 8
	TransactionIWallpaperEngineDestroy                  = binder.FirstCallTransaction + 9
	TransactionIWallpaperEngineSetZoomOut               = binder.FirstCallTransaction + 10
	TransactionIWallpaperEngineResizePreview            = binder.FirstCallTransaction + 11
	TransactionIWallpaperEngineRemoveLocalColorsAreas   = binder.FirstCallTransaction + 12
	TransactionIWallpaperEngineAddLocalColorsAreas      = binder.FirstCallTransaction + 13
	TransactionIWallpaperEngineMirrorSurfaceControl     = binder.FirstCallTransaction + 14
	TransactionIWallpaperEngineApplyDimming             = binder.FirstCallTransaction + 15
	TransactionIWallpaperEngineSetWallpaperFlags        = binder.FirstCallTransaction + 16
)
const (
	MethodIWallpaperEngineSetDesiredSize           = "setDesiredSize"
	MethodIWallpaperEngineSetDisplayPadding        = "setDisplayPadding"
	MethodIWallpaperEngineSetVisibility            = "setVisibility"
	MethodIWallpaperEngineOnScreenTurningOn        = "onScreenTurningOn"
	MethodIWallpaperEngineOnScreenTurnedOn         = "onScreenTurnedOn"
	MethodIWallpaperEngineSetInAmbientMode         = "setInAmbientMode"
	MethodIWallpaperEngineDispatchPointer          = "dispatchPointer"
	MethodIWallpaperEngineDispatchWallpaperCommand = "dispatchWallpaperCommand"
	MethodIWallpaperEngineRequestWallpaperColors   = "requestWallpaperColors"
	MethodIWallpaperEngineDestroy                  = "destroy"
	MethodIWallpaperEngineSetZoomOut               = "setZoomOut"
	MethodIWallpaperEngineResizePreview            = "resizePreview"
	MethodIWallpaperEngineRemoveLocalColorsAreas   = "removeLocalColorsAreas"
	MethodIWallpaperEngineAddLocalColorsAreas      = "addLocalColorsAreas"
	MethodIWallpaperEngineMirrorSurfaceControl     = "mirrorSurfaceControl"
	MethodIWallpaperEngineApplyDimming             = "applyDimming"
	MethodIWallpaperEngineSetWallpaperFlags        = "setWallpaperFlags"
)
const (
	TransactionIWallpaperServiceAttach = binder.FirstCallTransaction + 0
	TransactionIWallpaperServiceDetach = binder.FirstCallTransaction + 1
)
const (
	MethodIWallpaperServiceAttach = "attach"
	MethodIWallpaperServiceDetach = "detach"
)
const DescriptorIWallpaperConnection = "android.service.wallpaper.IWallpaperConnection"
const DescriptorIWallpaperEngine = "android.service.wallpaper.IWallpaperEngine"
const DescriptorIWallpaperService = "android.service.wallpaper.IWallpaperService"

Variables

This section is empty.

Functions

This section is empty.

Types

type IWallpaperConnection

type IWallpaperConnection interface {
	AsBinder() binder.IBinder
	AttachEngine(ctx context.Context, engine IWallpaperEngine, displayId int32) error
	EngineShown(ctx context.Context, engine IWallpaperEngine) error
	SetWallpaper(ctx context.Context, name string) (int32, error)
	OnWallpaperColorsChanged(ctx context.Context, colors app.WallpaperColors, displayId int32) error
	OnLocalWallpaperColorsChanged(ctx context.Context, area graphics.RectF, colors app.WallpaperColors, displayId int32) error
}

func NewWallpaperConnectionStub

func NewWallpaperConnectionStub(
	impl IWallpaperConnectionServer,
) IWallpaperConnection

NewWallpaperConnectionStub creates a server-side IWallpaperConnection wrapping the given server implementation. The returned value satisfies IWallpaperConnection and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IWallpaperConnectionServer

type IWallpaperConnectionServer interface {
	AttachEngine(ctx context.Context, engine IWallpaperEngine, displayId int32) error
	EngineShown(ctx context.Context, engine IWallpaperEngine) error
	SetWallpaper(ctx context.Context, name string) (int32, error)
	OnWallpaperColorsChanged(ctx context.Context, colors app.WallpaperColors, displayId int32) error
	OnLocalWallpaperColorsChanged(ctx context.Context, area graphics.RectF, colors app.WallpaperColors, displayId int32) error
}

IWallpaperConnectionServer is the server-side interface that user implementations provide to NewWallpaperConnectionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IWallpaperEngine

type IWallpaperEngine interface {
	AsBinder() binder.IBinder
	SetDesiredSize(ctx context.Context, width int32, height int32) error
	SetDisplayPadding(ctx context.Context, padding graphics.Rect) error
	SetVisibility(ctx context.Context, visible bool) error
	OnScreenTurningOn(ctx context.Context) error
	OnScreenTurnedOn(ctx context.Context) error
	SetInAmbientMode(ctx context.Context, inAmbientDisplay bool, animationDuration int64) error
	DispatchPointer(ctx context.Context, event view.MotionEvent) error
	DispatchWallpaperCommand(ctx context.Context, action string, x int32, y int32, z int32, extras os.Bundle) error
	RequestWallpaperColors(ctx context.Context) error
	Destroy(ctx context.Context) error
	SetZoomOut(ctx context.Context, scale float32) error
	ResizePreview(ctx context.Context, positionInWindow graphics.Rect) error
	RemoveLocalColorsAreas(ctx context.Context, regions []graphics.RectF) error
	AddLocalColorsAreas(ctx context.Context, regions []graphics.RectF) error
	MirrorSurfaceControl(ctx context.Context) (view.SurfaceControl, error)
	ApplyDimming(ctx context.Context, dimAmount float32) error
	SetWallpaperFlags(ctx context.Context, which int32) error
}

func NewWallpaperEngineStub

func NewWallpaperEngineStub(
	impl IWallpaperEngineServer,
) IWallpaperEngine

NewWallpaperEngineStub creates a server-side IWallpaperEngine wrapping the given server implementation. The returned value satisfies IWallpaperEngine and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IWallpaperEngineServer

type IWallpaperEngineServer interface {
	SetDesiredSize(ctx context.Context, width int32, height int32) error
	SetDisplayPadding(ctx context.Context, padding graphics.Rect) error
	SetVisibility(ctx context.Context, visible bool) error
	OnScreenTurningOn(ctx context.Context) error
	OnScreenTurnedOn(ctx context.Context) error
	SetInAmbientMode(ctx context.Context, inAmbientDisplay bool, animationDuration int64) error
	DispatchPointer(ctx context.Context, event view.MotionEvent) error
	DispatchWallpaperCommand(ctx context.Context, action string, x int32, y int32, z int32, extras os.Bundle) error
	RequestWallpaperColors(ctx context.Context) error
	Destroy(ctx context.Context) error
	SetZoomOut(ctx context.Context, scale float32) error
	ResizePreview(ctx context.Context, positionInWindow graphics.Rect) error
	RemoveLocalColorsAreas(ctx context.Context, regions []graphics.RectF) error
	AddLocalColorsAreas(ctx context.Context, regions []graphics.RectF) error
	MirrorSurfaceControl(ctx context.Context) (view.SurfaceControl, error)
	ApplyDimming(ctx context.Context, dimAmount float32) error
	SetWallpaperFlags(ctx context.Context, which int32) error
}

IWallpaperEngineServer is the server-side interface that user implementations provide to NewWallpaperEngineStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IWallpaperService

type IWallpaperService interface {
	AsBinder() binder.IBinder
	Attach(ctx context.Context, connection IWallpaperConnection, windowToken binder.IBinder, windowType int32, isPreview bool, reqWidth int32, reqHeight int32, padding graphics.Rect, displayId int32, which int32, info app.WallpaperInfo) error
	Detach(ctx context.Context, windowToken binder.IBinder) error
}

func NewWallpaperServiceStub

func NewWallpaperServiceStub(
	impl IWallpaperServiceServer,
) IWallpaperService

NewWallpaperServiceStub creates a server-side IWallpaperService wrapping the given server implementation. The returned value satisfies IWallpaperService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IWallpaperServiceServer

type IWallpaperServiceServer interface {
	Attach(ctx context.Context, connection IWallpaperConnection, windowToken binder.IBinder, windowType int32, isPreview bool, reqWidth int32, reqHeight int32, padding graphics.Rect, displayId int32, which int32, info app.WallpaperInfo) error
	Detach(ctx context.Context, windowToken binder.IBinder) error
}

IWallpaperServiceServer is the server-side interface that user implementations provide to NewWallpaperServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type WallpaperConnectionProxy

type WallpaperConnectionProxy struct {
	Remote binder.IBinder
}

func NewWallpaperConnectionProxy

func NewWallpaperConnectionProxy(
	remote binder.IBinder,
) *WallpaperConnectionProxy

func (*WallpaperConnectionProxy) AsBinder

func (p *WallpaperConnectionProxy) AsBinder() binder.IBinder

func (*WallpaperConnectionProxy) AttachEngine

func (p *WallpaperConnectionProxy) AttachEngine(
	ctx context.Context,
	engine IWallpaperEngine,
	displayId int32,
) error

func (*WallpaperConnectionProxy) EngineShown

func (p *WallpaperConnectionProxy) EngineShown(
	ctx context.Context,
	engine IWallpaperEngine,
) error

func (*WallpaperConnectionProxy) OnLocalWallpaperColorsChanged

func (p *WallpaperConnectionProxy) OnLocalWallpaperColorsChanged(
	ctx context.Context,
	area graphics.RectF,
	colors app.WallpaperColors,
	displayId int32,
) error

func (*WallpaperConnectionProxy) OnWallpaperColorsChanged

func (p *WallpaperConnectionProxy) OnWallpaperColorsChanged(
	ctx context.Context,
	colors app.WallpaperColors,
	displayId int32,
) error

func (*WallpaperConnectionProxy) SetWallpaper

func (p *WallpaperConnectionProxy) SetWallpaper(
	ctx context.Context,
	name string,
) (int32, error)

type WallpaperConnectionStub

type WallpaperConnectionStub struct {
	Impl      IWallpaperConnection
	Transport binder.VersionAwareTransport
}

WallpaperConnectionStub dispatches incoming binder transactions to a typed IWallpaperConnection implementation.

func (*WallpaperConnectionStub) Descriptor

func (s *WallpaperConnectionStub) Descriptor() string

func (*WallpaperConnectionStub) OnTransaction

func (s *WallpaperConnectionStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type WallpaperEngineProxy

type WallpaperEngineProxy struct {
	Remote binder.IBinder
}

func NewWallpaperEngineProxy

func NewWallpaperEngineProxy(
	remote binder.IBinder,
) *WallpaperEngineProxy

func (*WallpaperEngineProxy) AddLocalColorsAreas

func (p *WallpaperEngineProxy) AddLocalColorsAreas(
	ctx context.Context,
	regions []graphics.RectF,
) error

func (*WallpaperEngineProxy) ApplyDimming

func (p *WallpaperEngineProxy) ApplyDimming(
	ctx context.Context,
	dimAmount float32,
) error

func (*WallpaperEngineProxy) AsBinder

func (p *WallpaperEngineProxy) AsBinder() binder.IBinder

func (*WallpaperEngineProxy) Destroy

func (p *WallpaperEngineProxy) Destroy(
	ctx context.Context,
) error

func (*WallpaperEngineProxy) DispatchPointer

func (p *WallpaperEngineProxy) DispatchPointer(
	ctx context.Context,
	event view.MotionEvent,
) error

func (*WallpaperEngineProxy) DispatchWallpaperCommand

func (p *WallpaperEngineProxy) DispatchWallpaperCommand(
	ctx context.Context,
	action string,
	x int32,
	y int32,
	z int32,
	extras os.Bundle,
) error

func (*WallpaperEngineProxy) MirrorSurfaceControl

func (p *WallpaperEngineProxy) MirrorSurfaceControl(
	ctx context.Context,
) (view.SurfaceControl, error)

func (*WallpaperEngineProxy) OnScreenTurnedOn

func (p *WallpaperEngineProxy) OnScreenTurnedOn(
	ctx context.Context,
) error

func (*WallpaperEngineProxy) OnScreenTurningOn

func (p *WallpaperEngineProxy) OnScreenTurningOn(
	ctx context.Context,
) error

func (*WallpaperEngineProxy) RemoveLocalColorsAreas

func (p *WallpaperEngineProxy) RemoveLocalColorsAreas(
	ctx context.Context,
	regions []graphics.RectF,
) error

func (*WallpaperEngineProxy) RequestWallpaperColors

func (p *WallpaperEngineProxy) RequestWallpaperColors(
	ctx context.Context,
) error

func (*WallpaperEngineProxy) ResizePreview

func (p *WallpaperEngineProxy) ResizePreview(
	ctx context.Context,
	positionInWindow graphics.Rect,
) error

func (*WallpaperEngineProxy) SetDesiredSize

func (p *WallpaperEngineProxy) SetDesiredSize(
	ctx context.Context,
	width int32,
	height int32,
) error

func (*WallpaperEngineProxy) SetDisplayPadding

func (p *WallpaperEngineProxy) SetDisplayPadding(
	ctx context.Context,
	padding graphics.Rect,
) error

func (*WallpaperEngineProxy) SetInAmbientMode

func (p *WallpaperEngineProxy) SetInAmbientMode(
	ctx context.Context,
	inAmbientDisplay bool,
	animationDuration int64,
) error

func (*WallpaperEngineProxy) SetVisibility

func (p *WallpaperEngineProxy) SetVisibility(
	ctx context.Context,
	visible bool,
) error

func (*WallpaperEngineProxy) SetWallpaperFlags

func (p *WallpaperEngineProxy) SetWallpaperFlags(
	ctx context.Context,
	which int32,
) error

func (*WallpaperEngineProxy) SetZoomOut

func (p *WallpaperEngineProxy) SetZoomOut(
	ctx context.Context,
	scale float32,
) error

type WallpaperEngineStub

type WallpaperEngineStub struct {
	Impl      IWallpaperEngine
	Transport binder.VersionAwareTransport
}

WallpaperEngineStub dispatches incoming binder transactions to a typed IWallpaperEngine implementation.

func (*WallpaperEngineStub) Descriptor

func (s *WallpaperEngineStub) Descriptor() string

func (*WallpaperEngineStub) OnTransaction

func (s *WallpaperEngineStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type WallpaperServiceProxy

type WallpaperServiceProxy struct {
	Remote binder.IBinder
}

func NewWallpaperServiceProxy

func NewWallpaperServiceProxy(
	remote binder.IBinder,
) *WallpaperServiceProxy

func (*WallpaperServiceProxy) AsBinder

func (p *WallpaperServiceProxy) AsBinder() binder.IBinder

func (*WallpaperServiceProxy) Attach

func (p *WallpaperServiceProxy) Attach(
	ctx context.Context,
	connection IWallpaperConnection,
	windowToken binder.IBinder,
	windowType int32,
	isPreview bool,
	reqWidth int32,
	reqHeight int32,
	padding graphics.Rect,
	displayId int32,
	which int32,
	info app.WallpaperInfo,
) error

func (*WallpaperServiceProxy) Detach

func (p *WallpaperServiceProxy) Detach(
	ctx context.Context,
	windowToken binder.IBinder,
) error

type WallpaperServiceStub

type WallpaperServiceStub struct {
	Impl      IWallpaperService
	Transport binder.VersionAwareTransport
}

WallpaperServiceStub dispatches incoming binder transactions to a typed IWallpaperService implementation.

func (*WallpaperServiceStub) Descriptor

func (s *WallpaperServiceStub) Descriptor() string

func (*WallpaperServiceStub) OnTransaction

func (s *WallpaperServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to