tts

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	TransactionITextToSpeechCallbackOnStart          = binder.FirstCallTransaction + 0
	TransactionITextToSpeechCallbackOnSuccess        = binder.FirstCallTransaction + 1
	TransactionITextToSpeechCallbackOnStop           = binder.FirstCallTransaction + 2
	TransactionITextToSpeechCallbackOnError          = binder.FirstCallTransaction + 3
	TransactionITextToSpeechCallbackOnBeginSynthesis = binder.FirstCallTransaction + 4
	TransactionITextToSpeechCallbackOnAudioAvailable = binder.FirstCallTransaction + 5
	TransactionITextToSpeechCallbackOnRangeStart     = binder.FirstCallTransaction + 6
)
const (
	MethodITextToSpeechCallbackOnStart          = "onStart"
	MethodITextToSpeechCallbackOnSuccess        = "onSuccess"
	MethodITextToSpeechCallbackOnStop           = "onStop"
	MethodITextToSpeechCallbackOnError          = "onError"
	MethodITextToSpeechCallbackOnBeginSynthesis = "onBeginSynthesis"
	MethodITextToSpeechCallbackOnAudioAvailable = "onAudioAvailable"
	MethodITextToSpeechCallbackOnRangeStart     = "onRangeStart"
)
const (
	TransactionITextToSpeechServiceSpeak                      = binder.FirstCallTransaction + 0
	TransactionITextToSpeechServiceSynthesizeToFileDescriptor = binder.FirstCallTransaction + 1
	TransactionITextToSpeechServicePlayAudio                  = binder.FirstCallTransaction + 2
	TransactionITextToSpeechServicePlaySilence                = binder.FirstCallTransaction + 3
	TransactionITextToSpeechServiceIsSpeaking                 = binder.FirstCallTransaction + 4
	TransactionITextToSpeechServiceStop                       = binder.FirstCallTransaction + 5
	TransactionITextToSpeechServiceGetLanguage                = binder.FirstCallTransaction + 6
	TransactionITextToSpeechServiceGetClientDefaultLanguage   = binder.FirstCallTransaction + 7
	TransactionITextToSpeechServiceIsLanguageAvailable        = binder.FirstCallTransaction + 8
	TransactionITextToSpeechServiceGetFeaturesForLanguage     = binder.FirstCallTransaction + 9
	TransactionITextToSpeechServiceLoadLanguage               = binder.FirstCallTransaction + 10
	TransactionITextToSpeechServiceSetCallback                = binder.FirstCallTransaction + 11
	TransactionITextToSpeechServiceGetVoices                  = binder.FirstCallTransaction + 12
	TransactionITextToSpeechServiceLoadVoice                  = binder.FirstCallTransaction + 13
	TransactionITextToSpeechServiceGetDefaultVoiceNameFor     = binder.FirstCallTransaction + 14
)
const (
	MethodITextToSpeechServiceSpeak                      = "speak"
	MethodITextToSpeechServiceSynthesizeToFileDescriptor = "synthesizeToFileDescriptor"
	MethodITextToSpeechServicePlayAudio                  = "playAudio"
	MethodITextToSpeechServicePlaySilence                = "playSilence"
	MethodITextToSpeechServiceIsSpeaking                 = "isSpeaking"
	MethodITextToSpeechServiceStop                       = "stop"
	MethodITextToSpeechServiceGetLanguage                = "getLanguage"
	MethodITextToSpeechServiceGetClientDefaultLanguage   = "getClientDefaultLanguage"
	MethodITextToSpeechServiceIsLanguageAvailable        = "isLanguageAvailable"
	MethodITextToSpeechServiceGetFeaturesForLanguage     = "getFeaturesForLanguage"
	MethodITextToSpeechServiceLoadLanguage               = "loadLanguage"
	MethodITextToSpeechServiceSetCallback                = "setCallback"
	MethodITextToSpeechServiceGetVoices                  = "getVoices"
	MethodITextToSpeechServiceLoadVoice                  = "loadVoice"
	MethodITextToSpeechServiceGetDefaultVoiceNameFor     = "getDefaultVoiceNameFor"
)
const (
	TransactionITextToSpeechSessionCallbackOnConnected    = binder.FirstCallTransaction + 0
	TransactionITextToSpeechSessionCallbackOnDisconnected = binder.FirstCallTransaction + 1
	TransactionITextToSpeechSessionCallbackOnError        = binder.FirstCallTransaction + 2
)
const (
	MethodITextToSpeechSessionCallbackOnConnected    = "onConnected"
	MethodITextToSpeechSessionCallbackOnDisconnected = "onDisconnected"
	MethodITextToSpeechSessionCallbackOnError        = "onError"
)
const DescriptorITextToSpeechCallback = "android.speech.tts.ITextToSpeechCallback"
const DescriptorITextToSpeechManager = "android.speech.tts.ITextToSpeechManager"
const DescriptorITextToSpeechService = "android.speech.tts.ITextToSpeechService"
const DescriptorITextToSpeechSession = "android.speech.tts.ITextToSpeechSession"
const DescriptorITextToSpeechSessionCallback = "android.speech.tts.ITextToSpeechSessionCallback"
const (
	MethodITextToSpeechManagerCreateSession = "createSession"
)
const (
	MethodITextToSpeechSessionDisconnect = "disconnect"
)
const (
	TransactionITextToSpeechManagerCreateSession = binder.FirstCallTransaction + 0
)
const (
	TransactionITextToSpeechSessionDisconnect = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type ITextToSpeechCallback

type ITextToSpeechCallback interface {
	AsBinder() binder.IBinder
	OnStart(ctx context.Context, utteranceId string) error
	OnSuccess(ctx context.Context, utteranceId string) error
	OnStop(ctx context.Context, utteranceId string, isStarted bool) error
	OnError(ctx context.Context, utteranceId string, errorCode int32) error
	OnBeginSynthesis(ctx context.Context, utteranceId string, sampleRateInHz int32, audioFormat int32, channelCount int32) error
	OnAudioAvailable(ctx context.Context, utteranceId string, audio []byte) error
	OnRangeStart(ctx context.Context, utteranceId string, start int32, end int32, frame int32) error
}

func NewTextToSpeechCallbackStub

func NewTextToSpeechCallbackStub(
	impl ITextToSpeechCallbackServer,
) ITextToSpeechCallback

NewTextToSpeechCallbackStub creates a server-side ITextToSpeechCallback wrapping the given server implementation. The returned value satisfies ITextToSpeechCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ITextToSpeechCallbackServer

type ITextToSpeechCallbackServer interface {
	OnStart(ctx context.Context, utteranceId string) error
	OnSuccess(ctx context.Context, utteranceId string) error
	OnStop(ctx context.Context, utteranceId string, isStarted bool) error
	OnError(ctx context.Context, utteranceId string, errorCode int32) error
	OnBeginSynthesis(ctx context.Context, utteranceId string, sampleRateInHz int32, audioFormat int32, channelCount int32) error
	OnAudioAvailable(ctx context.Context, utteranceId string, audio []byte) error
	OnRangeStart(ctx context.Context, utteranceId string, start int32, end int32, frame int32) error
}

ITextToSpeechCallbackServer is the server-side interface that user implementations provide to NewTextToSpeechCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ITextToSpeechManager

type ITextToSpeechManager interface {
	AsBinder() binder.IBinder
	CreateSession(ctx context.Context, engine string, managerCallback ITextToSpeechSessionCallback) error
}

func NewTextToSpeechManagerStub

func NewTextToSpeechManagerStub(
	impl ITextToSpeechManagerServer,
) ITextToSpeechManager

NewTextToSpeechManagerStub creates a server-side ITextToSpeechManager wrapping the given server implementation. The returned value satisfies ITextToSpeechManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ITextToSpeechManagerServer

type ITextToSpeechManagerServer interface {
	CreateSession(ctx context.Context, engine string, managerCallback ITextToSpeechSessionCallback) error
}

ITextToSpeechManagerServer is the server-side interface that user implementations provide to NewTextToSpeechManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ITextToSpeechService

type ITextToSpeechService interface {
	AsBinder() binder.IBinder
	Speak(ctx context.Context, callingInstance binder.IBinder, text string, queueMode int32, params os.Bundle, utteranceId string) (int32, error)
	SynthesizeToFileDescriptor(ctx context.Context, callingInstance binder.IBinder, text string, fileDescriptor int32, params os.Bundle, utteranceId string) (int32, error)
	PlayAudio(ctx context.Context, callingInstance binder.IBinder, audioUri net.Uri, queueMode int32, params os.Bundle, utteranceId string) (int32, error)
	PlaySilence(ctx context.Context, callingInstance binder.IBinder, duration int64, queueMode int32, utteranceId string) (int32, error)
	IsSpeaking(ctx context.Context) (bool, error)
	Stop(ctx context.Context, callingInstance binder.IBinder) (int32, error)
	GetLanguage(ctx context.Context) ([]string, error)
	GetClientDefaultLanguage(ctx context.Context) ([]string, error)
	IsLanguageAvailable(ctx context.Context, lang string, country string, variant string) (int32, error)
	GetFeaturesForLanguage(ctx context.Context, lang string, country string, variant string) ([]string, error)
	LoadLanguage(ctx context.Context, caller binder.IBinder, lang string, country string, variant string) (int32, error)
	SetCallback(ctx context.Context, caller binder.IBinder, cb ITextToSpeechCallback) error
	GetVoices(ctx context.Context) ([]Voice, error)
	LoadVoice(ctx context.Context, caller binder.IBinder, voiceName string) (int32, error)
	GetDefaultVoiceNameFor(ctx context.Context, lang string, country string, variant string) (string, error)
}

func NewTextToSpeechServiceStub

func NewTextToSpeechServiceStub(
	impl ITextToSpeechServiceServer,
) ITextToSpeechService

NewTextToSpeechServiceStub creates a server-side ITextToSpeechService wrapping the given server implementation. The returned value satisfies ITextToSpeechService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ITextToSpeechServiceServer

type ITextToSpeechServiceServer interface {
	Speak(ctx context.Context, callingInstance binder.IBinder, text string, queueMode int32, params os.Bundle, utteranceId string) (int32, error)
	SynthesizeToFileDescriptor(ctx context.Context, callingInstance binder.IBinder, text string, fileDescriptor int32, params os.Bundle, utteranceId string) (int32, error)
	PlayAudio(ctx context.Context, callingInstance binder.IBinder, audioUri net.Uri, queueMode int32, params os.Bundle, utteranceId string) (int32, error)
	PlaySilence(ctx context.Context, callingInstance binder.IBinder, duration int64, queueMode int32, utteranceId string) (int32, error)
	IsSpeaking(ctx context.Context) (bool, error)
	Stop(ctx context.Context, callingInstance binder.IBinder) (int32, error)
	GetLanguage(ctx context.Context) ([]string, error)
	GetClientDefaultLanguage(ctx context.Context) ([]string, error)
	IsLanguageAvailable(ctx context.Context, lang string, country string, variant string) (int32, error)
	GetFeaturesForLanguage(ctx context.Context, lang string, country string, variant string) ([]string, error)
	LoadLanguage(ctx context.Context, caller binder.IBinder, lang string, country string, variant string) (int32, error)
	SetCallback(ctx context.Context, caller binder.IBinder, cb ITextToSpeechCallback) error
	GetVoices(ctx context.Context) ([]Voice, error)
	LoadVoice(ctx context.Context, caller binder.IBinder, voiceName string) (int32, error)
	GetDefaultVoiceNameFor(ctx context.Context, lang string, country string, variant string) (string, error)
}

ITextToSpeechServiceServer is the server-side interface that user implementations provide to NewTextToSpeechServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ITextToSpeechSession

type ITextToSpeechSession interface {
	AsBinder() binder.IBinder
	Disconnect(ctx context.Context) error
}

func NewTextToSpeechSessionStub

func NewTextToSpeechSessionStub(
	impl ITextToSpeechSessionServer,
) ITextToSpeechSession

NewTextToSpeechSessionStub creates a server-side ITextToSpeechSession wrapping the given server implementation. The returned value satisfies ITextToSpeechSession and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ITextToSpeechSessionCallback

type ITextToSpeechSessionCallback interface {
	AsBinder() binder.IBinder
	OnConnected(ctx context.Context, session ITextToSpeechSession, serviceBinder binder.IBinder) error
	OnDisconnected(ctx context.Context) error
	OnError(ctx context.Context, errorInfo string) error
}

func NewTextToSpeechSessionCallbackStub

func NewTextToSpeechSessionCallbackStub(
	impl ITextToSpeechSessionCallbackServer,
) ITextToSpeechSessionCallback

NewTextToSpeechSessionCallbackStub creates a server-side ITextToSpeechSessionCallback wrapping the given server implementation. The returned value satisfies ITextToSpeechSessionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ITextToSpeechSessionCallbackServer

type ITextToSpeechSessionCallbackServer interface {
	OnConnected(ctx context.Context, session ITextToSpeechSession, serviceBinder binder.IBinder) error
	OnDisconnected(ctx context.Context) error
	OnError(ctx context.Context, errorInfo string) error
}

ITextToSpeechSessionCallbackServer is the server-side interface that user implementations provide to NewTextToSpeechSessionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ITextToSpeechSessionServer

type ITextToSpeechSessionServer interface {
	Disconnect(ctx context.Context) error
}

ITextToSpeechSessionServer is the server-side interface that user implementations provide to NewTextToSpeechSessionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type TextToSpeechCallbackProxy

type TextToSpeechCallbackProxy struct {
	Remote binder.IBinder
}

func NewTextToSpeechCallbackProxy

func NewTextToSpeechCallbackProxy(
	remote binder.IBinder,
) *TextToSpeechCallbackProxy

func (*TextToSpeechCallbackProxy) AsBinder

func (*TextToSpeechCallbackProxy) OnAudioAvailable

func (p *TextToSpeechCallbackProxy) OnAudioAvailable(
	ctx context.Context,
	utteranceId string,
	audio []byte,
) error

func (*TextToSpeechCallbackProxy) OnBeginSynthesis

func (p *TextToSpeechCallbackProxy) OnBeginSynthesis(
	ctx context.Context,
	utteranceId string,
	sampleRateInHz int32,
	audioFormat int32,
	channelCount int32,
) error

func (*TextToSpeechCallbackProxy) OnError

func (p *TextToSpeechCallbackProxy) OnError(
	ctx context.Context,
	utteranceId string,
	errorCode int32,
) error

func (*TextToSpeechCallbackProxy) OnRangeStart

func (p *TextToSpeechCallbackProxy) OnRangeStart(
	ctx context.Context,
	utteranceId string,
	start int32,
	end int32,
	frame int32,
) error

func (*TextToSpeechCallbackProxy) OnStart

func (p *TextToSpeechCallbackProxy) OnStart(
	ctx context.Context,
	utteranceId string,
) error

func (*TextToSpeechCallbackProxy) OnStop

func (p *TextToSpeechCallbackProxy) OnStop(
	ctx context.Context,
	utteranceId string,
	isStarted bool,
) error

func (*TextToSpeechCallbackProxy) OnSuccess

func (p *TextToSpeechCallbackProxy) OnSuccess(
	ctx context.Context,
	utteranceId string,
) error

type TextToSpeechCallbackStub

type TextToSpeechCallbackStub struct {
	Impl      ITextToSpeechCallback
	Transport binder.VersionAwareTransport
}

TextToSpeechCallbackStub dispatches incoming binder transactions to a typed ITextToSpeechCallback implementation.

func (*TextToSpeechCallbackStub) Descriptor

func (s *TextToSpeechCallbackStub) Descriptor() string

func (*TextToSpeechCallbackStub) OnTransaction

func (s *TextToSpeechCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type TextToSpeechManagerProxy

type TextToSpeechManagerProxy struct {
	Remote binder.IBinder
}

func NewTextToSpeechManagerProxy

func NewTextToSpeechManagerProxy(
	remote binder.IBinder,
) *TextToSpeechManagerProxy

func (*TextToSpeechManagerProxy) AsBinder

func (p *TextToSpeechManagerProxy) AsBinder() binder.IBinder

func (*TextToSpeechManagerProxy) CreateSession

func (p *TextToSpeechManagerProxy) CreateSession(
	ctx context.Context,
	engine string,
	managerCallback ITextToSpeechSessionCallback,
) error

type TextToSpeechManagerStub

type TextToSpeechManagerStub struct {
	Impl      ITextToSpeechManager
	Transport binder.VersionAwareTransport
}

TextToSpeechManagerStub dispatches incoming binder transactions to a typed ITextToSpeechManager implementation.

func (*TextToSpeechManagerStub) Descriptor

func (s *TextToSpeechManagerStub) Descriptor() string

func (*TextToSpeechManagerStub) OnTransaction

func (s *TextToSpeechManagerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type TextToSpeechServiceProxy

type TextToSpeechServiceProxy struct {
	Remote binder.IBinder
}

func NewTextToSpeechServiceProxy

func NewTextToSpeechServiceProxy(
	remote binder.IBinder,
) *TextToSpeechServiceProxy

func (*TextToSpeechServiceProxy) AsBinder

func (p *TextToSpeechServiceProxy) AsBinder() binder.IBinder

func (*TextToSpeechServiceProxy) GetClientDefaultLanguage

func (p *TextToSpeechServiceProxy) GetClientDefaultLanguage(
	ctx context.Context,
) ([]string, error)

func (*TextToSpeechServiceProxy) GetDefaultVoiceNameFor

func (p *TextToSpeechServiceProxy) GetDefaultVoiceNameFor(
	ctx context.Context,
	lang string,
	country string,
	variant string,
) (string, error)

func (*TextToSpeechServiceProxy) GetFeaturesForLanguage

func (p *TextToSpeechServiceProxy) GetFeaturesForLanguage(
	ctx context.Context,
	lang string,
	country string,
	variant string,
) ([]string, error)

func (*TextToSpeechServiceProxy) GetLanguage

func (p *TextToSpeechServiceProxy) GetLanguage(
	ctx context.Context,
) ([]string, error)

func (*TextToSpeechServiceProxy) GetVoices

func (p *TextToSpeechServiceProxy) GetVoices(
	ctx context.Context,
) ([]Voice, error)

func (*TextToSpeechServiceProxy) IsLanguageAvailable

func (p *TextToSpeechServiceProxy) IsLanguageAvailable(
	ctx context.Context,
	lang string,
	country string,
	variant string,
) (int32, error)

func (*TextToSpeechServiceProxy) IsSpeaking

func (p *TextToSpeechServiceProxy) IsSpeaking(
	ctx context.Context,
) (bool, error)

func (*TextToSpeechServiceProxy) LoadLanguage

func (p *TextToSpeechServiceProxy) LoadLanguage(
	ctx context.Context,
	caller binder.IBinder,
	lang string,
	country string,
	variant string,
) (int32, error)

func (*TextToSpeechServiceProxy) LoadVoice

func (p *TextToSpeechServiceProxy) LoadVoice(
	ctx context.Context,
	caller binder.IBinder,
	voiceName string,
) (int32, error)

func (*TextToSpeechServiceProxy) PlayAudio

func (p *TextToSpeechServiceProxy) PlayAudio(
	ctx context.Context,
	callingInstance binder.IBinder,
	audioUri net.Uri,
	queueMode int32,
	params os.Bundle,
	utteranceId string,
) (int32, error)

func (*TextToSpeechServiceProxy) PlaySilence

func (p *TextToSpeechServiceProxy) PlaySilence(
	ctx context.Context,
	callingInstance binder.IBinder,
	duration int64,
	queueMode int32,
	utteranceId string,
) (int32, error)

func (*TextToSpeechServiceProxy) SetCallback

func (*TextToSpeechServiceProxy) Speak

func (p *TextToSpeechServiceProxy) Speak(
	ctx context.Context,
	callingInstance binder.IBinder,
	text string,
	queueMode int32,
	params os.Bundle,
	utteranceId string,
) (int32, error)

func (*TextToSpeechServiceProxy) Stop

func (p *TextToSpeechServiceProxy) Stop(
	ctx context.Context,
	callingInstance binder.IBinder,
) (int32, error)

func (*TextToSpeechServiceProxy) SynthesizeToFileDescriptor

func (p *TextToSpeechServiceProxy) SynthesizeToFileDescriptor(
	ctx context.Context,
	callingInstance binder.IBinder,
	text string,
	fileDescriptor int32,
	params os.Bundle,
	utteranceId string,
) (int32, error)

type TextToSpeechServiceStub

type TextToSpeechServiceStub struct {
	Impl      ITextToSpeechService
	Transport binder.VersionAwareTransport
}

TextToSpeechServiceStub dispatches incoming binder transactions to a typed ITextToSpeechService implementation.

func (*TextToSpeechServiceStub) Descriptor

func (s *TextToSpeechServiceStub) Descriptor() string

func (*TextToSpeechServiceStub) OnTransaction

func (s *TextToSpeechServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type TextToSpeechSessionCallbackProxy

type TextToSpeechSessionCallbackProxy struct {
	Remote binder.IBinder
}

func NewTextToSpeechSessionCallbackProxy

func NewTextToSpeechSessionCallbackProxy(
	remote binder.IBinder,
) *TextToSpeechSessionCallbackProxy

func (*TextToSpeechSessionCallbackProxy) AsBinder

func (*TextToSpeechSessionCallbackProxy) OnConnected

func (p *TextToSpeechSessionCallbackProxy) OnConnected(
	ctx context.Context,
	session ITextToSpeechSession,
	serviceBinder binder.IBinder,
) error

func (*TextToSpeechSessionCallbackProxy) OnDisconnected

func (p *TextToSpeechSessionCallbackProxy) OnDisconnected(
	ctx context.Context,
) error

func (*TextToSpeechSessionCallbackProxy) OnError

func (p *TextToSpeechSessionCallbackProxy) OnError(
	ctx context.Context,
	errorInfo string,
) error

type TextToSpeechSessionCallbackStub

type TextToSpeechSessionCallbackStub struct {
	Impl      ITextToSpeechSessionCallback
	Transport binder.VersionAwareTransport
}

TextToSpeechSessionCallbackStub dispatches incoming binder transactions to a typed ITextToSpeechSessionCallback implementation.

func (*TextToSpeechSessionCallbackStub) Descriptor

func (s *TextToSpeechSessionCallbackStub) Descriptor() string

func (*TextToSpeechSessionCallbackStub) OnTransaction

type TextToSpeechSessionProxy

type TextToSpeechSessionProxy struct {
	Remote binder.IBinder
}

func NewTextToSpeechSessionProxy

func NewTextToSpeechSessionProxy(
	remote binder.IBinder,
) *TextToSpeechSessionProxy

func (*TextToSpeechSessionProxy) AsBinder

func (p *TextToSpeechSessionProxy) AsBinder() binder.IBinder

func (*TextToSpeechSessionProxy) Disconnect

func (p *TextToSpeechSessionProxy) Disconnect(
	ctx context.Context,
) error

type TextToSpeechSessionStub

type TextToSpeechSessionStub struct {
	Impl      ITextToSpeechSession
	Transport binder.VersionAwareTransport
}

TextToSpeechSessionStub dispatches incoming binder transactions to a typed ITextToSpeechSession implementation.

func (*TextToSpeechSessionStub) Descriptor

func (s *TextToSpeechSessionStub) Descriptor() string

func (*TextToSpeechSessionStub) OnTransaction

func (s *TextToSpeechSessionStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type Voice

type Voice struct {
	Name    string
	Quality int32
	Latency int32
}

func (*Voice) MarshalParcel

func (s *Voice) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Voice) UnmarshalParcel

func (s *Voice) UnmarshalParcel(
	p *parcel.Parcel,
) error

Jump to