telephony

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIBootstrapAuthenticationCallbackOnKeysAvailable         = binder.FirstCallTransaction + 0
	TransactionIBootstrapAuthenticationCallbackOnAuthenticationFailure = binder.FirstCallTransaction + 1
)
const (
	MethodIBootstrapAuthenticationCallbackOnKeysAvailable         = "onKeysAvailable"
	MethodIBootstrapAuthenticationCallbackOnAuthenticationFailure = "onAuthenticationFailure"
)
const (
	TransactionICellBroadcastServiceHandleGsmCellBroadcastSms  = binder.FirstCallTransaction + 0
	TransactionICellBroadcastServiceHandleCdmaCellBroadcastSms = binder.FirstCallTransaction + 1
	TransactionICellBroadcastServiceHandleCdmaScpMessage       = binder.FirstCallTransaction + 2
	TransactionICellBroadcastServiceGetCellBroadcastAreaInfo   = binder.FirstCallTransaction + 3
)
const (
	MethodICellBroadcastServiceHandleGsmCellBroadcastSms  = "handleGsmCellBroadcastSms"
	MethodICellBroadcastServiceHandleCdmaCellBroadcastSms = "handleCdmaCellBroadcastSms"
	MethodICellBroadcastServiceHandleCdmaScpMessage       = "handleCdmaScpMessage"
	MethodICellBroadcastServiceGetCellBroadcastAreaInfo   = "getCellBroadcastAreaInfo"
)
const (
	TransactionICellInfoCallbackOnCellInfo = binder.FirstCallTransaction + 0
	TransactionICellInfoCallbackOnError    = binder.FirstCallTransaction + 1
)
const (
	MethodICellInfoCallbackOnCellInfo = "onCellInfo"
	MethodICellInfoCallbackOnError    = "onError"
)
const (
	TransactionINetworkServiceCreateNetworkServiceProvider                = binder.FirstCallTransaction + 0
	TransactionINetworkServiceRemoveNetworkServiceProvider                = binder.FirstCallTransaction + 1
	TransactionINetworkServiceRequestNetworkRegistrationInfo              = binder.FirstCallTransaction + 2
	TransactionINetworkServiceRegisterForNetworkRegistrationInfoChanged   = binder.FirstCallTransaction + 3
	TransactionINetworkServiceUnregisterForNetworkRegistrationInfoChanged = binder.FirstCallTransaction + 4
)
const (
	MethodINetworkServiceCreateNetworkServiceProvider                = "createNetworkServiceProvider"
	MethodINetworkServiceRemoveNetworkServiceProvider                = "removeNetworkServiceProvider"
	MethodINetworkServiceRequestNetworkRegistrationInfo              = "requestNetworkRegistrationInfo"
	MethodINetworkServiceRegisterForNetworkRegistrationInfoChanged   = "registerForNetworkRegistrationInfoChanged"
	MethodINetworkServiceUnregisterForNetworkRegistrationInfoChanged = "unregisterForNetworkRegistrationInfoChanged"
)
const (
	TransactionINetworkServiceCallbackOnRequestNetworkRegistrationInfoComplete = binder.FirstCallTransaction + 0
	TransactionINetworkServiceCallbackOnNetworkStateChanged                    = binder.FirstCallTransaction + 1
)
const (
	MethodINetworkServiceCallbackOnRequestNetworkRegistrationInfoComplete = "onRequestNetworkRegistrationInfoComplete"
	MethodINetworkServiceCallbackOnNetworkStateChanged                    = "onNetworkStateChanged"
)
const DescriptorIBooleanConsumer = "android.telephony.IBooleanConsumer"
const DescriptorIBootstrapAuthenticationCallback = "android.telephony.IBootstrapAuthenticationCallback"
const DescriptorICellBroadcastService = "android.telephony.ICellBroadcastService"
const DescriptorICellInfoCallback = "android.telephony.ICellInfoCallback"
const DescriptorIIntegerConsumer = "android.telephony.IIntegerConsumer"
const DescriptorINetworkService = "android.telephony.INetworkService"
const DescriptorINetworkServiceCallback = "android.telephony.INetworkServiceCallback"
const (
	MethodIBooleanConsumerAccept = "accept"
)
const (
	MethodIIntegerConsumerAccept = "accept"
)
const (
	TransactionIBooleanConsumerAccept = binder.FirstCallTransaction + 0
)
const (
	TransactionIIntegerConsumerAccept = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type ActivityStatsTechSpecificInfo

type ActivityStatsTechSpecificInfo struct {
	Rat            int32
	FrequencyRange int32
	RxTimeMs       int32
}

func (*ActivityStatsTechSpecificInfo) MarshalParcel

func (s *ActivityStatsTechSpecificInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ActivityStatsTechSpecificInfo) UnmarshalParcel

func (s *ActivityStatsTechSpecificInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type AvailableNetworkInfo

type AvailableNetworkInfo struct {
	SubId    int32
	Priority int32
}

func (*AvailableNetworkInfo) MarshalParcel

func (s *AvailableNetworkInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*AvailableNetworkInfo) UnmarshalParcel

func (s *AvailableNetworkInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type BarringInfo

type BarringInfo struct {
	CellIdentity *CellIdentity
}

func (*BarringInfo) MarshalParcel

func (s *BarringInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*BarringInfo) UnmarshalParcel

func (s *BarringInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type BooleanConsumerProxy

type BooleanConsumerProxy struct {
	Remote binder.IBinder
}

func NewBooleanConsumerProxy

func NewBooleanConsumerProxy(
	remote binder.IBinder,
) *BooleanConsumerProxy

func (*BooleanConsumerProxy) Accept

func (p *BooleanConsumerProxy) Accept(
	ctx context.Context,
	result bool,
) error

func (*BooleanConsumerProxy) AsBinder

func (p *BooleanConsumerProxy) AsBinder() binder.IBinder

type BooleanConsumerStub

type BooleanConsumerStub struct {
	Impl      IBooleanConsumer
	Transport binder.VersionAwareTransport
}

BooleanConsumerStub dispatches incoming binder transactions to a typed IBooleanConsumer implementation.

func (*BooleanConsumerStub) Descriptor

func (s *BooleanConsumerStub) Descriptor() string

func (*BooleanConsumerStub) OnTransaction

func (s *BooleanConsumerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type BootstrapAuthenticationCallbackProxy

type BootstrapAuthenticationCallbackProxy struct {
	Remote binder.IBinder
}

func NewBootstrapAuthenticationCallbackProxy

func NewBootstrapAuthenticationCallbackProxy(
	remote binder.IBinder,
) *BootstrapAuthenticationCallbackProxy

func (*BootstrapAuthenticationCallbackProxy) AsBinder

func (*BootstrapAuthenticationCallbackProxy) OnAuthenticationFailure

func (p *BootstrapAuthenticationCallbackProxy) OnAuthenticationFailure(
	ctx context.Context,
	token int32,
	reason int32,
) error

func (*BootstrapAuthenticationCallbackProxy) OnKeysAvailable

func (p *BootstrapAuthenticationCallbackProxy) OnKeysAvailable(
	ctx context.Context,
	token int32,
	gbaKey []byte,
	btId string,
) error

type BootstrapAuthenticationCallbackStub

type BootstrapAuthenticationCallbackStub struct {
	Impl      IBootstrapAuthenticationCallback
	Transport binder.VersionAwareTransport
}

BootstrapAuthenticationCallbackStub dispatches incoming binder transactions to a typed IBootstrapAuthenticationCallback implementation.

func (*BootstrapAuthenticationCallbackStub) Descriptor

func (*BootstrapAuthenticationCallbackStub) OnTransaction

type CallAttributes

type CallAttributes struct {
	NetworkType      int32
	PreciseCallState *PreciseCallState
}

func (*CallAttributes) MarshalParcel

func (s *CallAttributes) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CallAttributes) UnmarshalParcel

func (s *CallAttributes) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CallForwardingInfo

type CallForwardingInfo struct {
	Number      string
	Enabled     bool
	Reason      int32
	TimeSeconds int32
}

func (*CallForwardingInfo) MarshalParcel

func (s *CallForwardingInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CallForwardingInfo) UnmarshalParcel

func (s *CallForwardingInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CallQuality

type CallQuality struct {
	DownlinkCallQualityLevel     int32
	UplinkCallQualityLevel       int32
	CallDuration                 int32
	NumRtpPacketsTransmitted     int32
	NumRtpPacketsReceived        int32
	NumRtpPacketsTransmittedLost int32
	NumRtpPacketsNotReceived     int32
	AverageRelativeJitter        int32
	MaxRelativeJitter            int32
	AverageRoundTripTime         int32
	CodecType                    int32
	RtpInactivityDetected        bool
	RxSilenceDetected            bool
	TxSilenceDetected            bool
	NumVoiceFrames               int32
	NumNoDataFrames              int32
	NumDroppedRtpPackets         int32
	MinPlayoutDelayMillis        int64
	MaxPlayoutDelayMillis        int64
	NumRtpSidPacketsReceived     int32
	NumRtpDuplicatePackets       int32
}

func (*CallQuality) MarshalParcel

func (s *CallQuality) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CallQuality) UnmarshalParcel

func (s *CallQuality) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CallState

type CallState struct {
	PreciseCallState   int32
	NetworkType        int32
	CallClassification int32
	ImsCallId          string
	ImsCallServiceType int32
	ImsCallType        int32
}

func (*CallState) MarshalParcel

func (s *CallState) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CallState) UnmarshalParcel

func (s *CallState) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CarrierRestrictionRules

type CarrierRestrictionRules struct {
	CarrierRestrictionDefault int32
	MultiSimPolicy            int32
	CarrierRestrictionStatus  int32
}

func (*CarrierRestrictionRules) MarshalParcel

func (s *CarrierRestrictionRules) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CarrierRestrictionRules) UnmarshalParcel

func (s *CarrierRestrictionRules) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CellBroadcastIdRange

type CellBroadcastIdRange struct {
	StartId   int32
	EndId     int32
	Type      int32
	IsEnabled bool
}

func (*CellBroadcastIdRange) MarshalParcel

func (s *CellBroadcastIdRange) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CellBroadcastIdRange) UnmarshalParcel

func (s *CellBroadcastIdRange) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CellBroadcastServiceProxy

type CellBroadcastServiceProxy struct {
	Remote binder.IBinder
}

func NewCellBroadcastServiceProxy

func NewCellBroadcastServiceProxy(
	remote binder.IBinder,
) *CellBroadcastServiceProxy

func (*CellBroadcastServiceProxy) AsBinder

func (*CellBroadcastServiceProxy) GetCellBroadcastAreaInfo

func (p *CellBroadcastServiceProxy) GetCellBroadcastAreaInfo(
	ctx context.Context,
	slotIndex int32,
) (string, error)

func (*CellBroadcastServiceProxy) HandleCdmaCellBroadcastSms

func (p *CellBroadcastServiceProxy) HandleCdmaCellBroadcastSms(
	ctx context.Context,
	slotId int32,
	bearerData []byte,
	serviceCategory int32,
) error

func (*CellBroadcastServiceProxy) HandleCdmaScpMessage

func (p *CellBroadcastServiceProxy) HandleCdmaScpMessage(
	ctx context.Context,
	slotId int32,
	programData []cdma.CdmaSmsCbProgramData,
	originatingAddress string,
	callback types.RemoteCallback,
) error

func (*CellBroadcastServiceProxy) HandleGsmCellBroadcastSms

func (p *CellBroadcastServiceProxy) HandleGsmCellBroadcastSms(
	ctx context.Context,
	slotId int32,
	message []byte,
) error

type CellBroadcastServiceStub

type CellBroadcastServiceStub struct {
	Impl      ICellBroadcastService
	Transport binder.VersionAwareTransport
}

CellBroadcastServiceStub dispatches incoming binder transactions to a typed ICellBroadcastService implementation.

func (*CellBroadcastServiceStub) Descriptor

func (s *CellBroadcastServiceStub) Descriptor() string

func (*CellBroadcastServiceStub) OnTransaction

func (s *CellBroadcastServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type CellIdentity

type CellIdentity struct {
	Type       int32
	MccStr     string
	MncStr     string
	AlphaLong  string
	AlphaShort string
}

func (*CellIdentity) MarshalParcel

func (s *CellIdentity) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CellIdentity) UnmarshalParcel

func (s *CellIdentity) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CellIdentityCdma

type CellIdentityCdma struct {
	NetworkId     int32
	SystemId      int32
	BasestationId int32
	Longitude     int32
	Latitude      int32
}

func (*CellIdentityCdma) MarshalParcel

func (s *CellIdentityCdma) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CellIdentityCdma) UnmarshalParcel

func (s *CellIdentityCdma) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CellIdentityGsm

type CellIdentityGsm struct {
	Lac   int32
	Cid   int32
	Arfcn int32
	Bsic  int32
}

func (*CellIdentityGsm) MarshalParcel

func (s *CellIdentityGsm) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CellIdentityGsm) UnmarshalParcel

func (s *CellIdentityGsm) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CellIdentityLte

type CellIdentityLte struct {
	Ci        int32
	Pci       int32
	Tac       int32
	Earfcn    int32
	Bandwidth int32
}

func (*CellIdentityLte) MarshalParcel

func (s *CellIdentityLte) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CellIdentityLte) UnmarshalParcel

func (s *CellIdentityLte) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CellIdentityTdscdma

type CellIdentityTdscdma struct {
	Lac    int32
	Cid    int32
	Cpid   int32
	Uarfcn int32
}

func (*CellIdentityTdscdma) MarshalParcel

func (s *CellIdentityTdscdma) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CellIdentityTdscdma) UnmarshalParcel

func (s *CellIdentityTdscdma) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CellIdentityWcdma

type CellIdentityWcdma struct {
	Lac    int32
	Cid    int32
	Psc    int32
	Uarfcn int32
}

func (*CellIdentityWcdma) MarshalParcel

func (s *CellIdentityWcdma) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CellIdentityWcdma) UnmarshalParcel

func (s *CellIdentityWcdma) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CellInfo

type CellInfo struct {
	Type                 int32
	TimeStamp            int64
	CellConnectionStatus int32
}

func (*CellInfo) MarshalParcel

func (s *CellInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*CellInfo) UnmarshalParcel

func (s *CellInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type CellInfoCallbackProxy

type CellInfoCallbackProxy struct {
	Remote binder.IBinder
}

func NewCellInfoCallbackProxy

func NewCellInfoCallbackProxy(
	remote binder.IBinder,
) *CellInfoCallbackProxy

func (*CellInfoCallbackProxy) AsBinder

func (p *CellInfoCallbackProxy) AsBinder() binder.IBinder

func (*CellInfoCallbackProxy) OnCellInfo

func (p *CellInfoCallbackProxy) OnCellInfo(
	ctx context.Context,
	state []CellInfo,
) error

func (*CellInfoCallbackProxy) OnError

func (p *CellInfoCallbackProxy) OnError(
	ctx context.Context,
	errorCode int32,
	exceptionName string,
	message string,
) error

type CellInfoCallbackStub

type CellInfoCallbackStub struct {
	Impl      ICellInfoCallback
	Transport binder.VersionAwareTransport
}

CellInfoCallbackStub dispatches incoming binder transactions to a typed ICellInfoCallback implementation.

func (*CellInfoCallbackStub) Descriptor

func (s *CellInfoCallbackStub) Descriptor() string

func (*CellInfoCallbackStub) OnTransaction

func (s *CellInfoCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ClientRequestStats

type ClientRequestStats struct {
	CallingPackage                string
	CompletedRequestsWakelockTime int64
	CompletedRequestsCount        int64
	PendingRequestsWakelockTime   int64
	PendingRequestsCount          int64
}

func (*ClientRequestStats) MarshalParcel

func (s *ClientRequestStats) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ClientRequestStats) UnmarshalParcel

func (s *ClientRequestStats) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ClosedSubscriberGroupInfo

type ClosedSubscriberGroupInfo struct {
	CsgIndicator  bool
	HomeNodebName string
	CsgIdentity   int32
}

func (*ClosedSubscriberGroupInfo) MarshalParcel

func (s *ClosedSubscriberGroupInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ClosedSubscriberGroupInfo) UnmarshalParcel

func (s *ClosedSubscriberGroupInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type DataConnectionRealTimeInfo

type DataConnectionRealTimeInfo struct {
	Time         int64
	DcPowerState int32
}

func (*DataConnectionRealTimeInfo) MarshalParcel

func (s *DataConnectionRealTimeInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*DataConnectionRealTimeInfo) UnmarshalParcel

func (s *DataConnectionRealTimeInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type DataThrottlingRequest

type DataThrottlingRequest struct {
	DataThrottlingAction     int32
	CompletionDurationMillis int64
}

func (*DataThrottlingRequest) MarshalParcel

func (s *DataThrottlingRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*DataThrottlingRequest) UnmarshalParcel

func (s *DataThrottlingRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type DomainSelectionServiceSelectionAttributes

type DomainSelectionServiceSelectionAttributes struct {
}

func (*DomainSelectionServiceSelectionAttributes) MarshalParcel

func (*DomainSelectionServiceSelectionAttributes) UnmarshalParcel

type EmergencyRegistrationResult

type EmergencyRegistrationResult struct {
	AccessNetworkType    int32
	RegState             int32
	Domain               int32
	IsVopsSupported      bool
	IsEmcBearerSupported bool
	NwProvidedEmc        int32
	NwProvidedEmf        int32
	Mcc                  string
	Mnc                  string
	CountryIso           string
}

func (*EmergencyRegistrationResult) MarshalParcel

func (s *EmergencyRegistrationResult) MarshalParcel(
	p *parcel.Parcel,
) error

func (*EmergencyRegistrationResult) UnmarshalParcel

func (s *EmergencyRegistrationResult) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IBooleanConsumer

type IBooleanConsumer interface {
	AsBinder() binder.IBinder
	Accept(ctx context.Context, result bool) error
}

func NewBooleanConsumerStub

func NewBooleanConsumerStub(
	impl IBooleanConsumerServer,
) IBooleanConsumer

NewBooleanConsumerStub creates a server-side IBooleanConsumer wrapping the given server implementation. The returned value satisfies IBooleanConsumer and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBooleanConsumerServer

type IBooleanConsumerServer interface {
	Accept(ctx context.Context, result bool) error
}

IBooleanConsumerServer is the server-side interface that user implementations provide to NewBooleanConsumerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IBootstrapAuthenticationCallback

type IBootstrapAuthenticationCallback interface {
	AsBinder() binder.IBinder
	OnKeysAvailable(ctx context.Context, token int32, gbaKey []byte, btId string) error
	OnAuthenticationFailure(ctx context.Context, token int32, reason int32) error
}

func NewBootstrapAuthenticationCallbackStub

func NewBootstrapAuthenticationCallbackStub(
	impl IBootstrapAuthenticationCallbackServer,
) IBootstrapAuthenticationCallback

NewBootstrapAuthenticationCallbackStub creates a server-side IBootstrapAuthenticationCallback wrapping the given server implementation. The returned value satisfies IBootstrapAuthenticationCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBootstrapAuthenticationCallbackServer

type IBootstrapAuthenticationCallbackServer interface {
	OnKeysAvailable(ctx context.Context, token int32, gbaKey []byte, btId string) error
	OnAuthenticationFailure(ctx context.Context, token int32, reason int32) error
}

IBootstrapAuthenticationCallbackServer is the server-side interface that user implementations provide to NewBootstrapAuthenticationCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ICellBroadcastService

type ICellBroadcastService interface {
	AsBinder() binder.IBinder
	HandleGsmCellBroadcastSms(ctx context.Context, slotId int32, message []byte) error
	HandleCdmaCellBroadcastSms(ctx context.Context, slotId int32, bearerData []byte, serviceCategory int32) error
	HandleCdmaScpMessage(ctx context.Context, slotId int32, programData []cdma.CdmaSmsCbProgramData, originatingAddress string, callback types.RemoteCallback) error
	GetCellBroadcastAreaInfo(ctx context.Context, slotIndex int32) (string, error)
}

func NewCellBroadcastServiceStub

func NewCellBroadcastServiceStub(
	impl ICellBroadcastServiceServer,
) ICellBroadcastService

NewCellBroadcastServiceStub creates a server-side ICellBroadcastService wrapping the given server implementation. The returned value satisfies ICellBroadcastService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ICellBroadcastServiceServer

type ICellBroadcastServiceServer interface {
	HandleGsmCellBroadcastSms(ctx context.Context, slotId int32, message []byte) error
	HandleCdmaCellBroadcastSms(ctx context.Context, slotId int32, bearerData []byte, serviceCategory int32) error
	HandleCdmaScpMessage(ctx context.Context, slotId int32, programData []cdma.CdmaSmsCbProgramData, originatingAddress string, callback types.RemoteCallback) error
	GetCellBroadcastAreaInfo(ctx context.Context, slotIndex int32) (string, error)
}

ICellBroadcastServiceServer is the server-side interface that user implementations provide to NewCellBroadcastServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ICellInfoCallback

type ICellInfoCallback interface {
	AsBinder() binder.IBinder
	OnCellInfo(ctx context.Context, state []CellInfo) error
	OnError(ctx context.Context, errorCode int32, exceptionName string, message string) error
}

func NewCellInfoCallbackStub

func NewCellInfoCallbackStub(
	impl ICellInfoCallbackServer,
) ICellInfoCallback

NewCellInfoCallbackStub creates a server-side ICellInfoCallback wrapping the given server implementation. The returned value satisfies ICellInfoCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ICellInfoCallbackServer

type ICellInfoCallbackServer interface {
	OnCellInfo(ctx context.Context, state []CellInfo) error
	OnError(ctx context.Context, errorCode int32, exceptionName string, message string) error
}

ICellInfoCallbackServer is the server-side interface that user implementations provide to NewCellInfoCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IIntegerConsumer

type IIntegerConsumer interface {
	AsBinder() binder.IBinder
	Accept(ctx context.Context, result int32) error
}

func NewIntegerConsumerStub

func NewIntegerConsumerStub(
	impl IIntegerConsumerServer,
) IIntegerConsumer

NewIntegerConsumerStub creates a server-side IIntegerConsumer wrapping the given server implementation. The returned value satisfies IIntegerConsumer and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IIntegerConsumerServer

type IIntegerConsumerServer interface {
	Accept(ctx context.Context, result int32) error
}

IIntegerConsumerServer is the server-side interface that user implementations provide to NewIntegerConsumerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type INetworkService

type INetworkService interface {
	AsBinder() binder.IBinder
	CreateNetworkServiceProvider(ctx context.Context, slotId int32) error
	RemoveNetworkServiceProvider(ctx context.Context, slotId int32) error
	RequestNetworkRegistrationInfo(ctx context.Context, slotId int32, domain int32, callback INetworkServiceCallback) error
	RegisterForNetworkRegistrationInfoChanged(ctx context.Context, slotId int32, callback INetworkServiceCallback) error
	UnregisterForNetworkRegistrationInfoChanged(ctx context.Context, slotId int32, callback INetworkServiceCallback) error
}

func NewNetworkServiceStub

func NewNetworkServiceStub(
	impl INetworkServiceServer,
) INetworkService

NewNetworkServiceStub creates a server-side INetworkService wrapping the given server implementation. The returned value satisfies INetworkService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type INetworkServiceCallback

type INetworkServiceCallback interface {
	AsBinder() binder.IBinder
	OnRequestNetworkRegistrationInfoComplete(ctx context.Context, result int32, state NetworkRegistrationInfo) error
	OnNetworkStateChanged(ctx context.Context) error
}

func NewNetworkServiceCallbackStub

func NewNetworkServiceCallbackStub(
	impl INetworkServiceCallbackServer,
) INetworkServiceCallback

NewNetworkServiceCallbackStub creates a server-side INetworkServiceCallback wrapping the given server implementation. The returned value satisfies INetworkServiceCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type INetworkServiceCallbackServer

type INetworkServiceCallbackServer interface {
	OnRequestNetworkRegistrationInfoComplete(ctx context.Context, result int32, state NetworkRegistrationInfo) error
	OnNetworkStateChanged(ctx context.Context) error
}

INetworkServiceCallbackServer is the server-side interface that user implementations provide to NewNetworkServiceCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type INetworkServiceServer

type INetworkServiceServer interface {
	CreateNetworkServiceProvider(ctx context.Context, slotId int32) error
	RemoveNetworkServiceProvider(ctx context.Context, slotId int32) error
	RequestNetworkRegistrationInfo(ctx context.Context, slotId int32, domain int32, callback INetworkServiceCallback) error
	RegisterForNetworkRegistrationInfoChanged(ctx context.Context, slotId int32, callback INetworkServiceCallback) error
	UnregisterForNetworkRegistrationInfoChanged(ctx context.Context, slotId int32, callback INetworkServiceCallback) error
}

INetworkServiceServer is the server-side interface that user implementations provide to NewNetworkServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IccOpenLogicalChannelResponse

type IccOpenLogicalChannelResponse struct {
	Channel int32
	Status  int32
}

func (*IccOpenLogicalChannelResponse) MarshalParcel

func (s *IccOpenLogicalChannelResponse) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IccOpenLogicalChannelResponse) UnmarshalParcel

func (s *IccOpenLogicalChannelResponse) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ImsiEncryptionInfo

type ImsiEncryptionInfo struct {
	Mcc           string
	Mnc           string
	KeyIdentifier string
	KeyType       int32
	CarrierId     int32
}

func (*ImsiEncryptionInfo) MarshalParcel

func (s *ImsiEncryptionInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ImsiEncryptionInfo) UnmarshalParcel

func (s *ImsiEncryptionInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IntegerConsumerProxy

type IntegerConsumerProxy struct {
	Remote binder.IBinder
}

func NewIntegerConsumerProxy

func NewIntegerConsumerProxy(
	remote binder.IBinder,
) *IntegerConsumerProxy

func (*IntegerConsumerProxy) Accept

func (p *IntegerConsumerProxy) Accept(
	ctx context.Context,
	result int32,
) error

func (*IntegerConsumerProxy) AsBinder

func (p *IntegerConsumerProxy) AsBinder() binder.IBinder

type IntegerConsumerStub

type IntegerConsumerStub struct {
	Impl      IIntegerConsumer
	Transport binder.VersionAwareTransport
}

IntegerConsumerStub dispatches incoming binder transactions to a typed IIntegerConsumer implementation.

func (*IntegerConsumerStub) Descriptor

func (s *IntegerConsumerStub) Descriptor() string

func (*IntegerConsumerStub) OnTransaction

func (s *IntegerConsumerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type LinkCapacityEstimate

type LinkCapacityEstimate struct {
	DownlinkCapacityKbps int32
	UplinkCapacityKbps   int32
	Type                 int32
}

func (*LinkCapacityEstimate) MarshalParcel

func (s *LinkCapacityEstimate) MarshalParcel(
	p *parcel.Parcel,
) error

func (*LinkCapacityEstimate) UnmarshalParcel

func (s *LinkCapacityEstimate) UnmarshalParcel(
	p *parcel.Parcel,
) error

type LteVopsSupportInfo

type LteVopsSupportInfo struct {
	VopsSupport      int32
	EmcBearerSupport int32
}

func (*LteVopsSupportInfo) MarshalParcel

func (s *LteVopsSupportInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*LteVopsSupportInfo) UnmarshalParcel

func (s *LteVopsSupportInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ModemActivityInfo

type ModemActivityInfo struct {
	Timestamp   int64
	SleepTimeMs int32
	IdleTimeMs  int32
}

func (*ModemActivityInfo) MarshalParcel

func (s *ModemActivityInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ModemActivityInfo) UnmarshalParcel

func (s *ModemActivityInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type NeighboringCellInfo

type NeighboringCellInfo struct {
	Rssi        int32
	Lac         int32
	Cid         int32
	Psc         int32
	NetworkType int32
}

func (*NeighboringCellInfo) MarshalParcel

func (s *NeighboringCellInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NeighboringCellInfo) UnmarshalParcel

func (s *NeighboringCellInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type NetworkRegistrationInfo

type NetworkRegistrationInfo struct {
	Domain                    int32
	TransportType             int32
	RegistrationState         int32
	NetworkRegistrationState  int32
	RoamingType               int32
	AccessNetworkTechnology   int32
	RejectCause               int32
	EmergencyOnly             bool
	NrState                   int32
	Rplmn                     string
	IsUsingCarrierAggregation bool
	IsNonTerrestrialNetwork   bool
	CellIdentity              *CellIdentity
}

func (*NetworkRegistrationInfo) MarshalParcel

func (s *NetworkRegistrationInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NetworkRegistrationInfo) UnmarshalParcel

func (s *NetworkRegistrationInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type NetworkScanRequest

type NetworkScanRequest struct {
	ScanType                      int32
	SearchPeriodicity             int32
	MaxSearchTime                 int32
	IncrementalResults            bool
	IncrementalResultsPeriodicity int32
}

func (*NetworkScanRequest) MarshalParcel

func (s *NetworkScanRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NetworkScanRequest) UnmarshalParcel

func (s *NetworkScanRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type NetworkServiceCallbackProxy

type NetworkServiceCallbackProxy struct {
	Remote binder.IBinder
}

func NewNetworkServiceCallbackProxy

func NewNetworkServiceCallbackProxy(
	remote binder.IBinder,
) *NetworkServiceCallbackProxy

func (*NetworkServiceCallbackProxy) AsBinder

func (*NetworkServiceCallbackProxy) OnNetworkStateChanged

func (p *NetworkServiceCallbackProxy) OnNetworkStateChanged(
	ctx context.Context,
) error

func (*NetworkServiceCallbackProxy) OnRequestNetworkRegistrationInfoComplete

func (p *NetworkServiceCallbackProxy) OnRequestNetworkRegistrationInfoComplete(
	ctx context.Context,
	result int32,
	state NetworkRegistrationInfo,
) error

type NetworkServiceCallbackStub

type NetworkServiceCallbackStub struct {
	Impl      INetworkServiceCallback
	Transport binder.VersionAwareTransport
}

NetworkServiceCallbackStub dispatches incoming binder transactions to a typed INetworkServiceCallback implementation.

func (*NetworkServiceCallbackStub) Descriptor

func (s *NetworkServiceCallbackStub) Descriptor() string

func (*NetworkServiceCallbackStub) OnTransaction

func (s *NetworkServiceCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type NetworkServiceProxy

type NetworkServiceProxy struct {
	Remote binder.IBinder
}

func NewNetworkServiceProxy

func NewNetworkServiceProxy(
	remote binder.IBinder,
) *NetworkServiceProxy

func (*NetworkServiceProxy) AsBinder

func (p *NetworkServiceProxy) AsBinder() binder.IBinder

func (*NetworkServiceProxy) CreateNetworkServiceProvider

func (p *NetworkServiceProxy) CreateNetworkServiceProvider(
	ctx context.Context,
	slotId int32,
) error

func (*NetworkServiceProxy) RegisterForNetworkRegistrationInfoChanged

func (p *NetworkServiceProxy) RegisterForNetworkRegistrationInfoChanged(
	ctx context.Context,
	slotId int32,
	callback INetworkServiceCallback,
) error

func (*NetworkServiceProxy) RemoveNetworkServiceProvider

func (p *NetworkServiceProxy) RemoveNetworkServiceProvider(
	ctx context.Context,
	slotId int32,
) error

func (*NetworkServiceProxy) RequestNetworkRegistrationInfo

func (p *NetworkServiceProxy) RequestNetworkRegistrationInfo(
	ctx context.Context,
	slotId int32,
	domain int32,
	callback INetworkServiceCallback,
) error

func (*NetworkServiceProxy) UnregisterForNetworkRegistrationInfoChanged

func (p *NetworkServiceProxy) UnregisterForNetworkRegistrationInfoChanged(
	ctx context.Context,
	slotId int32,
	callback INetworkServiceCallback,
) error

type NetworkServiceStub

type NetworkServiceStub struct {
	Impl      INetworkService
	Transport binder.VersionAwareTransport
}

NetworkServiceStub dispatches incoming binder transactions to a typed INetworkService implementation.

func (*NetworkServiceStub) Descriptor

func (s *NetworkServiceStub) Descriptor() string

func (*NetworkServiceStub) OnTransaction

func (s *NetworkServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type NrVopsSupportInfo

type NrVopsSupportInfo struct {
	VopsSupport int32
	EmcSupport  int32
	EmfSupport  int32
}

func (*NrVopsSupportInfo) MarshalParcel

func (s *NrVopsSupportInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NrVopsSupportInfo) UnmarshalParcel

func (s *NrVopsSupportInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type PcoData

type PcoData struct {
	Cid         int32
	BearerProto string
	PcoId       int32
}

func (*PcoData) MarshalParcel

func (s *PcoData) MarshalParcel(
	p *parcel.Parcel,
) error

func (*PcoData) UnmarshalParcel

func (s *PcoData) UnmarshalParcel(
	p *parcel.Parcel,
) error

type PhoneCapability

type PhoneCapability struct {
	MaxActiveVoiceSubscriptions            int32
	MaxActiveDataSubscriptions             int32
	NetworkValidationBeforeSwitchSupported bool
}

func (*PhoneCapability) MarshalParcel

func (s *PhoneCapability) MarshalParcel(
	p *parcel.Parcel,
) error

func (*PhoneCapability) UnmarshalParcel

func (s *PhoneCapability) UnmarshalParcel(
	p *parcel.Parcel,
) error

type PhoneNumberRange

type PhoneNumberRange struct {
	CountryCode string
	Prefix      string
	LowerBound  string
	UpperBound  string
}

func (*PhoneNumberRange) MarshalParcel

func (s *PhoneNumberRange) MarshalParcel(
	p *parcel.Parcel,
) error

func (*PhoneNumberRange) UnmarshalParcel

func (s *PhoneNumberRange) UnmarshalParcel(
	p *parcel.Parcel,
) error

type PhysicalChannelConfig

type PhysicalChannelConfig struct {
	CellConnectionStatus     int32
	CellBandwidthDownlinkKhz int32
	CellBandwidthUplinkKhz   int32
	NetworkType              int32
	DownlinkChannelNumber    int32
	UplinkChannelNumber      int32
	FrequencyRange           int32
	PhysicalCellId           int32
	Band                     int32
}

func (*PhysicalChannelConfig) MarshalParcel

func (s *PhysicalChannelConfig) MarshalParcel(
	p *parcel.Parcel,
) error

func (*PhysicalChannelConfig) UnmarshalParcel

func (s *PhysicalChannelConfig) UnmarshalParcel(
	p *parcel.Parcel,
) error

type PreciseCallState

type PreciseCallState struct {
	RingingCallState       int32
	ForegroundCallState    int32
	BackgroundCallState    int32
	DisconnectCause        int32
	PreciseDisconnectCause int32
}

func (*PreciseCallState) MarshalParcel

func (s *PreciseCallState) MarshalParcel(
	p *parcel.Parcel,
) error

func (*PreciseCallState) UnmarshalParcel

func (s *PreciseCallState) UnmarshalParcel(
	p *parcel.Parcel,
) error

type PreciseDataConnectionState

type PreciseDataConnectionState struct {
	TransportType           int32
	Id                      int32
	State                   int32
	NetworkType             int32
	FailCause               int32
	NetworkValidationStatus int32
	ApnSetting              *types.ApnSetting
}

func (*PreciseDataConnectionState) MarshalParcel

func (s *PreciseDataConnectionState) MarshalParcel(
	p *parcel.Parcel,
) error

func (*PreciseDataConnectionState) UnmarshalParcel

func (s *PreciseDataConnectionState) UnmarshalParcel(
	p *parcel.Parcel,
) error

type RadioAccessFamily

type RadioAccessFamily struct {
	PhoneId           int32
	RadioAccessFamily int32
}

func (*RadioAccessFamily) MarshalParcel

func (s *RadioAccessFamily) MarshalParcel(
	p *parcel.Parcel,
) error

func (*RadioAccessFamily) UnmarshalParcel

func (s *RadioAccessFamily) UnmarshalParcel(
	p *parcel.Parcel,
) error

type RadioAccessSpecifier

type RadioAccessSpecifier struct {
	RadioAccessNetwork int32
}

func (*RadioAccessSpecifier) MarshalParcel

func (s *RadioAccessSpecifier) MarshalParcel(
	p *parcel.Parcel,
) error

func (*RadioAccessSpecifier) UnmarshalParcel

func (s *RadioAccessSpecifier) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ServiceState

type ServiceState struct {
	VoiceRegState                 int32
	DataRegState                  int32
	OperatorAlphaLong             string
	OperatorAlphaShort            string
	OperatorNumeric               string
	NetworkId                     int32
	SystemId                      int32
	CdmaRoamingIndicator          int32
	CdmaDefaultRoamingIndicator   int32
	CdmaEriIconIndex              int32
	CdmaEriIconMode               int32
	ArfcnRsrpBoost                int32
	ChannelNumber                 int32
	NrFrequencyRange              int32
	OperatorAlphaLongRaw          string
	OperatorAlphaShortRaw         string
	IsDataRoamingFromRegistration bool
	IsIwlanPreferred              bool
}

func (*ServiceState) MarshalParcel

func (s *ServiceState) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ServiceState) UnmarshalParcel

func (s *ServiceState) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SignalStrength

type SignalStrength struct {
	TimestampMillis int64
}

func (*SignalStrength) MarshalParcel

func (s *SignalStrength) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SignalStrength) UnmarshalParcel

func (s *SignalStrength) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SignalStrengthUpdateRequest

type SignalStrengthUpdateRequest struct {
	IsReportingRequestedWhileIdle                bool
	IsSystemThresholdReportingRequestedWhileIdle bool
}

func (*SignalStrengthUpdateRequest) MarshalParcel

func (s *SignalStrengthUpdateRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SignalStrengthUpdateRequest) UnmarshalParcel

func (s *SignalStrengthUpdateRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SubscriptionInfo

type SubscriptionInfo struct {
	Id                          int32
	IccId                       string
	SimSlotIndex                int32
	DisplayNameSource           int32
	IconTint                    int32
	Number                      string
	DataRoaming                 int32
	Mcc                         string
	Mnc                         string
	CountryIso                  string
	IsEmbedded                  bool
	CardString                  string
	CardId                      int32
	PortIndex                   int32
	IsOpportunistic             bool
	IsGroupDisabled             bool
	CarrierId                   int32
	ProfileClass                int32
	Type                        int32
	GroupOwner                  string
	AreUiccApplicationsEnabled  bool
	UsageSetting                int32
	IsOnlyNonTerrestrialNetwork bool
	ServiceCapabilities         int32
	TransferStatus              int32
}

func (*SubscriptionInfo) MarshalParcel

func (s *SubscriptionInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SubscriptionInfo) UnmarshalParcel

func (s *SubscriptionInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SubscriptionPlan

type SubscriptionPlan struct {
	DataLimitBytes    int64
	DataLimitBehavior int32
	DataUsageBytes    int64
	DataUsageTime     int64
}

func (*SubscriptionPlan) MarshalParcel

func (s *SubscriptionPlan) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SubscriptionPlan) UnmarshalParcel

func (s *SubscriptionPlan) UnmarshalParcel(
	p *parcel.Parcel,
) error

type TelephonyDisplayInfo

type TelephonyDisplayInfo struct {
	NetworkType         int32
	OverrideNetworkType int32
	IsRoaming           bool
}

func (*TelephonyDisplayInfo) MarshalParcel

func (s *TelephonyDisplayInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*TelephonyDisplayInfo) UnmarshalParcel

func (s *TelephonyDisplayInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type TelephonyHistogram

type TelephonyHistogram struct {
	Category      int32
	Id            int32
	MinTimeMs     int32
	MaxTimeMs     int32
	AverageTimeMs int32
	SampleCount   int32
	BucketCount   int32
}

func (*TelephonyHistogram) MarshalParcel

func (s *TelephonyHistogram) MarshalParcel(
	p *parcel.Parcel,
) error

func (*TelephonyHistogram) UnmarshalParcel

func (s *TelephonyHistogram) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ThermalMitigationRequest

type ThermalMitigationRequest struct {
	ThermalMitigationAction int32
	DataThrottlingRequest   *DataThrottlingRequest
}

func (*ThermalMitigationRequest) MarshalParcel

func (s *ThermalMitigationRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ThermalMitigationRequest) UnmarshalParcel

func (s *ThermalMitigationRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type UiccAccessRule

type UiccAccessRule struct {
	PackageName string
	AccessType  int64
}

func (*UiccAccessRule) MarshalParcel

func (s *UiccAccessRule) MarshalParcel(
	p *parcel.Parcel,
) error

func (*UiccAccessRule) UnmarshalParcel

func (s *UiccAccessRule) UnmarshalParcel(
	p *parcel.Parcel,
) error

type UiccCardInfo

type UiccCardInfo struct {
	IsEuicc                            bool
	CardId                             int32
	Eid                                string
	IccId                              string
	PhysicalSlotIndex                  int32
	IsRemovable                        bool
	IsMultipleEnabledProfilesSupported bool
	IccIdAccessRestricted              bool
}

func (*UiccCardInfo) MarshalParcel

func (s *UiccCardInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*UiccCardInfo) UnmarshalParcel

func (s *UiccCardInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type UiccPortInfo

type UiccPortInfo struct {
	IccId            string
	PortIndex        int32
	LogicalSlotIndex int32
	IsActive         bool
}

func (*UiccPortInfo) MarshalParcel

func (s *UiccPortInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*UiccPortInfo) UnmarshalParcel

func (s *UiccPortInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type UiccSlotInfo

type UiccSlotInfo struct {
	IsActive                    bool
	IsEuicc                     bool
	CardId                      string
	CardStateInfo               int32
	LogicalSlotIdx              int32
	IsExtendedApduSupported     bool
	IsRemovable                 bool
	LogicalSlotAccessRestricted bool
}

func (*UiccSlotInfo) MarshalParcel

func (s *UiccSlotInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*UiccSlotInfo) UnmarshalParcel

func (s *UiccSlotInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type UiccSlotMapping

type UiccSlotMapping struct {
	PortIndex         int32
	PhysicalSlotIndex int32
	LogicalSlotIndex  int32
}

func (*UiccSlotMapping) MarshalParcel

func (s *UiccSlotMapping) MarshalParcel(
	p *parcel.Parcel,
) error

func (*UiccSlotMapping) UnmarshalParcel

func (s *UiccSlotMapping) UnmarshalParcel(
	p *parcel.Parcel,
) error

type UssdResponse

type UssdResponse struct {
	UssdRequest string
}

func (*UssdResponse) MarshalParcel

func (s *UssdResponse) MarshalParcel(
	p *parcel.Parcel,
) error

func (*UssdResponse) UnmarshalParcel

func (s *UssdResponse) UnmarshalParcel(
	p *parcel.Parcel,
) error

type VisualVoicemailSmsFilterSettings

type VisualVoicemailSmsFilterSettings struct {
	ClientPrefix    string
	DestinationPort int32
	PackageName     string
}

func (*VisualVoicemailSmsFilterSettings) MarshalParcel

func (s *VisualVoicemailSmsFilterSettings) MarshalParcel(
	p *parcel.Parcel,
) error

func (*VisualVoicemailSmsFilterSettings) UnmarshalParcel

func (s *VisualVoicemailSmsFilterSettings) UnmarshalParcel(
	p *parcel.Parcel,
) error

type VoLteServiceState

type VoLteServiceState struct {
	SrvccState int32
}

func (*VoLteServiceState) MarshalParcel

func (s *VoLteServiceState) MarshalParcel(
	p *parcel.Parcel,
) error

func (*VoLteServiceState) UnmarshalParcel

func (s *VoLteServiceState) UnmarshalParcel(
	p *parcel.Parcel,
) error

type VopsSupportInfo

type VopsSupportInfo struct {
	Type int32
}

func (*VopsSupportInfo) MarshalParcel

func (s *VopsSupportInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*VopsSupportInfo) UnmarshalParcel

func (s *VopsSupportInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

Directories

Path Synopsis
ims

Jump to