Documentation
¶
Index ¶
- Constants
- type ApnSetting
- type DataCallResponse
- type DataProfile
- type DataServiceCallbackProxy
- func (p *DataServiceCallbackProxy) AsBinder() binder.IBinder
- func (p *DataServiceCallbackProxy) OnApnUnthrottled(ctx context.Context, apn string) error
- func (p *DataServiceCallbackProxy) OnDataCallListChanged(ctx context.Context, dataCallList []DataCallResponse) error
- func (p *DataServiceCallbackProxy) OnDataProfileUnthrottled(ctx context.Context, dp DataProfile) error
- func (p *DataServiceCallbackProxy) OnDeactivateDataCallComplete(ctx context.Context, result int32) error
- func (p *DataServiceCallbackProxy) OnHandoverCancelled(ctx context.Context, result int32) error
- func (p *DataServiceCallbackProxy) OnHandoverStarted(ctx context.Context, result int32) error
- func (p *DataServiceCallbackProxy) OnRequestDataCallListComplete(ctx context.Context, result int32, dataCallList []DataCallResponse) error
- func (p *DataServiceCallbackProxy) OnSetDataProfileComplete(ctx context.Context, result int32) error
- func (p *DataServiceCallbackProxy) OnSetInitialAttachApnComplete(ctx context.Context, result int32) error
- func (p *DataServiceCallbackProxy) OnSetupDataCallComplete(ctx context.Context, result int32, dataCallResponse DataCallResponse) error
- type DataServiceCallbackStub
- type DataServiceProxy
- func (p *DataServiceProxy) AsBinder() binder.IBinder
- func (p *DataServiceProxy) CancelHandover(ctx context.Context, slotId int32, cid int32, callback IDataServiceCallback) error
- func (p *DataServiceProxy) CreateDataServiceProvider(ctx context.Context, slotId int32) error
- func (p *DataServiceProxy) DeactivateDataCall(ctx context.Context, slotId int32, cid int32, reason int32, ...) error
- func (p *DataServiceProxy) RegisterForDataCallListChanged(ctx context.Context, slotId int32, callback IDataServiceCallback) error
- func (p *DataServiceProxy) RegisterForUnthrottleApn(ctx context.Context, slotIndex int32, callback IDataServiceCallback) error
- func (p *DataServiceProxy) RemoveDataServiceProvider(ctx context.Context, slotId int32) error
- func (p *DataServiceProxy) RequestDataCallList(ctx context.Context, slotId int32, callback IDataServiceCallback) error
- func (p *DataServiceProxy) RequestNetworkValidation(ctx context.Context, slotId int32, cid int32, ...) error
- func (p *DataServiceProxy) SetDataProfile(ctx context.Context, slotId int32, dps []DataProfile, isRoaming bool, ...) error
- func (p *DataServiceProxy) SetInitialAttachApn(ctx context.Context, slotId int32, dataProfile DataProfile, isRoaming bool, ...) error
- func (p *DataServiceProxy) SetupDataCall(ctx context.Context, slotId int32, accessNetwork int32, ...) error
- func (p *DataServiceProxy) StartHandover(ctx context.Context, slotId int32, cid int32, callback IDataServiceCallback) error
- func (p *DataServiceProxy) UnregisterForDataCallListChanged(ctx context.Context, slotId int32, callback IDataServiceCallback) error
- func (p *DataServiceProxy) UnregisterForUnthrottleApn(ctx context.Context, slotIndex int32, callback IDataServiceCallback) error
- type DataServiceStub
- type EpsBearerQosSessionAttributes
- type IDataService
- type IDataServiceCallback
- type IDataServiceCallbackServer
- type IDataServiceServer
- type IQualifiedNetworksService
- type IQualifiedNetworksServiceCallback
- type IQualifiedNetworksServiceCallbackServer
- type IQualifiedNetworksServiceServer
- type NetworkSliceInfo
- type NetworkSlicingConfig
- type NrQosSessionAttributes
- type QualifiedNetworksServiceCallbackProxy
- func (p *QualifiedNetworksServiceCallbackProxy) AsBinder() binder.IBinder
- func (p *QualifiedNetworksServiceCallbackProxy) OnNetworkValidationRequested(ctx context.Context, networkCapability int32, ...) error
- func (p *QualifiedNetworksServiceCallbackProxy) OnQualifiedNetworkTypesChanged(ctx context.Context, apnTypes int32, qualifiedNetworkTypes []int32) error
- func (p *QualifiedNetworksServiceCallbackProxy) OnReconnectQualifedNetworkType(ctx context.Context, apnTypes int32, qualifiedNetworkType int32) error
- type QualifiedNetworksServiceCallbackStub
- type QualifiedNetworksServiceProxy
- func (p *QualifiedNetworksServiceProxy) AsBinder() binder.IBinder
- func (p *QualifiedNetworksServiceProxy) CreateNetworkAvailabilityProvider(ctx context.Context, slotId int32, callback IQualifiedNetworksServiceCallback) error
- func (p *QualifiedNetworksServiceProxy) RemoveNetworkAvailabilityProvider(ctx context.Context, slotId int32) error
- func (p *QualifiedNetworksServiceProxy) ReportEmergencyDataNetworkPreferredTransportChanged(ctx context.Context, slotId int32, transportType int32) error
- func (p *QualifiedNetworksServiceProxy) ReportThrottleStatusChanged(ctx context.Context, slotId int32, statuses []ThrottleStatus) error
- type QualifiedNetworksServiceStub
- type RouteSelectionDescriptor
- type ThrottleStatus
- type TrafficDescriptor
- type UrspRule
Constants ¶
const ( TransactionIDataServiceCreateDataServiceProvider = binder.FirstCallTransaction + 0 TransactionIDataServiceRemoveDataServiceProvider = binder.FirstCallTransaction + 1 TransactionIDataServiceSetupDataCall = binder.FirstCallTransaction + 2 TransactionIDataServiceDeactivateDataCall = binder.FirstCallTransaction + 3 TransactionIDataServiceSetInitialAttachApn = binder.FirstCallTransaction + 4 TransactionIDataServiceSetDataProfile = binder.FirstCallTransaction + 5 TransactionIDataServiceRequestDataCallList = binder.FirstCallTransaction + 6 TransactionIDataServiceRegisterForDataCallListChanged = binder.FirstCallTransaction + 7 TransactionIDataServiceUnregisterForDataCallListChanged = binder.FirstCallTransaction + 8 TransactionIDataServiceStartHandover = binder.FirstCallTransaction + 9 TransactionIDataServiceCancelHandover = binder.FirstCallTransaction + 10 TransactionIDataServiceRegisterForUnthrottleApn = binder.FirstCallTransaction + 11 TransactionIDataServiceUnregisterForUnthrottleApn = binder.FirstCallTransaction + 12 TransactionIDataServiceRequestNetworkValidation = binder.FirstCallTransaction + 13 )
const ( MethodIDataServiceCreateDataServiceProvider = "createDataServiceProvider" MethodIDataServiceRemoveDataServiceProvider = "removeDataServiceProvider" MethodIDataServiceSetupDataCall = "setupDataCall" MethodIDataServiceDeactivateDataCall = "deactivateDataCall" MethodIDataServiceSetInitialAttachApn = "setInitialAttachApn" MethodIDataServiceSetDataProfile = "setDataProfile" MethodIDataServiceRequestDataCallList = "requestDataCallList" MethodIDataServiceRegisterForDataCallListChanged = "registerForDataCallListChanged" MethodIDataServiceUnregisterForDataCallListChanged = "unregisterForDataCallListChanged" MethodIDataServiceStartHandover = "startHandover" MethodIDataServiceCancelHandover = "cancelHandover" MethodIDataServiceRegisterForUnthrottleApn = "registerForUnthrottleApn" MethodIDataServiceUnregisterForUnthrottleApn = "unregisterForUnthrottleApn" MethodIDataServiceRequestNetworkValidation = "requestNetworkValidation" )
const ( TransactionIDataServiceCallbackOnSetupDataCallComplete = binder.FirstCallTransaction + 0 TransactionIDataServiceCallbackOnDeactivateDataCallComplete = binder.FirstCallTransaction + 1 TransactionIDataServiceCallbackOnSetInitialAttachApnComplete = binder.FirstCallTransaction + 2 TransactionIDataServiceCallbackOnSetDataProfileComplete = binder.FirstCallTransaction + 3 TransactionIDataServiceCallbackOnRequestDataCallListComplete = binder.FirstCallTransaction + 4 TransactionIDataServiceCallbackOnDataCallListChanged = binder.FirstCallTransaction + 5 TransactionIDataServiceCallbackOnHandoverStarted = binder.FirstCallTransaction + 6 TransactionIDataServiceCallbackOnHandoverCancelled = binder.FirstCallTransaction + 7 TransactionIDataServiceCallbackOnApnUnthrottled = binder.FirstCallTransaction + 8 TransactionIDataServiceCallbackOnDataProfileUnthrottled = binder.FirstCallTransaction + 9 )
const ( MethodIDataServiceCallbackOnSetupDataCallComplete = "onSetupDataCallComplete" MethodIDataServiceCallbackOnDeactivateDataCallComplete = "onDeactivateDataCallComplete" MethodIDataServiceCallbackOnSetInitialAttachApnComplete = "onSetInitialAttachApnComplete" MethodIDataServiceCallbackOnSetDataProfileComplete = "onSetDataProfileComplete" MethodIDataServiceCallbackOnRequestDataCallListComplete = "onRequestDataCallListComplete" MethodIDataServiceCallbackOnDataCallListChanged = "onDataCallListChanged" MethodIDataServiceCallbackOnHandoverStarted = "onHandoverStarted" MethodIDataServiceCallbackOnHandoverCancelled = "onHandoverCancelled" MethodIDataServiceCallbackOnApnUnthrottled = "onApnUnthrottled" MethodIDataServiceCallbackOnDataProfileUnthrottled = "onDataProfileUnthrottled" )
const ( TransactionIQualifiedNetworksServiceCreateNetworkAvailabilityProvider = binder.FirstCallTransaction + 0 TransactionIQualifiedNetworksServiceRemoveNetworkAvailabilityProvider = binder.FirstCallTransaction + 1 TransactionIQualifiedNetworksServiceReportThrottleStatusChanged = binder.FirstCallTransaction + 2 TransactionIQualifiedNetworksServiceReportEmergencyDataNetworkPreferredTransportChanged = binder.FirstCallTransaction + 3 )
const ( MethodIQualifiedNetworksServiceCreateNetworkAvailabilityProvider = "createNetworkAvailabilityProvider" MethodIQualifiedNetworksServiceRemoveNetworkAvailabilityProvider = "removeNetworkAvailabilityProvider" MethodIQualifiedNetworksServiceReportThrottleStatusChanged = "reportThrottleStatusChanged" MethodIQualifiedNetworksServiceReportEmergencyDataNetworkPreferredTransportChanged = "reportEmergencyDataNetworkPreferredTransportChanged" )
const ( TransactionIQualifiedNetworksServiceCallbackOnQualifiedNetworkTypesChanged = binder.FirstCallTransaction + 0 TransactionIQualifiedNetworksServiceCallbackOnNetworkValidationRequested = binder.FirstCallTransaction + 1 TransactionIQualifiedNetworksServiceCallbackOnReconnectQualifedNetworkType = binder.FirstCallTransaction + 2 )
const ( MethodIQualifiedNetworksServiceCallbackOnQualifiedNetworkTypesChanged = "onQualifiedNetworkTypesChanged" MethodIQualifiedNetworksServiceCallbackOnNetworkValidationRequested = "onNetworkValidationRequested" MethodIQualifiedNetworksServiceCallbackOnReconnectQualifedNetworkType = "onReconnectQualifedNetworkType" )
const DescriptorIDataService = "android.telephony.data.IDataService"
const DescriptorIDataServiceCallback = "android.telephony.data.IDataServiceCallback"
const DescriptorIQualifiedNetworksService = "android.telephony.data.IQualifiedNetworksService"
const DescriptorIQualifiedNetworksServiceCallback = "android.telephony.data.IQualifiedNetworksServiceCallback"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApnSetting ¶
type ApnSetting struct {
Id int32
OperatorNumeric string
EntryName string
ApnName string
ProxyAddress string
ProxyPort int32
MmsProxyAddress string
MmsProxyPort int32
User string
Password string
AuthType int32
ApnTypeBitmask int32
Protocol int32
RoamingProtocol int32
CarrierEnabled bool
NetworkTypeBitmask int32
LingeringNetworkTypeBitmask int64
ProfileId int32
Persistent bool
MaxConns int32
WaitTime int32
MaxConnsTime int32
MtuV4 int32
MtuV6 int32
MvnoType int32
MvnoMatchData string
ApnSetId int32
CarrierId int32
Skip464Xlat int32
AlwaysOn bool
InfrastructureBitmask int32
EsimBootstrapProvisioning bool
EditedStatus int32
}
func (*ApnSetting) MarshalParcel ¶
func (s *ApnSetting) MarshalParcel( p *parcel.Parcel, ) error
func (*ApnSetting) UnmarshalParcel ¶
func (s *ApnSetting) UnmarshalParcel( p *parcel.Parcel, ) error
type DataCallResponse ¶
type DataCallResponse struct {
Cause int32
SuggestedRetryTime int64
Id int32
LinkStatus int32
ProtocolType int32
InterfaceName string
Mtu int32
MtuV4 int32
MtuV6 int32
HandoverFailureMode int32
PduSessionId int32
NetworkValidationStatus int32
SliceInfo *radioData.SliceInfo
}
func (*DataCallResponse) MarshalParcel ¶
func (s *DataCallResponse) MarshalParcel( p *parcel.Parcel, ) error
func (*DataCallResponse) UnmarshalParcel ¶
func (s *DataCallResponse) UnmarshalParcel( p *parcel.Parcel, ) error
type DataProfile ¶
type DataProfile struct {
Type int32
Preferred bool
SetupTimestamp int64
ApnSetting *ApnSetting
}
func (*DataProfile) MarshalParcel ¶
func (s *DataProfile) MarshalParcel( p *parcel.Parcel, ) error
func (*DataProfile) UnmarshalParcel ¶
func (s *DataProfile) UnmarshalParcel( p *parcel.Parcel, ) error
type DataServiceCallbackProxy ¶
func NewDataServiceCallbackProxy ¶
func NewDataServiceCallbackProxy( remote binder.IBinder, ) *DataServiceCallbackProxy
func (*DataServiceCallbackProxy) AsBinder ¶
func (p *DataServiceCallbackProxy) AsBinder() binder.IBinder
func (*DataServiceCallbackProxy) OnApnUnthrottled ¶
func (p *DataServiceCallbackProxy) OnApnUnthrottled( ctx context.Context, apn string, ) error
func (*DataServiceCallbackProxy) OnDataCallListChanged ¶
func (p *DataServiceCallbackProxy) OnDataCallListChanged( ctx context.Context, dataCallList []DataCallResponse, ) error
func (*DataServiceCallbackProxy) OnDataProfileUnthrottled ¶
func (p *DataServiceCallbackProxy) OnDataProfileUnthrottled( ctx context.Context, dp DataProfile, ) error
func (*DataServiceCallbackProxy) OnDeactivateDataCallComplete ¶
func (p *DataServiceCallbackProxy) OnDeactivateDataCallComplete( ctx context.Context, result int32, ) error
func (*DataServiceCallbackProxy) OnHandoverCancelled ¶
func (p *DataServiceCallbackProxy) OnHandoverCancelled( ctx context.Context, result int32, ) error
func (*DataServiceCallbackProxy) OnHandoverStarted ¶
func (p *DataServiceCallbackProxy) OnHandoverStarted( ctx context.Context, result int32, ) error
func (*DataServiceCallbackProxy) OnRequestDataCallListComplete ¶
func (p *DataServiceCallbackProxy) OnRequestDataCallListComplete( ctx context.Context, result int32, dataCallList []DataCallResponse, ) error
func (*DataServiceCallbackProxy) OnSetDataProfileComplete ¶
func (p *DataServiceCallbackProxy) OnSetDataProfileComplete( ctx context.Context, result int32, ) error
func (*DataServiceCallbackProxy) OnSetInitialAttachApnComplete ¶
func (p *DataServiceCallbackProxy) OnSetInitialAttachApnComplete( ctx context.Context, result int32, ) error
func (*DataServiceCallbackProxy) OnSetupDataCallComplete ¶
func (p *DataServiceCallbackProxy) OnSetupDataCallComplete( ctx context.Context, result int32, dataCallResponse DataCallResponse, ) error
type DataServiceCallbackStub ¶
type DataServiceCallbackStub struct {
Impl IDataServiceCallback
Transport binder.VersionAwareTransport
}
DataServiceCallbackStub dispatches incoming binder transactions to a typed IDataServiceCallback implementation.
func (*DataServiceCallbackStub) Descriptor ¶
func (s *DataServiceCallbackStub) Descriptor() string
func (*DataServiceCallbackStub) OnTransaction ¶
func (s *DataServiceCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type DataServiceProxy ¶
func NewDataServiceProxy ¶
func NewDataServiceProxy( remote binder.IBinder, ) *DataServiceProxy
func (*DataServiceProxy) AsBinder ¶
func (p *DataServiceProxy) AsBinder() binder.IBinder
func (*DataServiceProxy) CancelHandover ¶
func (p *DataServiceProxy) CancelHandover( ctx context.Context, slotId int32, cid int32, callback IDataServiceCallback, ) error
func (*DataServiceProxy) CreateDataServiceProvider ¶
func (p *DataServiceProxy) CreateDataServiceProvider( ctx context.Context, slotId int32, ) error
func (*DataServiceProxy) DeactivateDataCall ¶
func (p *DataServiceProxy) DeactivateDataCall( ctx context.Context, slotId int32, cid int32, reason int32, callback IDataServiceCallback, ) error
func (*DataServiceProxy) RegisterForDataCallListChanged ¶
func (p *DataServiceProxy) RegisterForDataCallListChanged( ctx context.Context, slotId int32, callback IDataServiceCallback, ) error
func (*DataServiceProxy) RegisterForUnthrottleApn ¶
func (p *DataServiceProxy) RegisterForUnthrottleApn( ctx context.Context, slotIndex int32, callback IDataServiceCallback, ) error
func (*DataServiceProxy) RemoveDataServiceProvider ¶
func (p *DataServiceProxy) RemoveDataServiceProvider( ctx context.Context, slotId int32, ) error
func (*DataServiceProxy) RequestDataCallList ¶
func (p *DataServiceProxy) RequestDataCallList( ctx context.Context, slotId int32, callback IDataServiceCallback, ) error
func (*DataServiceProxy) RequestNetworkValidation ¶
func (p *DataServiceProxy) RequestNetworkValidation( ctx context.Context, slotId int32, cid int32, callback telephony.IIntegerConsumer, ) error
func (*DataServiceProxy) SetDataProfile ¶
func (p *DataServiceProxy) SetDataProfile( ctx context.Context, slotId int32, dps []DataProfile, isRoaming bool, callback IDataServiceCallback, ) error
func (*DataServiceProxy) SetInitialAttachApn ¶
func (p *DataServiceProxy) SetInitialAttachApn( ctx context.Context, slotId int32, dataProfile DataProfile, isRoaming bool, callback IDataServiceCallback, ) error
func (*DataServiceProxy) SetupDataCall ¶
func (p *DataServiceProxy) SetupDataCall( ctx context.Context, slotId int32, accessNetwork int32, dataProfile DataProfile, isRoaming bool, allowRoaming bool, reason int32, linkProperties any, pduSessionId int32, sliceInfo NetworkSliceInfo, trafficDescriptor TrafficDescriptor, matchAllRuleAllowed bool, callback IDataServiceCallback, ) error
func (*DataServiceProxy) StartHandover ¶
func (p *DataServiceProxy) StartHandover( ctx context.Context, slotId int32, cid int32, callback IDataServiceCallback, ) error
func (*DataServiceProxy) UnregisterForDataCallListChanged ¶
func (p *DataServiceProxy) UnregisterForDataCallListChanged( ctx context.Context, slotId int32, callback IDataServiceCallback, ) error
func (*DataServiceProxy) UnregisterForUnthrottleApn ¶
func (p *DataServiceProxy) UnregisterForUnthrottleApn( ctx context.Context, slotIndex int32, callback IDataServiceCallback, ) error
type DataServiceStub ¶
type DataServiceStub struct {
Impl IDataService
Transport binder.VersionAwareTransport
}
DataServiceStub dispatches incoming binder transactions to a typed IDataService implementation.
func (*DataServiceStub) Descriptor ¶
func (s *DataServiceStub) Descriptor() string
func (*DataServiceStub) OnTransaction ¶
func (s *DataServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type EpsBearerQosSessionAttributes ¶
type EpsBearerQosSessionAttributes struct {
Qci int32
MaxDownlinkBitRate int64
MaxUplinkBitRate int64
GuaranteedDownlinkBitRate int64
GuaranteedUplinkBitRate int64
Size int32
}
func (*EpsBearerQosSessionAttributes) MarshalParcel ¶
func (s *EpsBearerQosSessionAttributes) MarshalParcel( p *parcel.Parcel, ) error
func (*EpsBearerQosSessionAttributes) UnmarshalParcel ¶
func (s *EpsBearerQosSessionAttributes) UnmarshalParcel( p *parcel.Parcel, ) error
type IDataService ¶
type IDataService interface {
AsBinder() binder.IBinder
CreateDataServiceProvider(ctx context.Context, slotId int32) error
RemoveDataServiceProvider(ctx context.Context, slotId int32) error
SetupDataCall(ctx context.Context, slotId int32, accessNetwork int32, dataProfile DataProfile, isRoaming bool, allowRoaming bool, reason int32, linkProperties any, pduSessionId int32, sliceInfo NetworkSliceInfo, trafficDescriptor TrafficDescriptor, matchAllRuleAllowed bool, callback IDataServiceCallback) error
DeactivateDataCall(ctx context.Context, slotId int32, cid int32, reason int32, callback IDataServiceCallback) error
SetInitialAttachApn(ctx context.Context, slotId int32, dataProfile DataProfile, isRoaming bool, callback IDataServiceCallback) error
SetDataProfile(ctx context.Context, slotId int32, dps []DataProfile, isRoaming bool, callback IDataServiceCallback) error
RequestDataCallList(ctx context.Context, slotId int32, callback IDataServiceCallback) error
RegisterForDataCallListChanged(ctx context.Context, slotId int32, callback IDataServiceCallback) error
UnregisterForDataCallListChanged(ctx context.Context, slotId int32, callback IDataServiceCallback) error
StartHandover(ctx context.Context, slotId int32, cid int32, callback IDataServiceCallback) error
CancelHandover(ctx context.Context, slotId int32, cid int32, callback IDataServiceCallback) error
RegisterForUnthrottleApn(ctx context.Context, slotIndex int32, callback IDataServiceCallback) error
UnregisterForUnthrottleApn(ctx context.Context, slotIndex int32, callback IDataServiceCallback) error
RequestNetworkValidation(ctx context.Context, slotId int32, cid int32, callback telephony.IIntegerConsumer) error
}
func NewDataServiceStub ¶
func NewDataServiceStub( impl IDataServiceServer, ) IDataService
NewDataServiceStub creates a server-side IDataService wrapping the given server implementation. The returned value satisfies IDataService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IDataServiceCallback ¶
type IDataServiceCallback interface {
AsBinder() binder.IBinder
OnSetupDataCallComplete(ctx context.Context, result int32, dataCallResponse DataCallResponse) error
OnDeactivateDataCallComplete(ctx context.Context, result int32) error
OnSetInitialAttachApnComplete(ctx context.Context, result int32) error
OnSetDataProfileComplete(ctx context.Context, result int32) error
OnRequestDataCallListComplete(ctx context.Context, result int32, dataCallList []DataCallResponse) error
OnDataCallListChanged(ctx context.Context, dataCallList []DataCallResponse) error
OnHandoverStarted(ctx context.Context, result int32) error
OnHandoverCancelled(ctx context.Context, result int32) error
OnApnUnthrottled(ctx context.Context, apn string) error
OnDataProfileUnthrottled(ctx context.Context, dp DataProfile) error
}
func NewDataServiceCallbackStub ¶
func NewDataServiceCallbackStub( impl IDataServiceCallbackServer, ) IDataServiceCallback
NewDataServiceCallbackStub creates a server-side IDataServiceCallback wrapping the given server implementation. The returned value satisfies IDataServiceCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IDataServiceCallbackServer ¶
type IDataServiceCallbackServer interface {
OnSetupDataCallComplete(ctx context.Context, result int32, dataCallResponse DataCallResponse) error
OnDeactivateDataCallComplete(ctx context.Context, result int32) error
OnSetInitialAttachApnComplete(ctx context.Context, result int32) error
OnSetDataProfileComplete(ctx context.Context, result int32) error
OnRequestDataCallListComplete(ctx context.Context, result int32, dataCallList []DataCallResponse) error
OnDataCallListChanged(ctx context.Context, dataCallList []DataCallResponse) error
OnHandoverStarted(ctx context.Context, result int32) error
OnHandoverCancelled(ctx context.Context, result int32) error
OnApnUnthrottled(ctx context.Context, apn string) error
OnDataProfileUnthrottled(ctx context.Context, dp DataProfile) error
}
IDataServiceCallbackServer is the server-side interface that user implementations provide to NewDataServiceCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IDataServiceServer ¶
type IDataServiceServer interface {
CreateDataServiceProvider(ctx context.Context, slotId int32) error
RemoveDataServiceProvider(ctx context.Context, slotId int32) error
SetupDataCall(ctx context.Context, slotId int32, accessNetwork int32, dataProfile DataProfile, isRoaming bool, allowRoaming bool, reason int32, linkProperties any, pduSessionId int32, sliceInfo NetworkSliceInfo, trafficDescriptor TrafficDescriptor, matchAllRuleAllowed bool, callback IDataServiceCallback) error
DeactivateDataCall(ctx context.Context, slotId int32, cid int32, reason int32, callback IDataServiceCallback) error
SetInitialAttachApn(ctx context.Context, slotId int32, dataProfile DataProfile, isRoaming bool, callback IDataServiceCallback) error
SetDataProfile(ctx context.Context, slotId int32, dps []DataProfile, isRoaming bool, callback IDataServiceCallback) error
RequestDataCallList(ctx context.Context, slotId int32, callback IDataServiceCallback) error
RegisterForDataCallListChanged(ctx context.Context, slotId int32, callback IDataServiceCallback) error
UnregisterForDataCallListChanged(ctx context.Context, slotId int32, callback IDataServiceCallback) error
StartHandover(ctx context.Context, slotId int32, cid int32, callback IDataServiceCallback) error
CancelHandover(ctx context.Context, slotId int32, cid int32, callback IDataServiceCallback) error
RegisterForUnthrottleApn(ctx context.Context, slotIndex int32, callback IDataServiceCallback) error
UnregisterForUnthrottleApn(ctx context.Context, slotIndex int32, callback IDataServiceCallback) error
RequestNetworkValidation(ctx context.Context, slotId int32, cid int32, callback telephony.IIntegerConsumer) error
}
IDataServiceServer is the server-side interface that user implementations provide to NewDataServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IQualifiedNetworksService ¶
type IQualifiedNetworksService interface {
AsBinder() binder.IBinder
CreateNetworkAvailabilityProvider(ctx context.Context, slotId int32, callback IQualifiedNetworksServiceCallback) error
RemoveNetworkAvailabilityProvider(ctx context.Context, slotId int32) error
ReportThrottleStatusChanged(ctx context.Context, slotId int32, statuses []ThrottleStatus) error
ReportEmergencyDataNetworkPreferredTransportChanged(ctx context.Context, slotId int32, transportType int32) error
}
func NewQualifiedNetworksServiceStub ¶
func NewQualifiedNetworksServiceStub( impl IQualifiedNetworksServiceServer, ) IQualifiedNetworksService
NewQualifiedNetworksServiceStub creates a server-side IQualifiedNetworksService wrapping the given server implementation. The returned value satisfies IQualifiedNetworksService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IQualifiedNetworksServiceCallback ¶
type IQualifiedNetworksServiceCallback interface {
AsBinder() binder.IBinder
OnQualifiedNetworkTypesChanged(ctx context.Context, apnTypes int32, qualifiedNetworkTypes []int32) error
OnNetworkValidationRequested(ctx context.Context, networkCapability int32, callback telephony.IIntegerConsumer) error
OnReconnectQualifedNetworkType(ctx context.Context, apnTypes int32, qualifiedNetworkType int32) error
}
func NewQualifiedNetworksServiceCallbackStub ¶
func NewQualifiedNetworksServiceCallbackStub( impl IQualifiedNetworksServiceCallbackServer, ) IQualifiedNetworksServiceCallback
NewQualifiedNetworksServiceCallbackStub creates a server-side IQualifiedNetworksServiceCallback wrapping the given server implementation. The returned value satisfies IQualifiedNetworksServiceCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IQualifiedNetworksServiceCallbackServer ¶
type IQualifiedNetworksServiceCallbackServer interface {
OnQualifiedNetworkTypesChanged(ctx context.Context, apnTypes int32, qualifiedNetworkTypes []int32) error
OnNetworkValidationRequested(ctx context.Context, networkCapability int32, callback telephony.IIntegerConsumer) error
OnReconnectQualifedNetworkType(ctx context.Context, apnTypes int32, qualifiedNetworkType int32) error
}
IQualifiedNetworksServiceCallbackServer is the server-side interface that user implementations provide to NewQualifiedNetworksServiceCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IQualifiedNetworksServiceServer ¶
type IQualifiedNetworksServiceServer interface {
CreateNetworkAvailabilityProvider(ctx context.Context, slotId int32, callback IQualifiedNetworksServiceCallback) error
RemoveNetworkAvailabilityProvider(ctx context.Context, slotId int32) error
ReportThrottleStatusChanged(ctx context.Context, slotId int32, statuses []ThrottleStatus) error
ReportEmergencyDataNetworkPreferredTransportChanged(ctx context.Context, slotId int32, transportType int32) error
}
IQualifiedNetworksServiceServer is the server-side interface that user implementations provide to NewQualifiedNetworksServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type NetworkSliceInfo ¶
type NetworkSliceInfo struct {
SliceServiceType int32
SliceDifferentiator int32
MappedHplmnSliceServiceType int32
MappedHplmnSliceDifferentiator int32
Status int32
}
func (*NetworkSliceInfo) MarshalParcel ¶
func (s *NetworkSliceInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*NetworkSliceInfo) UnmarshalParcel ¶
func (s *NetworkSliceInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type NetworkSlicingConfig ¶
type NetworkSlicingConfig struct {
}
func (*NetworkSlicingConfig) MarshalParcel ¶
func (s *NetworkSlicingConfig) MarshalParcel( p *parcel.Parcel, ) error
func (*NetworkSlicingConfig) UnmarshalParcel ¶
func (s *NetworkSlicingConfig) UnmarshalParcel( p *parcel.Parcel, ) error
type NrQosSessionAttributes ¶
type NrQosSessionAttributes struct {
M5Qi int32
Qfi int32
MaxDownlinkBitRate int64
MaxUplinkBitRate int64
GuaranteedDownlinkBitRate int64
GuaranteedUplinkBitRate int64
AveragingWindow int64
Size int32
}
func (*NrQosSessionAttributes) MarshalParcel ¶
func (s *NrQosSessionAttributes) MarshalParcel( p *parcel.Parcel, ) error
func (*NrQosSessionAttributes) UnmarshalParcel ¶
func (s *NrQosSessionAttributes) UnmarshalParcel( p *parcel.Parcel, ) error
type QualifiedNetworksServiceCallbackProxy ¶
func NewQualifiedNetworksServiceCallbackProxy ¶
func NewQualifiedNetworksServiceCallbackProxy( remote binder.IBinder, ) *QualifiedNetworksServiceCallbackProxy
func (*QualifiedNetworksServiceCallbackProxy) AsBinder ¶
func (p *QualifiedNetworksServiceCallbackProxy) AsBinder() binder.IBinder
func (*QualifiedNetworksServiceCallbackProxy) OnNetworkValidationRequested ¶
func (p *QualifiedNetworksServiceCallbackProxy) OnNetworkValidationRequested( ctx context.Context, networkCapability int32, callback telephony.IIntegerConsumer, ) error
func (*QualifiedNetworksServiceCallbackProxy) OnQualifiedNetworkTypesChanged ¶
func (*QualifiedNetworksServiceCallbackProxy) OnReconnectQualifedNetworkType ¶
type QualifiedNetworksServiceCallbackStub ¶
type QualifiedNetworksServiceCallbackStub struct {
Impl IQualifiedNetworksServiceCallback
Transport binder.VersionAwareTransport
}
QualifiedNetworksServiceCallbackStub dispatches incoming binder transactions to a typed IQualifiedNetworksServiceCallback implementation.
func (*QualifiedNetworksServiceCallbackStub) Descriptor ¶
func (s *QualifiedNetworksServiceCallbackStub) Descriptor() string
func (*QualifiedNetworksServiceCallbackStub) OnTransaction ¶
func (s *QualifiedNetworksServiceCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type QualifiedNetworksServiceProxy ¶
func NewQualifiedNetworksServiceProxy ¶
func NewQualifiedNetworksServiceProxy( remote binder.IBinder, ) *QualifiedNetworksServiceProxy
func (*QualifiedNetworksServiceProxy) AsBinder ¶
func (p *QualifiedNetworksServiceProxy) AsBinder() binder.IBinder
func (*QualifiedNetworksServiceProxy) CreateNetworkAvailabilityProvider ¶
func (p *QualifiedNetworksServiceProxy) CreateNetworkAvailabilityProvider( ctx context.Context, slotId int32, callback IQualifiedNetworksServiceCallback, ) error
func (*QualifiedNetworksServiceProxy) RemoveNetworkAvailabilityProvider ¶
func (p *QualifiedNetworksServiceProxy) RemoveNetworkAvailabilityProvider( ctx context.Context, slotId int32, ) error
func (*QualifiedNetworksServiceProxy) ReportEmergencyDataNetworkPreferredTransportChanged ¶
func (*QualifiedNetworksServiceProxy) ReportThrottleStatusChanged ¶
func (p *QualifiedNetworksServiceProxy) ReportThrottleStatusChanged( ctx context.Context, slotId int32, statuses []ThrottleStatus, ) error
type QualifiedNetworksServiceStub ¶
type QualifiedNetworksServiceStub struct {
Impl IQualifiedNetworksService
Transport binder.VersionAwareTransport
}
QualifiedNetworksServiceStub dispatches incoming binder transactions to a typed IQualifiedNetworksService implementation.
func (*QualifiedNetworksServiceStub) Descriptor ¶
func (s *QualifiedNetworksServiceStub) Descriptor() string
func (*QualifiedNetworksServiceStub) OnTransaction ¶
func (s *QualifiedNetworksServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type RouteSelectionDescriptor ¶
func (*RouteSelectionDescriptor) MarshalParcel ¶
func (s *RouteSelectionDescriptor) MarshalParcel( p *parcel.Parcel, ) error
func (*RouteSelectionDescriptor) UnmarshalParcel ¶
func (s *RouteSelectionDescriptor) UnmarshalParcel( p *parcel.Parcel, ) error
type ThrottleStatus ¶
type ThrottleStatus struct {
SlotIndex int32
TransportType int32
ApnType int32
ThrottleExpiryTimeMillis int64
RetryType int32
ThrottleType int32
}
func (*ThrottleStatus) MarshalParcel ¶
func (s *ThrottleStatus) MarshalParcel( p *parcel.Parcel, ) error
func (*ThrottleStatus) UnmarshalParcel ¶
func (s *ThrottleStatus) UnmarshalParcel( p *parcel.Parcel, ) error
type TrafficDescriptor ¶
type TrafficDescriptor struct {
Dnn string
}
func (*TrafficDescriptor) MarshalParcel ¶
func (s *TrafficDescriptor) MarshalParcel( p *parcel.Parcel, ) error
func (*TrafficDescriptor) UnmarshalParcel ¶
func (s *TrafficDescriptor) UnmarshalParcel( p *parcel.Parcel, ) error
Source Files
¶
- apnsetting.go
- datacallresponse.go
- dataprofile.go
- epsbearerqossessionattributes.go
- idataservice.go
- idataservicecallback.go
- iqualifiednetworksservice.go
- iqualifiednetworksservicecallback.go
- networksliceinfo.go
- networkslicingconfig.go
- nrqossessionattributes.go
- routeselectiondescriptor.go
- throttlestatus.go
- trafficdescriptor.go
- ursprule.go