Documentation
¶
Index ¶
- Constants
- type AugmentedAutofillManagerClientProxy
- func (p *AugmentedAutofillManagerClientProxy) AsBinder() binder.IBinder
- func (p *AugmentedAutofillManagerClientProxy) Autofill(ctx context.Context, sessionId int32, ids []AutofillId, values []AutofillValue, ...) error
- func (p *AugmentedAutofillManagerClientProxy) GetViewCoordinates(ctx context.Context, id AutofillId) (graphics.Rect, error)
- func (p *AugmentedAutofillManagerClientProxy) GetViewNodeParcelable(ctx context.Context, id AutofillId) (assist.AssistStructureViewNodeParcelable, error)
- func (p *AugmentedAutofillManagerClientProxy) RequestAutofill(ctx context.Context, sessionId int32, id AutofillId) (bool, error)
- func (p *AugmentedAutofillManagerClientProxy) RequestHideFillUi(ctx context.Context, sessionId int32, id AutofillId) error
- func (p *AugmentedAutofillManagerClientProxy) RequestShowFillUi(ctx context.Context, sessionId int32, id AutofillId, width int32, height int32, ...) error
- type AugmentedAutofillManagerClientStub
- type AutoFillManagerClientProxy
- func (p *AutoFillManagerClientProxy) AsBinder() binder.IBinder
- func (p *AutoFillManagerClientProxy) Authenticate(ctx context.Context, sessionId int32, authenticationId int32, ...) error
- func (p *AutoFillManagerClientProxy) Autofill(ctx context.Context, sessionId int32, ids []AutofillId, values []AutofillValue, ...) error
- func (p *AutoFillManagerClientProxy) AutofillContent(ctx context.Context, sessionId int32, id AutofillId, ...) error
- func (p *AutoFillManagerClientProxy) DispatchUnhandledKey(ctx context.Context, sessionId int32, id AutofillId, keyEvent view.KeyEvent) error
- func (p *AutoFillManagerClientProxy) GetAugmentedAutofillClient(ctx context.Context, result os.IResultReceiver) error
- func (p *AutoFillManagerClientProxy) NotifyDisableAutofill(ctx context.Context, disableDuration int64, ...) error
- func (p *AutoFillManagerClientProxy) NotifyFillDialogTriggerIds(ctx context.Context, ids []AutofillId) error
- func (p *AutoFillManagerClientProxy) NotifyFillUiHidden(ctx context.Context, sessionId int32, id AutofillId) error
- func (p *AutoFillManagerClientProxy) NotifyFillUiShown(ctx context.Context, sessionId int32, id AutofillId) error
- func (p *AutoFillManagerClientProxy) NotifyNoFillUi(ctx context.Context, sessionId int32, id AutofillId, ...) error
- func (p *AutoFillManagerClientProxy) OnGetCredentialException(ctx context.Context, sessionId int32, id AutofillId, errorType string, ...) error
- func (p *AutoFillManagerClientProxy) OnGetCredentialResponse(ctx context.Context, sessionId int32, id AutofillId, ...) error
- func (p *AutoFillManagerClientProxy) RequestHideFillUi(ctx context.Context, sessionId int32, id AutofillId) error
- func (p *AutoFillManagerClientProxy) RequestHideFillUiWhenDestroyed(ctx context.Context, sessionId int32, id AutofillId) error
- func (p *AutoFillManagerClientProxy) RequestShowFillUi(ctx context.Context, sessionId int32, id AutofillId, width int32, height int32, ...) error
- func (p *AutoFillManagerClientProxy) RequestShowSoftInput(ctx context.Context, id AutofillId) error
- func (p *AutoFillManagerClientProxy) SetSaveUiState(ctx context.Context, sessionId int32, shown bool) error
- func (p *AutoFillManagerClientProxy) SetSessionFinished(ctx context.Context, newState int32, autofillableIds []AutofillId) error
- func (p *AutoFillManagerClientProxy) SetState(ctx context.Context, flags int32) error
- func (p *AutoFillManagerClientProxy) SetTrackedViews(ctx context.Context, sessionId int32, savableIds []AutofillId, ...) error
- func (p *AutoFillManagerClientProxy) StartIntentSender(ctx context.Context, intentSender androidContent.IntentSender, ...) error
- type AutoFillManagerClientStub
- type AutoFillManagerProxy
- func (p *AutoFillManagerProxy) AddClient(ctx context.Context, client IAutoFillManagerClient, ...) error
- func (p *AutoFillManagerProxy) AsBinder() binder.IBinder
- func (p *AutoFillManagerProxy) CancelSession(ctx context.Context, sessionId int32) error
- func (p *AutoFillManagerProxy) DisableOwnedAutofillServices(ctx context.Context) error
- func (p *AutoFillManagerProxy) FinishSession(ctx context.Context, sessionId int32, commitReason int32) error
- func (p *AutoFillManagerProxy) GetAutofillServiceComponentName(ctx context.Context, result os.IResultReceiver) error
- func (p *AutoFillManagerProxy) GetAvailableFieldClassificationAlgorithms(ctx context.Context, result os.IResultReceiver) error
- func (p *AutoFillManagerProxy) GetDefaultFieldClassificationAlgorithm(ctx context.Context, result os.IResultReceiver) error
- func (p *AutoFillManagerProxy) GetFillEventHistory(ctx context.Context, result os.IResultReceiver) error
- func (p *AutoFillManagerProxy) GetUserData(ctx context.Context, result os.IResultReceiver) error
- func (p *AutoFillManagerProxy) GetUserDataId(ctx context.Context, result os.IResultReceiver) error
- func (p *AutoFillManagerProxy) IsFieldClassificationEnabled(ctx context.Context, result os.IResultReceiver) error
- func (p *AutoFillManagerProxy) IsServiceEnabled(ctx context.Context, packageName string, result os.IResultReceiver) error
- func (p *AutoFillManagerProxy) IsServiceSupported(ctx context.Context, result os.IResultReceiver) error
- func (p *AutoFillManagerProxy) OnPendingSaveUi(ctx context.Context, operation int32, token binder.IBinder) error
- func (p *AutoFillManagerProxy) RemoveClient(ctx context.Context, client IAutoFillManagerClient) error
- func (p *AutoFillManagerProxy) RestoreSession(ctx context.Context, sessionId int32, activityToken binder.IBinder, ...) error
- func (p *AutoFillManagerProxy) SetAugmentedAutofillWhitelist(ctx context.Context, packages []string, activities []content.ComponentName, ...) error
- func (p *AutoFillManagerProxy) SetAuthenticationResult(ctx context.Context, data androidOs.Bundle, sessionId int32, ...) error
- func (p *AutoFillManagerProxy) SetAutofillFailure(ctx context.Context, sessionId int32, ids []AutofillId) error
- func (p *AutoFillManagerProxy) SetHasCallback(ctx context.Context, sessionId int32, hasIt bool) error
- func (p *AutoFillManagerProxy) SetUserData(ctx context.Context, userData serviceAutofill.UserData) error
- func (p *AutoFillManagerProxy) StartSession(ctx context.Context, activityToken binder.IBinder, appCallback binder.IBinder, ...) error
- func (p *AutoFillManagerProxy) UpdateSession(ctx context.Context, sessionId int32, id AutofillId, bounds graphics.Rect, ...) error
- type AutoFillManagerStub
- type AutofillId
- type AutofillValue
- type AutofillWindowPresenterProxy
- type AutofillWindowPresenterStub
- type IAugmentedAutofillManagerClient
- type IAugmentedAutofillManagerClientServer
- type IAutoFillManager
- type IAutoFillManagerClient
- type IAutoFillManagerClientServer
- type IAutoFillManagerServer
- type IAutofillWindowPresenter
- type IAutofillWindowPresenterServer
Constants ¶
const ( TransactionIAugmentedAutofillManagerClientGetViewCoordinates = binder.FirstCallTransaction + 0 TransactionIAugmentedAutofillManagerClientGetViewNodeParcelable = binder.FirstCallTransaction + 1 TransactionIAugmentedAutofillManagerClientAutofill = binder.FirstCallTransaction + 2 TransactionIAugmentedAutofillManagerClientRequestShowFillUi = binder.FirstCallTransaction + 3 TransactionIAugmentedAutofillManagerClientRequestHideFillUi = binder.FirstCallTransaction + 4 TransactionIAugmentedAutofillManagerClientRequestAutofill = binder.FirstCallTransaction + 5 )
const ( MethodIAugmentedAutofillManagerClientGetViewCoordinates = "getViewCoordinates" MethodIAugmentedAutofillManagerClientGetViewNodeParcelable = "getViewNodeParcelable" MethodIAugmentedAutofillManagerClientAutofill = "autofill" MethodIAugmentedAutofillManagerClientRequestShowFillUi = "requestShowFillUi" MethodIAugmentedAutofillManagerClientRequestHideFillUi = "requestHideFillUi" MethodIAugmentedAutofillManagerClientRequestAutofill = "requestAutofill" )
const ( TransactionIAutoFillManagerAddClient = binder.FirstCallTransaction + 0 TransactionIAutoFillManagerRemoveClient = binder.FirstCallTransaction + 1 TransactionIAutoFillManagerStartSession = binder.FirstCallTransaction + 2 TransactionIAutoFillManagerGetFillEventHistory = binder.FirstCallTransaction + 3 TransactionIAutoFillManagerRestoreSession = binder.FirstCallTransaction + 4 TransactionIAutoFillManagerUpdateSession = binder.FirstCallTransaction + 5 TransactionIAutoFillManagerSetAutofillFailure = binder.FirstCallTransaction + 6 TransactionIAutoFillManagerFinishSession = binder.FirstCallTransaction + 7 TransactionIAutoFillManagerCancelSession = binder.FirstCallTransaction + 8 TransactionIAutoFillManagerSetAuthenticationResult = binder.FirstCallTransaction + 9 TransactionIAutoFillManagerSetHasCallback = binder.FirstCallTransaction + 10 TransactionIAutoFillManagerDisableOwnedAutofillServices = binder.FirstCallTransaction + 11 TransactionIAutoFillManagerIsServiceSupported = binder.FirstCallTransaction + 12 TransactionIAutoFillManagerIsServiceEnabled = binder.FirstCallTransaction + 13 TransactionIAutoFillManagerOnPendingSaveUi = binder.FirstCallTransaction + 14 TransactionIAutoFillManagerGetUserData = binder.FirstCallTransaction + 15 TransactionIAutoFillManagerGetUserDataId = binder.FirstCallTransaction + 16 TransactionIAutoFillManagerSetUserData = binder.FirstCallTransaction + 17 TransactionIAutoFillManagerIsFieldClassificationEnabled = binder.FirstCallTransaction + 18 TransactionIAutoFillManagerGetAutofillServiceComponentName = binder.FirstCallTransaction + 19 TransactionIAutoFillManagerGetAvailableFieldClassificationAlgorithms = binder.FirstCallTransaction + 20 TransactionIAutoFillManagerGetDefaultFieldClassificationAlgorithm = binder.FirstCallTransaction + 21 TransactionIAutoFillManagerSetAugmentedAutofillWhitelist = binder.FirstCallTransaction + 22 )
const ( MethodIAutoFillManagerAddClient = "addClient" MethodIAutoFillManagerRemoveClient = "removeClient" MethodIAutoFillManagerStartSession = "startSession" MethodIAutoFillManagerGetFillEventHistory = "getFillEventHistory" MethodIAutoFillManagerRestoreSession = "restoreSession" MethodIAutoFillManagerUpdateSession = "updateSession" MethodIAutoFillManagerSetAutofillFailure = "setAutofillFailure" MethodIAutoFillManagerFinishSession = "finishSession" MethodIAutoFillManagerCancelSession = "cancelSession" MethodIAutoFillManagerSetAuthenticationResult = "setAuthenticationResult" MethodIAutoFillManagerSetHasCallback = "setHasCallback" MethodIAutoFillManagerDisableOwnedAutofillServices = "disableOwnedAutofillServices" MethodIAutoFillManagerIsServiceSupported = "isServiceSupported" MethodIAutoFillManagerIsServiceEnabled = "isServiceEnabled" MethodIAutoFillManagerOnPendingSaveUi = "onPendingSaveUi" MethodIAutoFillManagerGetUserData = "getUserData" MethodIAutoFillManagerGetUserDataId = "getUserDataId" MethodIAutoFillManagerSetUserData = "setUserData" MethodIAutoFillManagerIsFieldClassificationEnabled = "isFieldClassificationEnabled" MethodIAutoFillManagerGetAutofillServiceComponentName = "getAutofillServiceComponentName" MethodIAutoFillManagerGetAvailableFieldClassificationAlgorithms = "getAvailableFieldClassificationAlgorithms" MethodIAutoFillManagerGetDefaultFieldClassificationAlgorithm = "getDefaultFieldClassificationAlgorithm" MethodIAutoFillManagerSetAugmentedAutofillWhitelist = "setAugmentedAutofillWhitelist" )
const ( TransactionIAutoFillManagerClientSetState = binder.FirstCallTransaction + 0 TransactionIAutoFillManagerClientAutofill = binder.FirstCallTransaction + 1 TransactionIAutoFillManagerClientOnGetCredentialResponse = binder.FirstCallTransaction + 2 TransactionIAutoFillManagerClientOnGetCredentialException = binder.FirstCallTransaction + 3 TransactionIAutoFillManagerClientAutofillContent = binder.FirstCallTransaction + 4 TransactionIAutoFillManagerClientAuthenticate = binder.FirstCallTransaction + 5 TransactionIAutoFillManagerClientSetTrackedViews = binder.FirstCallTransaction + 6 TransactionIAutoFillManagerClientRequestShowFillUi = binder.FirstCallTransaction + 7 TransactionIAutoFillManagerClientRequestHideFillUi = binder.FirstCallTransaction + 8 TransactionIAutoFillManagerClientRequestHideFillUiWhenDestroyed = binder.FirstCallTransaction + 9 TransactionIAutoFillManagerClientNotifyNoFillUi = binder.FirstCallTransaction + 10 TransactionIAutoFillManagerClientNotifyFillUiShown = binder.FirstCallTransaction + 11 TransactionIAutoFillManagerClientNotifyFillUiHidden = binder.FirstCallTransaction + 12 TransactionIAutoFillManagerClientDispatchUnhandledKey = binder.FirstCallTransaction + 13 TransactionIAutoFillManagerClientStartIntentSender = binder.FirstCallTransaction + 14 TransactionIAutoFillManagerClientSetSaveUiState = binder.FirstCallTransaction + 15 TransactionIAutoFillManagerClientSetSessionFinished = binder.FirstCallTransaction + 16 TransactionIAutoFillManagerClientGetAugmentedAutofillClient = binder.FirstCallTransaction + 17 TransactionIAutoFillManagerClientNotifyDisableAutofill = binder.FirstCallTransaction + 18 TransactionIAutoFillManagerClientRequestShowSoftInput = binder.FirstCallTransaction + 19 TransactionIAutoFillManagerClientNotifyFillDialogTriggerIds = binder.FirstCallTransaction + 20 )
const ( MethodIAutoFillManagerClientSetState = "setState" MethodIAutoFillManagerClientAutofill = "autofill" MethodIAutoFillManagerClientOnGetCredentialResponse = "onGetCredentialResponse" MethodIAutoFillManagerClientOnGetCredentialException = "onGetCredentialException" MethodIAutoFillManagerClientAutofillContent = "autofillContent" MethodIAutoFillManagerClientAuthenticate = "authenticate" MethodIAutoFillManagerClientSetTrackedViews = "setTrackedViews" MethodIAutoFillManagerClientRequestShowFillUi = "requestShowFillUi" MethodIAutoFillManagerClientRequestHideFillUi = "requestHideFillUi" MethodIAutoFillManagerClientRequestHideFillUiWhenDestroyed = "requestHideFillUiWhenDestroyed" MethodIAutoFillManagerClientNotifyNoFillUi = "notifyNoFillUi" MethodIAutoFillManagerClientNotifyFillUiShown = "notifyFillUiShown" MethodIAutoFillManagerClientNotifyFillUiHidden = "notifyFillUiHidden" MethodIAutoFillManagerClientDispatchUnhandledKey = "dispatchUnhandledKey" MethodIAutoFillManagerClientStartIntentSender = "startIntentSender" MethodIAutoFillManagerClientSetSaveUiState = "setSaveUiState" MethodIAutoFillManagerClientSetSessionFinished = "setSessionFinished" MethodIAutoFillManagerClientGetAugmentedAutofillClient = "getAugmentedAutofillClient" MethodIAutoFillManagerClientNotifyDisableAutofill = "notifyDisableAutofill" MethodIAutoFillManagerClientRequestShowSoftInput = "requestShowSoftInput" MethodIAutoFillManagerClientNotifyFillDialogTriggerIds = "notifyFillDialogTriggerIds" )
const ( TransactionIAutofillWindowPresenterShow = binder.FirstCallTransaction + 0 TransactionIAutofillWindowPresenterHide = binder.FirstCallTransaction + 1 )
const ( MethodIAutofillWindowPresenterShow = "show" MethodIAutofillWindowPresenterHide = "hide" )
const DescriptorIAugmentedAutofillManagerClient = "android.view.autofill.IAugmentedAutofillManagerClient"
const DescriptorIAutoFillManager = "android.view.autofill.IAutoFillManager"
const DescriptorIAutoFillManagerClient = "android.view.autofill.IAutoFillManagerClient"
const DescriptorIAutofillWindowPresenter = "android.view.autofill.IAutofillWindowPresenter"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AugmentedAutofillManagerClientProxy ¶
func NewAugmentedAutofillManagerClientProxy ¶
func NewAugmentedAutofillManagerClientProxy( remote binder.IBinder, ) *AugmentedAutofillManagerClientProxy
func (*AugmentedAutofillManagerClientProxy) AsBinder ¶
func (p *AugmentedAutofillManagerClientProxy) AsBinder() binder.IBinder
func (*AugmentedAutofillManagerClientProxy) Autofill ¶
func (p *AugmentedAutofillManagerClientProxy) Autofill( ctx context.Context, sessionId int32, ids []AutofillId, values []AutofillValue, hideHighlight bool, ) error
func (*AugmentedAutofillManagerClientProxy) GetViewCoordinates ¶
func (p *AugmentedAutofillManagerClientProxy) GetViewCoordinates( ctx context.Context, id AutofillId, ) (graphics.Rect, error)
func (*AugmentedAutofillManagerClientProxy) GetViewNodeParcelable ¶
func (p *AugmentedAutofillManagerClientProxy) GetViewNodeParcelable( ctx context.Context, id AutofillId, ) (assist.AssistStructureViewNodeParcelable, error)
func (*AugmentedAutofillManagerClientProxy) RequestAutofill ¶
func (p *AugmentedAutofillManagerClientProxy) RequestAutofill( ctx context.Context, sessionId int32, id AutofillId, ) (bool, error)
func (*AugmentedAutofillManagerClientProxy) RequestHideFillUi ¶
func (p *AugmentedAutofillManagerClientProxy) RequestHideFillUi( ctx context.Context, sessionId int32, id AutofillId, ) error
func (*AugmentedAutofillManagerClientProxy) RequestShowFillUi ¶
func (p *AugmentedAutofillManagerClientProxy) RequestShowFillUi( ctx context.Context, sessionId int32, id AutofillId, width int32, height int32, anchorBounds graphics.Rect, presenter IAutofillWindowPresenter, ) error
type AugmentedAutofillManagerClientStub ¶
type AugmentedAutofillManagerClientStub struct {
Impl IAugmentedAutofillManagerClient
Transport binder.VersionAwareTransport
}
AugmentedAutofillManagerClientStub dispatches incoming binder transactions to a typed IAugmentedAutofillManagerClient implementation.
func (*AugmentedAutofillManagerClientStub) Descriptor ¶
func (s *AugmentedAutofillManagerClientStub) Descriptor() string
func (*AugmentedAutofillManagerClientStub) OnTransaction ¶
func (s *AugmentedAutofillManagerClientStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type AutoFillManagerClientProxy ¶
func NewAutoFillManagerClientProxy ¶
func NewAutoFillManagerClientProxy( remote binder.IBinder, ) *AutoFillManagerClientProxy
func (*AutoFillManagerClientProxy) AsBinder ¶
func (p *AutoFillManagerClientProxy) AsBinder() binder.IBinder
func (*AutoFillManagerClientProxy) Authenticate ¶
func (p *AutoFillManagerClientProxy) Authenticate( ctx context.Context, sessionId int32, authenticationId int32, intent androidContent.IntentSender, fillInIntent androidContent.Intent, authenticateInline bool, ) error
func (*AutoFillManagerClientProxy) Autofill ¶
func (p *AutoFillManagerClientProxy) Autofill( ctx context.Context, sessionId int32, ids []AutofillId, values []AutofillValue, hideHighlight bool, ) error
func (*AutoFillManagerClientProxy) AutofillContent ¶
func (p *AutoFillManagerClientProxy) AutofillContent( ctx context.Context, sessionId int32, id AutofillId, content androidContent.ClipData, ) error
func (*AutoFillManagerClientProxy) DispatchUnhandledKey ¶
func (p *AutoFillManagerClientProxy) DispatchUnhandledKey( ctx context.Context, sessionId int32, id AutofillId, keyEvent view.KeyEvent, ) error
func (*AutoFillManagerClientProxy) GetAugmentedAutofillClient ¶
func (p *AutoFillManagerClientProxy) GetAugmentedAutofillClient( ctx context.Context, result os.IResultReceiver, ) error
func (*AutoFillManagerClientProxy) NotifyDisableAutofill ¶
func (p *AutoFillManagerClientProxy) NotifyDisableAutofill( ctx context.Context, disableDuration int64, componentName androidContent.ComponentName, ) error
func (*AutoFillManagerClientProxy) NotifyFillDialogTriggerIds ¶
func (p *AutoFillManagerClientProxy) NotifyFillDialogTriggerIds( ctx context.Context, ids []AutofillId, ) error
func (*AutoFillManagerClientProxy) NotifyFillUiHidden ¶
func (p *AutoFillManagerClientProxy) NotifyFillUiHidden( ctx context.Context, sessionId int32, id AutofillId, ) error
func (*AutoFillManagerClientProxy) NotifyFillUiShown ¶
func (p *AutoFillManagerClientProxy) NotifyFillUiShown( ctx context.Context, sessionId int32, id AutofillId, ) error
func (*AutoFillManagerClientProxy) NotifyNoFillUi ¶
func (p *AutoFillManagerClientProxy) NotifyNoFillUi( ctx context.Context, sessionId int32, id AutofillId, sessionFinishedState int32, ) error
func (*AutoFillManagerClientProxy) OnGetCredentialException ¶
func (p *AutoFillManagerClientProxy) OnGetCredentialException( ctx context.Context, sessionId int32, id AutofillId, errorType string, errorMsg string, ) error
func (*AutoFillManagerClientProxy) OnGetCredentialResponse ¶
func (p *AutoFillManagerClientProxy) OnGetCredentialResponse( ctx context.Context, sessionId int32, id AutofillId, response credentials.GetCredentialResponse, ) error
func (*AutoFillManagerClientProxy) RequestHideFillUi ¶
func (p *AutoFillManagerClientProxy) RequestHideFillUi( ctx context.Context, sessionId int32, id AutofillId, ) error
func (*AutoFillManagerClientProxy) RequestHideFillUiWhenDestroyed ¶
func (p *AutoFillManagerClientProxy) RequestHideFillUiWhenDestroyed( ctx context.Context, sessionId int32, id AutofillId, ) error
func (*AutoFillManagerClientProxy) RequestShowFillUi ¶
func (p *AutoFillManagerClientProxy) RequestShowFillUi( ctx context.Context, sessionId int32, id AutofillId, width int32, height int32, anchorBounds graphics.Rect, presenter IAutofillWindowPresenter, ) error
func (*AutoFillManagerClientProxy) RequestShowSoftInput ¶
func (p *AutoFillManagerClientProxy) RequestShowSoftInput( ctx context.Context, id AutofillId, ) error
func (*AutoFillManagerClientProxy) SetSaveUiState ¶
func (*AutoFillManagerClientProxy) SetSessionFinished ¶
func (p *AutoFillManagerClientProxy) SetSessionFinished( ctx context.Context, newState int32, autofillableIds []AutofillId, ) error
func (*AutoFillManagerClientProxy) SetState ¶
func (p *AutoFillManagerClientProxy) SetState( ctx context.Context, flags int32, ) error
func (*AutoFillManagerClientProxy) SetTrackedViews ¶
func (p *AutoFillManagerClientProxy) SetTrackedViews( ctx context.Context, sessionId int32, savableIds []AutofillId, saveOnAllViewsInvisible bool, saveOnFinish bool, fillableIds []AutofillId, saveTriggerId AutofillId, ) error
func (*AutoFillManagerClientProxy) StartIntentSender ¶
func (p *AutoFillManagerClientProxy) StartIntentSender( ctx context.Context, intentSender androidContent.IntentSender, intent androidContent.Intent, ) error
type AutoFillManagerClientStub ¶
type AutoFillManagerClientStub struct {
Impl IAutoFillManagerClient
Transport binder.VersionAwareTransport
}
AutoFillManagerClientStub dispatches incoming binder transactions to a typed IAutoFillManagerClient implementation.
func (*AutoFillManagerClientStub) Descriptor ¶
func (s *AutoFillManagerClientStub) Descriptor() string
func (*AutoFillManagerClientStub) OnTransaction ¶
func (s *AutoFillManagerClientStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type AutoFillManagerProxy ¶
func GetAutoFillManager ¶
func GetAutoFillManager( ctx context.Context, sm *servicemanager.ServiceManager, ) (*AutoFillManagerProxy, error)
GetAutoFillManager retrieves the AutofillManagerService service and returns a typed proxy.
func NewAutoFillManagerProxy ¶
func NewAutoFillManagerProxy( remote binder.IBinder, ) *AutoFillManagerProxy
func (*AutoFillManagerProxy) AddClient ¶
func (p *AutoFillManagerProxy) AddClient( ctx context.Context, client IAutoFillManagerClient, componentName content.ComponentName, result os.IResultReceiver, ) error
func (*AutoFillManagerProxy) AsBinder ¶
func (p *AutoFillManagerProxy) AsBinder() binder.IBinder
func (*AutoFillManagerProxy) CancelSession ¶
func (p *AutoFillManagerProxy) CancelSession( ctx context.Context, sessionId int32, ) error
func (*AutoFillManagerProxy) DisableOwnedAutofillServices ¶
func (p *AutoFillManagerProxy) DisableOwnedAutofillServices( ctx context.Context, ) error
func (*AutoFillManagerProxy) FinishSession ¶
func (*AutoFillManagerProxy) GetAutofillServiceComponentName ¶
func (p *AutoFillManagerProxy) GetAutofillServiceComponentName( ctx context.Context, result os.IResultReceiver, ) error
func (*AutoFillManagerProxy) GetAvailableFieldClassificationAlgorithms ¶
func (p *AutoFillManagerProxy) GetAvailableFieldClassificationAlgorithms( ctx context.Context, result os.IResultReceiver, ) error
func (*AutoFillManagerProxy) GetDefaultFieldClassificationAlgorithm ¶
func (p *AutoFillManagerProxy) GetDefaultFieldClassificationAlgorithm( ctx context.Context, result os.IResultReceiver, ) error
func (*AutoFillManagerProxy) GetFillEventHistory ¶
func (p *AutoFillManagerProxy) GetFillEventHistory( ctx context.Context, result os.IResultReceiver, ) error
func (*AutoFillManagerProxy) GetUserData ¶
func (p *AutoFillManagerProxy) GetUserData( ctx context.Context, result os.IResultReceiver, ) error
func (*AutoFillManagerProxy) GetUserDataId ¶
func (p *AutoFillManagerProxy) GetUserDataId( ctx context.Context, result os.IResultReceiver, ) error
func (*AutoFillManagerProxy) IsFieldClassificationEnabled ¶
func (p *AutoFillManagerProxy) IsFieldClassificationEnabled( ctx context.Context, result os.IResultReceiver, ) error
func (*AutoFillManagerProxy) IsServiceEnabled ¶
func (p *AutoFillManagerProxy) IsServiceEnabled( ctx context.Context, packageName string, result os.IResultReceiver, ) error
func (*AutoFillManagerProxy) IsServiceSupported ¶
func (p *AutoFillManagerProxy) IsServiceSupported( ctx context.Context, result os.IResultReceiver, ) error
func (*AutoFillManagerProxy) OnPendingSaveUi ¶
func (*AutoFillManagerProxy) RemoveClient ¶
func (p *AutoFillManagerProxy) RemoveClient( ctx context.Context, client IAutoFillManagerClient, ) error
func (*AutoFillManagerProxy) RestoreSession ¶
func (*AutoFillManagerProxy) SetAugmentedAutofillWhitelist ¶
func (p *AutoFillManagerProxy) SetAugmentedAutofillWhitelist( ctx context.Context, packages []string, activities []content.ComponentName, result os.IResultReceiver, ) error
func (*AutoFillManagerProxy) SetAuthenticationResult ¶
func (*AutoFillManagerProxy) SetAutofillFailure ¶
func (p *AutoFillManagerProxy) SetAutofillFailure( ctx context.Context, sessionId int32, ids []AutofillId, ) error
func (*AutoFillManagerProxy) SetHasCallback ¶
func (*AutoFillManagerProxy) SetUserData ¶
func (p *AutoFillManagerProxy) SetUserData( ctx context.Context, userData serviceAutofill.UserData, ) error
func (*AutoFillManagerProxy) StartSession ¶
func (p *AutoFillManagerProxy) StartSession( ctx context.Context, activityToken binder.IBinder, appCallback binder.IBinder, autoFillId AutofillId, bounds graphics.Rect, value AutofillValue, hasCallback bool, flags int32, componentName content.ComponentName, compatMode bool, result os.IResultReceiver, ) error
func (*AutoFillManagerProxy) UpdateSession ¶
func (p *AutoFillManagerProxy) UpdateSession( ctx context.Context, sessionId int32, id AutofillId, bounds graphics.Rect, value AutofillValue, action int32, flags int32, ) error
type AutoFillManagerStub ¶
type AutoFillManagerStub struct {
Impl IAutoFillManager
Transport binder.VersionAwareTransport
}
AutoFillManagerStub dispatches incoming binder transactions to a typed IAutoFillManager implementation.
func (*AutoFillManagerStub) Descriptor ¶
func (s *AutoFillManagerStub) Descriptor() string
func (*AutoFillManagerStub) OnTransaction ¶
func (s *AutoFillManagerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type AutofillId ¶
func (*AutofillId) MarshalParcel ¶
func (s *AutofillId) MarshalParcel( p *parcel.Parcel, ) error
func (*AutofillId) UnmarshalParcel ¶
func (s *AutofillId) UnmarshalParcel( p *parcel.Parcel, ) error
type AutofillValue ¶
type AutofillValue struct {
Type int32
}
func (*AutofillValue) MarshalParcel ¶
func (s *AutofillValue) MarshalParcel( p *parcel.Parcel, ) error
func (*AutofillValue) UnmarshalParcel ¶
func (s *AutofillValue) UnmarshalParcel( p *parcel.Parcel, ) error
type AutofillWindowPresenterProxy ¶
func NewAutofillWindowPresenterProxy ¶
func NewAutofillWindowPresenterProxy( remote binder.IBinder, ) *AutofillWindowPresenterProxy
func (*AutofillWindowPresenterProxy) AsBinder ¶
func (p *AutofillWindowPresenterProxy) AsBinder() binder.IBinder
type AutofillWindowPresenterStub ¶
type AutofillWindowPresenterStub struct {
Impl IAutofillWindowPresenter
Transport binder.VersionAwareTransport
}
AutofillWindowPresenterStub dispatches incoming binder transactions to a typed IAutofillWindowPresenter implementation.
func (*AutofillWindowPresenterStub) Descriptor ¶
func (s *AutofillWindowPresenterStub) Descriptor() string
func (*AutofillWindowPresenterStub) OnTransaction ¶
func (s *AutofillWindowPresenterStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type IAugmentedAutofillManagerClient ¶
type IAugmentedAutofillManagerClient interface {
AsBinder() binder.IBinder
GetViewCoordinates(ctx context.Context, id AutofillId) (graphics.Rect, error)
GetViewNodeParcelable(ctx context.Context, id AutofillId) (assist.AssistStructureViewNodeParcelable, error)
Autofill(ctx context.Context, sessionId int32, ids []AutofillId, values []AutofillValue, hideHighlight bool) error
RequestShowFillUi(ctx context.Context, sessionId int32, id AutofillId, width int32, height int32, anchorBounds graphics.Rect, presenter IAutofillWindowPresenter) error
RequestHideFillUi(ctx context.Context, sessionId int32, id AutofillId) error
RequestAutofill(ctx context.Context, sessionId int32, id AutofillId) (bool, error)
}
func NewAugmentedAutofillManagerClientStub ¶
func NewAugmentedAutofillManagerClientStub( impl IAugmentedAutofillManagerClientServer, ) IAugmentedAutofillManagerClient
NewAugmentedAutofillManagerClientStub creates a server-side IAugmentedAutofillManagerClient wrapping the given server implementation. The returned value satisfies IAugmentedAutofillManagerClient and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IAugmentedAutofillManagerClientServer ¶
type IAugmentedAutofillManagerClientServer interface {
GetViewCoordinates(ctx context.Context, id AutofillId) (graphics.Rect, error)
GetViewNodeParcelable(ctx context.Context, id AutofillId) (assist.AssistStructureViewNodeParcelable, error)
Autofill(ctx context.Context, sessionId int32, ids []AutofillId, values []AutofillValue, hideHighlight bool) error
RequestShowFillUi(ctx context.Context, sessionId int32, id AutofillId, width int32, height int32, anchorBounds graphics.Rect, presenter IAutofillWindowPresenter) error
RequestHideFillUi(ctx context.Context, sessionId int32, id AutofillId) error
RequestAutofill(ctx context.Context, sessionId int32, id AutofillId) (bool, error)
}
IAugmentedAutofillManagerClientServer is the server-side interface that user implementations provide to NewAugmentedAutofillManagerClientStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IAutoFillManager ¶
type IAutoFillManager interface {
AsBinder() binder.IBinder
AddClient(ctx context.Context, client IAutoFillManagerClient, componentName content.ComponentName, result os.IResultReceiver) error
RemoveClient(ctx context.Context, client IAutoFillManagerClient) error
StartSession(ctx context.Context, activityToken binder.IBinder, appCallback binder.IBinder, autoFillId AutofillId, bounds graphics.Rect, value AutofillValue, hasCallback bool, flags int32, componentName content.ComponentName, compatMode bool, result os.IResultReceiver) error
GetFillEventHistory(ctx context.Context, result os.IResultReceiver) error
RestoreSession(ctx context.Context, sessionId int32, activityToken binder.IBinder, appCallback binder.IBinder, result os.IResultReceiver) error
UpdateSession(ctx context.Context, sessionId int32, id AutofillId, bounds graphics.Rect, value AutofillValue, action int32, flags int32) error
SetAutofillFailure(ctx context.Context, sessionId int32, ids []AutofillId) error
FinishSession(ctx context.Context, sessionId int32, commitReason int32) error
CancelSession(ctx context.Context, sessionId int32) error
SetAuthenticationResult(ctx context.Context, data androidOs.Bundle, sessionId int32, authenticationId int32) error
SetHasCallback(ctx context.Context, sessionId int32, hasIt bool) error
DisableOwnedAutofillServices(ctx context.Context) error
IsServiceSupported(ctx context.Context, result os.IResultReceiver) error
IsServiceEnabled(ctx context.Context, packageName string, result os.IResultReceiver) error
OnPendingSaveUi(ctx context.Context, operation int32, token binder.IBinder) error
GetUserData(ctx context.Context, result os.IResultReceiver) error
GetUserDataId(ctx context.Context, result os.IResultReceiver) error
SetUserData(ctx context.Context, userData serviceAutofill.UserData) error
IsFieldClassificationEnabled(ctx context.Context, result os.IResultReceiver) error
GetAutofillServiceComponentName(ctx context.Context, result os.IResultReceiver) error
GetAvailableFieldClassificationAlgorithms(ctx context.Context, result os.IResultReceiver) error
GetDefaultFieldClassificationAlgorithm(ctx context.Context, result os.IResultReceiver) error
SetAugmentedAutofillWhitelist(ctx context.Context, packages []string, activities []content.ComponentName, result os.IResultReceiver) error
}
func NewAutoFillManagerStub ¶
func NewAutoFillManagerStub( impl IAutoFillManagerServer, ) IAutoFillManager
NewAutoFillManagerStub creates a server-side IAutoFillManager wrapping the given server implementation. The returned value satisfies IAutoFillManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IAutoFillManagerClient ¶
type IAutoFillManagerClient interface {
AsBinder() binder.IBinder
SetState(ctx context.Context, flags int32) error
Autofill(ctx context.Context, sessionId int32, ids []AutofillId, values []AutofillValue, hideHighlight bool) error
OnGetCredentialResponse(ctx context.Context, sessionId int32, id AutofillId, response credentials.GetCredentialResponse) error
OnGetCredentialException(ctx context.Context, sessionId int32, id AutofillId, errorType string, errorMsg string) error
AutofillContent(ctx context.Context, sessionId int32, id AutofillId, content androidContent.ClipData) error
Authenticate(ctx context.Context, sessionId int32, authenticationId int32, intent androidContent.IntentSender, fillInIntent androidContent.Intent, authenticateInline bool) error
SetTrackedViews(ctx context.Context, sessionId int32, savableIds []AutofillId, saveOnAllViewsInvisible bool, saveOnFinish bool, fillableIds []AutofillId, saveTriggerId AutofillId) error
RequestShowFillUi(ctx context.Context, sessionId int32, id AutofillId, width int32, height int32, anchorBounds graphics.Rect, presenter IAutofillWindowPresenter) error
RequestHideFillUi(ctx context.Context, sessionId int32, id AutofillId) error
RequestHideFillUiWhenDestroyed(ctx context.Context, sessionId int32, id AutofillId) error
NotifyNoFillUi(ctx context.Context, sessionId int32, id AutofillId, sessionFinishedState int32) error
NotifyFillUiShown(ctx context.Context, sessionId int32, id AutofillId) error
NotifyFillUiHidden(ctx context.Context, sessionId int32, id AutofillId) error
DispatchUnhandledKey(ctx context.Context, sessionId int32, id AutofillId, keyEvent view.KeyEvent) error
StartIntentSender(ctx context.Context, intentSender androidContent.IntentSender, intent androidContent.Intent) error
SetSaveUiState(ctx context.Context, sessionId int32, shown bool) error
SetSessionFinished(ctx context.Context, newState int32, autofillableIds []AutofillId) error
GetAugmentedAutofillClient(ctx context.Context, result os.IResultReceiver) error
NotifyDisableAutofill(ctx context.Context, disableDuration int64, componentName androidContent.ComponentName) error
RequestShowSoftInput(ctx context.Context, id AutofillId) error
NotifyFillDialogTriggerIds(ctx context.Context, ids []AutofillId) error
}
func NewAutoFillManagerClientStub ¶
func NewAutoFillManagerClientStub( impl IAutoFillManagerClientServer, ) IAutoFillManagerClient
NewAutoFillManagerClientStub creates a server-side IAutoFillManagerClient wrapping the given server implementation. The returned value satisfies IAutoFillManagerClient and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IAutoFillManagerClientServer ¶
type IAutoFillManagerClientServer interface {
SetState(ctx context.Context, flags int32) error
Autofill(ctx context.Context, sessionId int32, ids []AutofillId, values []AutofillValue, hideHighlight bool) error
OnGetCredentialResponse(ctx context.Context, sessionId int32, id AutofillId, response credentials.GetCredentialResponse) error
OnGetCredentialException(ctx context.Context, sessionId int32, id AutofillId, errorType string, errorMsg string) error
AutofillContent(ctx context.Context, sessionId int32, id AutofillId, content androidContent.ClipData) error
Authenticate(ctx context.Context, sessionId int32, authenticationId int32, intent androidContent.IntentSender, fillInIntent androidContent.Intent, authenticateInline bool) error
SetTrackedViews(ctx context.Context, sessionId int32, savableIds []AutofillId, saveOnAllViewsInvisible bool, saveOnFinish bool, fillableIds []AutofillId, saveTriggerId AutofillId) error
RequestShowFillUi(ctx context.Context, sessionId int32, id AutofillId, width int32, height int32, anchorBounds graphics.Rect, presenter IAutofillWindowPresenter) error
RequestHideFillUi(ctx context.Context, sessionId int32, id AutofillId) error
RequestHideFillUiWhenDestroyed(ctx context.Context, sessionId int32, id AutofillId) error
NotifyNoFillUi(ctx context.Context, sessionId int32, id AutofillId, sessionFinishedState int32) error
NotifyFillUiShown(ctx context.Context, sessionId int32, id AutofillId) error
NotifyFillUiHidden(ctx context.Context, sessionId int32, id AutofillId) error
DispatchUnhandledKey(ctx context.Context, sessionId int32, id AutofillId, keyEvent view.KeyEvent) error
StartIntentSender(ctx context.Context, intentSender androidContent.IntentSender, intent androidContent.Intent) error
SetSaveUiState(ctx context.Context, sessionId int32, shown bool) error
SetSessionFinished(ctx context.Context, newState int32, autofillableIds []AutofillId) error
GetAugmentedAutofillClient(ctx context.Context, result os.IResultReceiver) error
NotifyDisableAutofill(ctx context.Context, disableDuration int64, componentName androidContent.ComponentName) error
RequestShowSoftInput(ctx context.Context, id AutofillId) error
NotifyFillDialogTriggerIds(ctx context.Context, ids []AutofillId) error
}
IAutoFillManagerClientServer is the server-side interface that user implementations provide to NewAutoFillManagerClientStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IAutoFillManagerServer ¶
type IAutoFillManagerServer interface {
AddClient(ctx context.Context, client IAutoFillManagerClient, componentName content.ComponentName, result os.IResultReceiver) error
RemoveClient(ctx context.Context, client IAutoFillManagerClient) error
StartSession(ctx context.Context, activityToken binder.IBinder, appCallback binder.IBinder, autoFillId AutofillId, bounds graphics.Rect, value AutofillValue, hasCallback bool, flags int32, componentName content.ComponentName, compatMode bool, result os.IResultReceiver) error
GetFillEventHistory(ctx context.Context, result os.IResultReceiver) error
RestoreSession(ctx context.Context, sessionId int32, activityToken binder.IBinder, appCallback binder.IBinder, result os.IResultReceiver) error
UpdateSession(ctx context.Context, sessionId int32, id AutofillId, bounds graphics.Rect, value AutofillValue, action int32, flags int32) error
SetAutofillFailure(ctx context.Context, sessionId int32, ids []AutofillId) error
FinishSession(ctx context.Context, sessionId int32, commitReason int32) error
CancelSession(ctx context.Context, sessionId int32) error
SetAuthenticationResult(ctx context.Context, data androidOs.Bundle, sessionId int32, authenticationId int32) error
SetHasCallback(ctx context.Context, sessionId int32, hasIt bool) error
DisableOwnedAutofillServices(ctx context.Context) error
IsServiceSupported(ctx context.Context, result os.IResultReceiver) error
IsServiceEnabled(ctx context.Context, packageName string, result os.IResultReceiver) error
OnPendingSaveUi(ctx context.Context, operation int32, token binder.IBinder) error
GetUserData(ctx context.Context, result os.IResultReceiver) error
GetUserDataId(ctx context.Context, result os.IResultReceiver) error
SetUserData(ctx context.Context, userData serviceAutofill.UserData) error
IsFieldClassificationEnabled(ctx context.Context, result os.IResultReceiver) error
GetAutofillServiceComponentName(ctx context.Context, result os.IResultReceiver) error
GetAvailableFieldClassificationAlgorithms(ctx context.Context, result os.IResultReceiver) error
GetDefaultFieldClassificationAlgorithm(ctx context.Context, result os.IResultReceiver) error
SetAugmentedAutofillWhitelist(ctx context.Context, packages []string, activities []content.ComponentName, result os.IResultReceiver) error
}
IAutoFillManagerServer is the server-side interface that user implementations provide to NewAutoFillManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IAutofillWindowPresenter ¶
type IAutofillWindowPresenter interface {
AsBinder() binder.IBinder
Show(ctx context.Context, p_ view.WindowManagerLayoutParams, transitionEpicenter graphics.Rect, fitsSystemWindows bool, layoutDirection int32) error
Hide(ctx context.Context, transitionEpicenter graphics.Rect) error
}
func NewAutofillWindowPresenterStub ¶
func NewAutofillWindowPresenterStub( impl IAutofillWindowPresenterServer, ) IAutofillWindowPresenter
NewAutofillWindowPresenterStub creates a server-side IAutofillWindowPresenter wrapping the given server implementation. The returned value satisfies IAutofillWindowPresenter and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IAutofillWindowPresenterServer ¶
type IAutofillWindowPresenterServer interface {
Show(ctx context.Context, p_ view.WindowManagerLayoutParams, transitionEpicenter graphics.Rect, fitsSystemWindows bool, layoutDirection int32) error
Hide(ctx context.Context, transitionEpicenter graphics.Rect) error
}
IAutofillWindowPresenterServer is the server-side interface that user implementations provide to NewAutofillWindowPresenterStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).