contentcapture

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIContentCaptureManagerStartSession                          = binder.FirstCallTransaction + 0
	TransactionIContentCaptureManagerFinishSession                         = binder.FirstCallTransaction + 1
	TransactionIContentCaptureManagerGetServiceComponentName               = binder.FirstCallTransaction + 2
	TransactionIContentCaptureManagerRemoveData                            = binder.FirstCallTransaction + 3
	TransactionIContentCaptureManagerShareData                             = binder.FirstCallTransaction + 4
	TransactionIContentCaptureManagerIsContentCaptureFeatureEnabled        = binder.FirstCallTransaction + 5
	TransactionIContentCaptureManagerGetServiceSettingsActivity            = binder.FirstCallTransaction + 6
	TransactionIContentCaptureManagerGetContentCaptureConditions           = binder.FirstCallTransaction + 7
	TransactionIContentCaptureManagerResetTemporaryService                 = binder.FirstCallTransaction + 8
	TransactionIContentCaptureManagerSetTemporaryService                   = binder.FirstCallTransaction + 9
	TransactionIContentCaptureManagerSetDefaultServiceEnabled              = binder.FirstCallTransaction + 10
	TransactionIContentCaptureManagerRegisterContentCaptureOptionsCallback = binder.FirstCallTransaction + 11
	TransactionIContentCaptureManagerOnLoginDetected                       = binder.FirstCallTransaction + 12
)
const (
	MethodIContentCaptureManagerStartSession                          = "startSession"
	MethodIContentCaptureManagerFinishSession                         = "finishSession"
	MethodIContentCaptureManagerGetServiceComponentName               = "getServiceComponentName"
	MethodIContentCaptureManagerRemoveData                            = "removeData"
	MethodIContentCaptureManagerShareData                             = "shareData"
	MethodIContentCaptureManagerIsContentCaptureFeatureEnabled        = "isContentCaptureFeatureEnabled"
	MethodIContentCaptureManagerGetServiceSettingsActivity            = "getServiceSettingsActivity"
	MethodIContentCaptureManagerGetContentCaptureConditions           = "getContentCaptureConditions"
	MethodIContentCaptureManagerResetTemporaryService                 = "resetTemporaryService"
	MethodIContentCaptureManagerSetTemporaryService                   = "setTemporaryService"
	MethodIContentCaptureManagerSetDefaultServiceEnabled              = "setDefaultServiceEnabled"
	MethodIContentCaptureManagerRegisterContentCaptureOptionsCallback = "registerContentCaptureOptionsCallback"
	MethodIContentCaptureManagerOnLoginDetected                       = "onLoginDetected"
)
const (
	TransactionIDataShareWriteAdapterWrite    = binder.FirstCallTransaction + 0
	TransactionIDataShareWriteAdapterError    = binder.FirstCallTransaction + 1
	TransactionIDataShareWriteAdapterRejected = binder.FirstCallTransaction + 2
	TransactionIDataShareWriteAdapterFinish   = binder.FirstCallTransaction + 3
)
const (
	MethodIDataShareWriteAdapterWrite    = "write"
	MethodIDataShareWriteAdapterError    = "error"
	MethodIDataShareWriteAdapterRejected = "rejected"
	MethodIDataShareWriteAdapterFinish   = "finish"
)
const DescriptorIContentCaptureDirectManager = "android.view.contentcapture.IContentCaptureDirectManager"
const DescriptorIContentCaptureManager = "android.view.contentcapture.IContentCaptureManager"
const DescriptorIContentCaptureOptionsCallback = "android.view.contentcapture.IContentCaptureOptionsCallback"
const DescriptorIDataShareWriteAdapter = "android.view.contentcapture.IDataShareWriteAdapter"
const (
	MethodIContentCaptureDirectManagerSendEvents = "sendEvents"
)
const (
	MethodIContentCaptureOptionsCallbackSetContentCaptureOptions = "setContentCaptureOptions"
)
const (
	TransactionIContentCaptureDirectManagerSendEvents = binder.FirstCallTransaction + 0
)
const (
	TransactionIContentCaptureOptionsCallbackSetContentCaptureOptions = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type ContentCaptureCondition

type ContentCaptureCondition struct {
	Flags   int32
	LocusId *types.LocusId
}

func (*ContentCaptureCondition) MarshalParcel

func (s *ContentCaptureCondition) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ContentCaptureCondition) UnmarshalParcel

func (s *ContentCaptureCondition) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ContentCaptureContext

type ContentCaptureContext struct {
	ComponentName *types.ComponentName
}

func (*ContentCaptureContext) MarshalParcel

func (s *ContentCaptureContext) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ContentCaptureContext) UnmarshalParcel

func (s *ContentCaptureContext) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ContentCaptureDirectManagerProxy

type ContentCaptureDirectManagerProxy struct {
	Remote binder.IBinder
}

func NewContentCaptureDirectManagerProxy

func NewContentCaptureDirectManagerProxy(
	remote binder.IBinder,
) *ContentCaptureDirectManagerProxy

func (*ContentCaptureDirectManagerProxy) AsBinder

func (*ContentCaptureDirectManagerProxy) SendEvents

type ContentCaptureDirectManagerStub

type ContentCaptureDirectManagerStub struct {
	Impl      IContentCaptureDirectManager
	Transport binder.VersionAwareTransport
}

ContentCaptureDirectManagerStub dispatches incoming binder transactions to a typed IContentCaptureDirectManager implementation.

func (*ContentCaptureDirectManagerStub) Descriptor

func (s *ContentCaptureDirectManagerStub) Descriptor() string

func (*ContentCaptureDirectManagerStub) OnTransaction

type ContentCaptureEvent

type ContentCaptureEvent struct {
	SessionId int32
	Type      int32
	EventTime int64
	Insets    *graphics.Insets
}

func (*ContentCaptureEvent) MarshalParcel

func (s *ContentCaptureEvent) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ContentCaptureEvent) UnmarshalParcel

func (s *ContentCaptureEvent) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ContentCaptureManagerProxy

type ContentCaptureManagerProxy struct {
	Remote binder.IBinder
}

func GetContentCaptureManager

func GetContentCaptureManager(
	ctx context.Context,
	sm *servicemanager.ServiceManager,
) (*ContentCaptureManagerProxy, error)

GetContentCaptureManager retrieves the ContentCaptureManagerService service and returns a typed proxy.

func NewContentCaptureManagerProxy

func NewContentCaptureManagerProxy(
	remote binder.IBinder,
) *ContentCaptureManagerProxy

func (*ContentCaptureManagerProxy) AsBinder

func (*ContentCaptureManagerProxy) FinishSession

func (p *ContentCaptureManagerProxy) FinishSession(
	ctx context.Context,
	sessionId int32,
) error

func (*ContentCaptureManagerProxy) GetContentCaptureConditions

func (p *ContentCaptureManagerProxy) GetContentCaptureConditions(
	ctx context.Context,
	packageName string,
	result os.IResultReceiver,
) error

func (*ContentCaptureManagerProxy) GetServiceComponentName

func (p *ContentCaptureManagerProxy) GetServiceComponentName(
	ctx context.Context,
	result os.IResultReceiver,
) error

func (*ContentCaptureManagerProxy) GetServiceSettingsActivity

func (p *ContentCaptureManagerProxy) GetServiceSettingsActivity(
	ctx context.Context,
	result os.IResultReceiver,
) error

func (*ContentCaptureManagerProxy) IsContentCaptureFeatureEnabled

func (p *ContentCaptureManagerProxy) IsContentCaptureFeatureEnabled(
	ctx context.Context,
	result os.IResultReceiver,
) error

func (*ContentCaptureManagerProxy) OnLoginDetected

func (p *ContentCaptureManagerProxy) OnLoginDetected(
	ctx context.Context,
	events types.ParceledListSlice,
) error

func (*ContentCaptureManagerProxy) RegisterContentCaptureOptionsCallback

func (p *ContentCaptureManagerProxy) RegisterContentCaptureOptionsCallback(
	ctx context.Context,
	packageName string,
	callback IContentCaptureOptionsCallback,
) error

func (*ContentCaptureManagerProxy) RemoveData

func (p *ContentCaptureManagerProxy) RemoveData(
	ctx context.Context,
	request DataRemovalRequest,
) error

func (*ContentCaptureManagerProxy) ResetTemporaryService

func (p *ContentCaptureManagerProxy) ResetTemporaryService(
	ctx context.Context,
) error

func (*ContentCaptureManagerProxy) SetDefaultServiceEnabled

func (p *ContentCaptureManagerProxy) SetDefaultServiceEnabled(
	ctx context.Context,
	enabled bool,
) error

func (*ContentCaptureManagerProxy) SetTemporaryService

func (p *ContentCaptureManagerProxy) SetTemporaryService(
	ctx context.Context,
	serviceName string,
	duration int32,
) error

func (*ContentCaptureManagerProxy) ShareData

func (*ContentCaptureManagerProxy) StartSession

func (p *ContentCaptureManagerProxy) StartSession(
	ctx context.Context,
	activityToken binder.IBinder,
	shareableActivityToken binder.IBinder,
	componentName content.ComponentName,
	sessionId int32,
	flags int32,
	result os.IResultReceiver,
) error

type ContentCaptureManagerStub

type ContentCaptureManagerStub struct {
	Impl      IContentCaptureManager
	Transport binder.VersionAwareTransport
}

ContentCaptureManagerStub dispatches incoming binder transactions to a typed IContentCaptureManager implementation.

func (*ContentCaptureManagerStub) Descriptor

func (s *ContentCaptureManagerStub) Descriptor() string

func (*ContentCaptureManagerStub) OnTransaction

func (s *ContentCaptureManagerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ContentCaptureOptionsCallbackProxy

type ContentCaptureOptionsCallbackProxy struct {
	Remote binder.IBinder
}

func NewContentCaptureOptionsCallbackProxy

func NewContentCaptureOptionsCallbackProxy(
	remote binder.IBinder,
) *ContentCaptureOptionsCallbackProxy

func (*ContentCaptureOptionsCallbackProxy) AsBinder

func (*ContentCaptureOptionsCallbackProxy) SetContentCaptureOptions

func (p *ContentCaptureOptionsCallbackProxy) SetContentCaptureOptions(
	ctx context.Context,
	options content.ContentCaptureOptions,
) error

type ContentCaptureOptionsCallbackStub

type ContentCaptureOptionsCallbackStub struct {
	Impl      IContentCaptureOptionsCallback
	Transport binder.VersionAwareTransport
}

ContentCaptureOptionsCallbackStub dispatches incoming binder transactions to a typed IContentCaptureOptionsCallback implementation.

func (*ContentCaptureOptionsCallbackStub) Descriptor

func (s *ContentCaptureOptionsCallbackStub) Descriptor() string

func (*ContentCaptureOptionsCallbackStub) OnTransaction

type DataRemovalRequest

type DataRemovalRequest struct {
	PackageName   string
	ForEverything bool
}

func (*DataRemovalRequest) MarshalParcel

func (s *DataRemovalRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*DataRemovalRequest) UnmarshalParcel

func (s *DataRemovalRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type DataShareRequest

type DataShareRequest struct {
	Flg         int32
	PackageName string
	MimeType    string
	LocusId     *types.LocusId
}

func (*DataShareRequest) MarshalParcel

func (s *DataShareRequest) MarshalParcel(
	p *parcel.Parcel,
) error

func (*DataShareRequest) UnmarshalParcel

func (s *DataShareRequest) UnmarshalParcel(
	p *parcel.Parcel,
) error

type DataShareWriteAdapterProxy

type DataShareWriteAdapterProxy struct {
	Remote binder.IBinder
}

func NewDataShareWriteAdapterProxy

func NewDataShareWriteAdapterProxy(
	remote binder.IBinder,
) *DataShareWriteAdapterProxy

func (*DataShareWriteAdapterProxy) AsBinder

func (*DataShareWriteAdapterProxy) Error

func (p *DataShareWriteAdapterProxy) Error(
	ctx context.Context,
	errorCode int32,
) error

func (*DataShareWriteAdapterProxy) Finish

func (p *DataShareWriteAdapterProxy) Finish(
	ctx context.Context,
) error

func (*DataShareWriteAdapterProxy) Rejected

func (p *DataShareWriteAdapterProxy) Rejected(
	ctx context.Context,
) error

func (*DataShareWriteAdapterProxy) Write

func (p *DataShareWriteAdapterProxy) Write(
	ctx context.Context,
	destination int32,
) error

type DataShareWriteAdapterStub

type DataShareWriteAdapterStub struct {
	Impl      IDataShareWriteAdapter
	Transport binder.VersionAwareTransport
}

DataShareWriteAdapterStub dispatches incoming binder transactions to a typed IDataShareWriteAdapter implementation.

func (*DataShareWriteAdapterStub) Descriptor

func (s *DataShareWriteAdapterStub) Descriptor() string

func (*DataShareWriteAdapterStub) OnTransaction

func (s *DataShareWriteAdapterStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IContentCaptureDirectManager

type IContentCaptureDirectManager interface {
	AsBinder() binder.IBinder
	SendEvents(ctx context.Context, events types.ParceledListSlice, reason int32, options content.ContentCaptureOptions) error
}

func NewContentCaptureDirectManagerStub

func NewContentCaptureDirectManagerStub(
	impl IContentCaptureDirectManagerServer,
) IContentCaptureDirectManager

NewContentCaptureDirectManagerStub creates a server-side IContentCaptureDirectManager wrapping the given server implementation. The returned value satisfies IContentCaptureDirectManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IContentCaptureDirectManagerServer

type IContentCaptureDirectManagerServer interface {
	SendEvents(ctx context.Context, events types.ParceledListSlice, reason int32, options content.ContentCaptureOptions) error
}

IContentCaptureDirectManagerServer is the server-side interface that user implementations provide to NewContentCaptureDirectManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IContentCaptureManager

type IContentCaptureManager interface {
	AsBinder() binder.IBinder
	StartSession(ctx context.Context, activityToken binder.IBinder, shareableActivityToken binder.IBinder, componentName content.ComponentName, sessionId int32, flags int32, result os.IResultReceiver) error
	FinishSession(ctx context.Context, sessionId int32) error
	GetServiceComponentName(ctx context.Context, result os.IResultReceiver) error
	RemoveData(ctx context.Context, request DataRemovalRequest) error
	ShareData(ctx context.Context, request DataShareRequest, adapter IDataShareWriteAdapter) error
	IsContentCaptureFeatureEnabled(ctx context.Context, result os.IResultReceiver) error
	GetServiceSettingsActivity(ctx context.Context, result os.IResultReceiver) error
	GetContentCaptureConditions(ctx context.Context, packageName string, result os.IResultReceiver) error
	ResetTemporaryService(ctx context.Context) error
	SetTemporaryService(ctx context.Context, serviceName string, duration int32) error
	SetDefaultServiceEnabled(ctx context.Context, enabled bool) error
	RegisterContentCaptureOptionsCallback(ctx context.Context, packageName string, callback IContentCaptureOptionsCallback) error
	OnLoginDetected(ctx context.Context, events types.ParceledListSlice) error
}

func NewContentCaptureManagerStub

func NewContentCaptureManagerStub(
	impl IContentCaptureManagerServer,
) IContentCaptureManager

NewContentCaptureManagerStub creates a server-side IContentCaptureManager wrapping the given server implementation. The returned value satisfies IContentCaptureManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IContentCaptureManagerServer

type IContentCaptureManagerServer interface {
	StartSession(ctx context.Context, activityToken binder.IBinder, shareableActivityToken binder.IBinder, componentName content.ComponentName, sessionId int32, flags int32, result os.IResultReceiver) error
	FinishSession(ctx context.Context, sessionId int32) error
	GetServiceComponentName(ctx context.Context, result os.IResultReceiver) error
	RemoveData(ctx context.Context, request DataRemovalRequest) error
	ShareData(ctx context.Context, request DataShareRequest, adapter IDataShareWriteAdapter) error
	IsContentCaptureFeatureEnabled(ctx context.Context, result os.IResultReceiver) error
	GetServiceSettingsActivity(ctx context.Context, result os.IResultReceiver) error
	GetContentCaptureConditions(ctx context.Context, packageName string, result os.IResultReceiver) error
	ResetTemporaryService(ctx context.Context) error
	SetTemporaryService(ctx context.Context, serviceName string, duration int32) error
	SetDefaultServiceEnabled(ctx context.Context, enabled bool) error
	RegisterContentCaptureOptionsCallback(ctx context.Context, packageName string, callback IContentCaptureOptionsCallback) error
	OnLoginDetected(ctx context.Context, events types.ParceledListSlice) error
}

IContentCaptureManagerServer is the server-side interface that user implementations provide to NewContentCaptureManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IContentCaptureOptionsCallback

type IContentCaptureOptionsCallback interface {
	AsBinder() binder.IBinder
	SetContentCaptureOptions(ctx context.Context, options content.ContentCaptureOptions) error
}

func NewContentCaptureOptionsCallbackStub

func NewContentCaptureOptionsCallbackStub(
	impl IContentCaptureOptionsCallbackServer,
) IContentCaptureOptionsCallback

NewContentCaptureOptionsCallbackStub creates a server-side IContentCaptureOptionsCallback wrapping the given server implementation. The returned value satisfies IContentCaptureOptionsCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IContentCaptureOptionsCallbackServer

type IContentCaptureOptionsCallbackServer interface {
	SetContentCaptureOptions(ctx context.Context, options content.ContentCaptureOptions) error
}

IContentCaptureOptionsCallbackServer is the server-side interface that user implementations provide to NewContentCaptureOptionsCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IDataShareWriteAdapter

type IDataShareWriteAdapter interface {
	AsBinder() binder.IBinder
	Write(ctx context.Context, destination int32) error
	Error(ctx context.Context, errorCode int32) error
	Rejected(ctx context.Context) error
	Finish(ctx context.Context) error
}

func NewDataShareWriteAdapterStub

func NewDataShareWriteAdapterStub(
	impl IDataShareWriteAdapterServer,
) IDataShareWriteAdapter

NewDataShareWriteAdapterStub creates a server-side IDataShareWriteAdapter wrapping the given server implementation. The returned value satisfies IDataShareWriteAdapter and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDataShareWriteAdapterServer

type IDataShareWriteAdapterServer interface {
	Write(ctx context.Context, destination int32) error
	Error(ctx context.Context, errorCode int32) error
	Rejected(ctx context.Context) error
	Finish(ctx context.Context) error
}

IDataShareWriteAdapterServer is the server-side interface that user implementations provide to NewDataShareWriteAdapterStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

Jump to