aidl

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIBinderProxyCountingServiceRegisterCallback   = binder.FirstCallTransaction + 0
	TransactionIBinderProxyCountingServiceUnregisterCallback = binder.FirstCallTransaction + 1
)
const (
	MethodIBinderProxyCountingServiceRegisterCallback   = "registerCallback"
	MethodIBinderProxyCountingServiceUnregisterCallback = "unregisterCallback"
)
const (
	TransactionIBpcTestAppCmdServiceCreateSystemBinders   = binder.FirstCallTransaction + 0
	TransactionIBpcTestAppCmdServiceReleaseSystemBinders  = binder.FirstCallTransaction + 1
	TransactionIBpcTestAppCmdServiceCreateTestBinders     = binder.FirstCallTransaction + 2
	TransactionIBpcTestAppCmdServiceReleaseTestBinders    = binder.FirstCallTransaction + 3
	TransactionIBpcTestAppCmdServiceReleaseAllBinders     = binder.FirstCallTransaction + 4
	TransactionIBpcTestAppCmdServiceBindToTestService     = binder.FirstCallTransaction + 5
	TransactionIBpcTestAppCmdServiceUnbindFromTestService = binder.FirstCallTransaction + 6
)
const (
	MethodIBpcTestAppCmdServiceCreateSystemBinders   = "createSystemBinders"
	MethodIBpcTestAppCmdServiceReleaseSystemBinders  = "releaseSystemBinders"
	MethodIBpcTestAppCmdServiceCreateTestBinders     = "createTestBinders"
	MethodIBpcTestAppCmdServiceReleaseTestBinders    = "releaseTestBinders"
	MethodIBpcTestAppCmdServiceReleaseAllBinders     = "releaseAllBinders"
	MethodIBpcTestAppCmdServiceBindToTestService     = "bindToTestService"
	MethodIBpcTestAppCmdServiceUnbindFromTestService = "unbindFromTestService"
)
const (
	TransactionIBpcTestServiceCmdServiceForceGc                     = binder.FirstCallTransaction + 0
	TransactionIBpcTestServiceCmdServiceGetBinderProxyCount         = binder.FirstCallTransaction + 1
	TransactionIBpcTestServiceCmdServiceSetBinderProxyWatermarks    = binder.FirstCallTransaction + 2
	TransactionIBpcTestServiceCmdServiceEnableBinderProxyLimit      = binder.FirstCallTransaction + 3
	TransactionIBpcTestServiceCmdServiceSetBinderProxyCountCallback = binder.FirstCallTransaction + 4
)
const (
	MethodIBpcTestServiceCmdServiceForceGc                     = "forceGc"
	MethodIBpcTestServiceCmdServiceGetBinderProxyCount         = "getBinderProxyCount"
	MethodIBpcTestServiceCmdServiceSetBinderProxyWatermarks    = "setBinderProxyWatermarks"
	MethodIBpcTestServiceCmdServiceEnableBinderProxyLimit      = "enableBinderProxyLimit"
	MethodIBpcTestServiceCmdServiceSetBinderProxyCountCallback = "setBinderProxyCountCallback"
)
const (
	TransactionICmdReceiverDoSomeWork             = binder.FirstCallTransaction + 0
	TransactionICmdReceiverShowApplicationOverlay = binder.FirstCallTransaction + 1
	TransactionICmdReceiverFinishHost             = binder.FirstCallTransaction + 2
)
const (
	MethodICmdReceiverDoSomeWork             = "doSomeWork"
	MethodICmdReceiverShowApplicationOverlay = "showApplicationOverlay"
	MethodICmdReceiverFinishHost             = "finishHost"
)
const DescriptorIBinderProxyCountingService = "com.android.frameworks.coretests.aidl.IBinderProxyCountingService"
const DescriptorIBpcCallbackObserver = "com.android.frameworks.coretests.aidl.IBpcCallbackObserver"
const DescriptorIBpcTestAppCmdService = "com.android.frameworks.coretests.aidl.IBpcTestAppCmdService"
const DescriptorIBpcTestServiceCmdService = "com.android.frameworks.coretests.aidl.IBpcTestServiceCmdService"
const DescriptorICmdCallback = "com.android.frameworks.coretests.aidl.ICmdCallback"
const DescriptorICmdReceiver = "com.android.frameworks.coretests.aidl.ICmdReceiver"
const DescriptorITestRemoteCallback = "com.android.frameworks.coretests.aidl.ITestRemoteCallback"
const DescriptorITestServiceConnectorService = "com.android.frameworks.coretests.aidl.ITestServiceConnectorService"
const (
	MethodIBpcCallbackObserverOnCallback = "onCallback"
)
const (
	MethodICmdCallbackOnLaunched = "onLaunched"
)
const (
	MethodITestServiceConnectorServiceCrashProcess = "crashProcess"
)
const (
	TransactionIBpcCallbackObserverOnCallback = binder.FirstCallTransaction + 0
)
const (
	TransactionICmdCallbackOnLaunched = binder.FirstCallTransaction + 0
)
const (
	TransactionITestServiceConnectorServiceCrashProcess = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type BinderProxyCountingServiceProxy

type BinderProxyCountingServiceProxy struct {
	Remote binder.IBinder
}

func NewBinderProxyCountingServiceProxy

func NewBinderProxyCountingServiceProxy(
	remote binder.IBinder,
) *BinderProxyCountingServiceProxy

func (*BinderProxyCountingServiceProxy) AsBinder

func (*BinderProxyCountingServiceProxy) RegisterCallback

func (p *BinderProxyCountingServiceProxy) RegisterCallback(
	ctx context.Context,
	callback ITestRemoteCallback,
) error

func (*BinderProxyCountingServiceProxy) UnregisterCallback

func (p *BinderProxyCountingServiceProxy) UnregisterCallback(
	ctx context.Context,
	callback ITestRemoteCallback,
) error

type BinderProxyCountingServiceStub

type BinderProxyCountingServiceStub struct {
	Impl      IBinderProxyCountingService
	Transport binder.VersionAwareTransport
}

BinderProxyCountingServiceStub dispatches incoming binder transactions to a typed IBinderProxyCountingService implementation.

func (*BinderProxyCountingServiceStub) Descriptor

func (s *BinderProxyCountingServiceStub) Descriptor() string

func (*BinderProxyCountingServiceStub) OnTransaction

type BpcCallbackObserverProxy

type BpcCallbackObserverProxy struct {
	Remote binder.IBinder
}

func NewBpcCallbackObserverProxy

func NewBpcCallbackObserverProxy(
	remote binder.IBinder,
) *BpcCallbackObserverProxy

func (*BpcCallbackObserverProxy) AsBinder

func (p *BpcCallbackObserverProxy) AsBinder() binder.IBinder

func (*BpcCallbackObserverProxy) OnCallback

func (p *BpcCallbackObserverProxy) OnCallback(
	ctx context.Context,
	uid int32,
) error

type BpcCallbackObserverStub

type BpcCallbackObserverStub struct {
	Impl      IBpcCallbackObserver
	Transport binder.VersionAwareTransport
}

BpcCallbackObserverStub dispatches incoming binder transactions to a typed IBpcCallbackObserver implementation.

func (*BpcCallbackObserverStub) Descriptor

func (s *BpcCallbackObserverStub) Descriptor() string

func (*BpcCallbackObserverStub) OnTransaction

func (s *BpcCallbackObserverStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type BpcTestAppCmdServiceProxy

type BpcTestAppCmdServiceProxy struct {
	Remote binder.IBinder
}

func NewBpcTestAppCmdServiceProxy

func NewBpcTestAppCmdServiceProxy(
	remote binder.IBinder,
) *BpcTestAppCmdServiceProxy

func (*BpcTestAppCmdServiceProxy) AsBinder

func (*BpcTestAppCmdServiceProxy) BindToTestService

func (p *BpcTestAppCmdServiceProxy) BindToTestService(
	ctx context.Context,
) (string, error)

func (*BpcTestAppCmdServiceProxy) CreateSystemBinders

func (p *BpcTestAppCmdServiceProxy) CreateSystemBinders(
	ctx context.Context,
	count int32,
) error

func (*BpcTestAppCmdServiceProxy) CreateTestBinders

func (p *BpcTestAppCmdServiceProxy) CreateTestBinders(
	ctx context.Context,
	count int32,
) error

func (*BpcTestAppCmdServiceProxy) ReleaseAllBinders

func (p *BpcTestAppCmdServiceProxy) ReleaseAllBinders(
	ctx context.Context,
) error

func (*BpcTestAppCmdServiceProxy) ReleaseSystemBinders

func (p *BpcTestAppCmdServiceProxy) ReleaseSystemBinders(
	ctx context.Context,
	count int32,
) error

func (*BpcTestAppCmdServiceProxy) ReleaseTestBinders

func (p *BpcTestAppCmdServiceProxy) ReleaseTestBinders(
	ctx context.Context,
	count int32,
) error

func (*BpcTestAppCmdServiceProxy) UnbindFromTestService

func (p *BpcTestAppCmdServiceProxy) UnbindFromTestService(
	ctx context.Context,
) error

type BpcTestAppCmdServiceStub

type BpcTestAppCmdServiceStub struct {
	Impl      IBpcTestAppCmdService
	Transport binder.VersionAwareTransport
}

BpcTestAppCmdServiceStub dispatches incoming binder transactions to a typed IBpcTestAppCmdService implementation.

func (*BpcTestAppCmdServiceStub) Descriptor

func (s *BpcTestAppCmdServiceStub) Descriptor() string

func (*BpcTestAppCmdServiceStub) OnTransaction

func (s *BpcTestAppCmdServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type BpcTestServiceCmdServiceProxy

type BpcTestServiceCmdServiceProxy struct {
	Remote binder.IBinder
}

func NewBpcTestServiceCmdServiceProxy

func NewBpcTestServiceCmdServiceProxy(
	remote binder.IBinder,
) *BpcTestServiceCmdServiceProxy

func (*BpcTestServiceCmdServiceProxy) AsBinder

func (*BpcTestServiceCmdServiceProxy) EnableBinderProxyLimit

func (p *BpcTestServiceCmdServiceProxy) EnableBinderProxyLimit(
	ctx context.Context,
	enable bool,
) error

func (*BpcTestServiceCmdServiceProxy) ForceGc

func (*BpcTestServiceCmdServiceProxy) GetBinderProxyCount

func (p *BpcTestServiceCmdServiceProxy) GetBinderProxyCount(
	ctx context.Context,
	uid int32,
) (int32, error)

func (*BpcTestServiceCmdServiceProxy) SetBinderProxyCountCallback

func (p *BpcTestServiceCmdServiceProxy) SetBinderProxyCountCallback(
	ctx context.Context,
	observer IBpcCallbackObserver,
) error

func (*BpcTestServiceCmdServiceProxy) SetBinderProxyWatermarks

func (p *BpcTestServiceCmdServiceProxy) SetBinderProxyWatermarks(
	ctx context.Context,
	high int32,
	low int32,
) error

type BpcTestServiceCmdServiceStub

type BpcTestServiceCmdServiceStub struct {
	Impl      IBpcTestServiceCmdService
	Transport binder.VersionAwareTransport
}

BpcTestServiceCmdServiceStub dispatches incoming binder transactions to a typed IBpcTestServiceCmdService implementation.

func (*BpcTestServiceCmdServiceStub) Descriptor

func (s *BpcTestServiceCmdServiceStub) Descriptor() string

func (*BpcTestServiceCmdServiceStub) OnTransaction

type CmdCallbackProxy

type CmdCallbackProxy struct {
	Remote binder.IBinder
}

func NewCmdCallbackProxy

func NewCmdCallbackProxy(
	remote binder.IBinder,
) *CmdCallbackProxy

func (*CmdCallbackProxy) AsBinder

func (p *CmdCallbackProxy) AsBinder() binder.IBinder

func (*CmdCallbackProxy) OnLaunched

func (p *CmdCallbackProxy) OnLaunched(
	ctx context.Context,
	receiver binder.IBinder,
) error

type CmdCallbackStub

type CmdCallbackStub struct {
	Impl      ICmdCallback
	Transport binder.VersionAwareTransport
}

CmdCallbackStub dispatches incoming binder transactions to a typed ICmdCallback implementation.

func (*CmdCallbackStub) Descriptor

func (s *CmdCallbackStub) Descriptor() string

func (*CmdCallbackStub) OnTransaction

func (s *CmdCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type CmdReceiverProxy

type CmdReceiverProxy struct {
	Remote binder.IBinder
}

func NewCmdReceiverProxy

func NewCmdReceiverProxy(
	remote binder.IBinder,
) *CmdReceiverProxy

func (*CmdReceiverProxy) AsBinder

func (p *CmdReceiverProxy) AsBinder() binder.IBinder

func (*CmdReceiverProxy) DoSomeWork

func (p *CmdReceiverProxy) DoSomeWork(
	ctx context.Context,
	durationMs int32,
) error

func (*CmdReceiverProxy) FinishHost

func (p *CmdReceiverProxy) FinishHost(
	ctx context.Context,
) error

func (*CmdReceiverProxy) ShowApplicationOverlay

func (p *CmdReceiverProxy) ShowApplicationOverlay(
	ctx context.Context,
) error

type CmdReceiverStub

type CmdReceiverStub struct {
	Impl      ICmdReceiver
	Transport binder.VersionAwareTransport
}

CmdReceiverStub dispatches incoming binder transactions to a typed ICmdReceiver implementation.

func (*CmdReceiverStub) Descriptor

func (s *CmdReceiverStub) Descriptor() string

func (*CmdReceiverStub) OnTransaction

func (s *CmdReceiverStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IBinderProxyCountingService

type IBinderProxyCountingService interface {
	AsBinder() binder.IBinder
	RegisterCallback(ctx context.Context, callback ITestRemoteCallback) error
	UnregisterCallback(ctx context.Context, callback ITestRemoteCallback) error
}

func NewBinderProxyCountingServiceStub

func NewBinderProxyCountingServiceStub(
	impl IBinderProxyCountingServiceServer,
) IBinderProxyCountingService

NewBinderProxyCountingServiceStub creates a server-side IBinderProxyCountingService wrapping the given server implementation. The returned value satisfies IBinderProxyCountingService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBinderProxyCountingServiceServer

type IBinderProxyCountingServiceServer interface {
	RegisterCallback(ctx context.Context, callback ITestRemoteCallback) error
	UnregisterCallback(ctx context.Context, callback ITestRemoteCallback) error
}

IBinderProxyCountingServiceServer is the server-side interface that user implementations provide to NewBinderProxyCountingServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IBpcCallbackObserver

type IBpcCallbackObserver interface {
	AsBinder() binder.IBinder
	OnCallback(ctx context.Context, uid int32) error
}

func NewBpcCallbackObserverStub

func NewBpcCallbackObserverStub(
	impl IBpcCallbackObserverServer,
) IBpcCallbackObserver

NewBpcCallbackObserverStub creates a server-side IBpcCallbackObserver wrapping the given server implementation. The returned value satisfies IBpcCallbackObserver and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBpcCallbackObserverServer

type IBpcCallbackObserverServer interface {
	OnCallback(ctx context.Context, uid int32) error
}

IBpcCallbackObserverServer is the server-side interface that user implementations provide to NewBpcCallbackObserverStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IBpcTestAppCmdService

type IBpcTestAppCmdService interface {
	AsBinder() binder.IBinder
	CreateSystemBinders(ctx context.Context, count int32) error
	ReleaseSystemBinders(ctx context.Context, count int32) error
	CreateTestBinders(ctx context.Context, count int32) error
	ReleaseTestBinders(ctx context.Context, count int32) error
	ReleaseAllBinders(ctx context.Context) error
	BindToTestService(ctx context.Context) (string, error)
	UnbindFromTestService(ctx context.Context) error
}

func NewBpcTestAppCmdServiceStub

func NewBpcTestAppCmdServiceStub(
	impl IBpcTestAppCmdServiceServer,
) IBpcTestAppCmdService

NewBpcTestAppCmdServiceStub creates a server-side IBpcTestAppCmdService wrapping the given server implementation. The returned value satisfies IBpcTestAppCmdService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBpcTestAppCmdServiceServer

type IBpcTestAppCmdServiceServer interface {
	CreateSystemBinders(ctx context.Context, count int32) error
	ReleaseSystemBinders(ctx context.Context, count int32) error
	CreateTestBinders(ctx context.Context, count int32) error
	ReleaseTestBinders(ctx context.Context, count int32) error
	ReleaseAllBinders(ctx context.Context) error
	BindToTestService(ctx context.Context) (string, error)
	UnbindFromTestService(ctx context.Context) error
}

IBpcTestAppCmdServiceServer is the server-side interface that user implementations provide to NewBpcTestAppCmdServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IBpcTestServiceCmdService

type IBpcTestServiceCmdService interface {
	AsBinder() binder.IBinder
	ForceGc(ctx context.Context) error
	GetBinderProxyCount(ctx context.Context, uid int32) (int32, error)
	SetBinderProxyWatermarks(ctx context.Context, high int32, low int32) error
	EnableBinderProxyLimit(ctx context.Context, enable bool) error
	SetBinderProxyCountCallback(ctx context.Context, observer IBpcCallbackObserver) error
}

func NewBpcTestServiceCmdServiceStub

func NewBpcTestServiceCmdServiceStub(
	impl IBpcTestServiceCmdServiceServer,
) IBpcTestServiceCmdService

NewBpcTestServiceCmdServiceStub creates a server-side IBpcTestServiceCmdService wrapping the given server implementation. The returned value satisfies IBpcTestServiceCmdService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBpcTestServiceCmdServiceServer

type IBpcTestServiceCmdServiceServer interface {
	ForceGc(ctx context.Context) error
	GetBinderProxyCount(ctx context.Context, uid int32) (int32, error)
	SetBinderProxyWatermarks(ctx context.Context, high int32, low int32) error
	EnableBinderProxyLimit(ctx context.Context, enable bool) error
	SetBinderProxyCountCallback(ctx context.Context, observer IBpcCallbackObserver) error
}

IBpcTestServiceCmdServiceServer is the server-side interface that user implementations provide to NewBpcTestServiceCmdServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ICmdCallback

type ICmdCallback interface {
	AsBinder() binder.IBinder
	OnLaunched(ctx context.Context, receiver binder.IBinder) error
}

func NewCmdCallbackStub

func NewCmdCallbackStub(
	impl ICmdCallbackServer,
) ICmdCallback

NewCmdCallbackStub creates a server-side ICmdCallback wrapping the given server implementation. The returned value satisfies ICmdCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ICmdCallbackServer

type ICmdCallbackServer interface {
	OnLaunched(ctx context.Context, receiver binder.IBinder) error
}

ICmdCallbackServer is the server-side interface that user implementations provide to NewCmdCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ICmdReceiver

type ICmdReceiver interface {
	AsBinder() binder.IBinder
	DoSomeWork(ctx context.Context, durationMs int32) error
	ShowApplicationOverlay(ctx context.Context) error
	FinishHost(ctx context.Context) error
}

func NewCmdReceiverStub

func NewCmdReceiverStub(
	impl ICmdReceiverServer,
) ICmdReceiver

NewCmdReceiverStub creates a server-side ICmdReceiver wrapping the given server implementation. The returned value satisfies ICmdReceiver and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ICmdReceiverServer

type ICmdReceiverServer interface {
	DoSomeWork(ctx context.Context, durationMs int32) error
	ShowApplicationOverlay(ctx context.Context) error
	FinishHost(ctx context.Context) error
}

ICmdReceiverServer is the server-side interface that user implementations provide to NewCmdReceiverStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ITestRemoteCallback

type ITestRemoteCallback interface {
	AsBinder() binder.IBinder
}

func NewTestRemoteCallbackStub

func NewTestRemoteCallbackStub(
	impl ITestRemoteCallbackServer,
) ITestRemoteCallback

NewTestRemoteCallbackStub creates a server-side ITestRemoteCallback wrapping the given server implementation. The returned value satisfies ITestRemoteCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ITestRemoteCallbackServer

type ITestRemoteCallbackServer interface {
}

ITestRemoteCallbackServer is the server-side interface that user implementations provide to NewTestRemoteCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ITestServiceConnectorService

type ITestServiceConnectorService interface {
	AsBinder() binder.IBinder
	CrashProcess(ctx context.Context) error
}

func NewTestServiceConnectorServiceStub

func NewTestServiceConnectorServiceStub(
	impl ITestServiceConnectorServiceServer,
) ITestServiceConnectorService

NewTestServiceConnectorServiceStub creates a server-side ITestServiceConnectorService wrapping the given server implementation. The returned value satisfies ITestServiceConnectorService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ITestServiceConnectorServiceServer

type ITestServiceConnectorServiceServer interface {
	CrashProcess(ctx context.Context) error
}

ITestServiceConnectorServiceServer is the server-side interface that user implementations provide to NewTestServiceConnectorServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type TestRemoteCallbackProxy

type TestRemoteCallbackProxy struct {
	Remote binder.IBinder
}

func NewTestRemoteCallbackProxy

func NewTestRemoteCallbackProxy(
	remote binder.IBinder,
) *TestRemoteCallbackProxy

func (*TestRemoteCallbackProxy) AsBinder

func (p *TestRemoteCallbackProxy) AsBinder() binder.IBinder

type TestRemoteCallbackStub

type TestRemoteCallbackStub struct {
	Impl      ITestRemoteCallback
	Transport binder.VersionAwareTransport
}

TestRemoteCallbackStub dispatches incoming binder transactions to a typed ITestRemoteCallback implementation.

func (*TestRemoteCallbackStub) Descriptor

func (s *TestRemoteCallbackStub) Descriptor() string

func (*TestRemoteCallbackStub) OnTransaction

func (s *TestRemoteCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type TestServiceConnectorServiceProxy

type TestServiceConnectorServiceProxy struct {
	Remote binder.IBinder
}

func NewTestServiceConnectorServiceProxy

func NewTestServiceConnectorServiceProxy(
	remote binder.IBinder,
) *TestServiceConnectorServiceProxy

func (*TestServiceConnectorServiceProxy) AsBinder

func (*TestServiceConnectorServiceProxy) CrashProcess

func (p *TestServiceConnectorServiceProxy) CrashProcess(
	ctx context.Context,
) error

type TestServiceConnectorServiceStub

type TestServiceConnectorServiceStub struct {
	Impl      ITestServiceConnectorService
	Transport binder.VersionAwareTransport
}

TestServiceConnectorServiceStub dispatches incoming binder transactions to a typed ITestServiceConnectorService implementation.

func (*TestServiceConnectorServiceStub) Descriptor

func (s *TestServiceConnectorServiceStub) Descriptor() string

func (*TestServiceConnectorServiceStub) OnTransaction

Jump to