options

package
v0.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 28, 2026 License: CC0-1.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIOptionsListenerGetVersionCb        = binder.FirstCallTransaction + 0
	TransactionIOptionsListenerServiceAvailable    = binder.FirstCallTransaction + 1
	TransactionIOptionsListenerServiceUnavailable  = binder.FirstCallTransaction + 2
	TransactionIOptionsListenerSipResponseReceived = binder.FirstCallTransaction + 3
	TransactionIOptionsListenerCmdStatus           = binder.FirstCallTransaction + 4
	TransactionIOptionsListenerIncomingOptions     = binder.FirstCallTransaction + 5
)
const (
	MethodIOptionsListenerGetVersionCb        = "getVersionCb"
	MethodIOptionsListenerServiceAvailable    = "serviceAvailable"
	MethodIOptionsListenerServiceUnavailable  = "serviceUnavailable"
	MethodIOptionsListenerSipResponseReceived = "sipResponseReceived"
	MethodIOptionsListenerCmdStatus           = "cmdStatus"
	MethodIOptionsListenerIncomingOptions     = "incomingOptions"
)
const (
	TransactionIOptionsServiceGetVersion              = binder.FirstCallTransaction + 0
	TransactionIOptionsServiceAddListener             = binder.FirstCallTransaction + 1
	TransactionIOptionsServiceRemoveListener          = binder.FirstCallTransaction + 2
	TransactionIOptionsServiceSetMyInfo               = binder.FirstCallTransaction + 3
	TransactionIOptionsServiceGetMyInfo               = binder.FirstCallTransaction + 4
	TransactionIOptionsServiceGetContactCap           = binder.FirstCallTransaction + 5
	TransactionIOptionsServiceGetContactListCap       = binder.FirstCallTransaction + 6
	TransactionIOptionsServiceResponseIncomingOptions = binder.FirstCallTransaction + 7
)
const (
	MethodIOptionsServiceGetVersion              = "getVersion"
	MethodIOptionsServiceAddListener             = "addListener"
	MethodIOptionsServiceRemoveListener          = "removeListener"
	MethodIOptionsServiceSetMyInfo               = "setMyInfo"
	MethodIOptionsServiceGetMyInfo               = "getMyInfo"
	MethodIOptionsServiceGetContactCap           = "getContactCap"
	MethodIOptionsServiceGetContactListCap       = "getContactListCap"
	MethodIOptionsServiceResponseIncomingOptions = "responseIncomingOptions"
)
const DescriptorIOptionsListener = "com.android.ims.internal.uce.options.IOptionsListener"
const DescriptorIOptionsService = "com.android.ims.internal.uce.options.IOptionsService"

Variables

This section is empty.

Functions

This section is empty.

Types

type IOptionsListener

type IOptionsListener interface {
	AsBinder() binder.IBinder
	GetVersionCb(ctx context.Context, version string) error
	ServiceAvailable(ctx context.Context, statusCode common.StatusCode) error
	ServiceUnavailable(ctx context.Context, statusCode common.StatusCode) error
	SipResponseReceived(ctx context.Context, uri string, sipResponse OptionsSipResponse, capInfo OptionsCapInfo) error
	CmdStatus(ctx context.Context, cmdStatus OptionsCmdStatus) error
	IncomingOptions(ctx context.Context, uri string, capInfo OptionsCapInfo, tID int32) error
}

func NewOptionsListenerStub

func NewOptionsListenerStub(
	impl IOptionsListenerServer,
) IOptionsListener

NewOptionsListenerStub creates a server-side IOptionsListener wrapping the given server implementation. The returned value satisfies IOptionsListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IOptionsListenerServer

type IOptionsListenerServer interface {
	GetVersionCb(ctx context.Context, version string) error
	ServiceAvailable(ctx context.Context, statusCode common.StatusCode) error
	ServiceUnavailable(ctx context.Context, statusCode common.StatusCode) error
	SipResponseReceived(ctx context.Context, uri string, sipResponse OptionsSipResponse, capInfo OptionsCapInfo) error
	CmdStatus(ctx context.Context, cmdStatus OptionsCmdStatus) error
	IncomingOptions(ctx context.Context, uri string, capInfo OptionsCapInfo, tID int32) error
}

IOptionsListenerServer is the server-side interface that user implementations provide to NewOptionsListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IOptionsService

type IOptionsService interface {
	AsBinder() binder.IBinder
	GetVersion(ctx context.Context, optionsServiceHandle int32) (common.StatusCode, error)
	AddListener(ctx context.Context, optionsServiceHandle int32, optionsListener IOptionsListener, optionsServiceListenerHdl common.UceLong) (common.StatusCode, error)
	RemoveListener(ctx context.Context, optionsServiceHandle int32, optionsServiceListenerHdl common.UceLong) (common.StatusCode, error)
	SetMyInfo(ctx context.Context, optionsServiceHandle int32, capInfo common.CapInfo, reqUserData int32) (common.StatusCode, error)
	GetMyInfo(ctx context.Context, optionsServiceHandle int32, reqUserdata int32) (common.StatusCode, error)
	GetContactCap(ctx context.Context, optionsServiceHandle int32, remoteURI string, reqUserData int32) (common.StatusCode, error)
	GetContactListCap(ctx context.Context, optionsServiceHandle int32, remoteURIList []string, reqUserData int32) (common.StatusCode, error)
	ResponseIncomingOptions(ctx context.Context, optionsServiceHandle int32, tId int32, sipResponseCode int32, reasonPhrase string, capInfo OptionsCapInfo, bContactInBL bool) (common.StatusCode, error)
}

func NewOptionsServiceStub

func NewOptionsServiceStub(
	impl IOptionsServiceServer,
) IOptionsService

NewOptionsServiceStub creates a server-side IOptionsService wrapping the given server implementation. The returned value satisfies IOptionsService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IOptionsServiceServer

type IOptionsServiceServer interface {
	GetVersion(ctx context.Context, optionsServiceHandle int32) (common.StatusCode, error)
	AddListener(ctx context.Context, optionsServiceHandle int32, optionsListener IOptionsListener, optionsServiceListenerHdl common.UceLong) (common.StatusCode, error)
	RemoveListener(ctx context.Context, optionsServiceHandle int32, optionsServiceListenerHdl common.UceLong) (common.StatusCode, error)
	SetMyInfo(ctx context.Context, optionsServiceHandle int32, capInfo common.CapInfo, reqUserData int32) (common.StatusCode, error)
	GetMyInfo(ctx context.Context, optionsServiceHandle int32, reqUserdata int32) (common.StatusCode, error)
	GetContactCap(ctx context.Context, optionsServiceHandle int32, remoteURI string, reqUserData int32) (common.StatusCode, error)
	GetContactListCap(ctx context.Context, optionsServiceHandle int32, remoteURIList []string, reqUserData int32) (common.StatusCode, error)
	ResponseIncomingOptions(ctx context.Context, optionsServiceHandle int32, tId int32, sipResponseCode int32, reasonPhrase string, capInfo OptionsCapInfo, bContactInBL bool) (common.StatusCode, error)
}

IOptionsServiceServer is the server-side interface that user implementations provide to NewOptionsServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type OptionsCapInfo

type OptionsCapInfo struct {
	Sdp     string
	CapInfo *common.CapInfo
}

func (*OptionsCapInfo) MarshalParcel

func (s *OptionsCapInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*OptionsCapInfo) UnmarshalParcel

func (s *OptionsCapInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type OptionsCmdId

type OptionsCmdId struct {
	CmdId int32
}

func (*OptionsCmdId) MarshalParcel

func (s *OptionsCmdId) MarshalParcel(
	p *parcel.Parcel,
) error

func (*OptionsCmdId) UnmarshalParcel

func (s *OptionsCmdId) UnmarshalParcel(
	p *parcel.Parcel,
) error

type OptionsCmdStatus

type OptionsCmdStatus struct {
	UserData int32
	CapInfo  *common.CapInfo
}

func (*OptionsCmdStatus) MarshalParcel

func (s *OptionsCmdStatus) MarshalParcel(
	p *parcel.Parcel,
) error

func (*OptionsCmdStatus) UnmarshalParcel

func (s *OptionsCmdStatus) UnmarshalParcel(
	p *parcel.Parcel,
) error

type OptionsListenerProxy

type OptionsListenerProxy struct {
	Remote binder.IBinder
}

func NewOptionsListenerProxy

func NewOptionsListenerProxy(
	remote binder.IBinder,
) *OptionsListenerProxy

func (*OptionsListenerProxy) AsBinder

func (p *OptionsListenerProxy) AsBinder() binder.IBinder

func (*OptionsListenerProxy) CmdStatus

func (p *OptionsListenerProxy) CmdStatus(
	ctx context.Context,
	cmdStatus OptionsCmdStatus,
) error

func (*OptionsListenerProxy) GetVersionCb

func (p *OptionsListenerProxy) GetVersionCb(
	ctx context.Context,
	version string,
) error

func (*OptionsListenerProxy) IncomingOptions

func (p *OptionsListenerProxy) IncomingOptions(
	ctx context.Context,
	uri string,
	capInfo OptionsCapInfo,
	tID int32,
) error

func (*OptionsListenerProxy) ServiceAvailable

func (p *OptionsListenerProxy) ServiceAvailable(
	ctx context.Context,
	statusCode common.StatusCode,
) error

func (*OptionsListenerProxy) ServiceUnavailable

func (p *OptionsListenerProxy) ServiceUnavailable(
	ctx context.Context,
	statusCode common.StatusCode,
) error

func (*OptionsListenerProxy) SipResponseReceived

func (p *OptionsListenerProxy) SipResponseReceived(
	ctx context.Context,
	uri string,
	sipResponse OptionsSipResponse,
	capInfo OptionsCapInfo,
) error

type OptionsListenerStub

type OptionsListenerStub struct {
	Impl      IOptionsListener
	Transport binder.VersionAwareTransport
}

OptionsListenerStub dispatches incoming binder transactions to a typed IOptionsListener implementation.

func (*OptionsListenerStub) Descriptor

func (s *OptionsListenerStub) Descriptor() string

func (*OptionsListenerStub) OnTransaction

func (s *OptionsListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type OptionsServiceProxy

type OptionsServiceProxy struct {
	Remote binder.IBinder
}

func NewOptionsServiceProxy

func NewOptionsServiceProxy(
	remote binder.IBinder,
) *OptionsServiceProxy

func (*OptionsServiceProxy) AddListener

func (p *OptionsServiceProxy) AddListener(
	ctx context.Context,
	optionsServiceHandle int32,
	optionsListener IOptionsListener,
	optionsServiceListenerHdl common.UceLong,
) (common.StatusCode, error)

func (*OptionsServiceProxy) AsBinder

func (p *OptionsServiceProxy) AsBinder() binder.IBinder

func (*OptionsServiceProxy) GetContactCap

func (p *OptionsServiceProxy) GetContactCap(
	ctx context.Context,
	optionsServiceHandle int32,
	remoteURI string,
	reqUserData int32,
) (common.StatusCode, error)

func (*OptionsServiceProxy) GetContactListCap

func (p *OptionsServiceProxy) GetContactListCap(
	ctx context.Context,
	optionsServiceHandle int32,
	remoteURIList []string,
	reqUserData int32,
) (common.StatusCode, error)

func (*OptionsServiceProxy) GetMyInfo

func (p *OptionsServiceProxy) GetMyInfo(
	ctx context.Context,
	optionsServiceHandle int32,
	reqUserdata int32,
) (common.StatusCode, error)

func (*OptionsServiceProxy) GetVersion

func (p *OptionsServiceProxy) GetVersion(
	ctx context.Context,
	optionsServiceHandle int32,
) (common.StatusCode, error)

func (*OptionsServiceProxy) RemoveListener

func (p *OptionsServiceProxy) RemoveListener(
	ctx context.Context,
	optionsServiceHandle int32,
	optionsServiceListenerHdl common.UceLong,
) (common.StatusCode, error)

func (*OptionsServiceProxy) ResponseIncomingOptions

func (p *OptionsServiceProxy) ResponseIncomingOptions(
	ctx context.Context,
	optionsServiceHandle int32,
	tId int32,
	sipResponseCode int32,
	reasonPhrase string,
	capInfo OptionsCapInfo,
	bContactInBL bool,
) (common.StatusCode, error)

func (*OptionsServiceProxy) SetMyInfo

func (p *OptionsServiceProxy) SetMyInfo(
	ctx context.Context,
	optionsServiceHandle int32,
	capInfo common.CapInfo,
	reqUserData int32,
) (common.StatusCode, error)

type OptionsServiceStub

type OptionsServiceStub struct {
	Impl      IOptionsService
	Transport binder.VersionAwareTransport
}

OptionsServiceStub dispatches incoming binder transactions to a typed IOptionsService implementation.

func (*OptionsServiceStub) Descriptor

func (s *OptionsServiceStub) Descriptor() string

func (*OptionsServiceStub) OnTransaction

func (s *OptionsServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type OptionsSipResponse

type OptionsSipResponse struct {
	RequestId       int32
	SipResponseCode int32
	ReasonPhrase    string
	RetryAfter      int32
	ReasonHeader    string
}

func (*OptionsSipResponse) MarshalParcel

func (s *OptionsSipResponse) MarshalParcel(
	p *parcel.Parcel,
) error

func (*OptionsSipResponse) UnmarshalParcel

func (s *OptionsSipResponse) UnmarshalParcel(
	p *parcel.Parcel,
) error

Jump to