os

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIBinaryTransparencyServiceGetSignedImageInfo               = binder.FirstCallTransaction + 0
	TransactionIBinaryTransparencyServiceRecordMeasurementsForAllPackages = binder.FirstCallTransaction + 1
	TransactionIBinaryTransparencyServiceCollectAllApexInfo               = binder.FirstCallTransaction + 2
	TransactionIBinaryTransparencyServiceCollectAllUpdatedPreloadInfo     = binder.FirstCallTransaction + 3
	TransactionIBinaryTransparencyServiceCollectAllSilentInstalledMbaInfo = binder.FirstCallTransaction + 4
)
const (
	MethodIBinaryTransparencyServiceGetSignedImageInfo               = "getSignedImageInfo"
	MethodIBinaryTransparencyServiceRecordMeasurementsForAllPackages = "recordMeasurementsForAllPackages"
	MethodIBinaryTransparencyServiceCollectAllApexInfo               = "collectAllApexInfo"
	MethodIBinaryTransparencyServiceCollectAllUpdatedPreloadInfo     = "collectAllUpdatedPreloadInfo"
	MethodIBinaryTransparencyServiceCollectAllSilentInstalledMbaInfo = "collectAllSilentInstalledMbaInfo"
)
const (
	TransactionIDropBoxManagerServiceAddData                     = binder.FirstCallTransaction + 0
	TransactionIDropBoxManagerServiceAddFile                     = binder.FirstCallTransaction + 1
	TransactionIDropBoxManagerServiceIsTagEnabled                = binder.FirstCallTransaction + 2
	TransactionIDropBoxManagerServiceGetNextEntry                = binder.FirstCallTransaction + 3
	TransactionIDropBoxManagerServiceGetNextEntryWithAttribution = binder.FirstCallTransaction + 4
)
const (
	MethodIDropBoxManagerServiceAddData                     = "addData"
	MethodIDropBoxManagerServiceAddFile                     = "addFile"
	MethodIDropBoxManagerServiceIsTagEnabled                = "isTagEnabled"
	MethodIDropBoxManagerServiceGetNextEntry                = "getNextEntry"
	MethodIDropBoxManagerServiceGetNextEntryWithAttribution = "getNextEntryWithAttribution"
)
const DescriptorIBinaryTransparencyService = "com.android.internal.os.IBinaryTransparencyService"
const DescriptorIDropBoxManagerService = "com.android.internal.os.IDropBoxManagerService"
const DescriptorIParcelFileDescriptorFactory = "com.android.internal.os.IParcelFileDescriptorFactory"
const DescriptorIResultReceiver = "com.android.internal.os.IResultReceiver"
const DescriptorIShellCallback = "com.android.internal.os.IShellCallback"
const (
	MethodIParcelFileDescriptorFactoryOpen = "open"
)
const (
	MethodIResultReceiverSend = "send"
)
const (
	MethodIShellCallbackOpenFile = "openFile"
)
const (
	TransactionIParcelFileDescriptorFactoryOpen = binder.FirstCallTransaction + 0
)
const (
	TransactionIResultReceiverSend = binder.FirstCallTransaction + 0
)
const (
	TransactionIShellCallbackOpenFile = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type AppFuseMount

type AppFuseMount struct {
}

func (*AppFuseMount) MarshalParcel

func (s *AppFuseMount) MarshalParcel(
	p *parcel.Parcel,
) error

func (*AppFuseMount) UnmarshalParcel

func (s *AppFuseMount) UnmarshalParcel(
	p *parcel.Parcel,
) error

type BinaryTransparencyServiceProxy

type BinaryTransparencyServiceProxy struct {
	Remote binder.IBinder
}

func GetBinaryTransparencyService

func GetBinaryTransparencyService(
	ctx context.Context,
	sm *servicemanager.ServiceManager,
) (*BinaryTransparencyServiceProxy, error)

GetBinaryTransparencyService retrieves the BinaryTransparencyService service and returns a typed proxy.

func NewBinaryTransparencyServiceProxy

func NewBinaryTransparencyServiceProxy(
	remote binder.IBinder,
) *BinaryTransparencyServiceProxy

func (*BinaryTransparencyServiceProxy) AsBinder

func (*BinaryTransparencyServiceProxy) CollectAllApexInfo

func (p *BinaryTransparencyServiceProxy) CollectAllApexInfo(
	ctx context.Context,
	includeTestOnly bool,
) ([]IBinaryTransparencyServiceApexInfo, error)

func (*BinaryTransparencyServiceProxy) CollectAllSilentInstalledMbaInfo

func (p *BinaryTransparencyServiceProxy) CollectAllSilentInstalledMbaInfo(
	ctx context.Context,
	packagesToSkip types.Bundle,
) ([]IBinaryTransparencyServiceAppInfo, error)

func (*BinaryTransparencyServiceProxy) CollectAllUpdatedPreloadInfo

func (p *BinaryTransparencyServiceProxy) CollectAllUpdatedPreloadInfo(
	ctx context.Context,
	packagesToSkip types.Bundle,
) ([]IBinaryTransparencyServiceAppInfo, error)

func (*BinaryTransparencyServiceProxy) GetSignedImageInfo

func (p *BinaryTransparencyServiceProxy) GetSignedImageInfo(
	ctx context.Context,
) (string, error)

func (*BinaryTransparencyServiceProxy) RecordMeasurementsForAllPackages

func (p *BinaryTransparencyServiceProxy) RecordMeasurementsForAllPackages(
	ctx context.Context,
) error

type BinaryTransparencyServiceStub

type BinaryTransparencyServiceStub struct {
	Impl      IBinaryTransparencyService
	Transport binder.VersionAwareTransport
}

BinaryTransparencyServiceStub dispatches incoming binder transactions to a typed IBinaryTransparencyService implementation.

func (*BinaryTransparencyServiceStub) Descriptor

func (s *BinaryTransparencyServiceStub) Descriptor() string

func (*BinaryTransparencyServiceStub) OnTransaction

type DropBoxManagerServiceProxy

type DropBoxManagerServiceProxy struct {
	Remote binder.IBinder
}

func GetDropBoxManagerService

func GetDropBoxManagerService(
	ctx context.Context,
	sm *servicemanager.ServiceManager,
) (*DropBoxManagerServiceProxy, error)

GetDropBoxManagerService retrieves the DropboxService service and returns a typed proxy.

func NewDropBoxManagerServiceProxy

func NewDropBoxManagerServiceProxy(
	remote binder.IBinder,
) *DropBoxManagerServiceProxy

func (*DropBoxManagerServiceProxy) AddData

func (p *DropBoxManagerServiceProxy) AddData(
	ctx context.Context,
	tag string,
	data []byte,
	flags int32,
) error

func (*DropBoxManagerServiceProxy) AddFile

func (p *DropBoxManagerServiceProxy) AddFile(
	ctx context.Context,
	tag string,
	fd int32,
	flags int32,
) error

func (*DropBoxManagerServiceProxy) AsBinder

func (*DropBoxManagerServiceProxy) GetNextEntry

func (p *DropBoxManagerServiceProxy) GetNextEntry(
	ctx context.Context,
	tag string,
	millis int64,
	packageName string,
) (types.DropBoxManagerEntry, error)

func (*DropBoxManagerServiceProxy) GetNextEntryWithAttribution

func (p *DropBoxManagerServiceProxy) GetNextEntryWithAttribution(
	ctx context.Context,
	tag string,
	millis int64,
	packageName string,
) (types.DropBoxManagerEntry, error)

func (*DropBoxManagerServiceProxy) IsTagEnabled

func (p *DropBoxManagerServiceProxy) IsTagEnabled(
	ctx context.Context,
	tag string,
) (bool, error)

type DropBoxManagerServiceStub

type DropBoxManagerServiceStub struct {
	Impl      IDropBoxManagerService
	Transport binder.VersionAwareTransport
}

DropBoxManagerServiceStub dispatches incoming binder transactions to a typed IDropBoxManagerService implementation.

func (*DropBoxManagerServiceStub) Descriptor

func (s *DropBoxManagerServiceStub) Descriptor() string

func (*DropBoxManagerServiceStub) OnTransaction

func (s *DropBoxManagerServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IBinaryTransparencyService

type IBinaryTransparencyService interface {
	AsBinder() binder.IBinder
	GetSignedImageInfo(ctx context.Context) (string, error)
	RecordMeasurementsForAllPackages(ctx context.Context) error
	CollectAllApexInfo(ctx context.Context, includeTestOnly bool) ([]IBinaryTransparencyServiceApexInfo, error)
	CollectAllUpdatedPreloadInfo(ctx context.Context, packagesToSkip types.Bundle) ([]IBinaryTransparencyServiceAppInfo, error)
	CollectAllSilentInstalledMbaInfo(ctx context.Context, packagesToSkip types.Bundle) ([]IBinaryTransparencyServiceAppInfo, error)
}

func NewBinaryTransparencyServiceStub

func NewBinaryTransparencyServiceStub(
	impl IBinaryTransparencyServiceServer,
) IBinaryTransparencyService

NewBinaryTransparencyServiceStub creates a server-side IBinaryTransparencyService wrapping the given server implementation. The returned value satisfies IBinaryTransparencyService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBinaryTransparencyServiceApexInfo

type IBinaryTransparencyServiceApexInfo struct {
	PackageName     string
	LongVersion     int64
	Digest          []byte
	DigestAlgorithm int32
	SignerDigests   []string
	ModuleName      string
}

func (*IBinaryTransparencyServiceApexInfo) MarshalParcel

func (s *IBinaryTransparencyServiceApexInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IBinaryTransparencyServiceApexInfo) UnmarshalParcel

func (s *IBinaryTransparencyServiceApexInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IBinaryTransparencyServiceAppInfo

type IBinaryTransparencyServiceAppInfo struct {
	PackageName            string
	LongVersion            int64
	SplitName              string
	Digest                 []byte
	DigestAlgorithm        int32
	SignerDigests          []string
	MbaStatus              int32
	Initiator              string
	InitiatorSignerDigests []string
	Installer              string
	Originator             string
}

func (*IBinaryTransparencyServiceAppInfo) MarshalParcel

func (s *IBinaryTransparencyServiceAppInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*IBinaryTransparencyServiceAppInfo) UnmarshalParcel

func (s *IBinaryTransparencyServiceAppInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IBinaryTransparencyServiceServer

type IBinaryTransparencyServiceServer interface {
	GetSignedImageInfo(ctx context.Context) (string, error)
	RecordMeasurementsForAllPackages(ctx context.Context) error
	CollectAllApexInfo(ctx context.Context, includeTestOnly bool) ([]IBinaryTransparencyServiceApexInfo, error)
	CollectAllUpdatedPreloadInfo(ctx context.Context, packagesToSkip types.Bundle) ([]IBinaryTransparencyServiceAppInfo, error)
	CollectAllSilentInstalledMbaInfo(ctx context.Context, packagesToSkip types.Bundle) ([]IBinaryTransparencyServiceAppInfo, error)
}

IBinaryTransparencyServiceServer is the server-side interface that user implementations provide to NewBinaryTransparencyServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IDropBoxManagerService

type IDropBoxManagerService interface {
	AsBinder() binder.IBinder
	AddData(ctx context.Context, tag string, data []byte, flags int32) error
	AddFile(ctx context.Context, tag string, fd int32, flags int32) error
	IsTagEnabled(ctx context.Context, tag string) (bool, error)
	GetNextEntry(ctx context.Context, tag string, millis int64, packageName string) (types.DropBoxManagerEntry, error)
	GetNextEntryWithAttribution(ctx context.Context, tag string, millis int64, packageName string) (types.DropBoxManagerEntry, error)
}

func NewDropBoxManagerServiceStub

func NewDropBoxManagerServiceStub(
	impl IDropBoxManagerServiceServer,
) IDropBoxManagerService

NewDropBoxManagerServiceStub creates a server-side IDropBoxManagerService wrapping the given server implementation. The returned value satisfies IDropBoxManagerService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDropBoxManagerServiceServer

type IDropBoxManagerServiceServer interface {
	AddData(ctx context.Context, tag string, data []byte, flags int32) error
	AddFile(ctx context.Context, tag string, fd int32, flags int32) error
	IsTagEnabled(ctx context.Context, tag string) (bool, error)
	GetNextEntry(ctx context.Context, tag string, millis int64, packageName string) (types.DropBoxManagerEntry, error)
	GetNextEntryWithAttribution(ctx context.Context, tag string, millis int64, packageName string) (types.DropBoxManagerEntry, error)
}

IDropBoxManagerServiceServer is the server-side interface that user implementations provide to NewDropBoxManagerServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IParcelFileDescriptorFactory

type IParcelFileDescriptorFactory interface {
	AsBinder() binder.IBinder
	Open(ctx context.Context, name string, mode int32) (int32, error)
}

func NewParcelFileDescriptorFactoryStub

func NewParcelFileDescriptorFactoryStub(
	impl IParcelFileDescriptorFactoryServer,
) IParcelFileDescriptorFactory

NewParcelFileDescriptorFactoryStub creates a server-side IParcelFileDescriptorFactory wrapping the given server implementation. The returned value satisfies IParcelFileDescriptorFactory and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IParcelFileDescriptorFactoryServer

type IParcelFileDescriptorFactoryServer interface {
	Open(ctx context.Context, name string, mode int32) (int32, error)
}

IParcelFileDescriptorFactoryServer is the server-side interface that user implementations provide to NewParcelFileDescriptorFactoryStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IResultReceiver

type IResultReceiver interface {
	AsBinder() binder.IBinder
	Send(ctx context.Context, resultCode int32, resultData types.Bundle) error
}

func NewResultReceiverStub

func NewResultReceiverStub(
	impl IResultReceiverServer,
) IResultReceiver

NewResultReceiverStub creates a server-side IResultReceiver wrapping the given server implementation. The returned value satisfies IResultReceiver and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IResultReceiverServer

type IResultReceiverServer interface {
	Send(ctx context.Context, resultCode int32, resultData types.Bundle) error
}

IResultReceiverServer is the server-side interface that user implementations provide to NewResultReceiverStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IShellCallback

type IShellCallback interface {
	AsBinder() binder.IBinder
	OpenFile(ctx context.Context, path string, seLinuxContext string, mode string) (int32, error)
}

func NewShellCallbackStub

func NewShellCallbackStub(
	impl IShellCallbackServer,
) IShellCallback

NewShellCallbackStub creates a server-side IShellCallback wrapping the given server implementation. The returned value satisfies IShellCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IShellCallbackServer

type IShellCallbackServer interface {
	OpenFile(ctx context.Context, path string, seLinuxContext string, mode string) (int32, error)
}

IShellCallbackServer is the server-side interface that user implementations provide to NewShellCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ParcelFileDescriptorFactoryProxy

type ParcelFileDescriptorFactoryProxy struct {
	Remote binder.IBinder
}

func NewParcelFileDescriptorFactoryProxy

func NewParcelFileDescriptorFactoryProxy(
	remote binder.IBinder,
) *ParcelFileDescriptorFactoryProxy

func (*ParcelFileDescriptorFactoryProxy) AsBinder

func (*ParcelFileDescriptorFactoryProxy) Open

func (p *ParcelFileDescriptorFactoryProxy) Open(
	ctx context.Context,
	name string,
	mode int32,
) (int32, error)

type ParcelFileDescriptorFactoryStub

type ParcelFileDescriptorFactoryStub struct {
	Impl      IParcelFileDescriptorFactory
	Transport binder.VersionAwareTransport
}

ParcelFileDescriptorFactoryStub dispatches incoming binder transactions to a typed IParcelFileDescriptorFactory implementation.

func (*ParcelFileDescriptorFactoryStub) Descriptor

func (s *ParcelFileDescriptorFactoryStub) Descriptor() string

func (*ParcelFileDescriptorFactoryStub) OnTransaction

type ResultReceiverProxy

type ResultReceiverProxy struct {
	Remote binder.IBinder
}

func NewResultReceiverProxy

func NewResultReceiverProxy(
	remote binder.IBinder,
) *ResultReceiverProxy

func (*ResultReceiverProxy) AsBinder

func (p *ResultReceiverProxy) AsBinder() binder.IBinder

func (*ResultReceiverProxy) Send

func (p *ResultReceiverProxy) Send(
	ctx context.Context,
	resultCode int32,
	resultData types.Bundle,
) error

type ResultReceiverStub

type ResultReceiverStub struct {
	Impl      IResultReceiver
	Transport binder.VersionAwareTransport
}

ResultReceiverStub dispatches incoming binder transactions to a typed IResultReceiver implementation.

func (*ResultReceiverStub) Descriptor

func (s *ResultReceiverStub) Descriptor() string

func (*ResultReceiverStub) OnTransaction

func (s *ResultReceiverStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ShellCallbackProxy

type ShellCallbackProxy struct {
	Remote binder.IBinder
}

func NewShellCallbackProxy

func NewShellCallbackProxy(
	remote binder.IBinder,
) *ShellCallbackProxy

func (*ShellCallbackProxy) AsBinder

func (p *ShellCallbackProxy) AsBinder() binder.IBinder

func (*ShellCallbackProxy) OpenFile

func (p *ShellCallbackProxy) OpenFile(
	ctx context.Context,
	path string,
	seLinuxContext string,
	mode string,
) (int32, error)

type ShellCallbackStub

type ShellCallbackStub struct {
	Impl      IShellCallback
	Transport binder.VersionAwareTransport
}

ShellCallbackStub dispatches incoming binder transactions to a typed IShellCallback implementation.

func (*ShellCallbackStub) Descriptor

func (s *ShellCallbackStub) Descriptor() string

func (*ShellCallbackStub) OnTransaction

func (s *ShellCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to