policy

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIKeyguardDismissCallbackOnDismissError     = binder.FirstCallTransaction + 0
	TransactionIKeyguardDismissCallbackOnDismissSucceeded = binder.FirstCallTransaction + 1
	TransactionIKeyguardDismissCallbackOnDismissCancelled = binder.FirstCallTransaction + 2
)
const (
	MethodIKeyguardDismissCallbackOnDismissError     = "onDismissError"
	MethodIKeyguardDismissCallbackOnDismissSucceeded = "onDismissSucceeded"
	MethodIKeyguardDismissCallbackOnDismissCancelled = "onDismissCancelled"
)
const (
	TransactionIKeyguardServiceSetOccluded                = binder.FirstCallTransaction + 0
	TransactionIKeyguardServiceAddStateMonitorCallback    = binder.FirstCallTransaction + 1
	TransactionIKeyguardServiceVerifyUnlock               = binder.FirstCallTransaction + 2
	TransactionIKeyguardServiceDismiss                    = binder.FirstCallTransaction + 3
	TransactionIKeyguardServiceOnDreamingStarted          = binder.FirstCallTransaction + 4
	TransactionIKeyguardServiceOnDreamingStopped          = binder.FirstCallTransaction + 5
	TransactionIKeyguardServiceOnStartedGoingToSleep      = binder.FirstCallTransaction + 6
	TransactionIKeyguardServiceOnFinishedGoingToSleep     = binder.FirstCallTransaction + 7
	TransactionIKeyguardServiceOnStartedWakingUp          = binder.FirstCallTransaction + 8
	TransactionIKeyguardServiceOnFinishedWakingUp         = binder.FirstCallTransaction + 9
	TransactionIKeyguardServiceOnScreenTurningOn          = binder.FirstCallTransaction + 10
	TransactionIKeyguardServiceOnScreenTurnedOn           = binder.FirstCallTransaction + 11
	TransactionIKeyguardServiceOnScreenTurningOff         = binder.FirstCallTransaction + 12
	TransactionIKeyguardServiceOnScreenTurnedOff          = binder.FirstCallTransaction + 13
	TransactionIKeyguardServiceSetKeyguardEnabled         = binder.FirstCallTransaction + 14
	TransactionIKeyguardServiceOnSystemReady              = binder.FirstCallTransaction + 15
	TransactionIKeyguardServiceDoKeyguardTimeout          = binder.FirstCallTransaction + 16
	TransactionIKeyguardServiceSetSwitchingUser           = binder.FirstCallTransaction + 17
	TransactionIKeyguardServiceSetCurrentUser             = binder.FirstCallTransaction + 18
	TransactionIKeyguardServiceOnBootCompleted            = binder.FirstCallTransaction + 19
	TransactionIKeyguardServiceStartKeyguardExitAnimation = binder.FirstCallTransaction + 20
	TransactionIKeyguardServiceOnShortPowerPressedGoHome  = binder.FirstCallTransaction + 21
	TransactionIKeyguardServiceDismissKeyguardToLaunch    = binder.FirstCallTransaction + 22
	TransactionIKeyguardServiceOnSystemKeyPressed         = binder.FirstCallTransaction + 23
	TransactionIKeyguardServiceShowDismissibleKeyguard    = binder.FirstCallTransaction + 24
)
const (
	MethodIKeyguardServiceSetOccluded                = "setOccluded"
	MethodIKeyguardServiceAddStateMonitorCallback    = "addStateMonitorCallback"
	MethodIKeyguardServiceVerifyUnlock               = "verifyUnlock"
	MethodIKeyguardServiceDismiss                    = "dismiss"
	MethodIKeyguardServiceOnDreamingStarted          = "onDreamingStarted"
	MethodIKeyguardServiceOnDreamingStopped          = "onDreamingStopped"
	MethodIKeyguardServiceOnStartedGoingToSleep      = "onStartedGoingToSleep"
	MethodIKeyguardServiceOnFinishedGoingToSleep     = "onFinishedGoingToSleep"
	MethodIKeyguardServiceOnStartedWakingUp          = "onStartedWakingUp"
	MethodIKeyguardServiceOnFinishedWakingUp         = "onFinishedWakingUp"
	MethodIKeyguardServiceOnScreenTurningOn          = "onScreenTurningOn"
	MethodIKeyguardServiceOnScreenTurnedOn           = "onScreenTurnedOn"
	MethodIKeyguardServiceOnScreenTurningOff         = "onScreenTurningOff"
	MethodIKeyguardServiceOnScreenTurnedOff          = "onScreenTurnedOff"
	MethodIKeyguardServiceSetKeyguardEnabled         = "setKeyguardEnabled"
	MethodIKeyguardServiceOnSystemReady              = "onSystemReady"
	MethodIKeyguardServiceDoKeyguardTimeout          = "doKeyguardTimeout"
	MethodIKeyguardServiceSetSwitchingUser           = "setSwitchingUser"
	MethodIKeyguardServiceSetCurrentUser             = "setCurrentUser"
	MethodIKeyguardServiceOnBootCompleted            = "onBootCompleted"
	MethodIKeyguardServiceStartKeyguardExitAnimation = "startKeyguardExitAnimation"
	MethodIKeyguardServiceOnShortPowerPressedGoHome  = "onShortPowerPressedGoHome"
	MethodIKeyguardServiceDismissKeyguardToLaunch    = "dismissKeyguardToLaunch"
	MethodIKeyguardServiceOnSystemKeyPressed         = "onSystemKeyPressed"
	MethodIKeyguardServiceShowDismissibleKeyguard    = "showDismissibleKeyguard"
)
const (
	TransactionIKeyguardStateCallbackOnShowingStateChanged         = binder.FirstCallTransaction + 0
	TransactionIKeyguardStateCallbackOnSimSecureStateChanged       = binder.FirstCallTransaction + 1
	TransactionIKeyguardStateCallbackOnInputRestrictedStateChanged = binder.FirstCallTransaction + 2
	TransactionIKeyguardStateCallbackOnTrustedChanged              = binder.FirstCallTransaction + 3
)
const (
	MethodIKeyguardStateCallbackOnShowingStateChanged         = "onShowingStateChanged"
	MethodIKeyguardStateCallbackOnSimSecureStateChanged       = "onSimSecureStateChanged"
	MethodIKeyguardStateCallbackOnInputRestrictedStateChanged = "onInputRestrictedStateChanged"
	MethodIKeyguardStateCallbackOnTrustedChanged              = "onTrustedChanged"
)
const DescriptorIKeyguardDismissCallback = "com.android.internal.policy.IKeyguardDismissCallback"
const DescriptorIKeyguardDrawnCallback = "com.android.internal.policy.IKeyguardDrawnCallback"
const DescriptorIKeyguardExitCallback = "com.android.internal.policy.IKeyguardExitCallback"
const DescriptorIKeyguardLockedStateListener = "com.android.internal.policy.IKeyguardLockedStateListener"
const DescriptorIKeyguardService = "com.android.internal.policy.IKeyguardService"
const DescriptorIKeyguardStateCallback = "com.android.internal.policy.IKeyguardStateCallback"
const DescriptorIShortcutService = "com.android.internal.policy.IShortcutService"
const (
	MethodIKeyguardDrawnCallbackOnDrawn = "onDrawn"
)
const (
	MethodIKeyguardExitCallbackOnKeyguardExitResult = "onKeyguardExitResult"
)
const (
	MethodIKeyguardLockedStateListenerOnKeyguardLockedStateChanged = "onKeyguardLockedStateChanged"
)
const (
	MethodIShortcutServiceNotifyShortcutKeyPressed = "notifyShortcutKeyPressed"
)
const (
	TransactionIKeyguardDrawnCallbackOnDrawn = binder.FirstCallTransaction + 0
)
const (
	TransactionIKeyguardExitCallbackOnKeyguardExitResult = binder.FirstCallTransaction + 0
)
const (
	TransactionIKeyguardLockedStateListenerOnKeyguardLockedStateChanged = binder.FirstCallTransaction + 0
)
const (
	TransactionIShortcutServiceNotifyShortcutKeyPressed = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type IKeyguardDismissCallback

type IKeyguardDismissCallback interface {
	AsBinder() binder.IBinder
	OnDismissError(ctx context.Context) error
	OnDismissSucceeded(ctx context.Context) error
	OnDismissCancelled(ctx context.Context) error
}

func NewKeyguardDismissCallbackStub

func NewKeyguardDismissCallbackStub(
	impl IKeyguardDismissCallbackServer,
) IKeyguardDismissCallback

NewKeyguardDismissCallbackStub creates a server-side IKeyguardDismissCallback wrapping the given server implementation. The returned value satisfies IKeyguardDismissCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IKeyguardDismissCallbackServer

type IKeyguardDismissCallbackServer interface {
	OnDismissError(ctx context.Context) error
	OnDismissSucceeded(ctx context.Context) error
	OnDismissCancelled(ctx context.Context) error
}

IKeyguardDismissCallbackServer is the server-side interface that user implementations provide to NewKeyguardDismissCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IKeyguardDrawnCallback

type IKeyguardDrawnCallback interface {
	AsBinder() binder.IBinder
	OnDrawn(ctx context.Context) error
}

func NewKeyguardDrawnCallbackStub

func NewKeyguardDrawnCallbackStub(
	impl IKeyguardDrawnCallbackServer,
) IKeyguardDrawnCallback

NewKeyguardDrawnCallbackStub creates a server-side IKeyguardDrawnCallback wrapping the given server implementation. The returned value satisfies IKeyguardDrawnCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IKeyguardDrawnCallbackServer

type IKeyguardDrawnCallbackServer interface {
	OnDrawn(ctx context.Context) error
}

IKeyguardDrawnCallbackServer is the server-side interface that user implementations provide to NewKeyguardDrawnCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IKeyguardExitCallback

type IKeyguardExitCallback interface {
	AsBinder() binder.IBinder
	OnKeyguardExitResult(ctx context.Context, success bool) error
}

func NewKeyguardExitCallbackStub

func NewKeyguardExitCallbackStub(
	impl IKeyguardExitCallbackServer,
) IKeyguardExitCallback

NewKeyguardExitCallbackStub creates a server-side IKeyguardExitCallback wrapping the given server implementation. The returned value satisfies IKeyguardExitCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IKeyguardExitCallbackServer

type IKeyguardExitCallbackServer interface {
	OnKeyguardExitResult(ctx context.Context, success bool) error
}

IKeyguardExitCallbackServer is the server-side interface that user implementations provide to NewKeyguardExitCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IKeyguardLockedStateListener

type IKeyguardLockedStateListener interface {
	AsBinder() binder.IBinder
	OnKeyguardLockedStateChanged(ctx context.Context, isKeyguardLocked bool) error
}

func NewKeyguardLockedStateListenerStub

func NewKeyguardLockedStateListenerStub(
	impl IKeyguardLockedStateListenerServer,
) IKeyguardLockedStateListener

NewKeyguardLockedStateListenerStub creates a server-side IKeyguardLockedStateListener wrapping the given server implementation. The returned value satisfies IKeyguardLockedStateListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IKeyguardLockedStateListenerServer

type IKeyguardLockedStateListenerServer interface {
	OnKeyguardLockedStateChanged(ctx context.Context, isKeyguardLocked bool) error
}

IKeyguardLockedStateListenerServer is the server-side interface that user implementations provide to NewKeyguardLockedStateListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IKeyguardService

type IKeyguardService interface {
	AsBinder() binder.IBinder
	SetOccluded(ctx context.Context, isOccluded bool, animate bool) error
	AddStateMonitorCallback(ctx context.Context, callback IKeyguardStateCallback) error
	VerifyUnlock(ctx context.Context, callback IKeyguardExitCallback) error
	Dismiss(ctx context.Context, callback IKeyguardDismissCallback, message string) error
	OnDreamingStarted(ctx context.Context) error
	OnDreamingStopped(ctx context.Context) error
	OnStartedGoingToSleep(ctx context.Context, pmSleepReason int32) error
	OnFinishedGoingToSleep(ctx context.Context, pmSleepReason int32, cameraGestureTriggered bool) error
	OnStartedWakingUp(ctx context.Context, pmWakeReason int32, cameraGestureTriggered bool) error
	OnFinishedWakingUp(ctx context.Context) error
	OnScreenTurningOn(ctx context.Context, callback IKeyguardDrawnCallback) error
	OnScreenTurnedOn(ctx context.Context) error
	OnScreenTurningOff(ctx context.Context) error
	OnScreenTurnedOff(ctx context.Context) error
	SetKeyguardEnabled(ctx context.Context, enabled bool) error
	OnSystemReady(ctx context.Context) error
	DoKeyguardTimeout(ctx context.Context, options os.Bundle) error
	SetSwitchingUser(ctx context.Context, switching bool) error
	SetCurrentUser(ctx context.Context) error
	OnBootCompleted(ctx context.Context) error
	StartKeyguardExitAnimation(ctx context.Context, startTime int64, fadeoutDuration int64) error
	OnShortPowerPressedGoHome(ctx context.Context) error
	DismissKeyguardToLaunch(ctx context.Context, intentToLaunch content.Intent) error
	OnSystemKeyPressed(ctx context.Context, keycode int32) error
	ShowDismissibleKeyguard(ctx context.Context) error
}

func NewKeyguardServiceStub

func NewKeyguardServiceStub(
	impl IKeyguardServiceServer,
) IKeyguardService

NewKeyguardServiceStub creates a server-side IKeyguardService wrapping the given server implementation. The returned value satisfies IKeyguardService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IKeyguardServiceServer

type IKeyguardServiceServer interface {
	SetOccluded(ctx context.Context, isOccluded bool, animate bool) error
	AddStateMonitorCallback(ctx context.Context, callback IKeyguardStateCallback) error
	VerifyUnlock(ctx context.Context, callback IKeyguardExitCallback) error
	Dismiss(ctx context.Context, callback IKeyguardDismissCallback, message string) error
	OnDreamingStarted(ctx context.Context) error
	OnDreamingStopped(ctx context.Context) error
	OnStartedGoingToSleep(ctx context.Context, pmSleepReason int32) error
	OnFinishedGoingToSleep(ctx context.Context, pmSleepReason int32, cameraGestureTriggered bool) error
	OnStartedWakingUp(ctx context.Context, pmWakeReason int32, cameraGestureTriggered bool) error
	OnFinishedWakingUp(ctx context.Context) error
	OnScreenTurningOn(ctx context.Context, callback IKeyguardDrawnCallback) error
	OnScreenTurnedOn(ctx context.Context) error
	OnScreenTurningOff(ctx context.Context) error
	OnScreenTurnedOff(ctx context.Context) error
	SetKeyguardEnabled(ctx context.Context, enabled bool) error
	OnSystemReady(ctx context.Context) error
	DoKeyguardTimeout(ctx context.Context, options os.Bundle) error
	SetSwitchingUser(ctx context.Context, switching bool) error
	SetCurrentUser(ctx context.Context) error
	OnBootCompleted(ctx context.Context) error
	StartKeyguardExitAnimation(ctx context.Context, startTime int64, fadeoutDuration int64) error
	OnShortPowerPressedGoHome(ctx context.Context) error
	DismissKeyguardToLaunch(ctx context.Context, intentToLaunch content.Intent) error
	OnSystemKeyPressed(ctx context.Context, keycode int32) error
	ShowDismissibleKeyguard(ctx context.Context) error
}

IKeyguardServiceServer is the server-side interface that user implementations provide to NewKeyguardServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IKeyguardStateCallback

type IKeyguardStateCallback interface {
	AsBinder() binder.IBinder
	OnShowingStateChanged(ctx context.Context, showing bool) error
	OnSimSecureStateChanged(ctx context.Context, simSecure bool) error
	OnInputRestrictedStateChanged(ctx context.Context, inputRestricted bool) error
	OnTrustedChanged(ctx context.Context, trusted bool) error
}

func NewKeyguardStateCallbackStub

func NewKeyguardStateCallbackStub(
	impl IKeyguardStateCallbackServer,
) IKeyguardStateCallback

NewKeyguardStateCallbackStub creates a server-side IKeyguardStateCallback wrapping the given server implementation. The returned value satisfies IKeyguardStateCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IKeyguardStateCallbackServer

type IKeyguardStateCallbackServer interface {
	OnShowingStateChanged(ctx context.Context, showing bool) error
	OnSimSecureStateChanged(ctx context.Context, simSecure bool) error
	OnInputRestrictedStateChanged(ctx context.Context, inputRestricted bool) error
	OnTrustedChanged(ctx context.Context, trusted bool) error
}

IKeyguardStateCallbackServer is the server-side interface that user implementations provide to NewKeyguardStateCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IShortcutService

type IShortcutService interface {
	AsBinder() binder.IBinder
	NotifyShortcutKeyPressed(ctx context.Context, shortcutCode int64) error
}

func NewShortcutServiceStub

func NewShortcutServiceStub(
	impl IShortcutServiceServer,
) IShortcutService

NewShortcutServiceStub creates a server-side IShortcutService wrapping the given server implementation. The returned value satisfies IShortcutService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IShortcutServiceServer

type IShortcutServiceServer interface {
	NotifyShortcutKeyPressed(ctx context.Context, shortcutCode int64) error
}

IShortcutServiceServer is the server-side interface that user implementations provide to NewShortcutServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type KeyguardDismissCallbackProxy

type KeyguardDismissCallbackProxy struct {
	Remote binder.IBinder
}

func NewKeyguardDismissCallbackProxy

func NewKeyguardDismissCallbackProxy(
	remote binder.IBinder,
) *KeyguardDismissCallbackProxy

func (*KeyguardDismissCallbackProxy) AsBinder

func (*KeyguardDismissCallbackProxy) OnDismissCancelled

func (p *KeyguardDismissCallbackProxy) OnDismissCancelled(
	ctx context.Context,
) error

func (*KeyguardDismissCallbackProxy) OnDismissError

func (p *KeyguardDismissCallbackProxy) OnDismissError(
	ctx context.Context,
) error

func (*KeyguardDismissCallbackProxy) OnDismissSucceeded

func (p *KeyguardDismissCallbackProxy) OnDismissSucceeded(
	ctx context.Context,
) error

type KeyguardDismissCallbackStub

type KeyguardDismissCallbackStub struct {
	Impl      IKeyguardDismissCallback
	Transport binder.VersionAwareTransport
}

KeyguardDismissCallbackStub dispatches incoming binder transactions to a typed IKeyguardDismissCallback implementation.

func (*KeyguardDismissCallbackStub) Descriptor

func (s *KeyguardDismissCallbackStub) Descriptor() string

func (*KeyguardDismissCallbackStub) OnTransaction

func (s *KeyguardDismissCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type KeyguardDrawnCallbackProxy

type KeyguardDrawnCallbackProxy struct {
	Remote binder.IBinder
}

func NewKeyguardDrawnCallbackProxy

func NewKeyguardDrawnCallbackProxy(
	remote binder.IBinder,
) *KeyguardDrawnCallbackProxy

func (*KeyguardDrawnCallbackProxy) AsBinder

func (*KeyguardDrawnCallbackProxy) OnDrawn

func (p *KeyguardDrawnCallbackProxy) OnDrawn(
	ctx context.Context,
) error

type KeyguardDrawnCallbackStub

type KeyguardDrawnCallbackStub struct {
	Impl      IKeyguardDrawnCallback
	Transport binder.VersionAwareTransport
}

KeyguardDrawnCallbackStub dispatches incoming binder transactions to a typed IKeyguardDrawnCallback implementation.

func (*KeyguardDrawnCallbackStub) Descriptor

func (s *KeyguardDrawnCallbackStub) Descriptor() string

func (*KeyguardDrawnCallbackStub) OnTransaction

func (s *KeyguardDrawnCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type KeyguardExitCallbackProxy

type KeyguardExitCallbackProxy struct {
	Remote binder.IBinder
}

func NewKeyguardExitCallbackProxy

func NewKeyguardExitCallbackProxy(
	remote binder.IBinder,
) *KeyguardExitCallbackProxy

func (*KeyguardExitCallbackProxy) AsBinder

func (*KeyguardExitCallbackProxy) OnKeyguardExitResult

func (p *KeyguardExitCallbackProxy) OnKeyguardExitResult(
	ctx context.Context,
	success bool,
) error

type KeyguardExitCallbackStub

type KeyguardExitCallbackStub struct {
	Impl      IKeyguardExitCallback
	Transport binder.VersionAwareTransport
}

KeyguardExitCallbackStub dispatches incoming binder transactions to a typed IKeyguardExitCallback implementation.

func (*KeyguardExitCallbackStub) Descriptor

func (s *KeyguardExitCallbackStub) Descriptor() string

func (*KeyguardExitCallbackStub) OnTransaction

func (s *KeyguardExitCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type KeyguardLockedStateListenerProxy

type KeyguardLockedStateListenerProxy struct {
	Remote binder.IBinder
}

func NewKeyguardLockedStateListenerProxy

func NewKeyguardLockedStateListenerProxy(
	remote binder.IBinder,
) *KeyguardLockedStateListenerProxy

func (*KeyguardLockedStateListenerProxy) AsBinder

func (*KeyguardLockedStateListenerProxy) OnKeyguardLockedStateChanged

func (p *KeyguardLockedStateListenerProxy) OnKeyguardLockedStateChanged(
	ctx context.Context,
	isKeyguardLocked bool,
) error

type KeyguardLockedStateListenerStub

type KeyguardLockedStateListenerStub struct {
	Impl      IKeyguardLockedStateListener
	Transport binder.VersionAwareTransport
}

KeyguardLockedStateListenerStub dispatches incoming binder transactions to a typed IKeyguardLockedStateListener implementation.

func (*KeyguardLockedStateListenerStub) Descriptor

func (s *KeyguardLockedStateListenerStub) Descriptor() string

func (*KeyguardLockedStateListenerStub) OnTransaction

type KeyguardServiceProxy

type KeyguardServiceProxy struct {
	Remote binder.IBinder
}

func NewKeyguardServiceProxy

func NewKeyguardServiceProxy(
	remote binder.IBinder,
) *KeyguardServiceProxy

func (*KeyguardServiceProxy) AddStateMonitorCallback

func (p *KeyguardServiceProxy) AddStateMonitorCallback(
	ctx context.Context,
	callback IKeyguardStateCallback,
) error

func (*KeyguardServiceProxy) AsBinder

func (p *KeyguardServiceProxy) AsBinder() binder.IBinder

func (*KeyguardServiceProxy) Dismiss

func (p *KeyguardServiceProxy) Dismiss(
	ctx context.Context,
	callback IKeyguardDismissCallback,
	message string,
) error

func (*KeyguardServiceProxy) DismissKeyguardToLaunch

func (p *KeyguardServiceProxy) DismissKeyguardToLaunch(
	ctx context.Context,
	intentToLaunch content.Intent,
) error

func (*KeyguardServiceProxy) DoKeyguardTimeout

func (p *KeyguardServiceProxy) DoKeyguardTimeout(
	ctx context.Context,
	options os.Bundle,
) error

func (*KeyguardServiceProxy) OnBootCompleted

func (p *KeyguardServiceProxy) OnBootCompleted(
	ctx context.Context,
) error

func (*KeyguardServiceProxy) OnDreamingStarted

func (p *KeyguardServiceProxy) OnDreamingStarted(
	ctx context.Context,
) error

func (*KeyguardServiceProxy) OnDreamingStopped

func (p *KeyguardServiceProxy) OnDreamingStopped(
	ctx context.Context,
) error

func (*KeyguardServiceProxy) OnFinishedGoingToSleep

func (p *KeyguardServiceProxy) OnFinishedGoingToSleep(
	ctx context.Context,
	pmSleepReason int32,
	cameraGestureTriggered bool,
) error

func (*KeyguardServiceProxy) OnFinishedWakingUp

func (p *KeyguardServiceProxy) OnFinishedWakingUp(
	ctx context.Context,
) error

func (*KeyguardServiceProxy) OnScreenTurnedOff

func (p *KeyguardServiceProxy) OnScreenTurnedOff(
	ctx context.Context,
) error

func (*KeyguardServiceProxy) OnScreenTurnedOn

func (p *KeyguardServiceProxy) OnScreenTurnedOn(
	ctx context.Context,
) error

func (*KeyguardServiceProxy) OnScreenTurningOff

func (p *KeyguardServiceProxy) OnScreenTurningOff(
	ctx context.Context,
) error

func (*KeyguardServiceProxy) OnScreenTurningOn

func (p *KeyguardServiceProxy) OnScreenTurningOn(
	ctx context.Context,
	callback IKeyguardDrawnCallback,
) error

func (*KeyguardServiceProxy) OnShortPowerPressedGoHome

func (p *KeyguardServiceProxy) OnShortPowerPressedGoHome(
	ctx context.Context,
) error

func (*KeyguardServiceProxy) OnStartedGoingToSleep

func (p *KeyguardServiceProxy) OnStartedGoingToSleep(
	ctx context.Context,
	pmSleepReason int32,
) error

func (*KeyguardServiceProxy) OnStartedWakingUp

func (p *KeyguardServiceProxy) OnStartedWakingUp(
	ctx context.Context,
	pmWakeReason int32,
	cameraGestureTriggered bool,
) error

func (*KeyguardServiceProxy) OnSystemKeyPressed

func (p *KeyguardServiceProxy) OnSystemKeyPressed(
	ctx context.Context,
	keycode int32,
) error

func (*KeyguardServiceProxy) OnSystemReady

func (p *KeyguardServiceProxy) OnSystemReady(
	ctx context.Context,
) error

func (*KeyguardServiceProxy) SetCurrentUser

func (p *KeyguardServiceProxy) SetCurrentUser(
	ctx context.Context,
) error

func (*KeyguardServiceProxy) SetKeyguardEnabled

func (p *KeyguardServiceProxy) SetKeyguardEnabled(
	ctx context.Context,
	enabled bool,
) error

func (*KeyguardServiceProxy) SetOccluded

func (p *KeyguardServiceProxy) SetOccluded(
	ctx context.Context,
	isOccluded bool,
	animate bool,
) error

func (*KeyguardServiceProxy) SetSwitchingUser

func (p *KeyguardServiceProxy) SetSwitchingUser(
	ctx context.Context,
	switching bool,
) error

func (*KeyguardServiceProxy) ShowDismissibleKeyguard

func (p *KeyguardServiceProxy) ShowDismissibleKeyguard(
	ctx context.Context,
) error

func (*KeyguardServiceProxy) StartKeyguardExitAnimation

func (p *KeyguardServiceProxy) StartKeyguardExitAnimation(
	ctx context.Context,
	startTime int64,
	fadeoutDuration int64,
) error

func (*KeyguardServiceProxy) VerifyUnlock

func (p *KeyguardServiceProxy) VerifyUnlock(
	ctx context.Context,
	callback IKeyguardExitCallback,
) error

type KeyguardServiceStub

type KeyguardServiceStub struct {
	Impl      IKeyguardService
	Transport binder.VersionAwareTransport
}

KeyguardServiceStub dispatches incoming binder transactions to a typed IKeyguardService implementation.

func (*KeyguardServiceStub) Descriptor

func (s *KeyguardServiceStub) Descriptor() string

func (*KeyguardServiceStub) OnTransaction

func (s *KeyguardServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type KeyguardStateCallbackProxy

type KeyguardStateCallbackProxy struct {
	Remote binder.IBinder
}

func NewKeyguardStateCallbackProxy

func NewKeyguardStateCallbackProxy(
	remote binder.IBinder,
) *KeyguardStateCallbackProxy

func (*KeyguardStateCallbackProxy) AsBinder

func (*KeyguardStateCallbackProxy) OnInputRestrictedStateChanged

func (p *KeyguardStateCallbackProxy) OnInputRestrictedStateChanged(
	ctx context.Context,
	inputRestricted bool,
) error

func (*KeyguardStateCallbackProxy) OnShowingStateChanged

func (p *KeyguardStateCallbackProxy) OnShowingStateChanged(
	ctx context.Context,
	showing bool,
) error

func (*KeyguardStateCallbackProxy) OnSimSecureStateChanged

func (p *KeyguardStateCallbackProxy) OnSimSecureStateChanged(
	ctx context.Context,
	simSecure bool,
) error

func (*KeyguardStateCallbackProxy) OnTrustedChanged

func (p *KeyguardStateCallbackProxy) OnTrustedChanged(
	ctx context.Context,
	trusted bool,
) error

type KeyguardStateCallbackStub

type KeyguardStateCallbackStub struct {
	Impl      IKeyguardStateCallback
	Transport binder.VersionAwareTransport
}

KeyguardStateCallbackStub dispatches incoming binder transactions to a typed IKeyguardStateCallback implementation.

func (*KeyguardStateCallbackStub) Descriptor

func (s *KeyguardStateCallbackStub) Descriptor() string

func (*KeyguardStateCallbackStub) OnTransaction

func (s *KeyguardStateCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ShortcutServiceProxy

type ShortcutServiceProxy struct {
	Remote binder.IBinder
}

func NewShortcutServiceProxy

func NewShortcutServiceProxy(
	remote binder.IBinder,
) *ShortcutServiceProxy

func (*ShortcutServiceProxy) AsBinder

func (p *ShortcutServiceProxy) AsBinder() binder.IBinder

func (*ShortcutServiceProxy) NotifyShortcutKeyPressed

func (p *ShortcutServiceProxy) NotifyShortcutKeyPressed(
	ctx context.Context,
	shortcutCode int64,
) error

type ShortcutServiceStub

type ShortcutServiceStub struct {
	Impl      IShortcutService
	Transport binder.VersionAwareTransport
}

ShortcutServiceStub dispatches incoming binder transactions to a typed IShortcutService implementation.

func (*ShortcutServiceStub) Descriptor

func (s *ShortcutServiceStub) Descriptor() string

func (*ShortcutServiceStub) OnTransaction

func (s *ShortcutServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to