inline

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIInlineContentCallbackOnContent   = binder.FirstCallTransaction + 0
	TransactionIInlineContentCallbackOnClick     = binder.FirstCallTransaction + 1
	TransactionIInlineContentCallbackOnLongClick = binder.FirstCallTransaction + 2
)
const (
	MethodIInlineContentCallbackOnContent   = "onContent"
	MethodIInlineContentCallbackOnClick     = "onClick"
	MethodIInlineContentCallbackOnLongClick = "onLongClick"
)
const (
	TransactionIInlineContentProviderProvideContent           = binder.FirstCallTransaction + 0
	TransactionIInlineContentProviderRequestSurfacePackage    = binder.FirstCallTransaction + 1
	TransactionIInlineContentProviderOnSurfacePackageReleased = binder.FirstCallTransaction + 2
)
const (
	MethodIInlineContentProviderProvideContent           = "provideContent"
	MethodIInlineContentProviderRequestSurfacePackage    = "requestSurfacePackage"
	MethodIInlineContentProviderOnSurfacePackageReleased = "onSurfacePackageReleased"
)
const DescriptorIInlineContentCallback = "com.android.internal.view.inline.IInlineContentCallback"
const DescriptorIInlineContentProvider = "com.android.internal.view.inline.IInlineContentProvider"

Variables

This section is empty.

Functions

This section is empty.

Types

type IInlineContentCallback

type IInlineContentCallback interface {
	AsBinder() binder.IBinder
	OnContent(ctx context.Context, content view.SurfaceControlViewHostSurfacePackage, width int32, height int32) error
	OnClick(ctx context.Context) error
	OnLongClick(ctx context.Context) error
}

func NewInlineContentCallbackStub

func NewInlineContentCallbackStub(
	impl IInlineContentCallbackServer,
) IInlineContentCallback

NewInlineContentCallbackStub creates a server-side IInlineContentCallback wrapping the given server implementation. The returned value satisfies IInlineContentCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IInlineContentCallbackServer

type IInlineContentCallbackServer interface {
	OnContent(ctx context.Context, content view.SurfaceControlViewHostSurfacePackage, width int32, height int32) error
	OnClick(ctx context.Context) error
	OnLongClick(ctx context.Context) error
}

IInlineContentCallbackServer is the server-side interface that user implementations provide to NewInlineContentCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IInlineContentProvider

type IInlineContentProvider interface {
	AsBinder() binder.IBinder
	ProvideContent(ctx context.Context, width int32, height int32, callback IInlineContentCallback) error
	RequestSurfacePackage(ctx context.Context) error
	OnSurfacePackageReleased(ctx context.Context) error
}

func NewInlineContentProviderStub

func NewInlineContentProviderStub(
	impl IInlineContentProviderServer,
) IInlineContentProvider

NewInlineContentProviderStub creates a server-side IInlineContentProvider wrapping the given server implementation. The returned value satisfies IInlineContentProvider and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IInlineContentProviderServer

type IInlineContentProviderServer interface {
	ProvideContent(ctx context.Context, width int32, height int32, callback IInlineContentCallback) error
	RequestSurfacePackage(ctx context.Context) error
	OnSurfacePackageReleased(ctx context.Context) error
}

IInlineContentProviderServer is the server-side interface that user implementations provide to NewInlineContentProviderStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type InlineContentCallbackProxy

type InlineContentCallbackProxy struct {
	Remote binder.IBinder
}

func NewInlineContentCallbackProxy

func NewInlineContentCallbackProxy(
	remote binder.IBinder,
) *InlineContentCallbackProxy

func (*InlineContentCallbackProxy) AsBinder

func (*InlineContentCallbackProxy) OnClick

func (p *InlineContentCallbackProxy) OnClick(
	ctx context.Context,
) error

func (*InlineContentCallbackProxy) OnContent

func (*InlineContentCallbackProxy) OnLongClick

func (p *InlineContentCallbackProxy) OnLongClick(
	ctx context.Context,
) error

type InlineContentCallbackStub

type InlineContentCallbackStub struct {
	Impl      IInlineContentCallback
	Transport binder.VersionAwareTransport
}

InlineContentCallbackStub dispatches incoming binder transactions to a typed IInlineContentCallback implementation.

func (*InlineContentCallbackStub) Descriptor

func (s *InlineContentCallbackStub) Descriptor() string

func (*InlineContentCallbackStub) OnTransaction

func (s *InlineContentCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type InlineContentProviderProxy

type InlineContentProviderProxy struct {
	Remote binder.IBinder
}

func NewInlineContentProviderProxy

func NewInlineContentProviderProxy(
	remote binder.IBinder,
) *InlineContentProviderProxy

func (*InlineContentProviderProxy) AsBinder

func (*InlineContentProviderProxy) OnSurfacePackageReleased

func (p *InlineContentProviderProxy) OnSurfacePackageReleased(
	ctx context.Context,
) error

func (*InlineContentProviderProxy) ProvideContent

func (p *InlineContentProviderProxy) ProvideContent(
	ctx context.Context,
	width int32,
	height int32,
	callback IInlineContentCallback,
) error

func (*InlineContentProviderProxy) RequestSurfacePackage

func (p *InlineContentProviderProxy) RequestSurfacePackage(
	ctx context.Context,
) error

type InlineContentProviderStub

type InlineContentProviderStub struct {
	Impl      IInlineContentProvider
	Transport binder.VersionAwareTransport
}

InlineContentProviderStub dispatches incoming binder transactions to a typed IInlineContentProvider implementation.

func (*InlineContentProviderStub) Descriptor

func (s *InlineContentProviderStub) Descriptor() string

func (*InlineContentProviderStub) OnTransaction

func (s *InlineContentProviderStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to