net

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIProxyServiceResolvePacFile = binder.FirstCallTransaction + 0
	TransactionIProxyServiceSetPacFile     = binder.FirstCallTransaction + 1
)
const (
	MethodIProxyServiceResolvePacFile = "resolvePacFile"
	MethodIProxyServiceSetPacFile     = "setPacFile"
)
const DescriptorIProxyCallback = "com.android.net.IProxyCallback"
const DescriptorIProxyPortListener = "com.android.net.IProxyPortListener"
const DescriptorIProxyService = "com.android.net.IProxyService"
const (
	MethodIProxyCallbackGetProxyPort = "getProxyPort"
)
const (
	MethodIProxyPortListenerSetProxyPort = "setProxyPort"
)
const (
	TransactionIProxyCallbackGetProxyPort = binder.FirstCallTransaction + 0
)
const (
	TransactionIProxyPortListenerSetProxyPort = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type IProxyCallback

type IProxyCallback interface {
	AsBinder() binder.IBinder
	GetProxyPort(ctx context.Context, callback binder.IBinder) error
}

func NewProxyCallbackStub

func NewProxyCallbackStub(
	impl IProxyCallbackServer,
) IProxyCallback

NewProxyCallbackStub creates a server-side IProxyCallback wrapping the given server implementation. The returned value satisfies IProxyCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IProxyCallbackServer

type IProxyCallbackServer interface {
	GetProxyPort(ctx context.Context, callback binder.IBinder) error
}

IProxyCallbackServer is the server-side interface that user implementations provide to NewProxyCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IProxyPortListener

type IProxyPortListener interface {
	AsBinder() binder.IBinder
	SetProxyPort(ctx context.Context, port int32) error
}

func NewProxyPortListenerStub

func NewProxyPortListenerStub(
	impl IProxyPortListenerServer,
) IProxyPortListener

NewProxyPortListenerStub creates a server-side IProxyPortListener wrapping the given server implementation. The returned value satisfies IProxyPortListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IProxyPortListenerServer

type IProxyPortListenerServer interface {
	SetProxyPort(ctx context.Context, port int32) error
}

IProxyPortListenerServer is the server-side interface that user implementations provide to NewProxyPortListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IProxyService

type IProxyService interface {
	AsBinder() binder.IBinder
	ResolvePacFile(ctx context.Context, host string, url string) (string, error)
	SetPacFile(ctx context.Context, scriptContents string) error
}

func NewProxyServiceStub

func NewProxyServiceStub(
	impl IProxyServiceServer,
) IProxyService

NewProxyServiceStub creates a server-side IProxyService wrapping the given server implementation. The returned value satisfies IProxyService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IProxyServiceServer

type IProxyServiceServer interface {
	ResolvePacFile(ctx context.Context, host string, url string) (string, error)
	SetPacFile(ctx context.Context, scriptContents string) error
}

IProxyServiceServer is the server-side interface that user implementations provide to NewProxyServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ProxyCallbackProxy

type ProxyCallbackProxy struct {
	Remote binder.IBinder
}

func NewProxyCallbackProxy

func NewProxyCallbackProxy(
	remote binder.IBinder,
) *ProxyCallbackProxy

func (*ProxyCallbackProxy) AsBinder

func (p *ProxyCallbackProxy) AsBinder() binder.IBinder

func (*ProxyCallbackProxy) GetProxyPort

func (p *ProxyCallbackProxy) GetProxyPort(
	ctx context.Context,
	callback binder.IBinder,
) error

type ProxyCallbackStub

type ProxyCallbackStub struct {
	Impl      IProxyCallback
	Transport binder.VersionAwareTransport
}

ProxyCallbackStub dispatches incoming binder transactions to a typed IProxyCallback implementation.

func (*ProxyCallbackStub) Descriptor

func (s *ProxyCallbackStub) Descriptor() string

func (*ProxyCallbackStub) OnTransaction

func (s *ProxyCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ProxyPortListenerProxy

type ProxyPortListenerProxy struct {
	Remote binder.IBinder
}

func NewProxyPortListenerProxy

func NewProxyPortListenerProxy(
	remote binder.IBinder,
) *ProxyPortListenerProxy

func (*ProxyPortListenerProxy) AsBinder

func (p *ProxyPortListenerProxy) AsBinder() binder.IBinder

func (*ProxyPortListenerProxy) SetProxyPort

func (p *ProxyPortListenerProxy) SetProxyPort(
	ctx context.Context,
	port int32,
) error

type ProxyPortListenerStub

type ProxyPortListenerStub struct {
	Impl      IProxyPortListener
	Transport binder.VersionAwareTransport
}

ProxyPortListenerStub dispatches incoming binder transactions to a typed IProxyPortListener implementation.

func (*ProxyPortListenerStub) Descriptor

func (s *ProxyPortListenerStub) Descriptor() string

func (*ProxyPortListenerStub) OnTransaction

func (s *ProxyPortListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ProxyServiceProxy

type ProxyServiceProxy struct {
	Remote binder.IBinder
}

func NewProxyServiceProxy

func NewProxyServiceProxy(
	remote binder.IBinder,
) *ProxyServiceProxy

func (*ProxyServiceProxy) AsBinder

func (p *ProxyServiceProxy) AsBinder() binder.IBinder

func (*ProxyServiceProxy) ResolvePacFile

func (p *ProxyServiceProxy) ResolvePacFile(
	ctx context.Context,
	host string,
	url string,
) (string, error)

func (*ProxyServiceProxy) SetPacFile

func (p *ProxyServiceProxy) SetPacFile(
	ctx context.Context,
	scriptContents string,
) error

type ProxyServiceStub

type ProxyServiceStub struct {
	Impl      IProxyService
	Transport binder.VersionAwareTransport
}

ProxyServiceStub dispatches incoming binder transactions to a typed IProxyService implementation.

func (*ProxyServiceStub) Descriptor

func (s *ProxyServiceStub) Descriptor() string

func (*ProxyServiceStub) OnTransaction

func (s *ProxyServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to