screenshot

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIScreenshotProxyIsNotificationShadeExpanded = binder.FirstCallTransaction + 0
	TransactionIScreenshotProxyDismissKeyguard             = binder.FirstCallTransaction + 1
)
const (
	MethodIScreenshotProxyIsNotificationShadeExpanded = "isNotificationShadeExpanded"
	MethodIScreenshotProxyDismissKeyguard             = "dismissKeyguard"
)
const DescriptorICrossProfileService = "com.android.systemui.screenshot.ICrossProfileService"
const DescriptorIOnDoneCallback = "com.android.systemui.screenshot.IOnDoneCallback"
const DescriptorIScreenshotProxy = "com.android.systemui.screenshot.IScreenshotProxy"
const (
	MethodICrossProfileServiceLaunchIntent = "launchIntent"
)
const (
	MethodIOnDoneCallbackOnDone = "onDone"
)
const (
	TransactionICrossProfileServiceLaunchIntent = binder.FirstCallTransaction + 0
)
const (
	TransactionIOnDoneCallbackOnDone = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type CrossProfileServiceProxy

type CrossProfileServiceProxy struct {
	Remote binder.IBinder
}

func NewCrossProfileServiceProxy

func NewCrossProfileServiceProxy(
	remote binder.IBinder,
) *CrossProfileServiceProxy

func (*CrossProfileServiceProxy) AsBinder

func (p *CrossProfileServiceProxy) AsBinder() binder.IBinder

func (*CrossProfileServiceProxy) LaunchIntent

func (p *CrossProfileServiceProxy) LaunchIntent(
	ctx context.Context,
	intent content.Intent,
	bundle os.Bundle,
) error

type CrossProfileServiceStub

type CrossProfileServiceStub struct {
	Impl      ICrossProfileService
	Transport binder.VersionAwareTransport
}

CrossProfileServiceStub dispatches incoming binder transactions to a typed ICrossProfileService implementation.

func (*CrossProfileServiceStub) Descriptor

func (s *CrossProfileServiceStub) Descriptor() string

func (*CrossProfileServiceStub) OnTransaction

func (s *CrossProfileServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ICrossProfileService

type ICrossProfileService interface {
	AsBinder() binder.IBinder
	LaunchIntent(ctx context.Context, intent content.Intent, bundle os.Bundle) error
}

func NewCrossProfileServiceStub

func NewCrossProfileServiceStub(
	impl ICrossProfileServiceServer,
) ICrossProfileService

NewCrossProfileServiceStub creates a server-side ICrossProfileService wrapping the given server implementation. The returned value satisfies ICrossProfileService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ICrossProfileServiceServer

type ICrossProfileServiceServer interface {
	LaunchIntent(ctx context.Context, intent content.Intent, bundle os.Bundle) error
}

ICrossProfileServiceServer is the server-side interface that user implementations provide to NewCrossProfileServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IOnDoneCallback

type IOnDoneCallback interface {
	AsBinder() binder.IBinder
	OnDone(ctx context.Context, success bool) error
}

func NewOnDoneCallbackStub

func NewOnDoneCallbackStub(
	impl IOnDoneCallbackServer,
) IOnDoneCallback

NewOnDoneCallbackStub creates a server-side IOnDoneCallback wrapping the given server implementation. The returned value satisfies IOnDoneCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IOnDoneCallbackServer

type IOnDoneCallbackServer interface {
	OnDone(ctx context.Context, success bool) error
}

IOnDoneCallbackServer is the server-side interface that user implementations provide to NewOnDoneCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IScreenshotProxy

type IScreenshotProxy interface {
	AsBinder() binder.IBinder
	IsNotificationShadeExpanded(ctx context.Context) (bool, error)
	DismissKeyguard(ctx context.Context, callback IOnDoneCallback) error
}

func NewScreenshotProxyStub

func NewScreenshotProxyStub(
	impl IScreenshotProxyServer,
) IScreenshotProxy

NewScreenshotProxyStub creates a server-side IScreenshotProxy wrapping the given server implementation. The returned value satisfies IScreenshotProxy and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IScreenshotProxyServer

type IScreenshotProxyServer interface {
	IsNotificationShadeExpanded(ctx context.Context) (bool, error)
	DismissKeyguard(ctx context.Context, callback IOnDoneCallback) error
}

IScreenshotProxyServer is the server-side interface that user implementations provide to NewScreenshotProxyStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type OnDoneCallbackProxy

type OnDoneCallbackProxy struct {
	Remote binder.IBinder
}

func NewOnDoneCallbackProxy

func NewOnDoneCallbackProxy(
	remote binder.IBinder,
) *OnDoneCallbackProxy

func (*OnDoneCallbackProxy) AsBinder

func (p *OnDoneCallbackProxy) AsBinder() binder.IBinder

func (*OnDoneCallbackProxy) OnDone

func (p *OnDoneCallbackProxy) OnDone(
	ctx context.Context,
	success bool,
) error

type OnDoneCallbackStub

type OnDoneCallbackStub struct {
	Impl      IOnDoneCallback
	Transport binder.VersionAwareTransport
}

OnDoneCallbackStub dispatches incoming binder transactions to a typed IOnDoneCallback implementation.

func (*OnDoneCallbackStub) Descriptor

func (s *OnDoneCallbackStub) Descriptor() string

func (*OnDoneCallbackStub) OnTransaction

func (s *OnDoneCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ScreenshotProxyProxy

type ScreenshotProxyProxy struct {
	Remote binder.IBinder
}

func NewScreenshotProxyProxy

func NewScreenshotProxyProxy(
	remote binder.IBinder,
) *ScreenshotProxyProxy

func (*ScreenshotProxyProxy) AsBinder

func (p *ScreenshotProxyProxy) AsBinder() binder.IBinder

func (*ScreenshotProxyProxy) DismissKeyguard

func (p *ScreenshotProxyProxy) DismissKeyguard(
	ctx context.Context,
	callback IOnDoneCallback,
) error

func (*ScreenshotProxyProxy) IsNotificationShadeExpanded

func (p *ScreenshotProxyProxy) IsNotificationShadeExpanded(
	ctx context.Context,
) (bool, error)

type ScreenshotProxyStub

type ScreenshotProxyStub struct {
	Impl      IScreenshotProxy
	Transport binder.VersionAwareTransport
}

ScreenshotProxyStub dispatches incoming binder transactions to a typed IScreenshotProxy implementation.

func (*ScreenshotProxyStub) Descriptor

func (s *ScreenshotProxyStub) Descriptor() string

func (*ScreenshotProxyStub) OnTransaction

func (s *ScreenshotProxyStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Directories

Path Synopsis

Jump to