controller

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIWalletContextualLocationsServiceAddWalletCardsUpdatedListener           = binder.FirstCallTransaction + 0
	TransactionIWalletContextualLocationsServiceOnWalletContextualLocationsStateUpdated = binder.FirstCallTransaction + 1
)
const (
	MethodIWalletContextualLocationsServiceAddWalletCardsUpdatedListener           = "addWalletCardsUpdatedListener"
	MethodIWalletContextualLocationsServiceOnWalletContextualLocationsStateUpdated = "onWalletContextualLocationsStateUpdated"
)
const DescriptorIWalletCardsUpdatedListener = "com.android.systemui.wallet.controller.IWalletCardsUpdatedListener"
const DescriptorIWalletContextualLocationsService = "com.android.systemui.wallet.controller.IWalletContextualLocationsService"
const (
	MethodIWalletCardsUpdatedListenerRegisterNewWalletCards = "registerNewWalletCards"
)
const (
	TransactionIWalletCardsUpdatedListenerRegisterNewWalletCards = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type IWalletCardsUpdatedListener

type IWalletCardsUpdatedListener interface {
	AsBinder() binder.IBinder
	RegisterNewWalletCards(ctx context.Context, cards []quickaccesswallet.WalletCard) error
}

func NewWalletCardsUpdatedListenerStub

func NewWalletCardsUpdatedListenerStub(
	impl IWalletCardsUpdatedListenerServer,
) IWalletCardsUpdatedListener

NewWalletCardsUpdatedListenerStub creates a server-side IWalletCardsUpdatedListener wrapping the given server implementation. The returned value satisfies IWalletCardsUpdatedListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IWalletCardsUpdatedListenerServer

type IWalletCardsUpdatedListenerServer interface {
	RegisterNewWalletCards(ctx context.Context, cards []quickaccesswallet.WalletCard) error
}

IWalletCardsUpdatedListenerServer is the server-side interface that user implementations provide to NewWalletCardsUpdatedListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IWalletContextualLocationsService

type IWalletContextualLocationsService interface {
	AsBinder() binder.IBinder
	AddWalletCardsUpdatedListener(ctx context.Context, listener IWalletCardsUpdatedListener) error
	OnWalletContextualLocationsStateUpdated(ctx context.Context, storeLocations []string) error
}

func NewWalletContextualLocationsServiceStub

func NewWalletContextualLocationsServiceStub(
	impl IWalletContextualLocationsServiceServer,
) IWalletContextualLocationsService

NewWalletContextualLocationsServiceStub creates a server-side IWalletContextualLocationsService wrapping the given server implementation. The returned value satisfies IWalletContextualLocationsService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IWalletContextualLocationsServiceServer

type IWalletContextualLocationsServiceServer interface {
	AddWalletCardsUpdatedListener(ctx context.Context, listener IWalletCardsUpdatedListener) error
	OnWalletContextualLocationsStateUpdated(ctx context.Context, storeLocations []string) error
}

IWalletContextualLocationsServiceServer is the server-side interface that user implementations provide to NewWalletContextualLocationsServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type WalletCardsUpdatedListenerProxy

type WalletCardsUpdatedListenerProxy struct {
	Remote binder.IBinder
}

func NewWalletCardsUpdatedListenerProxy

func NewWalletCardsUpdatedListenerProxy(
	remote binder.IBinder,
) *WalletCardsUpdatedListenerProxy

func (*WalletCardsUpdatedListenerProxy) AsBinder

func (*WalletCardsUpdatedListenerProxy) RegisterNewWalletCards

func (p *WalletCardsUpdatedListenerProxy) RegisterNewWalletCards(
	ctx context.Context,
	cards []quickaccesswallet.WalletCard,
) error

type WalletCardsUpdatedListenerStub

type WalletCardsUpdatedListenerStub struct {
	Impl      IWalletCardsUpdatedListener
	Transport binder.VersionAwareTransport
}

WalletCardsUpdatedListenerStub dispatches incoming binder transactions to a typed IWalletCardsUpdatedListener implementation.

func (*WalletCardsUpdatedListenerStub) Descriptor

func (s *WalletCardsUpdatedListenerStub) Descriptor() string

func (*WalletCardsUpdatedListenerStub) OnTransaction

type WalletContextualLocationsServiceProxy

type WalletContextualLocationsServiceProxy struct {
	Remote binder.IBinder
}

func NewWalletContextualLocationsServiceProxy

func NewWalletContextualLocationsServiceProxy(
	remote binder.IBinder,
) *WalletContextualLocationsServiceProxy

func (*WalletContextualLocationsServiceProxy) AddWalletCardsUpdatedListener

func (p *WalletContextualLocationsServiceProxy) AddWalletCardsUpdatedListener(
	ctx context.Context,
	listener IWalletCardsUpdatedListener,
) error

func (*WalletContextualLocationsServiceProxy) AsBinder

func (*WalletContextualLocationsServiceProxy) OnWalletContextualLocationsStateUpdated

func (p *WalletContextualLocationsServiceProxy) OnWalletContextualLocationsStateUpdated(
	ctx context.Context,
	storeLocations []string,
) error

type WalletContextualLocationsServiceStub

type WalletContextualLocationsServiceStub struct {
	Impl      IWalletContextualLocationsService
	Transport binder.VersionAwareTransport
}

WalletContextualLocationsServiceStub dispatches incoming binder transactions to a typed IWalletContextualLocationsService implementation.

func (*WalletContextualLocationsServiceStub) Descriptor

func (*WalletContextualLocationsServiceStub) OnTransaction

Jump to