viewembed

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIAttachEmbeddedWindowAttachEmbedded                 = binder.FirstCallTransaction + 0
	TransactionIAttachEmbeddedWindowRelayout                       = binder.FirstCallTransaction + 1
	TransactionIAttachEmbeddedWindowAttachEmbeddedSurfaceControl   = binder.FirstCallTransaction + 2
	TransactionIAttachEmbeddedWindowTearDownEmbeddedSurfaceControl = binder.FirstCallTransaction + 3
)
const (
	MethodIAttachEmbeddedWindowAttachEmbedded                 = "attachEmbedded"
	MethodIAttachEmbeddedWindowRelayout                       = "relayout"
	MethodIAttachEmbeddedWindowAttachEmbeddedSurfaceControl   = "attachEmbeddedSurfaceControl"
	MethodIAttachEmbeddedWindowTearDownEmbeddedSurfaceControl = "tearDownEmbeddedSurfaceControl"
)
const DescriptorIAttachEmbeddedWindow = "com.android.test.viewembed.IAttachEmbeddedWindow"
const DescriptorIAttachEmbeddedWindowCallback = "com.android.test.viewembed.IAttachEmbeddedWindowCallback"
const (
	MethodIAttachEmbeddedWindowCallbackOnEmbeddedWindowAttached = "onEmbeddedWindowAttached"
)
const (
	TransactionIAttachEmbeddedWindowCallbackOnEmbeddedWindowAttached = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type AttachEmbeddedWindowCallbackProxy

type AttachEmbeddedWindowCallbackProxy struct {
	Remote binder.IBinder
}

func NewAttachEmbeddedWindowCallbackProxy

func NewAttachEmbeddedWindowCallbackProxy(
	remote binder.IBinder,
) *AttachEmbeddedWindowCallbackProxy

func (*AttachEmbeddedWindowCallbackProxy) AsBinder

func (*AttachEmbeddedWindowCallbackProxy) OnEmbeddedWindowAttached

func (p *AttachEmbeddedWindowCallbackProxy) OnEmbeddedWindowAttached(
	ctx context.Context,
	surfacePackage view.SurfaceControlViewHostSurfacePackage,
) error

type AttachEmbeddedWindowCallbackStub

type AttachEmbeddedWindowCallbackStub struct {
	Impl      IAttachEmbeddedWindowCallback
	Transport binder.VersionAwareTransport
}

AttachEmbeddedWindowCallbackStub dispatches incoming binder transactions to a typed IAttachEmbeddedWindowCallback implementation.

func (*AttachEmbeddedWindowCallbackStub) Descriptor

func (s *AttachEmbeddedWindowCallbackStub) Descriptor() string

func (*AttachEmbeddedWindowCallbackStub) OnTransaction

type AttachEmbeddedWindowProxy

type AttachEmbeddedWindowProxy struct {
	Remote binder.IBinder
}

func NewAttachEmbeddedWindowProxy

func NewAttachEmbeddedWindowProxy(
	remote binder.IBinder,
) *AttachEmbeddedWindowProxy

func (*AttachEmbeddedWindowProxy) AsBinder

func (*AttachEmbeddedWindowProxy) AttachEmbedded

func (p *AttachEmbeddedWindowProxy) AttachEmbedded(
	ctx context.Context,
	hostToken binder.IBinder,
	width int32,
	height int32,
	callback IAttachEmbeddedWindowCallback,
) error

func (*AttachEmbeddedWindowProxy) AttachEmbeddedSurfaceControl

func (p *AttachEmbeddedWindowProxy) AttachEmbeddedSurfaceControl(
	ctx context.Context,
	parentSurfaceControl view.SurfaceControl,
	displayId int32,
	inputTransferToken window.InputTransferToken,
) error

func (*AttachEmbeddedWindowProxy) Relayout

func (*AttachEmbeddedWindowProxy) TearDownEmbeddedSurfaceControl

func (p *AttachEmbeddedWindowProxy) TearDownEmbeddedSurfaceControl(
	ctx context.Context,
) error

type AttachEmbeddedWindowStub

type AttachEmbeddedWindowStub struct {
	Impl      IAttachEmbeddedWindow
	Transport binder.VersionAwareTransport
}

AttachEmbeddedWindowStub dispatches incoming binder transactions to a typed IAttachEmbeddedWindow implementation.

func (*AttachEmbeddedWindowStub) Descriptor

func (s *AttachEmbeddedWindowStub) Descriptor() string

func (*AttachEmbeddedWindowStub) OnTransaction

func (s *AttachEmbeddedWindowStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IAttachEmbeddedWindow

type IAttachEmbeddedWindow interface {
	AsBinder() binder.IBinder
	AttachEmbedded(ctx context.Context, hostToken binder.IBinder, width int32, height int32, callback IAttachEmbeddedWindowCallback) error
	Relayout(ctx context.Context, lp view.WindowManagerLayoutParams) error
	AttachEmbeddedSurfaceControl(ctx context.Context, parentSurfaceControl view.SurfaceControl, displayId int32, inputTransferToken window.InputTransferToken) error
	TearDownEmbeddedSurfaceControl(ctx context.Context) error
}

func NewAttachEmbeddedWindowStub

func NewAttachEmbeddedWindowStub(
	impl IAttachEmbeddedWindowServer,
) IAttachEmbeddedWindow

NewAttachEmbeddedWindowStub creates a server-side IAttachEmbeddedWindow wrapping the given server implementation. The returned value satisfies IAttachEmbeddedWindow and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IAttachEmbeddedWindowCallback

type IAttachEmbeddedWindowCallback interface {
	AsBinder() binder.IBinder
	OnEmbeddedWindowAttached(ctx context.Context, surfacePackage view.SurfaceControlViewHostSurfacePackage) error
}

func NewAttachEmbeddedWindowCallbackStub

func NewAttachEmbeddedWindowCallbackStub(
	impl IAttachEmbeddedWindowCallbackServer,
) IAttachEmbeddedWindowCallback

NewAttachEmbeddedWindowCallbackStub creates a server-side IAttachEmbeddedWindowCallback wrapping the given server implementation. The returned value satisfies IAttachEmbeddedWindowCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IAttachEmbeddedWindowCallbackServer

type IAttachEmbeddedWindowCallbackServer interface {
	OnEmbeddedWindowAttached(ctx context.Context, surfacePackage view.SurfaceControlViewHostSurfacePackage) error
}

IAttachEmbeddedWindowCallbackServer is the server-side interface that user implementations provide to NewAttachEmbeddedWindowCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IAttachEmbeddedWindowServer

type IAttachEmbeddedWindowServer interface {
	AttachEmbedded(ctx context.Context, hostToken binder.IBinder, width int32, height int32, callback IAttachEmbeddedWindowCallback) error
	Relayout(ctx context.Context, lp view.WindowManagerLayoutParams) error
	AttachEmbeddedSurfaceControl(ctx context.Context, parentSurfaceControl view.SurfaceControl, displayId int32, inputTransferToken window.InputTransferToken) error
	TearDownEmbeddedSurfaceControl(ctx context.Context) error
}

IAttachEmbeddedWindowServer is the server-side interface that user implementations provide to NewAttachEmbeddedWindowStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

Jump to