bubbles

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIBubblesRegisterBubbleListener   = binder.FirstCallTransaction + 0
	TransactionIBubblesUnregisterBubbleListener = binder.FirstCallTransaction + 1
	TransactionIBubblesShowBubble               = binder.FirstCallTransaction + 2
	TransactionIBubblesRemoveBubble             = binder.FirstCallTransaction + 3
	TransactionIBubblesRemoveAllBubbles         = binder.FirstCallTransaction + 4
	TransactionIBubblesCollapseBubbles          = binder.FirstCallTransaction + 5
	TransactionIBubblesOnBubbleDrag             = binder.FirstCallTransaction + 6
	TransactionIBubblesShowUserEducation        = binder.FirstCallTransaction + 7
)
const (
	MethodIBubblesRegisterBubbleListener   = "registerBubbleListener"
	MethodIBubblesUnregisterBubbleListener = "unregisterBubbleListener"
	MethodIBubblesShowBubble               = "showBubble"
	MethodIBubblesRemoveBubble             = "removeBubble"
	MethodIBubblesRemoveAllBubbles         = "removeAllBubbles"
	MethodIBubblesCollapseBubbles          = "collapseBubbles"
	MethodIBubblesOnBubbleDrag             = "onBubbleDrag"
	MethodIBubblesShowUserEducation        = "showUserEducation"
)
const DescriptorIBubbles = "com.android.wm.shell.bubbles.IBubbles"
const DescriptorIBubblesListener = "com.android.wm.shell.bubbles.IBubblesListener"
const (
	MethodIBubblesListenerOnBubbleStateChange = "onBubbleStateChange"
)
const (
	TransactionIBubblesListenerOnBubbleStateChange = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type BubblesListenerProxy

type BubblesListenerProxy struct {
	Remote binder.IBinder
}

func NewBubblesListenerProxy

func NewBubblesListenerProxy(
	remote binder.IBinder,
) *BubblesListenerProxy

func (*BubblesListenerProxy) AsBinder

func (p *BubblesListenerProxy) AsBinder() binder.IBinder

func (*BubblesListenerProxy) OnBubbleStateChange

func (p *BubblesListenerProxy) OnBubbleStateChange(
	ctx context.Context,
	update os.Bundle,
) error

type BubblesListenerStub

type BubblesListenerStub struct {
	Impl      IBubblesListener
	Transport binder.VersionAwareTransport
}

BubblesListenerStub dispatches incoming binder transactions to a typed IBubblesListener implementation.

func (*BubblesListenerStub) Descriptor

func (s *BubblesListenerStub) Descriptor() string

func (*BubblesListenerStub) OnTransaction

func (s *BubblesListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type BubblesProxy

type BubblesProxy struct {
	Remote binder.IBinder
}

func NewBubblesProxy

func NewBubblesProxy(
	remote binder.IBinder,
) *BubblesProxy

func (*BubblesProxy) AsBinder

func (p *BubblesProxy) AsBinder() binder.IBinder

func (*BubblesProxy) CollapseBubbles

func (p *BubblesProxy) CollapseBubbles(
	ctx context.Context,
) error

func (*BubblesProxy) OnBubbleDrag

func (p *BubblesProxy) OnBubbleDrag(
	ctx context.Context,
	key string,
	isBeingDragged bool,
) error

func (*BubblesProxy) RegisterBubbleListener

func (p *BubblesProxy) RegisterBubbleListener(
	ctx context.Context,
	listener IBubblesListener,
) error

func (*BubblesProxy) RemoveAllBubbles

func (p *BubblesProxy) RemoveAllBubbles(
	ctx context.Context,
) error

func (*BubblesProxy) RemoveBubble

func (p *BubblesProxy) RemoveBubble(
	ctx context.Context,
	key string,
) error

func (*BubblesProxy) ShowBubble

func (p *BubblesProxy) ShowBubble(
	ctx context.Context,
	key string,
	bubbleBarBounds graphics.Rect,
) error

func (*BubblesProxy) ShowUserEducation

func (p *BubblesProxy) ShowUserEducation(
	ctx context.Context,
	positionX int32,
	positionY int32,
) error

func (*BubblesProxy) UnregisterBubbleListener

func (p *BubblesProxy) UnregisterBubbleListener(
	ctx context.Context,
	listener IBubblesListener,
) error

type BubblesStub

type BubblesStub struct {
	Impl      IBubbles
	Transport binder.VersionAwareTransport
}

BubblesStub dispatches incoming binder transactions to a typed IBubbles implementation.

func (*BubblesStub) Descriptor

func (s *BubblesStub) Descriptor() string

func (*BubblesStub) OnTransaction

func (s *BubblesStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IBubbles

type IBubbles interface {
	AsBinder() binder.IBinder
	RegisterBubbleListener(ctx context.Context, listener IBubblesListener) error
	UnregisterBubbleListener(ctx context.Context, listener IBubblesListener) error
	ShowBubble(ctx context.Context, key string, bubbleBarBounds graphics.Rect) error
	RemoveBubble(ctx context.Context, key string) error
	RemoveAllBubbles(ctx context.Context) error
	CollapseBubbles(ctx context.Context) error
	OnBubbleDrag(ctx context.Context, key string, isBeingDragged bool) error
	ShowUserEducation(ctx context.Context, positionX int32, positionY int32) error
}

func NewBubblesStub

func NewBubblesStub(
	impl IBubblesServer,
) IBubbles

NewBubblesStub creates a server-side IBubbles wrapping the given server implementation. The returned value satisfies IBubbles and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBubblesListener

type IBubblesListener interface {
	AsBinder() binder.IBinder
	OnBubbleStateChange(ctx context.Context, update os.Bundle) error
}

func NewBubblesListenerStub

func NewBubblesListenerStub(
	impl IBubblesListenerServer,
) IBubblesListener

NewBubblesListenerStub creates a server-side IBubblesListener wrapping the given server implementation. The returned value satisfies IBubblesListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBubblesListenerServer

type IBubblesListenerServer interface {
	OnBubbleStateChange(ctx context.Context, update os.Bundle) error
}

IBubblesListenerServer is the server-side interface that user implementations provide to NewBubblesListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IBubblesServer

type IBubblesServer interface {
	RegisterBubbleListener(ctx context.Context, listener IBubblesListener) error
	UnregisterBubbleListener(ctx context.Context, listener IBubblesListener) error
	ShowBubble(ctx context.Context, key string, bubbleBarBounds graphics.Rect) error
	RemoveBubble(ctx context.Context, key string) error
	RemoveAllBubbles(ctx context.Context) error
	CollapseBubbles(ctx context.Context) error
	OnBubbleDrag(ctx context.Context, key string, isBeingDragged bool) error
	ShowUserEducation(ctx context.Context, positionX int32, positionY int32) error
}

IBubblesServer is the server-side interface that user implementations provide to NewBubblesStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

Jump to