desktopmode

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIDesktopModeShowDesktopApps                  = binder.FirstCallTransaction + 0
	TransactionIDesktopModeStashDesktopApps                 = binder.FirstCallTransaction + 1
	TransactionIDesktopModeHideStashedDesktopApps           = binder.FirstCallTransaction + 2
	TransactionIDesktopModeShowDesktopApp                   = binder.FirstCallTransaction + 3
	TransactionIDesktopModeGetVisibleTaskCount              = binder.FirstCallTransaction + 4
	TransactionIDesktopModeOnDesktopSplitSelectAnimComplete = binder.FirstCallTransaction + 5
	TransactionIDesktopModeSetTaskListener                  = binder.FirstCallTransaction + 6
)
const (
	MethodIDesktopModeShowDesktopApps                  = "showDesktopApps"
	MethodIDesktopModeStashDesktopApps                 = "stashDesktopApps"
	MethodIDesktopModeHideStashedDesktopApps           = "hideStashedDesktopApps"
	MethodIDesktopModeShowDesktopApp                   = "showDesktopApp"
	MethodIDesktopModeGetVisibleTaskCount              = "getVisibleTaskCount"
	MethodIDesktopModeOnDesktopSplitSelectAnimComplete = "onDesktopSplitSelectAnimComplete"
	MethodIDesktopModeSetTaskListener                  = "setTaskListener"
)
const (
	TransactionIDesktopTaskListenerOnTasksVisibilityChanged = binder.FirstCallTransaction + 0
	TransactionIDesktopTaskListenerOnStashedChanged         = binder.FirstCallTransaction + 1
)
const (
	MethodIDesktopTaskListenerOnTasksVisibilityChanged = "onTasksVisibilityChanged"
	MethodIDesktopTaskListenerOnStashedChanged         = "onStashedChanged"
)
const DescriptorIDesktopMode = "com.android.wm.shell.desktopmode.IDesktopMode"
const DescriptorIDesktopTaskListener = "com.android.wm.shell.desktopmode.IDesktopTaskListener"

Variables

This section is empty.

Functions

This section is empty.

Types

type DesktopModeProxy

type DesktopModeProxy struct {
	Remote binder.IBinder
}

func NewDesktopModeProxy

func NewDesktopModeProxy(
	remote binder.IBinder,
) *DesktopModeProxy

func (*DesktopModeProxy) AsBinder

func (p *DesktopModeProxy) AsBinder() binder.IBinder

func (*DesktopModeProxy) GetVisibleTaskCount

func (p *DesktopModeProxy) GetVisibleTaskCount(
	ctx context.Context,
	displayId int32,
) (int32, error)

func (*DesktopModeProxy) HideStashedDesktopApps

func (p *DesktopModeProxy) HideStashedDesktopApps(
	ctx context.Context,
	displayId int32,
) error

func (*DesktopModeProxy) OnDesktopSplitSelectAnimComplete

func (p *DesktopModeProxy) OnDesktopSplitSelectAnimComplete(
	ctx context.Context,
	taskInfo app.ActivityManagerRunningTaskInfo,
) error

func (*DesktopModeProxy) SetTaskListener

func (p *DesktopModeProxy) SetTaskListener(
	ctx context.Context,
	listener IDesktopTaskListener,
) error

func (*DesktopModeProxy) ShowDesktopApp

func (p *DesktopModeProxy) ShowDesktopApp(
	ctx context.Context,
	taskId int32,
) error

func (*DesktopModeProxy) ShowDesktopApps

func (p *DesktopModeProxy) ShowDesktopApps(
	ctx context.Context,
	displayId int32,
	remoteTransition window.RemoteTransition,
) error

func (*DesktopModeProxy) StashDesktopApps

func (p *DesktopModeProxy) StashDesktopApps(
	ctx context.Context,
	displayId int32,
) error

type DesktopModeStub

type DesktopModeStub struct {
	Impl      IDesktopMode
	Transport binder.VersionAwareTransport
}

DesktopModeStub dispatches incoming binder transactions to a typed IDesktopMode implementation.

func (*DesktopModeStub) Descriptor

func (s *DesktopModeStub) Descriptor() string

func (*DesktopModeStub) OnTransaction

func (s *DesktopModeStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type DesktopTaskListenerProxy

type DesktopTaskListenerProxy struct {
	Remote binder.IBinder
}

func NewDesktopTaskListenerProxy

func NewDesktopTaskListenerProxy(
	remote binder.IBinder,
) *DesktopTaskListenerProxy

func (*DesktopTaskListenerProxy) AsBinder

func (p *DesktopTaskListenerProxy) AsBinder() binder.IBinder

func (*DesktopTaskListenerProxy) OnStashedChanged

func (p *DesktopTaskListenerProxy) OnStashedChanged(
	ctx context.Context,
	displayId int32,
	stashed bool,
) error

func (*DesktopTaskListenerProxy) OnTasksVisibilityChanged

func (p *DesktopTaskListenerProxy) OnTasksVisibilityChanged(
	ctx context.Context,
	displayId int32,
	visibleTasksCount int32,
) error

type DesktopTaskListenerStub

type DesktopTaskListenerStub struct {
	Impl      IDesktopTaskListener
	Transport binder.VersionAwareTransport
}

DesktopTaskListenerStub dispatches incoming binder transactions to a typed IDesktopTaskListener implementation.

func (*DesktopTaskListenerStub) Descriptor

func (s *DesktopTaskListenerStub) Descriptor() string

func (*DesktopTaskListenerStub) OnTransaction

func (s *DesktopTaskListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IDesktopMode

type IDesktopMode interface {
	AsBinder() binder.IBinder
	ShowDesktopApps(ctx context.Context, displayId int32, remoteTransition window.RemoteTransition) error
	StashDesktopApps(ctx context.Context, displayId int32) error
	HideStashedDesktopApps(ctx context.Context, displayId int32) error
	ShowDesktopApp(ctx context.Context, taskId int32) error
	GetVisibleTaskCount(ctx context.Context, displayId int32) (int32, error)
	OnDesktopSplitSelectAnimComplete(ctx context.Context, taskInfo app.ActivityManagerRunningTaskInfo) error
	SetTaskListener(ctx context.Context, listener IDesktopTaskListener) error
}

func NewDesktopModeStub

func NewDesktopModeStub(
	impl IDesktopModeServer,
) IDesktopMode

NewDesktopModeStub creates a server-side IDesktopMode wrapping the given server implementation. The returned value satisfies IDesktopMode and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDesktopModeServer

type IDesktopModeServer interface {
	ShowDesktopApps(ctx context.Context, displayId int32, remoteTransition window.RemoteTransition) error
	StashDesktopApps(ctx context.Context, displayId int32) error
	HideStashedDesktopApps(ctx context.Context, displayId int32) error
	ShowDesktopApp(ctx context.Context, taskId int32) error
	GetVisibleTaskCount(ctx context.Context, displayId int32) (int32, error)
	OnDesktopSplitSelectAnimComplete(ctx context.Context, taskInfo app.ActivityManagerRunningTaskInfo) error
	SetTaskListener(ctx context.Context, listener IDesktopTaskListener) error
}

IDesktopModeServer is the server-side interface that user implementations provide to NewDesktopModeStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IDesktopTaskListener

type IDesktopTaskListener interface {
	AsBinder() binder.IBinder
	OnTasksVisibilityChanged(ctx context.Context, displayId int32, visibleTasksCount int32) error
	OnStashedChanged(ctx context.Context, displayId int32, stashed bool) error
}

func NewDesktopTaskListenerStub

func NewDesktopTaskListenerStub(
	impl IDesktopTaskListenerServer,
) IDesktopTaskListener

NewDesktopTaskListenerStub creates a server-side IDesktopTaskListener wrapping the given server implementation. The returned value satisfies IDesktopTaskListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDesktopTaskListenerServer

type IDesktopTaskListenerServer interface {
	OnTasksVisibilityChanged(ctx context.Context, displayId int32, visibleTasksCount int32) error
	OnStashedChanged(ctx context.Context, displayId int32, stashed bool) error
}

IDesktopTaskListenerServer is the server-side interface that user implementations provide to NewDesktopTaskListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

Jump to