splitscreen

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

const (
	TransactionISplitScreenRegisterSplitScreenListener              = binder.FirstCallTransaction + 0
	TransactionISplitScreenUnregisterSplitScreenListener            = binder.FirstCallTransaction + 1
	TransactionISplitScreenRegisterSplitSelectListener              = binder.FirstCallTransaction + 19
	TransactionISplitScreenUnregisterSplitSelectListener            = binder.FirstCallTransaction + 20
	TransactionISplitScreenRemoveFromSideStage                      = binder.FirstCallTransaction + 3
	TransactionISplitScreenExitSplitScreen                          = binder.FirstCallTransaction + 4
	TransactionISplitScreenExitSplitScreenOnHide                    = binder.FirstCallTransaction + 5
	TransactionISplitScreenStartTask                                = binder.FirstCallTransaction + 6
	TransactionISplitScreenStartShortcut                            = binder.FirstCallTransaction + 7
	TransactionISplitScreenStartIntent                              = binder.FirstCallTransaction + 8
	TransactionISplitScreenStartTasks                               = binder.FirstCallTransaction + 9
	TransactionISplitScreenStartIntentAndTask                       = binder.FirstCallTransaction + 15
	TransactionISplitScreenStartShortcutAndTask                     = binder.FirstCallTransaction + 16
	TransactionISplitScreenStartTasksWithLegacyTransition           = binder.FirstCallTransaction + 10
	TransactionISplitScreenStartIntentAndTaskWithLegacyTransition   = binder.FirstCallTransaction + 11
	TransactionISplitScreenStartShortcutAndTaskWithLegacyTransition = binder.FirstCallTransaction + 14
	TransactionISplitScreenStartIntentsWithLegacyTransition         = binder.FirstCallTransaction + 17
	TransactionISplitScreenStartIntents                             = binder.FirstCallTransaction + 18
	TransactionISplitScreenOnGoingToRecentsLegacy                   = binder.FirstCallTransaction + 12
	TransactionISplitScreenOnStartingSplitLegacy                    = binder.FirstCallTransaction + 13
	TransactionISplitScreenSwitchSplitPosition                      = binder.FirstCallTransaction + 21
)
const (
	MethodISplitScreenRegisterSplitScreenListener              = "registerSplitScreenListener"
	MethodISplitScreenUnregisterSplitScreenListener            = "unregisterSplitScreenListener"
	MethodISplitScreenRegisterSplitSelectListener              = "registerSplitSelectListener"
	MethodISplitScreenUnregisterSplitSelectListener            = "unregisterSplitSelectListener"
	MethodISplitScreenRemoveFromSideStage                      = "removeFromSideStage"
	MethodISplitScreenExitSplitScreen                          = "exitSplitScreen"
	MethodISplitScreenExitSplitScreenOnHide                    = "exitSplitScreenOnHide"
	MethodISplitScreenStartTask                                = "startTask"
	MethodISplitScreenStartShortcut                            = "startShortcut"
	MethodISplitScreenStartIntent                              = "startIntent"
	MethodISplitScreenStartTasks                               = "startTasks"
	MethodISplitScreenStartIntentAndTask                       = "startIntentAndTask"
	MethodISplitScreenStartShortcutAndTask                     = "startShortcutAndTask"
	MethodISplitScreenStartTasksWithLegacyTransition           = "startTasksWithLegacyTransition"
	MethodISplitScreenStartIntentAndTaskWithLegacyTransition   = "startIntentAndTaskWithLegacyTransition"
	MethodISplitScreenStartShortcutAndTaskWithLegacyTransition = "startShortcutAndTaskWithLegacyTransition"
	MethodISplitScreenStartIntentsWithLegacyTransition         = "startIntentsWithLegacyTransition"
	MethodISplitScreenStartIntents                             = "startIntents"
	MethodISplitScreenOnGoingToRecentsLegacy                   = "onGoingToRecentsLegacy"
	MethodISplitScreenOnStartingSplitLegacy                    = "onStartingSplitLegacy"
	MethodISplitScreenSwitchSplitPosition                      = "switchSplitPosition"
)
const (
	TransactionISplitScreenListenerOnStagePositionChanged = binder.FirstCallTransaction + 0
	TransactionISplitScreenListenerOnTaskStageChanged     = binder.FirstCallTransaction + 1
)
const (
	MethodISplitScreenListenerOnStagePositionChanged = "onStagePositionChanged"
	MethodISplitScreenListenerOnTaskStageChanged     = "onTaskStageChanged"
)
const DescriptorISplitScreen = "com.android.wm.shell.splitscreen.ISplitScreen"
const DescriptorISplitScreenListener = "com.android.wm.shell.splitscreen.ISplitScreenListener"
const DescriptorISplitSelectListener = "com.android.wm.shell.splitscreen.ISplitSelectListener"
const (
	MethodISplitSelectListenerOnRequestSplitSelect = "onRequestSplitSelect"
)
const (
	TransactionISplitSelectListenerOnRequestSplitSelect = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type ISplitScreen

type ISplitScreen interface {
	AsBinder() binder.IBinder
	RegisterSplitScreenListener(ctx context.Context, listener ISplitScreenListener) error
	UnregisterSplitScreenListener(ctx context.Context, listener ISplitScreenListener) error
	RegisterSplitSelectListener(ctx context.Context, listener ISplitSelectListener) error
	UnregisterSplitSelectListener(ctx context.Context, listener ISplitSelectListener) error
	RemoveFromSideStage(ctx context.Context, taskId int32) error
	ExitSplitScreen(ctx context.Context, toTopTaskId int32) error
	ExitSplitScreenOnHide(ctx context.Context, exitSplitScreenOnHide bool) error
	StartTask(ctx context.Context, taskId int32, position int32, options os.Bundle) error
	StartShortcut(ctx context.Context, packageName string, shortcutId string, position int32, options os.Bundle, user os.UserHandle, instanceId logging.InstanceId) error
	StartIntent(ctx context.Context, intent app.PendingIntent, fillInIntent content.Intent, position int32, options os.Bundle, instanceId logging.InstanceId) error
	StartTasks(ctx context.Context, taskId1 int32, options1 os.Bundle, taskId2 int32, options2 os.Bundle, splitPosition int32, snapPosition int32, remoteTransition window.RemoteTransition, instanceId logging.InstanceId) error
	StartIntentAndTask(ctx context.Context, pendingIntent app.PendingIntent, userId1 int32, options1 os.Bundle, taskId int32, options2 os.Bundle, sidePosition int32, snapPosition int32, remoteTransition window.RemoteTransition, instanceId logging.InstanceId) error
	StartShortcutAndTask(ctx context.Context, shortcutInfo pm.ShortcutInfo, options1 os.Bundle, taskId int32, options2 os.Bundle, splitPosition int32, snapPosition int32, remoteTransition window.RemoteTransition, instanceId logging.InstanceId) error
	StartTasksWithLegacyTransition(ctx context.Context, taskId1 int32, options1 os.Bundle, taskId2 int32, options2 os.Bundle, splitPosition int32, snapPosition int32, adapter view.RemoteAnimationAdapter, instanceId logging.InstanceId) error
	StartIntentAndTaskWithLegacyTransition(ctx context.Context, pendingIntent app.PendingIntent, userId1 int32, options1 os.Bundle, taskId int32, options2 os.Bundle, splitPosition int32, snapPosition int32, adapter view.RemoteAnimationAdapter, instanceId logging.InstanceId) error
	StartShortcutAndTaskWithLegacyTransition(ctx context.Context, shortcutInfo pm.ShortcutInfo, options1 os.Bundle, taskId int32, options2 os.Bundle, splitPosition int32, snapPosition int32, adapter view.RemoteAnimationAdapter, instanceId logging.InstanceId) error
	StartIntentsWithLegacyTransition(ctx context.Context, pendingIntent1 app.PendingIntent, userId1 int32, shortcutInfo1 pm.ShortcutInfo, options1 os.Bundle, pendingIntent2 app.PendingIntent, userId2 int32, shortcutInfo2 pm.ShortcutInfo, options2 os.Bundle, splitPosition int32, snapPosition int32, adapter view.RemoteAnimationAdapter, instanceId logging.InstanceId) error
	StartIntents(ctx context.Context, pendingIntent1 app.PendingIntent, userId1 int32, shortcutInfo1 pm.ShortcutInfo, options1 os.Bundle, pendingIntent2 app.PendingIntent, userId2 int32, shortcutInfo2 pm.ShortcutInfo, options2 os.Bundle, splitPosition int32, snapPosition int32, remoteTransition window.RemoteTransition, instanceId logging.InstanceId) error
	OnGoingToRecentsLegacy(ctx context.Context, appTargets []view.RemoteAnimationTarget) ([]view.RemoteAnimationTarget, error)
	OnStartingSplitLegacy(ctx context.Context, appTargets []view.RemoteAnimationTarget) ([]view.RemoteAnimationTarget, error)
	SwitchSplitPosition(ctx context.Context) error
}

func NewSplitScreenStub

func NewSplitScreenStub(
	impl ISplitScreenServer,
) ISplitScreen

NewSplitScreenStub creates a server-side ISplitScreen wrapping the given server implementation. The returned value satisfies ISplitScreen and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISplitScreenListener

type ISplitScreenListener interface {
	AsBinder() binder.IBinder
	OnStagePositionChanged(ctx context.Context, stage int32, position int32) error
	OnTaskStageChanged(ctx context.Context, taskId int32, stage int32, visible bool) error
}

func NewSplitScreenListenerStub

func NewSplitScreenListenerStub(
	impl ISplitScreenListenerServer,
) ISplitScreenListener

NewSplitScreenListenerStub creates a server-side ISplitScreenListener wrapping the given server implementation. The returned value satisfies ISplitScreenListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISplitScreenListenerServer

type ISplitScreenListenerServer interface {
	OnStagePositionChanged(ctx context.Context, stage int32, position int32) error
	OnTaskStageChanged(ctx context.Context, taskId int32, stage int32, visible bool) error
}

ISplitScreenListenerServer is the server-side interface that user implementations provide to NewSplitScreenListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISplitScreenServer

type ISplitScreenServer interface {
	RegisterSplitScreenListener(ctx context.Context, listener ISplitScreenListener) error
	UnregisterSplitScreenListener(ctx context.Context, listener ISplitScreenListener) error
	RegisterSplitSelectListener(ctx context.Context, listener ISplitSelectListener) error
	UnregisterSplitSelectListener(ctx context.Context, listener ISplitSelectListener) error
	RemoveFromSideStage(ctx context.Context, taskId int32) error
	ExitSplitScreen(ctx context.Context, toTopTaskId int32) error
	ExitSplitScreenOnHide(ctx context.Context, exitSplitScreenOnHide bool) error
	StartTask(ctx context.Context, taskId int32, position int32, options os.Bundle) error
	StartShortcut(ctx context.Context, packageName string, shortcutId string, position int32, options os.Bundle, user os.UserHandle, instanceId logging.InstanceId) error
	StartIntent(ctx context.Context, intent app.PendingIntent, fillInIntent content.Intent, position int32, options os.Bundle, instanceId logging.InstanceId) error
	StartTasks(ctx context.Context, taskId1 int32, options1 os.Bundle, taskId2 int32, options2 os.Bundle, splitPosition int32, snapPosition int32, remoteTransition window.RemoteTransition, instanceId logging.InstanceId) error
	StartIntentAndTask(ctx context.Context, pendingIntent app.PendingIntent, userId1 int32, options1 os.Bundle, taskId int32, options2 os.Bundle, sidePosition int32, snapPosition int32, remoteTransition window.RemoteTransition, instanceId logging.InstanceId) error
	StartShortcutAndTask(ctx context.Context, shortcutInfo pm.ShortcutInfo, options1 os.Bundle, taskId int32, options2 os.Bundle, splitPosition int32, snapPosition int32, remoteTransition window.RemoteTransition, instanceId logging.InstanceId) error
	StartTasksWithLegacyTransition(ctx context.Context, taskId1 int32, options1 os.Bundle, taskId2 int32, options2 os.Bundle, splitPosition int32, snapPosition int32, adapter view.RemoteAnimationAdapter, instanceId logging.InstanceId) error
	StartIntentAndTaskWithLegacyTransition(ctx context.Context, pendingIntent app.PendingIntent, userId1 int32, options1 os.Bundle, taskId int32, options2 os.Bundle, splitPosition int32, snapPosition int32, adapter view.RemoteAnimationAdapter, instanceId logging.InstanceId) error
	StartShortcutAndTaskWithLegacyTransition(ctx context.Context, shortcutInfo pm.ShortcutInfo, options1 os.Bundle, taskId int32, options2 os.Bundle, splitPosition int32, snapPosition int32, adapter view.RemoteAnimationAdapter, instanceId logging.InstanceId) error
	StartIntentsWithLegacyTransition(ctx context.Context, pendingIntent1 app.PendingIntent, userId1 int32, shortcutInfo1 pm.ShortcutInfo, options1 os.Bundle, pendingIntent2 app.PendingIntent, userId2 int32, shortcutInfo2 pm.ShortcutInfo, options2 os.Bundle, splitPosition int32, snapPosition int32, adapter view.RemoteAnimationAdapter, instanceId logging.InstanceId) error
	StartIntents(ctx context.Context, pendingIntent1 app.PendingIntent, userId1 int32, shortcutInfo1 pm.ShortcutInfo, options1 os.Bundle, pendingIntent2 app.PendingIntent, userId2 int32, shortcutInfo2 pm.ShortcutInfo, options2 os.Bundle, splitPosition int32, snapPosition int32, remoteTransition window.RemoteTransition, instanceId logging.InstanceId) error
	OnGoingToRecentsLegacy(ctx context.Context, appTargets []view.RemoteAnimationTarget) ([]view.RemoteAnimationTarget, error)
	OnStartingSplitLegacy(ctx context.Context, appTargets []view.RemoteAnimationTarget) ([]view.RemoteAnimationTarget, error)
	SwitchSplitPosition(ctx context.Context) error
}

ISplitScreenServer is the server-side interface that user implementations provide to NewSplitScreenStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISplitSelectListener

type ISplitSelectListener interface {
	AsBinder() binder.IBinder
	OnRequestSplitSelect(ctx context.Context, taskInfo app.ActivityManagerRunningTaskInfo, splitPosition int32, taskBounds graphics.Rect) (bool, error)
}

func NewSplitSelectListenerStub

func NewSplitSelectListenerStub(
	impl ISplitSelectListenerServer,
) ISplitSelectListener

NewSplitSelectListenerStub creates a server-side ISplitSelectListener wrapping the given server implementation. The returned value satisfies ISplitSelectListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISplitSelectListenerServer

type ISplitSelectListenerServer interface {
	OnRequestSplitSelect(ctx context.Context, taskInfo app.ActivityManagerRunningTaskInfo, splitPosition int32, taskBounds graphics.Rect) (bool, error)
}

ISplitSelectListenerServer is the server-side interface that user implementations provide to NewSplitSelectListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type SplitScreenListenerProxy

type SplitScreenListenerProxy struct {
	Remote binder.IBinder
}

func NewSplitScreenListenerProxy

func NewSplitScreenListenerProxy(
	remote binder.IBinder,
) *SplitScreenListenerProxy

func (*SplitScreenListenerProxy) AsBinder

func (p *SplitScreenListenerProxy) AsBinder() binder.IBinder

func (*SplitScreenListenerProxy) OnStagePositionChanged

func (p *SplitScreenListenerProxy) OnStagePositionChanged(
	ctx context.Context,
	stage int32,
	position int32,
) error

func (*SplitScreenListenerProxy) OnTaskStageChanged

func (p *SplitScreenListenerProxy) OnTaskStageChanged(
	ctx context.Context,
	taskId int32,
	stage int32,
	visible bool,
) error

type SplitScreenListenerStub

type SplitScreenListenerStub struct {
	Impl      ISplitScreenListener
	Transport binder.VersionAwareTransport
}

SplitScreenListenerStub dispatches incoming binder transactions to a typed ISplitScreenListener implementation.

func (*SplitScreenListenerStub) Descriptor

func (s *SplitScreenListenerStub) Descriptor() string

func (*SplitScreenListenerStub) OnTransaction

func (s *SplitScreenListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type SplitScreenProxy

type SplitScreenProxy struct {
	Remote binder.IBinder
}

func NewSplitScreenProxy

func NewSplitScreenProxy(
	remote binder.IBinder,
) *SplitScreenProxy

func (*SplitScreenProxy) AsBinder

func (p *SplitScreenProxy) AsBinder() binder.IBinder

func (*SplitScreenProxy) ExitSplitScreen

func (p *SplitScreenProxy) ExitSplitScreen(
	ctx context.Context,
	toTopTaskId int32,
) error

func (*SplitScreenProxy) ExitSplitScreenOnHide

func (p *SplitScreenProxy) ExitSplitScreenOnHide(
	ctx context.Context,
	exitSplitScreenOnHide bool,
) error

func (*SplitScreenProxy) OnGoingToRecentsLegacy

func (p *SplitScreenProxy) OnGoingToRecentsLegacy(
	ctx context.Context,
	appTargets []view.RemoteAnimationTarget,
) ([]view.RemoteAnimationTarget, error)

func (*SplitScreenProxy) OnStartingSplitLegacy

func (p *SplitScreenProxy) OnStartingSplitLegacy(
	ctx context.Context,
	appTargets []view.RemoteAnimationTarget,
) ([]view.RemoteAnimationTarget, error)

func (*SplitScreenProxy) RegisterSplitScreenListener

func (p *SplitScreenProxy) RegisterSplitScreenListener(
	ctx context.Context,
	listener ISplitScreenListener,
) error

func (*SplitScreenProxy) RegisterSplitSelectListener

func (p *SplitScreenProxy) RegisterSplitSelectListener(
	ctx context.Context,
	listener ISplitSelectListener,
) error

func (*SplitScreenProxy) RemoveFromSideStage

func (p *SplitScreenProxy) RemoveFromSideStage(
	ctx context.Context,
	taskId int32,
) error

func (*SplitScreenProxy) StartIntent

func (p *SplitScreenProxy) StartIntent(
	ctx context.Context,
	intent app.PendingIntent,
	fillInIntent content.Intent,
	position int32,
	options os.Bundle,
	instanceId logging.InstanceId,
) error

func (*SplitScreenProxy) StartIntentAndTask

func (p *SplitScreenProxy) StartIntentAndTask(
	ctx context.Context,
	pendingIntent app.PendingIntent,
	userId1 int32,
	options1 os.Bundle,
	taskId int32,
	options2 os.Bundle,
	sidePosition int32,
	snapPosition int32,
	remoteTransition window.RemoteTransition,
	instanceId logging.InstanceId,
) error

func (*SplitScreenProxy) StartIntentAndTaskWithLegacyTransition

func (p *SplitScreenProxy) StartIntentAndTaskWithLegacyTransition(
	ctx context.Context,
	pendingIntent app.PendingIntent,
	userId1 int32,
	options1 os.Bundle,
	taskId int32,
	options2 os.Bundle,
	splitPosition int32,
	snapPosition int32,
	adapter view.RemoteAnimationAdapter,
	instanceId logging.InstanceId,
) error

func (*SplitScreenProxy) StartIntents

func (p *SplitScreenProxy) StartIntents(
	ctx context.Context,
	pendingIntent1 app.PendingIntent,
	userId1 int32,
	shortcutInfo1 pm.ShortcutInfo,
	options1 os.Bundle,
	pendingIntent2 app.PendingIntent,
	userId2 int32,
	shortcutInfo2 pm.ShortcutInfo,
	options2 os.Bundle,
	splitPosition int32,
	snapPosition int32,
	remoteTransition window.RemoteTransition,
	instanceId logging.InstanceId,
) error

func (*SplitScreenProxy) StartIntentsWithLegacyTransition

func (p *SplitScreenProxy) StartIntentsWithLegacyTransition(
	ctx context.Context,
	pendingIntent1 app.PendingIntent,
	userId1 int32,
	shortcutInfo1 pm.ShortcutInfo,
	options1 os.Bundle,
	pendingIntent2 app.PendingIntent,
	userId2 int32,
	shortcutInfo2 pm.ShortcutInfo,
	options2 os.Bundle,
	splitPosition int32,
	snapPosition int32,
	adapter view.RemoteAnimationAdapter,
	instanceId logging.InstanceId,
) error

func (*SplitScreenProxy) StartShortcut

func (p *SplitScreenProxy) StartShortcut(
	ctx context.Context,
	packageName string,
	shortcutId string,
	position int32,
	options os.Bundle,
	user os.UserHandle,
	instanceId logging.InstanceId,
) error

func (*SplitScreenProxy) StartShortcutAndTask

func (p *SplitScreenProxy) StartShortcutAndTask(
	ctx context.Context,
	shortcutInfo pm.ShortcutInfo,
	options1 os.Bundle,
	taskId int32,
	options2 os.Bundle,
	splitPosition int32,
	snapPosition int32,
	remoteTransition window.RemoteTransition,
	instanceId logging.InstanceId,
) error

func (*SplitScreenProxy) StartShortcutAndTaskWithLegacyTransition

func (p *SplitScreenProxy) StartShortcutAndTaskWithLegacyTransition(
	ctx context.Context,
	shortcutInfo pm.ShortcutInfo,
	options1 os.Bundle,
	taskId int32,
	options2 os.Bundle,
	splitPosition int32,
	snapPosition int32,
	adapter view.RemoteAnimationAdapter,
	instanceId logging.InstanceId,
) error

func (*SplitScreenProxy) StartTask

func (p *SplitScreenProxy) StartTask(
	ctx context.Context,
	taskId int32,
	position int32,
	options os.Bundle,
) error

func (*SplitScreenProxy) StartTasks

func (p *SplitScreenProxy) StartTasks(
	ctx context.Context,
	taskId1 int32,
	options1 os.Bundle,
	taskId2 int32,
	options2 os.Bundle,
	splitPosition int32,
	snapPosition int32,
	remoteTransition window.RemoteTransition,
	instanceId logging.InstanceId,
) error

func (*SplitScreenProxy) StartTasksWithLegacyTransition

func (p *SplitScreenProxy) StartTasksWithLegacyTransition(
	ctx context.Context,
	taskId1 int32,
	options1 os.Bundle,
	taskId2 int32,
	options2 os.Bundle,
	splitPosition int32,
	snapPosition int32,
	adapter view.RemoteAnimationAdapter,
	instanceId logging.InstanceId,
) error

func (*SplitScreenProxy) SwitchSplitPosition

func (p *SplitScreenProxy) SwitchSplitPosition(
	ctx context.Context,
) error

func (*SplitScreenProxy) UnregisterSplitScreenListener

func (p *SplitScreenProxy) UnregisterSplitScreenListener(
	ctx context.Context,
	listener ISplitScreenListener,
) error

func (*SplitScreenProxy) UnregisterSplitSelectListener

func (p *SplitScreenProxy) UnregisterSplitSelectListener(
	ctx context.Context,
	listener ISplitSelectListener,
) error

type SplitScreenStub

type SplitScreenStub struct {
	Impl      ISplitScreen
	Transport binder.VersionAwareTransport
}

SplitScreenStub dispatches incoming binder transactions to a typed ISplitScreen implementation.

func (*SplitScreenStub) Descriptor

func (s *SplitScreenStub) Descriptor() string

func (*SplitScreenStub) OnTransaction

func (s *SplitScreenStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type SplitSelectListenerProxy

type SplitSelectListenerProxy struct {
	Remote binder.IBinder
}

func NewSplitSelectListenerProxy

func NewSplitSelectListenerProxy(
	remote binder.IBinder,
) *SplitSelectListenerProxy

func (*SplitSelectListenerProxy) AsBinder

func (p *SplitSelectListenerProxy) AsBinder() binder.IBinder

func (*SplitSelectListenerProxy) OnRequestSplitSelect

func (p *SplitSelectListenerProxy) OnRequestSplitSelect(
	ctx context.Context,
	taskInfo app.ActivityManagerRunningTaskInfo,
	splitPosition int32,
	taskBounds graphics.Rect,
) (bool, error)

type SplitSelectListenerStub

type SplitSelectListenerStub struct {
	Impl      ISplitSelectListener
	Transport binder.VersionAwareTransport
}

SplitSelectListenerStub dispatches incoming binder transactions to a typed ISplitSelectListener implementation.

func (*SplitSelectListenerStub) Descriptor

func (s *SplitSelectListenerStub) Descriptor() string

func (*SplitSelectListenerStub) OnTransaction

func (s *SplitSelectListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to