startingsurface

package
v0.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 28, 2026 License: CC0-1.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const DescriptorIStartingWindow = "com.android.wm.shell.startingsurface.IStartingWindow"
const DescriptorIStartingWindowListener = "com.android.wm.shell.startingsurface.IStartingWindowListener"
const (
	MethodIStartingWindowListenerOnTaskLaunching = "onTaskLaunching"
)
const (
	MethodIStartingWindowSetStartingWindowListener = "setStartingWindowListener"
)
const (
	TransactionIStartingWindowListenerOnTaskLaunching = binder.FirstCallTransaction + 0
)
const (
	TransactionIStartingWindowSetStartingWindowListener = binder.FirstCallTransaction + 42
)

Variables

This section is empty.

Functions

This section is empty.

Types

type IStartingWindow

type IStartingWindow interface {
	AsBinder() binder.IBinder
	SetStartingWindowListener(ctx context.Context, listener IStartingWindowListener) error
}

func NewStartingWindowStub

func NewStartingWindowStub(
	impl IStartingWindowServer,
) IStartingWindow

NewStartingWindowStub creates a server-side IStartingWindow wrapping the given server implementation. The returned value satisfies IStartingWindow and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IStartingWindowListener

type IStartingWindowListener interface {
	AsBinder() binder.IBinder
	OnTaskLaunching(ctx context.Context, taskId int32, supportedType int32, splashScreenBackgroundColor int32) error
}

func NewStartingWindowListenerStub

func NewStartingWindowListenerStub(
	impl IStartingWindowListenerServer,
) IStartingWindowListener

NewStartingWindowListenerStub creates a server-side IStartingWindowListener wrapping the given server implementation. The returned value satisfies IStartingWindowListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IStartingWindowListenerServer

type IStartingWindowListenerServer interface {
	OnTaskLaunching(ctx context.Context, taskId int32, supportedType int32, splashScreenBackgroundColor int32) error
}

IStartingWindowListenerServer is the server-side interface that user implementations provide to NewStartingWindowListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IStartingWindowServer

type IStartingWindowServer interface {
	SetStartingWindowListener(ctx context.Context, listener IStartingWindowListener) error
}

IStartingWindowServer is the server-side interface that user implementations provide to NewStartingWindowStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type StartingWindowListenerProxy

type StartingWindowListenerProxy struct {
	Remote binder.IBinder
}

func NewStartingWindowListenerProxy

func NewStartingWindowListenerProxy(
	remote binder.IBinder,
) *StartingWindowListenerProxy

func (*StartingWindowListenerProxy) AsBinder

func (*StartingWindowListenerProxy) OnTaskLaunching

func (p *StartingWindowListenerProxy) OnTaskLaunching(
	ctx context.Context,
	taskId int32,
	supportedType int32,
	splashScreenBackgroundColor int32,
) error

type StartingWindowListenerStub

type StartingWindowListenerStub struct {
	Impl      IStartingWindowListener
	Transport binder.VersionAwareTransport
}

StartingWindowListenerStub dispatches incoming binder transactions to a typed IStartingWindowListener implementation.

func (*StartingWindowListenerStub) Descriptor

func (s *StartingWindowListenerStub) Descriptor() string

func (*StartingWindowListenerStub) OnTransaction

func (s *StartingWindowListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type StartingWindowProxy

type StartingWindowProxy struct {
	Remote binder.IBinder
}

func NewStartingWindowProxy

func NewStartingWindowProxy(
	remote binder.IBinder,
) *StartingWindowProxy

func (*StartingWindowProxy) AsBinder

func (p *StartingWindowProxy) AsBinder() binder.IBinder

func (*StartingWindowProxy) SetStartingWindowListener

func (p *StartingWindowProxy) SetStartingWindowListener(
	ctx context.Context,
	listener IStartingWindowListener,
) error

type StartingWindowStub

type StartingWindowStub struct {
	Impl      IStartingWindow
	Transport binder.VersionAwareTransport
}

StartingWindowStub dispatches incoming binder transactions to a typed IStartingWindow implementation.

func (*StartingWindowStub) Descriptor

func (s *StartingWindowStub) Descriptor() string

func (*StartingWindowStub) OnTransaction

func (s *StartingWindowStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to