android

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIGraphicBufferSourceConfigure                     = binder.FirstCallTransaction + 0
	TransactionIGraphicBufferSourceSetSuspend                    = binder.FirstCallTransaction + 1
	TransactionIGraphicBufferSourceSetRepeatPreviousFrameDelayUs = binder.FirstCallTransaction + 2
	TransactionIGraphicBufferSourceSetMaxFps                     = binder.FirstCallTransaction + 3
	TransactionIGraphicBufferSourceSetTimeLapseConfig            = binder.FirstCallTransaction + 4
	TransactionIGraphicBufferSourceSetStartTimeUs                = binder.FirstCallTransaction + 5
	TransactionIGraphicBufferSourceSetStopTimeUs                 = binder.FirstCallTransaction + 6
	TransactionIGraphicBufferSourceGetStopTimeOffsetUs           = binder.FirstCallTransaction + 7
	TransactionIGraphicBufferSourceSetColorAspects               = binder.FirstCallTransaction + 8
	TransactionIGraphicBufferSourceSetTimeOffsetUs               = binder.FirstCallTransaction + 9
	TransactionIGraphicBufferSourceSignalEndOfInputStream        = binder.FirstCallTransaction + 10
)
const (
	MethodIGraphicBufferSourceConfigure                     = "configure"
	MethodIGraphicBufferSourceSetSuspend                    = "setSuspend"
	MethodIGraphicBufferSourceSetRepeatPreviousFrameDelayUs = "setRepeatPreviousFrameDelayUs"
	MethodIGraphicBufferSourceSetMaxFps                     = "setMaxFps"
	MethodIGraphicBufferSourceSetTimeLapseConfig            = "setTimeLapseConfig"
	MethodIGraphicBufferSourceSetStartTimeUs                = "setStartTimeUs"
	MethodIGraphicBufferSourceSetStopTimeUs                 = "setStopTimeUs"
	MethodIGraphicBufferSourceGetStopTimeOffsetUs           = "getStopTimeOffsetUs"
	MethodIGraphicBufferSourceSetColorAspects               = "setColorAspects"
	MethodIGraphicBufferSourceSetTimeOffsetUs               = "setTimeOffsetUs"
	MethodIGraphicBufferSourceSignalEndOfInputStream        = "signalEndOfInputStream"
)
const (
	TransactionIMediaExtractorServiceMakeExtractor     = binder.FirstCallTransaction + 0
	TransactionIMediaExtractorServiceMakeIDataSource   = binder.FirstCallTransaction + 1
	TransactionIMediaExtractorServiceGetSupportedTypes = binder.FirstCallTransaction + 2
)
const (
	MethodIMediaExtractorServiceMakeExtractor     = "makeExtractor"
	MethodIMediaExtractorServiceMakeIDataSource   = "makeIDataSource"
	MethodIMediaExtractorServiceGetSupportedTypes = "getSupportedTypes"
)
const (
	TransactionIOMXBufferSourceOnOmxExecuting       = binder.FirstCallTransaction + 0
	TransactionIOMXBufferSourceOnOmxIdle            = binder.FirstCallTransaction + 1
	TransactionIOMXBufferSourceOnOmxLoaded          = binder.FirstCallTransaction + 2
	TransactionIOMXBufferSourceOnInputBufferAdded   = binder.FirstCallTransaction + 3
	TransactionIOMXBufferSourceOnInputBufferEmptied = binder.FirstCallTransaction + 4
)
const (
	MethodIOMXBufferSourceOnOmxExecuting       = "onOmxExecuting"
	MethodIOMXBufferSourceOnOmxIdle            = "onOmxIdle"
	MethodIOMXBufferSourceOnOmxLoaded          = "onOmxLoaded"
	MethodIOMXBufferSourceOnInputBufferAdded   = "onInputBufferAdded"
	MethodIOMXBufferSourceOnInputBufferEmptied = "onInputBufferEmptied"
)
const DescriptorIDataSource = "android.IDataSource"
const DescriptorIGraphicBufferSource = "android.IGraphicBufferSource"
const DescriptorIMediaExtractor = "android.IMediaExtractor"
const DescriptorIMediaExtractorService = "android.IMediaExtractorService"
const DescriptorIOMXBufferSource = "android.IOMXBufferSource"
const DescriptorIOMXNode = "android.IOMXNode"

Variables

This section is empty.

Functions

This section is empty.

Types

type DataSourceProxy

type DataSourceProxy struct {
	Remote binder.IBinder
}

func NewDataSourceProxy

func NewDataSourceProxy(
	remote binder.IBinder,
) *DataSourceProxy

func (*DataSourceProxy) AsBinder

func (p *DataSourceProxy) AsBinder() binder.IBinder

type DataSourceStub

type DataSourceStub struct {
	Impl      IDataSource
	Transport binder.VersionAwareTransport
}

DataSourceStub dispatches incoming binder transactions to a typed IDataSource implementation.

func (*DataSourceStub) Descriptor

func (s *DataSourceStub) Descriptor() string

func (*DataSourceStub) OnTransaction

func (s *DataSourceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type GraphicBufferSourceProxy

type GraphicBufferSourceProxy struct {
	Remote binder.IBinder
}

func NewGraphicBufferSourceProxy

func NewGraphicBufferSourceProxy(
	remote binder.IBinder,
) *GraphicBufferSourceProxy

func (*GraphicBufferSourceProxy) AsBinder

func (p *GraphicBufferSourceProxy) AsBinder() binder.IBinder

func (*GraphicBufferSourceProxy) Configure

func (p *GraphicBufferSourceProxy) Configure(
	ctx context.Context,
	omxNode IOMXNode,
	dataSpace int32,
) error

func (*GraphicBufferSourceProxy) GetStopTimeOffsetUs

func (p *GraphicBufferSourceProxy) GetStopTimeOffsetUs(
	ctx context.Context,
) (int64, error)

func (*GraphicBufferSourceProxy) SetColorAspects

func (p *GraphicBufferSourceProxy) SetColorAspects(
	ctx context.Context,
	aspects int32,
) error

func (*GraphicBufferSourceProxy) SetMaxFps

func (p *GraphicBufferSourceProxy) SetMaxFps(
	ctx context.Context,
	maxFps float32,
) error

func (*GraphicBufferSourceProxy) SetRepeatPreviousFrameDelayUs

func (p *GraphicBufferSourceProxy) SetRepeatPreviousFrameDelayUs(
	ctx context.Context,
	repeatAfterUs int64,
) error

func (*GraphicBufferSourceProxy) SetStartTimeUs

func (p *GraphicBufferSourceProxy) SetStartTimeUs(
	ctx context.Context,
	startTimeUs int64,
) error

func (*GraphicBufferSourceProxy) SetStopTimeUs

func (p *GraphicBufferSourceProxy) SetStopTimeUs(
	ctx context.Context,
	stopTimeUs int64,
) error

func (*GraphicBufferSourceProxy) SetSuspend

func (p *GraphicBufferSourceProxy) SetSuspend(
	ctx context.Context,
	suspend bool,
	suspendTimeUs int64,
) error

func (*GraphicBufferSourceProxy) SetTimeLapseConfig

func (p *GraphicBufferSourceProxy) SetTimeLapseConfig(
	ctx context.Context,
	fps float64,
	captureFps float64,
) error

func (*GraphicBufferSourceProxy) SetTimeOffsetUs

func (p *GraphicBufferSourceProxy) SetTimeOffsetUs(
	ctx context.Context,
	timeOffsetsUs int64,
) error

func (*GraphicBufferSourceProxy) SignalEndOfInputStream

func (p *GraphicBufferSourceProxy) SignalEndOfInputStream(
	ctx context.Context,
) error

type GraphicBufferSourceStub

type GraphicBufferSourceStub struct {
	Impl      IGraphicBufferSource
	Transport binder.VersionAwareTransport
}

GraphicBufferSourceStub dispatches incoming binder transactions to a typed IGraphicBufferSource implementation.

func (*GraphicBufferSourceStub) Descriptor

func (s *GraphicBufferSourceStub) Descriptor() string

func (*GraphicBufferSourceStub) OnTransaction

func (s *GraphicBufferSourceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IDataSource

type IDataSource interface {
	AsBinder() binder.IBinder
}

func NewDataSourceStub

func NewDataSourceStub(
	impl IDataSourceServer,
) IDataSource

NewDataSourceStub creates a server-side IDataSource wrapping the given server implementation. The returned value satisfies IDataSource and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDataSourceServer

type IDataSourceServer interface {
}

IDataSourceServer is the server-side interface that user implementations provide to NewDataSourceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IGraphicBufferSource

type IGraphicBufferSource interface {
	AsBinder() binder.IBinder
	Configure(ctx context.Context, omxNode IOMXNode, dataSpace int32) error
	SetSuspend(ctx context.Context, suspend bool, suspendTimeUs int64) error
	SetRepeatPreviousFrameDelayUs(ctx context.Context, repeatAfterUs int64) error
	SetMaxFps(ctx context.Context, maxFps float32) error
	SetTimeLapseConfig(ctx context.Context, fps float64, captureFps float64) error
	SetStartTimeUs(ctx context.Context, startTimeUs int64) error
	SetStopTimeUs(ctx context.Context, stopTimeUs int64) error
	GetStopTimeOffsetUs(ctx context.Context) (int64, error)
	SetColorAspects(ctx context.Context, aspects int32) error
	SetTimeOffsetUs(ctx context.Context, timeOffsetsUs int64) error
	SignalEndOfInputStream(ctx context.Context) error
}

func NewGraphicBufferSourceStub

func NewGraphicBufferSourceStub(
	impl IGraphicBufferSourceServer,
) IGraphicBufferSource

NewGraphicBufferSourceStub creates a server-side IGraphicBufferSource wrapping the given server implementation. The returned value satisfies IGraphicBufferSource and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IGraphicBufferSourceServer

type IGraphicBufferSourceServer interface {
	Configure(ctx context.Context, omxNode IOMXNode, dataSpace int32) error
	SetSuspend(ctx context.Context, suspend bool, suspendTimeUs int64) error
	SetRepeatPreviousFrameDelayUs(ctx context.Context, repeatAfterUs int64) error
	SetMaxFps(ctx context.Context, maxFps float32) error
	SetTimeLapseConfig(ctx context.Context, fps float64, captureFps float64) error
	SetStartTimeUs(ctx context.Context, startTimeUs int64) error
	SetStopTimeUs(ctx context.Context, stopTimeUs int64) error
	GetStopTimeOffsetUs(ctx context.Context) (int64, error)
	SetColorAspects(ctx context.Context, aspects int32) error
	SetTimeOffsetUs(ctx context.Context, timeOffsetsUs int64) error
	SignalEndOfInputStream(ctx context.Context) error
}

IGraphicBufferSourceServer is the server-side interface that user implementations provide to NewGraphicBufferSourceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IMediaExtractor

type IMediaExtractor interface {
	AsBinder() binder.IBinder
}

func NewMediaExtractorStub

func NewMediaExtractorStub(
	impl IMediaExtractorServer,
) IMediaExtractor

NewMediaExtractorStub creates a server-side IMediaExtractor wrapping the given server implementation. The returned value satisfies IMediaExtractor and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IMediaExtractorServer

type IMediaExtractorServer interface {
}

IMediaExtractorServer is the server-side interface that user implementations provide to NewMediaExtractorStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IMediaExtractorService

type IMediaExtractorService interface {
	AsBinder() binder.IBinder
	MakeExtractor(ctx context.Context, source IDataSource, mime string) (IMediaExtractor, error)
	MakeIDataSource(ctx context.Context, fd int32, offset int64, length int64) (IDataSource, error)
	GetSupportedTypes(ctx context.Context) ([]string, error)
}

func NewMediaExtractorServiceStub

func NewMediaExtractorServiceStub(
	impl IMediaExtractorServiceServer,
) IMediaExtractorService

NewMediaExtractorServiceStub creates a server-side IMediaExtractorService wrapping the given server implementation. The returned value satisfies IMediaExtractorService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IMediaExtractorServiceServer

type IMediaExtractorServiceServer interface {
	MakeExtractor(ctx context.Context, source IDataSource, mime string) (IMediaExtractor, error)
	MakeIDataSource(ctx context.Context, fd int32, offset int64, length int64) (IDataSource, error)
	GetSupportedTypes(ctx context.Context) ([]string, error)
}

IMediaExtractorServiceServer is the server-side interface that user implementations provide to NewMediaExtractorServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IOMXBufferSource

type IOMXBufferSource interface {
	AsBinder() binder.IBinder
	OnOmxExecuting(ctx context.Context) error
	OnOmxIdle(ctx context.Context) error
	OnOmxLoaded(ctx context.Context) error
	OnInputBufferAdded(ctx context.Context, bufferID int32) error
	OnInputBufferEmptied(ctx context.Context, bufferID int32, fenceParcel OMXFenceParcelable) error
}

func NewOMXBufferSourceStub

func NewOMXBufferSourceStub(
	impl IOMXBufferSourceServer,
) IOMXBufferSource

NewOMXBufferSourceStub creates a server-side IOMXBufferSource wrapping the given server implementation. The returned value satisfies IOMXBufferSource and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IOMXBufferSourceServer

type IOMXBufferSourceServer interface {
	OnOmxExecuting(ctx context.Context) error
	OnOmxIdle(ctx context.Context) error
	OnOmxLoaded(ctx context.Context) error
	OnInputBufferAdded(ctx context.Context, bufferID int32) error
	OnInputBufferEmptied(ctx context.Context, bufferID int32, fenceParcel OMXFenceParcelable) error
}

IOMXBufferSourceServer is the server-side interface that user implementations provide to NewOMXBufferSourceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IOMXNode

type IOMXNode interface {
	AsBinder() binder.IBinder
}

func NewOMXNodeStub

func NewOMXNodeStub(
	impl IOMXNodeServer,
) IOMXNode

NewOMXNodeStub creates a server-side IOMXNode wrapping the given server implementation. The returned value satisfies IOMXNode and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IOMXNodeServer

type IOMXNodeServer interface {
}

IOMXNodeServer is the server-side interface that user implementations provide to NewOMXNodeStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type MediaExtractorProxy

type MediaExtractorProxy struct {
	Remote binder.IBinder
}

func NewMediaExtractorProxy

func NewMediaExtractorProxy(
	remote binder.IBinder,
) *MediaExtractorProxy

func (*MediaExtractorProxy) AsBinder

func (p *MediaExtractorProxy) AsBinder() binder.IBinder

type MediaExtractorServiceProxy

type MediaExtractorServiceProxy struct {
	Remote binder.IBinder
}

func NewMediaExtractorServiceProxy

func NewMediaExtractorServiceProxy(
	remote binder.IBinder,
) *MediaExtractorServiceProxy

func (*MediaExtractorServiceProxy) AsBinder

func (*MediaExtractorServiceProxy) GetSupportedTypes

func (p *MediaExtractorServiceProxy) GetSupportedTypes(
	ctx context.Context,
) ([]string, error)

func (*MediaExtractorServiceProxy) MakeExtractor

func (p *MediaExtractorServiceProxy) MakeExtractor(
	ctx context.Context,
	source IDataSource,
	mime string,
) (IMediaExtractor, error)

func (*MediaExtractorServiceProxy) MakeIDataSource

func (p *MediaExtractorServiceProxy) MakeIDataSource(
	ctx context.Context,
	fd int32,
	offset int64,
	length int64,
) (IDataSource, error)

type MediaExtractorServiceStub

type MediaExtractorServiceStub struct {
	Impl      IMediaExtractorService
	Transport binder.VersionAwareTransport
}

MediaExtractorServiceStub dispatches incoming binder transactions to a typed IMediaExtractorService implementation.

func (*MediaExtractorServiceStub) Descriptor

func (s *MediaExtractorServiceStub) Descriptor() string

func (*MediaExtractorServiceStub) OnTransaction

func (s *MediaExtractorServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type MediaExtractorStub

type MediaExtractorStub struct {
	Impl      IMediaExtractor
	Transport binder.VersionAwareTransport
}

MediaExtractorStub dispatches incoming binder transactions to a typed IMediaExtractor implementation.

func (*MediaExtractorStub) Descriptor

func (s *MediaExtractorStub) Descriptor() string

func (*MediaExtractorStub) OnTransaction

func (s *MediaExtractorStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type OMXBufferSourceProxy

type OMXBufferSourceProxy struct {
	Remote binder.IBinder
}

func NewOMXBufferSourceProxy

func NewOMXBufferSourceProxy(
	remote binder.IBinder,
) *OMXBufferSourceProxy

func (*OMXBufferSourceProxy) AsBinder

func (p *OMXBufferSourceProxy) AsBinder() binder.IBinder

func (*OMXBufferSourceProxy) OnInputBufferAdded

func (p *OMXBufferSourceProxy) OnInputBufferAdded(
	ctx context.Context,
	bufferID int32,
) error

func (*OMXBufferSourceProxy) OnInputBufferEmptied

func (p *OMXBufferSourceProxy) OnInputBufferEmptied(
	ctx context.Context,
	bufferID int32,
	fenceParcel OMXFenceParcelable,
) error

func (*OMXBufferSourceProxy) OnOmxExecuting

func (p *OMXBufferSourceProxy) OnOmxExecuting(
	ctx context.Context,
) error

func (*OMXBufferSourceProxy) OnOmxIdle

func (p *OMXBufferSourceProxy) OnOmxIdle(
	ctx context.Context,
) error

func (*OMXBufferSourceProxy) OnOmxLoaded

func (p *OMXBufferSourceProxy) OnOmxLoaded(
	ctx context.Context,
) error

type OMXBufferSourceStub

type OMXBufferSourceStub struct {
	Impl      IOMXBufferSource
	Transport binder.VersionAwareTransport
}

OMXBufferSourceStub dispatches incoming binder transactions to a typed IOMXBufferSource implementation.

func (*OMXBufferSourceStub) Descriptor

func (s *OMXBufferSourceStub) Descriptor() string

func (*OMXBufferSourceStub) OnTransaction

func (s *OMXBufferSourceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type OMXFenceParcelable

type OMXFenceParcelable struct {
}

func (*OMXFenceParcelable) MarshalParcel

func (s *OMXFenceParcelable) MarshalParcel(
	p *parcel.Parcel,
) error

func (*OMXFenceParcelable) UnmarshalParcel

func (s *OMXFenceParcelable) UnmarshalParcel(
	p *parcel.Parcel,
) error

type OMXNodeProxy

type OMXNodeProxy struct {
	Remote binder.IBinder
}

func NewOMXNodeProxy

func NewOMXNodeProxy(
	remote binder.IBinder,
) *OMXNodeProxy

func (*OMXNodeProxy) AsBinder

func (p *OMXNodeProxy) AsBinder() binder.IBinder

type OMXNodeStub

type OMXNodeStub struct {
	Impl      IOMXNode
	Transport binder.VersionAwareTransport
}

OMXNodeStub dispatches incoming binder transactions to a typed IOMXNode implementation.

func (*OMXNodeStub) Descriptor

func (s *OMXNodeStub) Descriptor() string

func (*OMXNodeStub) OnTransaction

func (s *OMXNodeStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Directories

Path Synopsis
app
job
binderdebug
le
om
pm
res
frameworks
cas
drm
ir
nfc
usb
uwb
tv
net
vcn
nfc
os
se
rkp
service
vr
tts
system
gba
ims
tests

Jump to