Documentation
¶
Index ¶
- Constants
- type Content
- type DownloadCallbackProxy
- func (p *DownloadCallbackProxy) AsBinder() binder.IBinder
- func (p *DownloadCallbackProxy) OnDownloadCompleted(ctx context.Context, downloadParams os.PersistableBundle) error
- func (p *DownloadCallbackProxy) OnDownloadFailed(ctx context.Context, failureStatus int32, errorMessage string, ...) error
- func (p *DownloadCallbackProxy) OnDownloadProgress(ctx context.Context, bytesDownloaded int64) error
- func (p *DownloadCallbackProxy) OnDownloadStarted(ctx context.Context, bytesToDownload int64) error
- type DownloadCallbackStub
- type Feature
- type FeatureCallbackProxy
- type FeatureCallbackStub
- type FeatureDetails
- type FeatureDetailsCallbackProxy
- type FeatureDetailsCallbackStub
- type IDownloadCallback
- type IDownloadCallbackServer
- type IFeatureCallback
- type IFeatureCallbackServer
- type IFeatureDetailsCallback
- type IFeatureDetailsCallbackServer
- type IListFeaturesCallback
- type IListFeaturesCallbackServer
- type IOnDeviceIntelligenceManager
- type IOnDeviceIntelligenceManagerServer
- type IProcessingSignal
- type IProcessingSignalServer
- type IResponseCallback
- type IResponseCallbackServer
- type IStreamingResponseCallback
- type IStreamingResponseCallbackServer
- type ITokenCountCallback
- type ITokenCountCallbackServer
- type ListFeaturesCallbackProxy
- type ListFeaturesCallbackStub
- type OnDeviceIntelligenceManagerProxy
- func (p *OnDeviceIntelligenceManagerProxy) AsBinder() binder.IBinder
- func (p *OnDeviceIntelligenceManagerProxy) GetFeature(ctx context.Context, featureId int32, remoteCallback IFeatureCallback) error
- func (p *OnDeviceIntelligenceManagerProxy) GetFeatureDetails(ctx context.Context, feature Feature, ...) error
- func (p *OnDeviceIntelligenceManagerProxy) GetVersion(ctx context.Context, remoteCallback os.RemoteCallback) error
- func (p *OnDeviceIntelligenceManagerProxy) ListFeatures(ctx context.Context, listFeaturesCallback IListFeaturesCallback) error
- func (p *OnDeviceIntelligenceManagerProxy) ProcessRequest(ctx context.Context, feature Feature, request Content, requestType int32, ...) error
- func (p *OnDeviceIntelligenceManagerProxy) ProcessRequestStreaming(ctx context.Context, feature Feature, request Content, requestType int32, ...) error
- func (p *OnDeviceIntelligenceManagerProxy) RequestFeatureDownload(ctx context.Context, feature Feature, signal os.ICancellationSignal, ...) error
- func (p *OnDeviceIntelligenceManagerProxy) RequestTokenCount(ctx context.Context, feature Feature, request Content, ...) error
- type OnDeviceIntelligenceManagerStub
- type ProcessingSignalProxy
- type ProcessingSignalStub
- type ResponseCallbackProxy
- type ResponseCallbackStub
- type StreamingResponseCallbackProxy
- func (p *StreamingResponseCallbackProxy) AsBinder() binder.IBinder
- func (p *StreamingResponseCallbackProxy) OnFailure(ctx context.Context, errorCode int32, errorMessage string, ...) error
- func (p *StreamingResponseCallbackProxy) OnNewContent(ctx context.Context, result Content) error
- func (p *StreamingResponseCallbackProxy) OnSuccess(ctx context.Context, result Content) error
- type StreamingResponseCallbackStub
- type TokenCountCallbackProxy
- type TokenCountCallbackStub
Constants ¶
const ( TransactionIDownloadCallbackOnDownloadStarted = binder.FirstCallTransaction + 0 TransactionIDownloadCallbackOnDownloadProgress = binder.FirstCallTransaction + 1 TransactionIDownloadCallbackOnDownloadFailed = binder.FirstCallTransaction + 2 TransactionIDownloadCallbackOnDownloadCompleted = binder.FirstCallTransaction + 3 )
const ( MethodIDownloadCallbackOnDownloadStarted = "onDownloadStarted" MethodIDownloadCallbackOnDownloadProgress = "onDownloadProgress" MethodIDownloadCallbackOnDownloadFailed = "onDownloadFailed" MethodIDownloadCallbackOnDownloadCompleted = "onDownloadCompleted" )
const ( TransactionIFeatureCallbackOnSuccess = binder.FirstCallTransaction + 0 TransactionIFeatureCallbackOnFailure = binder.FirstCallTransaction + 1 )
const ( MethodIFeatureCallbackOnSuccess = "onSuccess" MethodIFeatureCallbackOnFailure = "onFailure" )
const ( TransactionIFeatureDetailsCallbackOnSuccess = binder.FirstCallTransaction + 0 TransactionIFeatureDetailsCallbackOnFailure = binder.FirstCallTransaction + 1 )
const ( MethodIFeatureDetailsCallbackOnSuccess = "onSuccess" MethodIFeatureDetailsCallbackOnFailure = "onFailure" )
const ( TransactionIListFeaturesCallbackOnSuccess = binder.FirstCallTransaction + 0 TransactionIListFeaturesCallbackOnFailure = binder.FirstCallTransaction + 1 )
const ( MethodIListFeaturesCallbackOnSuccess = "onSuccess" MethodIListFeaturesCallbackOnFailure = "onFailure" )
const ( TransactionIOnDeviceIntelligenceManagerGetVersion = binder.FirstCallTransaction + 0 TransactionIOnDeviceIntelligenceManagerGetFeature = binder.FirstCallTransaction + 1 TransactionIOnDeviceIntelligenceManagerListFeatures = binder.FirstCallTransaction + 2 TransactionIOnDeviceIntelligenceManagerGetFeatureDetails = binder.FirstCallTransaction + 3 TransactionIOnDeviceIntelligenceManagerRequestFeatureDownload = binder.FirstCallTransaction + 4 TransactionIOnDeviceIntelligenceManagerRequestTokenCount = binder.FirstCallTransaction + 5 TransactionIOnDeviceIntelligenceManagerProcessRequest = binder.FirstCallTransaction + 6 TransactionIOnDeviceIntelligenceManagerProcessRequestStreaming = binder.FirstCallTransaction + 7 )
const ( MethodIOnDeviceIntelligenceManagerGetVersion = "getVersion" MethodIOnDeviceIntelligenceManagerGetFeature = "getFeature" MethodIOnDeviceIntelligenceManagerListFeatures = "listFeatures" MethodIOnDeviceIntelligenceManagerGetFeatureDetails = "getFeatureDetails" MethodIOnDeviceIntelligenceManagerRequestFeatureDownload = "requestFeatureDownload" MethodIOnDeviceIntelligenceManagerRequestTokenCount = "requestTokenCount" MethodIOnDeviceIntelligenceManagerProcessRequest = "processRequest" MethodIOnDeviceIntelligenceManagerProcessRequestStreaming = "processRequestStreaming" )
const ( TransactionIResponseCallbackOnSuccess = binder.FirstCallTransaction + 0 TransactionIResponseCallbackOnFailure = binder.FirstCallTransaction + 1 )
const ( MethodIResponseCallbackOnSuccess = "onSuccess" MethodIResponseCallbackOnFailure = "onFailure" )
const ( TransactionIStreamingResponseCallbackOnNewContent = binder.FirstCallTransaction + 0 TransactionIStreamingResponseCallbackOnSuccess = binder.FirstCallTransaction + 1 TransactionIStreamingResponseCallbackOnFailure = binder.FirstCallTransaction + 2 )
const ( MethodIStreamingResponseCallbackOnNewContent = "onNewContent" MethodIStreamingResponseCallbackOnSuccess = "onSuccess" MethodIStreamingResponseCallbackOnFailure = "onFailure" )
const ( TransactionITokenCountCallbackOnSuccess = binder.FirstCallTransaction + 0 TransactionITokenCountCallbackOnFailure = binder.FirstCallTransaction + 1 )
const ( MethodITokenCountCallbackOnSuccess = "onSuccess" MethodITokenCountCallbackOnFailure = "onFailure" )
const DescriptorIDownloadCallback = "android.app.ondeviceintelligence.IDownloadCallback"
const DescriptorIFeatureCallback = "android.app.ondeviceintelligence.IFeatureCallback"
const DescriptorIFeatureDetailsCallback = "android.app.ondeviceintelligence.IFeatureDetailsCallback"
const DescriptorIListFeaturesCallback = "android.app.ondeviceintelligence.IListFeaturesCallback"
const DescriptorIOnDeviceIntelligenceManager = "android.app.ondeviceintelligence.IOnDeviceIntelligenceManager"
const DescriptorIProcessingSignal = "android.app.ondeviceintelligence.IProcessingSignal"
const DescriptorIResponseCallback = "android.app.ondeviceintelligence.IResponseCallback"
const DescriptorIStreamingResponseCallback = "android.app.ondeviceintelligence.IStreamingResponseCallback"
const DescriptorITokenCountCallback = "android.app.ondeviceintelligence.ITokenCountCallback"
const (
MethodIProcessingSignalSendSignal = "sendSignal"
)
const (
TransactionIProcessingSignalSendSignal = binder.FirstCallTransaction + 1
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DownloadCallbackProxy ¶
func NewDownloadCallbackProxy ¶
func NewDownloadCallbackProxy( remote binder.IBinder, ) *DownloadCallbackProxy
func (*DownloadCallbackProxy) AsBinder ¶
func (p *DownloadCallbackProxy) AsBinder() binder.IBinder
func (*DownloadCallbackProxy) OnDownloadCompleted ¶
func (p *DownloadCallbackProxy) OnDownloadCompleted( ctx context.Context, downloadParams os.PersistableBundle, ) error
func (*DownloadCallbackProxy) OnDownloadFailed ¶
func (p *DownloadCallbackProxy) OnDownloadFailed( ctx context.Context, failureStatus int32, errorMessage string, errorParams os.PersistableBundle, ) error
func (*DownloadCallbackProxy) OnDownloadProgress ¶
func (p *DownloadCallbackProxy) OnDownloadProgress( ctx context.Context, bytesDownloaded int64, ) error
func (*DownloadCallbackProxy) OnDownloadStarted ¶
func (p *DownloadCallbackProxy) OnDownloadStarted( ctx context.Context, bytesToDownload int64, ) error
type DownloadCallbackStub ¶
type DownloadCallbackStub struct {
Impl IDownloadCallback
Transport binder.VersionAwareTransport
}
DownloadCallbackStub dispatches incoming binder transactions to a typed IDownloadCallback implementation.
func (*DownloadCallbackStub) Descriptor ¶
func (s *DownloadCallbackStub) Descriptor() string
func (*DownloadCallbackStub) OnTransaction ¶
func (s *DownloadCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type FeatureCallbackProxy ¶
func NewFeatureCallbackProxy ¶
func NewFeatureCallbackProxy( remote binder.IBinder, ) *FeatureCallbackProxy
func (*FeatureCallbackProxy) AsBinder ¶
func (p *FeatureCallbackProxy) AsBinder() binder.IBinder
func (*FeatureCallbackProxy) OnFailure ¶
func (p *FeatureCallbackProxy) OnFailure( ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle, ) error
type FeatureCallbackStub ¶
type FeatureCallbackStub struct {
Impl IFeatureCallback
Transport binder.VersionAwareTransport
}
FeatureCallbackStub dispatches incoming binder transactions to a typed IFeatureCallback implementation.
func (*FeatureCallbackStub) Descriptor ¶
func (s *FeatureCallbackStub) Descriptor() string
func (*FeatureCallbackStub) OnTransaction ¶
func (s *FeatureCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type FeatureDetails ¶
type FeatureDetails struct {
Status int32
}
func (*FeatureDetails) MarshalParcel ¶
func (s *FeatureDetails) MarshalParcel( p *parcel.Parcel, ) error
func (*FeatureDetails) UnmarshalParcel ¶
func (s *FeatureDetails) UnmarshalParcel( p *parcel.Parcel, ) error
type FeatureDetailsCallbackProxy ¶
func NewFeatureDetailsCallbackProxy ¶
func NewFeatureDetailsCallbackProxy( remote binder.IBinder, ) *FeatureDetailsCallbackProxy
func (*FeatureDetailsCallbackProxy) AsBinder ¶
func (p *FeatureDetailsCallbackProxy) AsBinder() binder.IBinder
func (*FeatureDetailsCallbackProxy) OnFailure ¶
func (p *FeatureDetailsCallbackProxy) OnFailure( ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle, ) error
func (*FeatureDetailsCallbackProxy) OnSuccess ¶
func (p *FeatureDetailsCallbackProxy) OnSuccess( ctx context.Context, result FeatureDetails, ) error
type FeatureDetailsCallbackStub ¶
type FeatureDetailsCallbackStub struct {
Impl IFeatureDetailsCallback
Transport binder.VersionAwareTransport
}
FeatureDetailsCallbackStub dispatches incoming binder transactions to a typed IFeatureDetailsCallback implementation.
func (*FeatureDetailsCallbackStub) Descriptor ¶
func (s *FeatureDetailsCallbackStub) Descriptor() string
func (*FeatureDetailsCallbackStub) OnTransaction ¶
func (s *FeatureDetailsCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type IDownloadCallback ¶
type IDownloadCallback interface {
AsBinder() binder.IBinder
OnDownloadStarted(ctx context.Context, bytesToDownload int64) error
OnDownloadProgress(ctx context.Context, bytesDownloaded int64) error
OnDownloadFailed(ctx context.Context, failureStatus int32, errorMessage string, errorParams os.PersistableBundle) error
OnDownloadCompleted(ctx context.Context, downloadParams os.PersistableBundle) error
}
func NewDownloadCallbackStub ¶
func NewDownloadCallbackStub( impl IDownloadCallbackServer, ) IDownloadCallback
NewDownloadCallbackStub creates a server-side IDownloadCallback wrapping the given server implementation. The returned value satisfies IDownloadCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IDownloadCallbackServer ¶
type IDownloadCallbackServer interface {
OnDownloadStarted(ctx context.Context, bytesToDownload int64) error
OnDownloadProgress(ctx context.Context, bytesDownloaded int64) error
OnDownloadFailed(ctx context.Context, failureStatus int32, errorMessage string, errorParams os.PersistableBundle) error
OnDownloadCompleted(ctx context.Context, downloadParams os.PersistableBundle) error
}
IDownloadCallbackServer is the server-side interface that user implementations provide to NewDownloadCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IFeatureCallback ¶
type IFeatureCallback interface {
AsBinder() binder.IBinder
OnSuccess(ctx context.Context, result Feature) error
OnFailure(ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle) error
}
func NewFeatureCallbackStub ¶
func NewFeatureCallbackStub( impl IFeatureCallbackServer, ) IFeatureCallback
NewFeatureCallbackStub creates a server-side IFeatureCallback wrapping the given server implementation. The returned value satisfies IFeatureCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IFeatureCallbackServer ¶
type IFeatureCallbackServer interface {
OnSuccess(ctx context.Context, result Feature) error
OnFailure(ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle) error
}
IFeatureCallbackServer is the server-side interface that user implementations provide to NewFeatureCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IFeatureDetailsCallback ¶
type IFeatureDetailsCallback interface {
AsBinder() binder.IBinder
OnSuccess(ctx context.Context, result FeatureDetails) error
OnFailure(ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle) error
}
func NewFeatureDetailsCallbackStub ¶
func NewFeatureDetailsCallbackStub( impl IFeatureDetailsCallbackServer, ) IFeatureDetailsCallback
NewFeatureDetailsCallbackStub creates a server-side IFeatureDetailsCallback wrapping the given server implementation. The returned value satisfies IFeatureDetailsCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IFeatureDetailsCallbackServer ¶
type IFeatureDetailsCallbackServer interface {
OnSuccess(ctx context.Context, result FeatureDetails) error
OnFailure(ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle) error
}
IFeatureDetailsCallbackServer is the server-side interface that user implementations provide to NewFeatureDetailsCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IListFeaturesCallback ¶
type IListFeaturesCallback interface {
AsBinder() binder.IBinder
OnSuccess(ctx context.Context, result []Feature) error
OnFailure(ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle) error
}
func NewListFeaturesCallbackStub ¶
func NewListFeaturesCallbackStub( impl IListFeaturesCallbackServer, ) IListFeaturesCallback
NewListFeaturesCallbackStub creates a server-side IListFeaturesCallback wrapping the given server implementation. The returned value satisfies IListFeaturesCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IListFeaturesCallbackServer ¶
type IListFeaturesCallbackServer interface {
OnSuccess(ctx context.Context, result []Feature) error
OnFailure(ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle) error
}
IListFeaturesCallbackServer is the server-side interface that user implementations provide to NewListFeaturesCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IOnDeviceIntelligenceManager ¶
type IOnDeviceIntelligenceManager interface {
AsBinder() binder.IBinder
GetVersion(ctx context.Context, remoteCallback os.RemoteCallback) error
GetFeature(ctx context.Context, featureId int32, remoteCallback IFeatureCallback) error
ListFeatures(ctx context.Context, listFeaturesCallback IListFeaturesCallback) error
GetFeatureDetails(ctx context.Context, feature Feature, featureDetailsCallback IFeatureDetailsCallback) error
RequestFeatureDownload(ctx context.Context, feature Feature, signal os.ICancellationSignal, callback IDownloadCallback) error
RequestTokenCount(ctx context.Context, feature Feature, request Content, signal os.ICancellationSignal, tokenCountcallback ITokenCountCallback) error
ProcessRequest(ctx context.Context, feature Feature, request Content, requestType int32, cancellationSignal os.ICancellationSignal, signal IProcessingSignal, responseCallback IResponseCallback) error
ProcessRequestStreaming(ctx context.Context, feature Feature, request Content, requestType int32, cancellationSignal os.ICancellationSignal, signal IProcessingSignal, streamingCallback IStreamingResponseCallback) error
}
func NewOnDeviceIntelligenceManagerStub ¶
func NewOnDeviceIntelligenceManagerStub( impl IOnDeviceIntelligenceManagerServer, ) IOnDeviceIntelligenceManager
NewOnDeviceIntelligenceManagerStub creates a server-side IOnDeviceIntelligenceManager wrapping the given server implementation. The returned value satisfies IOnDeviceIntelligenceManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IOnDeviceIntelligenceManagerServer ¶
type IOnDeviceIntelligenceManagerServer interface {
GetVersion(ctx context.Context, remoteCallback os.RemoteCallback) error
GetFeature(ctx context.Context, featureId int32, remoteCallback IFeatureCallback) error
ListFeatures(ctx context.Context, listFeaturesCallback IListFeaturesCallback) error
GetFeatureDetails(ctx context.Context, feature Feature, featureDetailsCallback IFeatureDetailsCallback) error
RequestFeatureDownload(ctx context.Context, feature Feature, signal os.ICancellationSignal, callback IDownloadCallback) error
RequestTokenCount(ctx context.Context, feature Feature, request Content, signal os.ICancellationSignal, tokenCountcallback ITokenCountCallback) error
ProcessRequest(ctx context.Context, feature Feature, request Content, requestType int32, cancellationSignal os.ICancellationSignal, signal IProcessingSignal, responseCallback IResponseCallback) error
ProcessRequestStreaming(ctx context.Context, feature Feature, request Content, requestType int32, cancellationSignal os.ICancellationSignal, signal IProcessingSignal, streamingCallback IStreamingResponseCallback) error
}
IOnDeviceIntelligenceManagerServer is the server-side interface that user implementations provide to NewOnDeviceIntelligenceManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IProcessingSignal ¶
type IProcessingSignal interface {
AsBinder() binder.IBinder
SendSignal(ctx context.Context, actionParams os.PersistableBundle) error
}
func NewProcessingSignalStub ¶
func NewProcessingSignalStub( impl IProcessingSignalServer, ) IProcessingSignal
NewProcessingSignalStub creates a server-side IProcessingSignal wrapping the given server implementation. The returned value satisfies IProcessingSignal and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IProcessingSignalServer ¶
type IProcessingSignalServer interface {
SendSignal(ctx context.Context, actionParams os.PersistableBundle) error
}
IProcessingSignalServer is the server-side interface that user implementations provide to NewProcessingSignalStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IResponseCallback ¶
type IResponseCallback interface {
AsBinder() binder.IBinder
OnSuccess(ctx context.Context, result Content) error
OnFailure(ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle) error
}
func NewResponseCallbackStub ¶
func NewResponseCallbackStub( impl IResponseCallbackServer, ) IResponseCallback
NewResponseCallbackStub creates a server-side IResponseCallback wrapping the given server implementation. The returned value satisfies IResponseCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IResponseCallbackServer ¶
type IResponseCallbackServer interface {
OnSuccess(ctx context.Context, result Content) error
OnFailure(ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle) error
}
IResponseCallbackServer is the server-side interface that user implementations provide to NewResponseCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IStreamingResponseCallback ¶
type IStreamingResponseCallback interface {
AsBinder() binder.IBinder
OnNewContent(ctx context.Context, result Content) error
OnSuccess(ctx context.Context, result Content) error
OnFailure(ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle) error
}
func NewStreamingResponseCallbackStub ¶
func NewStreamingResponseCallbackStub( impl IStreamingResponseCallbackServer, ) IStreamingResponseCallback
NewStreamingResponseCallbackStub creates a server-side IStreamingResponseCallback wrapping the given server implementation. The returned value satisfies IStreamingResponseCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IStreamingResponseCallbackServer ¶
type IStreamingResponseCallbackServer interface {
OnNewContent(ctx context.Context, result Content) error
OnSuccess(ctx context.Context, result Content) error
OnFailure(ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle) error
}
IStreamingResponseCallbackServer is the server-side interface that user implementations provide to NewStreamingResponseCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ITokenCountCallback ¶
type ITokenCountCallback interface {
AsBinder() binder.IBinder
OnSuccess(ctx context.Context, tokenCount int64) error
OnFailure(ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle) error
}
func NewTokenCountCallbackStub ¶
func NewTokenCountCallbackStub( impl ITokenCountCallbackServer, ) ITokenCountCallback
NewTokenCountCallbackStub creates a server-side ITokenCountCallback wrapping the given server implementation. The returned value satisfies ITokenCountCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITokenCountCallbackServer ¶
type ITokenCountCallbackServer interface {
OnSuccess(ctx context.Context, tokenCount int64) error
OnFailure(ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle) error
}
ITokenCountCallbackServer is the server-side interface that user implementations provide to NewTokenCountCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ListFeaturesCallbackProxy ¶
func NewListFeaturesCallbackProxy ¶
func NewListFeaturesCallbackProxy( remote binder.IBinder, ) *ListFeaturesCallbackProxy
func (*ListFeaturesCallbackProxy) AsBinder ¶
func (p *ListFeaturesCallbackProxy) AsBinder() binder.IBinder
func (*ListFeaturesCallbackProxy) OnFailure ¶
func (p *ListFeaturesCallbackProxy) OnFailure( ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle, ) error
type ListFeaturesCallbackStub ¶
type ListFeaturesCallbackStub struct {
Impl IListFeaturesCallback
Transport binder.VersionAwareTransport
}
ListFeaturesCallbackStub dispatches incoming binder transactions to a typed IListFeaturesCallback implementation.
func (*ListFeaturesCallbackStub) Descriptor ¶
func (s *ListFeaturesCallbackStub) Descriptor() string
func (*ListFeaturesCallbackStub) OnTransaction ¶
func (s *ListFeaturesCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type OnDeviceIntelligenceManagerProxy ¶
func NewOnDeviceIntelligenceManagerProxy ¶
func NewOnDeviceIntelligenceManagerProxy( remote binder.IBinder, ) *OnDeviceIntelligenceManagerProxy
func (*OnDeviceIntelligenceManagerProxy) AsBinder ¶
func (p *OnDeviceIntelligenceManagerProxy) AsBinder() binder.IBinder
func (*OnDeviceIntelligenceManagerProxy) GetFeature ¶
func (p *OnDeviceIntelligenceManagerProxy) GetFeature( ctx context.Context, featureId int32, remoteCallback IFeatureCallback, ) error
func (*OnDeviceIntelligenceManagerProxy) GetFeatureDetails ¶
func (p *OnDeviceIntelligenceManagerProxy) GetFeatureDetails( ctx context.Context, feature Feature, featureDetailsCallback IFeatureDetailsCallback, ) error
func (*OnDeviceIntelligenceManagerProxy) GetVersion ¶
func (p *OnDeviceIntelligenceManagerProxy) GetVersion( ctx context.Context, remoteCallback os.RemoteCallback, ) error
func (*OnDeviceIntelligenceManagerProxy) ListFeatures ¶
func (p *OnDeviceIntelligenceManagerProxy) ListFeatures( ctx context.Context, listFeaturesCallback IListFeaturesCallback, ) error
func (*OnDeviceIntelligenceManagerProxy) ProcessRequest ¶
func (p *OnDeviceIntelligenceManagerProxy) ProcessRequest( ctx context.Context, feature Feature, request Content, requestType int32, cancellationSignal os.ICancellationSignal, signal IProcessingSignal, responseCallback IResponseCallback, ) error
func (*OnDeviceIntelligenceManagerProxy) ProcessRequestStreaming ¶
func (p *OnDeviceIntelligenceManagerProxy) ProcessRequestStreaming( ctx context.Context, feature Feature, request Content, requestType int32, cancellationSignal os.ICancellationSignal, signal IProcessingSignal, streamingCallback IStreamingResponseCallback, ) error
func (*OnDeviceIntelligenceManagerProxy) RequestFeatureDownload ¶
func (p *OnDeviceIntelligenceManagerProxy) RequestFeatureDownload( ctx context.Context, feature Feature, signal os.ICancellationSignal, callback IDownloadCallback, ) error
func (*OnDeviceIntelligenceManagerProxy) RequestTokenCount ¶
func (p *OnDeviceIntelligenceManagerProxy) RequestTokenCount( ctx context.Context, feature Feature, request Content, signal os.ICancellationSignal, tokenCountcallback ITokenCountCallback, ) error
type OnDeviceIntelligenceManagerStub ¶
type OnDeviceIntelligenceManagerStub struct {
Impl IOnDeviceIntelligenceManager
Transport binder.VersionAwareTransport
}
OnDeviceIntelligenceManagerStub dispatches incoming binder transactions to a typed IOnDeviceIntelligenceManager implementation.
func (*OnDeviceIntelligenceManagerStub) Descriptor ¶
func (s *OnDeviceIntelligenceManagerStub) Descriptor() string
func (*OnDeviceIntelligenceManagerStub) OnTransaction ¶
func (s *OnDeviceIntelligenceManagerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ProcessingSignalProxy ¶
func NewProcessingSignalProxy ¶
func NewProcessingSignalProxy( remote binder.IBinder, ) *ProcessingSignalProxy
func (*ProcessingSignalProxy) AsBinder ¶
func (p *ProcessingSignalProxy) AsBinder() binder.IBinder
func (*ProcessingSignalProxy) SendSignal ¶
func (p *ProcessingSignalProxy) SendSignal( ctx context.Context, actionParams os.PersistableBundle, ) error
type ProcessingSignalStub ¶
type ProcessingSignalStub struct {
Impl IProcessingSignal
Transport binder.VersionAwareTransport
}
ProcessingSignalStub dispatches incoming binder transactions to a typed IProcessingSignal implementation.
func (*ProcessingSignalStub) Descriptor ¶
func (s *ProcessingSignalStub) Descriptor() string
func (*ProcessingSignalStub) OnTransaction ¶
func (s *ProcessingSignalStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ResponseCallbackProxy ¶
func NewResponseCallbackProxy ¶
func NewResponseCallbackProxy( remote binder.IBinder, ) *ResponseCallbackProxy
func (*ResponseCallbackProxy) AsBinder ¶
func (p *ResponseCallbackProxy) AsBinder() binder.IBinder
func (*ResponseCallbackProxy) OnFailure ¶
func (p *ResponseCallbackProxy) OnFailure( ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle, ) error
type ResponseCallbackStub ¶
type ResponseCallbackStub struct {
Impl IResponseCallback
Transport binder.VersionAwareTransport
}
ResponseCallbackStub dispatches incoming binder transactions to a typed IResponseCallback implementation.
func (*ResponseCallbackStub) Descriptor ¶
func (s *ResponseCallbackStub) Descriptor() string
func (*ResponseCallbackStub) OnTransaction ¶
func (s *ResponseCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type StreamingResponseCallbackProxy ¶
func NewStreamingResponseCallbackProxy ¶
func NewStreamingResponseCallbackProxy( remote binder.IBinder, ) *StreamingResponseCallbackProxy
func (*StreamingResponseCallbackProxy) AsBinder ¶
func (p *StreamingResponseCallbackProxy) AsBinder() binder.IBinder
func (*StreamingResponseCallbackProxy) OnFailure ¶
func (p *StreamingResponseCallbackProxy) OnFailure( ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle, ) error
func (*StreamingResponseCallbackProxy) OnNewContent ¶
func (p *StreamingResponseCallbackProxy) OnNewContent( ctx context.Context, result Content, ) error
type StreamingResponseCallbackStub ¶
type StreamingResponseCallbackStub struct {
Impl IStreamingResponseCallback
Transport binder.VersionAwareTransport
}
StreamingResponseCallbackStub dispatches incoming binder transactions to a typed IStreamingResponseCallback implementation.
func (*StreamingResponseCallbackStub) Descriptor ¶
func (s *StreamingResponseCallbackStub) Descriptor() string
func (*StreamingResponseCallbackStub) OnTransaction ¶
func (s *StreamingResponseCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type TokenCountCallbackProxy ¶
func NewTokenCountCallbackProxy ¶
func NewTokenCountCallbackProxy( remote binder.IBinder, ) *TokenCountCallbackProxy
func (*TokenCountCallbackProxy) AsBinder ¶
func (p *TokenCountCallbackProxy) AsBinder() binder.IBinder
func (*TokenCountCallbackProxy) OnFailure ¶
func (p *TokenCountCallbackProxy) OnFailure( ctx context.Context, errorCode int32, errorMessage string, errorParams os.PersistableBundle, ) error
type TokenCountCallbackStub ¶
type TokenCountCallbackStub struct {
Impl ITokenCountCallback
Transport binder.VersionAwareTransport
}
TokenCountCallbackStub dispatches incoming binder transactions to a typed ITokenCountCallback implementation.
func (*TokenCountCallbackStub) Descriptor ¶
func (s *TokenCountCallbackStub) Descriptor() string
func (*TokenCountCallbackStub) OnTransaction ¶
func (s *TokenCountCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)