Documentation
¶
Index ¶
- Constants
- type ISmartspaceCallback
- type ISmartspaceCallbackServer
- type ISmartspaceManager
- type ISmartspaceManagerServer
- type SmartspaceCallbackProxy
- type SmartspaceCallbackStub
- type SmartspaceConfig
- type SmartspaceManagerProxy
- func (p *SmartspaceManagerProxy) AsBinder() binder.IBinder
- func (p *SmartspaceManagerProxy) CreateSmartspaceSession(ctx context.Context, config SmartspaceConfig, sessionId SmartspaceSessionId, ...) error
- func (p *SmartspaceManagerProxy) DestroySmartspaceSession(ctx context.Context, sessionId SmartspaceSessionId) error
- func (p *SmartspaceManagerProxy) NotifySmartspaceEvent(ctx context.Context, sessionId SmartspaceSessionId, ...) error
- func (p *SmartspaceManagerProxy) RegisterSmartspaceUpdates(ctx context.Context, sessionId SmartspaceSessionId, ...) error
- func (p *SmartspaceManagerProxy) RequestSmartspaceUpdate(ctx context.Context, sessionId SmartspaceSessionId) error
- func (p *SmartspaceManagerProxy) UnregisterSmartspaceUpdates(ctx context.Context, sessionId SmartspaceSessionId, ...) error
- type SmartspaceManagerStub
- type SmartspaceSessionId
- type SmartspaceTarget
- type SmartspaceTargetEvent
Constants ¶
const ( TransactionISmartspaceManagerCreateSmartspaceSession = binder.FirstCallTransaction + 0 TransactionISmartspaceManagerNotifySmartspaceEvent = binder.FirstCallTransaction + 1 TransactionISmartspaceManagerRequestSmartspaceUpdate = binder.FirstCallTransaction + 2 TransactionISmartspaceManagerRegisterSmartspaceUpdates = binder.FirstCallTransaction + 3 TransactionISmartspaceManagerUnregisterSmartspaceUpdates = binder.FirstCallTransaction + 4 TransactionISmartspaceManagerDestroySmartspaceSession = binder.FirstCallTransaction + 5 )
const ( MethodISmartspaceManagerCreateSmartspaceSession = "createSmartspaceSession" MethodISmartspaceManagerNotifySmartspaceEvent = "notifySmartspaceEvent" MethodISmartspaceManagerRequestSmartspaceUpdate = "requestSmartspaceUpdate" MethodISmartspaceManagerRegisterSmartspaceUpdates = "registerSmartspaceUpdates" MethodISmartspaceManagerUnregisterSmartspaceUpdates = "unregisterSmartspaceUpdates" MethodISmartspaceManagerDestroySmartspaceSession = "destroySmartspaceSession" )
const DescriptorISmartspaceCallback = "android.app.smartspace.ISmartspaceCallback"
const DescriptorISmartspaceManager = "android.app.smartspace.ISmartspaceManager"
const (
MethodISmartspaceCallbackOnResult = "onResult"
)
const (
TransactionISmartspaceCallbackOnResult = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ISmartspaceCallback ¶
type ISmartspaceCallback interface {
AsBinder() binder.IBinder
OnResult(ctx context.Context, result pm.ParceledListSlice) error
}
func NewSmartspaceCallbackStub ¶
func NewSmartspaceCallbackStub( impl ISmartspaceCallbackServer, ) ISmartspaceCallback
NewSmartspaceCallbackStub creates a server-side ISmartspaceCallback wrapping the given server implementation. The returned value satisfies ISmartspaceCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ISmartspaceCallbackServer ¶
type ISmartspaceCallbackServer interface {
OnResult(ctx context.Context, result pm.ParceledListSlice) error
}
ISmartspaceCallbackServer is the server-side interface that user implementations provide to NewSmartspaceCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ISmartspaceManager ¶
type ISmartspaceManager interface {
AsBinder() binder.IBinder
CreateSmartspaceSession(ctx context.Context, config SmartspaceConfig, sessionId SmartspaceSessionId, token binder.IBinder) error
NotifySmartspaceEvent(ctx context.Context, sessionId SmartspaceSessionId, event SmartspaceTargetEvent) error
RequestSmartspaceUpdate(ctx context.Context, sessionId SmartspaceSessionId) error
RegisterSmartspaceUpdates(ctx context.Context, sessionId SmartspaceSessionId, callback ISmartspaceCallback) error
UnregisterSmartspaceUpdates(ctx context.Context, sessionId SmartspaceSessionId, callback ISmartspaceCallback) error
DestroySmartspaceSession(ctx context.Context, sessionId SmartspaceSessionId) error
}
func NewSmartspaceManagerStub ¶
func NewSmartspaceManagerStub( impl ISmartspaceManagerServer, ) ISmartspaceManager
NewSmartspaceManagerStub creates a server-side ISmartspaceManager wrapping the given server implementation. The returned value satisfies ISmartspaceManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ISmartspaceManagerServer ¶
type ISmartspaceManagerServer interface {
CreateSmartspaceSession(ctx context.Context, config SmartspaceConfig, sessionId SmartspaceSessionId, token binder.IBinder) error
NotifySmartspaceEvent(ctx context.Context, sessionId SmartspaceSessionId, event SmartspaceTargetEvent) error
RequestSmartspaceUpdate(ctx context.Context, sessionId SmartspaceSessionId) error
RegisterSmartspaceUpdates(ctx context.Context, sessionId SmartspaceSessionId, callback ISmartspaceCallback) error
UnregisterSmartspaceUpdates(ctx context.Context, sessionId SmartspaceSessionId, callback ISmartspaceCallback) error
DestroySmartspaceSession(ctx context.Context, sessionId SmartspaceSessionId) error
}
ISmartspaceManagerServer is the server-side interface that user implementations provide to NewSmartspaceManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type SmartspaceCallbackProxy ¶
func NewSmartspaceCallbackProxy ¶
func NewSmartspaceCallbackProxy( remote binder.IBinder, ) *SmartspaceCallbackProxy
func (*SmartspaceCallbackProxy) AsBinder ¶
func (p *SmartspaceCallbackProxy) AsBinder() binder.IBinder
func (*SmartspaceCallbackProxy) OnResult ¶
func (p *SmartspaceCallbackProxy) OnResult( ctx context.Context, result pm.ParceledListSlice, ) error
type SmartspaceCallbackStub ¶
type SmartspaceCallbackStub struct {
Impl ISmartspaceCallback
Transport binder.VersionAwareTransport
}
SmartspaceCallbackStub dispatches incoming binder transactions to a typed ISmartspaceCallback implementation.
func (*SmartspaceCallbackStub) Descriptor ¶
func (s *SmartspaceCallbackStub) Descriptor() string
func (*SmartspaceCallbackStub) OnTransaction ¶
func (s *SmartspaceCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type SmartspaceConfig ¶
func (*SmartspaceConfig) MarshalParcel ¶
func (s *SmartspaceConfig) MarshalParcel( p *parcel.Parcel, ) error
func (*SmartspaceConfig) UnmarshalParcel ¶
func (s *SmartspaceConfig) UnmarshalParcel( p *parcel.Parcel, ) error
type SmartspaceManagerProxy ¶
func NewSmartspaceManagerProxy ¶
func NewSmartspaceManagerProxy( remote binder.IBinder, ) *SmartspaceManagerProxy
func (*SmartspaceManagerProxy) AsBinder ¶
func (p *SmartspaceManagerProxy) AsBinder() binder.IBinder
func (*SmartspaceManagerProxy) CreateSmartspaceSession ¶
func (p *SmartspaceManagerProxy) CreateSmartspaceSession( ctx context.Context, config SmartspaceConfig, sessionId SmartspaceSessionId, token binder.IBinder, ) error
func (*SmartspaceManagerProxy) DestroySmartspaceSession ¶
func (p *SmartspaceManagerProxy) DestroySmartspaceSession( ctx context.Context, sessionId SmartspaceSessionId, ) error
func (*SmartspaceManagerProxy) NotifySmartspaceEvent ¶
func (p *SmartspaceManagerProxy) NotifySmartspaceEvent( ctx context.Context, sessionId SmartspaceSessionId, event SmartspaceTargetEvent, ) error
func (*SmartspaceManagerProxy) RegisterSmartspaceUpdates ¶
func (p *SmartspaceManagerProxy) RegisterSmartspaceUpdates( ctx context.Context, sessionId SmartspaceSessionId, callback ISmartspaceCallback, ) error
func (*SmartspaceManagerProxy) RequestSmartspaceUpdate ¶
func (p *SmartspaceManagerProxy) RequestSmartspaceUpdate( ctx context.Context, sessionId SmartspaceSessionId, ) error
func (*SmartspaceManagerProxy) UnregisterSmartspaceUpdates ¶
func (p *SmartspaceManagerProxy) UnregisterSmartspaceUpdates( ctx context.Context, sessionId SmartspaceSessionId, callback ISmartspaceCallback, ) error
type SmartspaceManagerStub ¶
type SmartspaceManagerStub struct {
Impl ISmartspaceManager
Transport binder.VersionAwareTransport
}
SmartspaceManagerStub dispatches incoming binder transactions to a typed ISmartspaceManager implementation.
func (*SmartspaceManagerStub) Descriptor ¶
func (s *SmartspaceManagerStub) Descriptor() string
func (*SmartspaceManagerStub) OnTransaction ¶
func (s *SmartspaceManagerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type SmartspaceSessionId ¶
type SmartspaceSessionId struct {
Id string
}
func (*SmartspaceSessionId) MarshalParcel ¶
func (s *SmartspaceSessionId) MarshalParcel( p *parcel.Parcel, ) error
func (*SmartspaceSessionId) UnmarshalParcel ¶
func (s *SmartspaceSessionId) UnmarshalParcel( p *parcel.Parcel, ) error
type SmartspaceTarget ¶
type SmartspaceTarget struct {
}
func (*SmartspaceTarget) MarshalParcel ¶
func (s *SmartspaceTarget) MarshalParcel( p *parcel.Parcel, ) error
func (*SmartspaceTarget) UnmarshalParcel ¶
func (s *SmartspaceTarget) UnmarshalParcel( p *parcel.Parcel, ) error
type SmartspaceTargetEvent ¶
type SmartspaceTargetEvent struct {
SmartspaceActionId string
EventType int32
SmartspaceTarget *SmartspaceTarget
}
func (*SmartspaceTargetEvent) MarshalParcel ¶
func (s *SmartspaceTargetEvent) MarshalParcel( p *parcel.Parcel, ) error
func (*SmartspaceTargetEvent) UnmarshalParcel ¶
func (s *SmartspaceTargetEvent) UnmarshalParcel( p *parcel.Parcel, ) error