Documentation
¶
Index ¶
- Constants
- type ExternalTimeSuggestion
- type ITimeDetectorListener
- type ITimeDetectorListenerServer
- type ITimeZoneDetectorListener
- type ITimeZoneDetectorListenerServer
- type LocationTimeZoneAlgorithmStatus
- type TelephonyTimeZoneAlgorithmStatus
- type TimeCapabilities
- type TimeCapabilitiesAndConfig
- type TimeConfiguration
- type TimeDetectorListenerProxy
- type TimeDetectorListenerStub
- type TimeState
- type TimeZoneCapabilities
- type TimeZoneCapabilitiesAndConfig
- type TimeZoneConfiguration
- type TimeZoneDetectorListenerProxy
- type TimeZoneDetectorListenerStub
- type TimeZoneDetectorStatus
- type TimeZoneState
- type UnixEpochTime
Constants ¶
const DescriptorITimeDetectorListener = "android.app.time.ITimeDetectorListener"
const DescriptorITimeZoneDetectorListener = "android.app.time.ITimeZoneDetectorListener"
const (
MethodITimeDetectorListenerOnChange = "onChange"
)
const (
MethodITimeZoneDetectorListenerOnChange = "onChange"
)
const (
TransactionITimeDetectorListenerOnChange = binder.FirstCallTransaction + 0
)
const (
TransactionITimeZoneDetectorListenerOnChange = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExternalTimeSuggestion ¶
type ExternalTimeSuggestion struct {
}
func (*ExternalTimeSuggestion) MarshalParcel ¶
func (s *ExternalTimeSuggestion) MarshalParcel( p *parcel.Parcel, ) error
func (*ExternalTimeSuggestion) UnmarshalParcel ¶
func (s *ExternalTimeSuggestion) UnmarshalParcel( p *parcel.Parcel, ) error
type ITimeDetectorListener ¶
type ITimeDetectorListener interface {
AsBinder() binder.IBinder
OnChange(ctx context.Context) error
}
func NewTimeDetectorListenerStub ¶
func NewTimeDetectorListenerStub( impl ITimeDetectorListenerServer, ) ITimeDetectorListener
NewTimeDetectorListenerStub creates a server-side ITimeDetectorListener wrapping the given server implementation. The returned value satisfies ITimeDetectorListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITimeDetectorListenerServer ¶
ITimeDetectorListenerServer is the server-side interface that user implementations provide to NewTimeDetectorListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ITimeZoneDetectorListener ¶
type ITimeZoneDetectorListener interface {
AsBinder() binder.IBinder
OnChange(ctx context.Context) error
}
func NewTimeZoneDetectorListenerStub ¶
func NewTimeZoneDetectorListenerStub( impl ITimeZoneDetectorListenerServer, ) ITimeZoneDetectorListener
NewTimeZoneDetectorListenerStub creates a server-side ITimeZoneDetectorListener wrapping the given server implementation. The returned value satisfies ITimeZoneDetectorListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITimeZoneDetectorListenerServer ¶
ITimeZoneDetectorListenerServer is the server-side interface that user implementations provide to NewTimeZoneDetectorListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type LocationTimeZoneAlgorithmStatus ¶
type LocationTimeZoneAlgorithmStatus struct {
Status int32
PrimaryProviderStatus int32
SecondaryProviderStatus int32
}
func (*LocationTimeZoneAlgorithmStatus) MarshalParcel ¶
func (s *LocationTimeZoneAlgorithmStatus) MarshalParcel( p *parcel.Parcel, ) error
func (*LocationTimeZoneAlgorithmStatus) UnmarshalParcel ¶
func (s *LocationTimeZoneAlgorithmStatus) UnmarshalParcel( p *parcel.Parcel, ) error
type TelephonyTimeZoneAlgorithmStatus ¶
type TelephonyTimeZoneAlgorithmStatus struct {
AlgorithmStatus int32
}
func (*TelephonyTimeZoneAlgorithmStatus) MarshalParcel ¶
func (s *TelephonyTimeZoneAlgorithmStatus) MarshalParcel( p *parcel.Parcel, ) error
func (*TelephonyTimeZoneAlgorithmStatus) UnmarshalParcel ¶
func (s *TelephonyTimeZoneAlgorithmStatus) UnmarshalParcel( p *parcel.Parcel, ) error
type TimeCapabilities ¶
type TimeCapabilities struct {
ConfigureAutoDetectionEnabledCapability int32
SetManualTimeCapability int32
}
func (*TimeCapabilities) MarshalParcel ¶
func (s *TimeCapabilities) MarshalParcel( p *parcel.Parcel, ) error
func (*TimeCapabilities) UnmarshalParcel ¶
func (s *TimeCapabilities) UnmarshalParcel( p *parcel.Parcel, ) error
type TimeCapabilitiesAndConfig ¶
type TimeCapabilitiesAndConfig struct {
Capabilities *neuralnetworks.Capabilities
Configuration *res.Configuration
}
func (*TimeCapabilitiesAndConfig) MarshalParcel ¶
func (s *TimeCapabilitiesAndConfig) MarshalParcel( p *parcel.Parcel, ) error
func (*TimeCapabilitiesAndConfig) UnmarshalParcel ¶
func (s *TimeCapabilitiesAndConfig) UnmarshalParcel( p *parcel.Parcel, ) error
type TimeConfiguration ¶
type TimeConfiguration struct {
}
func (*TimeConfiguration) MarshalParcel ¶
func (s *TimeConfiguration) MarshalParcel( p *parcel.Parcel, ) error
func (*TimeConfiguration) UnmarshalParcel ¶
func (s *TimeConfiguration) UnmarshalParcel( p *parcel.Parcel, ) error
type TimeDetectorListenerProxy ¶
func NewTimeDetectorListenerProxy ¶
func NewTimeDetectorListenerProxy( remote binder.IBinder, ) *TimeDetectorListenerProxy
func (*TimeDetectorListenerProxy) AsBinder ¶
func (p *TimeDetectorListenerProxy) AsBinder() binder.IBinder
type TimeDetectorListenerStub ¶
type TimeDetectorListenerStub struct {
Impl ITimeDetectorListener
Transport binder.VersionAwareTransport
}
TimeDetectorListenerStub dispatches incoming binder transactions to a typed ITimeDetectorListener implementation.
func (*TimeDetectorListenerStub) Descriptor ¶
func (s *TimeDetectorListenerStub) Descriptor() string
func (*TimeDetectorListenerStub) OnTransaction ¶
func (s *TimeDetectorListenerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type TimeState ¶
type TimeState struct {
UserShouldConfirmTime bool
UnixEpochTime *UnixEpochTime
}
type TimeZoneCapabilities ¶
type TimeZoneCapabilities struct {
ConfigureAutoDetectionEnabledCapability int32
UseLocationEnabled bool
ConfigureGeoDetectionEnabledCapability int32
SetManualTimeZoneCapability int32
}
func (*TimeZoneCapabilities) MarshalParcel ¶
func (s *TimeZoneCapabilities) MarshalParcel( p *parcel.Parcel, ) error
func (*TimeZoneCapabilities) UnmarshalParcel ¶
func (s *TimeZoneCapabilities) UnmarshalParcel( p *parcel.Parcel, ) error
type TimeZoneCapabilitiesAndConfig ¶
type TimeZoneCapabilitiesAndConfig struct {
Capabilities *neuralnetworks.Capabilities
Configuration *res.Configuration
}
func (*TimeZoneCapabilitiesAndConfig) MarshalParcel ¶
func (s *TimeZoneCapabilitiesAndConfig) MarshalParcel( p *parcel.Parcel, ) error
func (*TimeZoneCapabilitiesAndConfig) UnmarshalParcel ¶
func (s *TimeZoneCapabilitiesAndConfig) UnmarshalParcel( p *parcel.Parcel, ) error
type TimeZoneConfiguration ¶
type TimeZoneConfiguration struct {
}
func (*TimeZoneConfiguration) MarshalParcel ¶
func (s *TimeZoneConfiguration) MarshalParcel( p *parcel.Parcel, ) error
func (*TimeZoneConfiguration) UnmarshalParcel ¶
func (s *TimeZoneConfiguration) UnmarshalParcel( p *parcel.Parcel, ) error
type TimeZoneDetectorListenerProxy ¶
func NewTimeZoneDetectorListenerProxy ¶
func NewTimeZoneDetectorListenerProxy( remote binder.IBinder, ) *TimeZoneDetectorListenerProxy
func (*TimeZoneDetectorListenerProxy) AsBinder ¶
func (p *TimeZoneDetectorListenerProxy) AsBinder() binder.IBinder
type TimeZoneDetectorListenerStub ¶
type TimeZoneDetectorListenerStub struct {
Impl ITimeZoneDetectorListener
Transport binder.VersionAwareTransport
}
TimeZoneDetectorListenerStub dispatches incoming binder transactions to a typed ITimeZoneDetectorListener implementation.
func (*TimeZoneDetectorListenerStub) Descriptor ¶
func (s *TimeZoneDetectorListenerStub) Descriptor() string
func (*TimeZoneDetectorListenerStub) OnTransaction ¶
func (s *TimeZoneDetectorListenerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type TimeZoneDetectorStatus ¶
type TimeZoneDetectorStatus struct {
DetectorStatus int32
TelephonyTimeZoneAlgorithmStatus *TelephonyTimeZoneAlgorithmStatus
LocationTimeZoneAlgorithmStatus *LocationTimeZoneAlgorithmStatus
}
func (*TimeZoneDetectorStatus) MarshalParcel ¶
func (s *TimeZoneDetectorStatus) MarshalParcel( p *parcel.Parcel, ) error
func (*TimeZoneDetectorStatus) UnmarshalParcel ¶
func (s *TimeZoneDetectorStatus) UnmarshalParcel( p *parcel.Parcel, ) error
type TimeZoneState ¶
func (*TimeZoneState) MarshalParcel ¶
func (s *TimeZoneState) MarshalParcel( p *parcel.Parcel, ) error
func (*TimeZoneState) UnmarshalParcel ¶
func (s *TimeZoneState) UnmarshalParcel( p *parcel.Parcel, ) error
type UnixEpochTime ¶
func (*UnixEpochTime) MarshalParcel ¶
func (s *UnixEpochTime) MarshalParcel( p *parcel.Parcel, ) error
func (*UnixEpochTime) UnmarshalParcel ¶
func (s *UnixEpochTime) UnmarshalParcel( p *parcel.Parcel, ) error
Source Files
¶
- externaltimesuggestion.go
- itimedetectorlistener.go
- itimezonedetectorlistener.go
- locationtimezonealgorithmstatus.go
- telephonytimezonealgorithmstatus.go
- timecapabilities.go
- timecapabilitiesandconfig.go
- timeconfiguration.go
- timestate.go
- timezonecapabilities.go
- timezonecapabilitiesandconfig.go
- timezoneconfiguration.go
- timezonedetectorstatus.go
- timezonestate.go
- unixepochtime.go