Documentation
¶
Index ¶
- Constants
- type IStrongAuthTracker
- type IStrongAuthTrackerServer
- type ITrustListener
- type ITrustListenerServer
- type ITrustManager
- type ITrustManagerServer
- type StrongAuthTrackerProxy
- type StrongAuthTrackerStub
- type TrustListenerProxy
- func (p *TrustListenerProxy) AsBinder() binder.IBinder
- func (p *TrustListenerProxy) OnEnabledTrustAgentsChanged(ctx context.Context) error
- func (p *TrustListenerProxy) OnIsActiveUnlockRunningChanged(ctx context.Context, isRunning bool) error
- func (p *TrustListenerProxy) OnTrustChanged(ctx context.Context, enabled bool, newlyUnlocked bool, flags int32, ...) error
- func (p *TrustListenerProxy) OnTrustError(ctx context.Context, message string) error
- func (p *TrustListenerProxy) OnTrustManagedChanged(ctx context.Context, managed bool) error
- type TrustListenerStub
- type TrustManagerProxy
- func (p *TrustManagerProxy) AsBinder() binder.IBinder
- func (p *TrustManagerProxy) ClearAllBiometricRecognized(ctx context.Context, target biometrics.BiometricSourceType, unlockedUser int32) error
- func (p *TrustManagerProxy) IsActiveUnlockRunning(ctx context.Context) (bool, error)
- func (p *TrustManagerProxy) IsDeviceLocked(ctx context.Context, deviceId int32) (bool, error)
- func (p *TrustManagerProxy) IsDeviceSecure(ctx context.Context, deviceId int32) (bool, error)
- func (p *TrustManagerProxy) IsTrustUsuallyManaged(ctx context.Context) (bool, error)
- func (p *TrustManagerProxy) RegisterTrustListener(ctx context.Context, trustListener ITrustListener) error
- func (p *TrustManagerProxy) ReportEnabledTrustAgentsChanged(ctx context.Context) error
- func (p *TrustManagerProxy) ReportKeyguardShowingChanged(ctx context.Context) error
- func (p *TrustManagerProxy) ReportUnlockAttempt(ctx context.Context, successful bool) error
- func (p *TrustManagerProxy) ReportUnlockLockout(ctx context.Context, timeoutMs int32) error
- func (p *TrustManagerProxy) ReportUserMayRequestUnlock(ctx context.Context) error
- func (p *TrustManagerProxy) ReportUserRequestedUnlock(ctx context.Context, dismissKeyguard bool) error
- func (p *TrustManagerProxy) SetDeviceLockedForUser(ctx context.Context, locked bool) error
- func (p *TrustManagerProxy) UnlockedByBiometricForUser(ctx context.Context, source biometrics.BiometricSourceType) error
- func (p *TrustManagerProxy) UnregisterTrustListener(ctx context.Context, trustListener ITrustListener) error
- type TrustManagerStub
Constants ¶
const ( TransactionIStrongAuthTrackerOnStrongAuthRequiredChanged = binder.FirstCallTransaction + 0 TransactionIStrongAuthTrackerOnIsNonStrongBiometricAllowedChanged = binder.FirstCallTransaction + 1 )
const ( MethodIStrongAuthTrackerOnStrongAuthRequiredChanged = "onStrongAuthRequiredChanged" MethodIStrongAuthTrackerOnIsNonStrongBiometricAllowedChanged = "onIsNonStrongBiometricAllowedChanged" )
const ( TransactionITrustListenerOnEnabledTrustAgentsChanged = binder.FirstCallTransaction + 0 TransactionITrustListenerOnTrustChanged = binder.FirstCallTransaction + 1 TransactionITrustListenerOnTrustManagedChanged = binder.FirstCallTransaction + 2 TransactionITrustListenerOnTrustError = binder.FirstCallTransaction + 3 TransactionITrustListenerOnIsActiveUnlockRunningChanged = binder.FirstCallTransaction + 4 )
const ( MethodITrustListenerOnEnabledTrustAgentsChanged = "onEnabledTrustAgentsChanged" MethodITrustListenerOnTrustChanged = "onTrustChanged" MethodITrustListenerOnTrustManagedChanged = "onTrustManagedChanged" MethodITrustListenerOnTrustError = "onTrustError" MethodITrustListenerOnIsActiveUnlockRunningChanged = "onIsActiveUnlockRunningChanged" )
const ( TransactionITrustManagerReportUnlockAttempt = binder.FirstCallTransaction + 0 TransactionITrustManagerReportUserRequestedUnlock = binder.FirstCallTransaction + 1 TransactionITrustManagerReportUserMayRequestUnlock = binder.FirstCallTransaction + 2 TransactionITrustManagerReportUnlockLockout = binder.FirstCallTransaction + 3 TransactionITrustManagerReportEnabledTrustAgentsChanged = binder.FirstCallTransaction + 4 TransactionITrustManagerRegisterTrustListener = binder.FirstCallTransaction + 5 TransactionITrustManagerUnregisterTrustListener = binder.FirstCallTransaction + 6 TransactionITrustManagerReportKeyguardShowingChanged = binder.FirstCallTransaction + 7 TransactionITrustManagerSetDeviceLockedForUser = binder.FirstCallTransaction + 8 TransactionITrustManagerIsDeviceLocked = binder.FirstCallTransaction + 9 TransactionITrustManagerIsDeviceSecure = binder.FirstCallTransaction + 10 TransactionITrustManagerIsTrustUsuallyManaged = binder.FirstCallTransaction + 11 TransactionITrustManagerUnlockedByBiometricForUser = binder.FirstCallTransaction + 12 TransactionITrustManagerClearAllBiometricRecognized = binder.FirstCallTransaction + 13 TransactionITrustManagerIsActiveUnlockRunning = binder.FirstCallTransaction + 14 )
const ( MethodITrustManagerReportUnlockAttempt = "reportUnlockAttempt" MethodITrustManagerReportUserRequestedUnlock = "reportUserRequestedUnlock" MethodITrustManagerReportUserMayRequestUnlock = "reportUserMayRequestUnlock" MethodITrustManagerReportUnlockLockout = "reportUnlockLockout" MethodITrustManagerReportEnabledTrustAgentsChanged = "reportEnabledTrustAgentsChanged" MethodITrustManagerRegisterTrustListener = "registerTrustListener" MethodITrustManagerUnregisterTrustListener = "unregisterTrustListener" MethodITrustManagerReportKeyguardShowingChanged = "reportKeyguardShowingChanged" MethodITrustManagerSetDeviceLockedForUser = "setDeviceLockedForUser" MethodITrustManagerIsDeviceLocked = "isDeviceLocked" MethodITrustManagerIsDeviceSecure = "isDeviceSecure" MethodITrustManagerIsTrustUsuallyManaged = "isTrustUsuallyManaged" MethodITrustManagerUnlockedByBiometricForUser = "unlockedByBiometricForUser" MethodITrustManagerClearAllBiometricRecognized = "clearAllBiometricRecognized" MethodITrustManagerIsActiveUnlockRunning = "isActiveUnlockRunning" )
const DescriptorIStrongAuthTracker = "android.app.trust.IStrongAuthTracker"
const DescriptorITrustListener = "android.app.trust.ITrustListener"
const DescriptorITrustManager = "android.app.trust.ITrustManager"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IStrongAuthTracker ¶
type IStrongAuthTracker interface {
AsBinder() binder.IBinder
OnStrongAuthRequiredChanged(ctx context.Context, strongAuthRequired int32) error
OnIsNonStrongBiometricAllowedChanged(ctx context.Context, allowed bool) error
}
func NewStrongAuthTrackerStub ¶
func NewStrongAuthTrackerStub( impl IStrongAuthTrackerServer, ) IStrongAuthTracker
NewStrongAuthTrackerStub creates a server-side IStrongAuthTracker wrapping the given server implementation. The returned value satisfies IStrongAuthTracker and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IStrongAuthTrackerServer ¶
type IStrongAuthTrackerServer interface {
OnStrongAuthRequiredChanged(ctx context.Context, strongAuthRequired int32) error
OnIsNonStrongBiometricAllowedChanged(ctx context.Context, allowed bool) error
}
IStrongAuthTrackerServer is the server-side interface that user implementations provide to NewStrongAuthTrackerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ITrustListener ¶
type ITrustListener interface {
AsBinder() binder.IBinder
OnEnabledTrustAgentsChanged(ctx context.Context) error
OnTrustChanged(ctx context.Context, enabled bool, newlyUnlocked bool, flags int32, trustGrantedMessages []string) error
OnTrustManagedChanged(ctx context.Context, managed bool) error
OnTrustError(ctx context.Context, message string) error
OnIsActiveUnlockRunningChanged(ctx context.Context, isRunning bool) error
}
func NewTrustListenerStub ¶
func NewTrustListenerStub( impl ITrustListenerServer, ) ITrustListener
NewTrustListenerStub creates a server-side ITrustListener wrapping the given server implementation. The returned value satisfies ITrustListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITrustListenerServer ¶
type ITrustListenerServer interface {
OnEnabledTrustAgentsChanged(ctx context.Context) error
OnTrustChanged(ctx context.Context, enabled bool, newlyUnlocked bool, flags int32, trustGrantedMessages []string) error
OnTrustManagedChanged(ctx context.Context, managed bool) error
OnTrustError(ctx context.Context, message string) error
OnIsActiveUnlockRunningChanged(ctx context.Context, isRunning bool) error
}
ITrustListenerServer is the server-side interface that user implementations provide to NewTrustListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ITrustManager ¶
type ITrustManager interface {
AsBinder() binder.IBinder
ReportUnlockAttempt(ctx context.Context, successful bool) error
ReportUserRequestedUnlock(ctx context.Context, dismissKeyguard bool) error
ReportUserMayRequestUnlock(ctx context.Context) error
ReportUnlockLockout(ctx context.Context, timeoutMs int32) error
ReportEnabledTrustAgentsChanged(ctx context.Context) error
RegisterTrustListener(ctx context.Context, trustListener ITrustListener) error
UnregisterTrustListener(ctx context.Context, trustListener ITrustListener) error
ReportKeyguardShowingChanged(ctx context.Context) error
SetDeviceLockedForUser(ctx context.Context, locked bool) error
IsDeviceLocked(ctx context.Context, deviceId int32) (bool, error)
IsDeviceSecure(ctx context.Context, deviceId int32) (bool, error)
IsTrustUsuallyManaged(ctx context.Context) (bool, error)
UnlockedByBiometricForUser(ctx context.Context, source biometrics.BiometricSourceType) error
ClearAllBiometricRecognized(ctx context.Context, target biometrics.BiometricSourceType, unlockedUser int32) error
IsActiveUnlockRunning(ctx context.Context) (bool, error)
}
func NewTrustManagerStub ¶
func NewTrustManagerStub( impl ITrustManagerServer, ) ITrustManager
NewTrustManagerStub creates a server-side ITrustManager wrapping the given server implementation. The returned value satisfies ITrustManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITrustManagerServer ¶
type ITrustManagerServer interface {
ReportUnlockAttempt(ctx context.Context, successful bool) error
ReportUserRequestedUnlock(ctx context.Context, dismissKeyguard bool) error
ReportUserMayRequestUnlock(ctx context.Context) error
ReportUnlockLockout(ctx context.Context, timeoutMs int32) error
ReportEnabledTrustAgentsChanged(ctx context.Context) error
RegisterTrustListener(ctx context.Context, trustListener ITrustListener) error
UnregisterTrustListener(ctx context.Context, trustListener ITrustListener) error
ReportKeyguardShowingChanged(ctx context.Context) error
SetDeviceLockedForUser(ctx context.Context, locked bool) error
IsDeviceLocked(ctx context.Context, deviceId int32) (bool, error)
IsDeviceSecure(ctx context.Context, deviceId int32) (bool, error)
IsTrustUsuallyManaged(ctx context.Context) (bool, error)
UnlockedByBiometricForUser(ctx context.Context, source biometrics.BiometricSourceType) error
ClearAllBiometricRecognized(ctx context.Context, target biometrics.BiometricSourceType, unlockedUser int32) error
IsActiveUnlockRunning(ctx context.Context) (bool, error)
}
ITrustManagerServer is the server-side interface that user implementations provide to NewTrustManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type StrongAuthTrackerProxy ¶
func NewStrongAuthTrackerProxy ¶
func NewStrongAuthTrackerProxy( remote binder.IBinder, ) *StrongAuthTrackerProxy
func (*StrongAuthTrackerProxy) AsBinder ¶
func (p *StrongAuthTrackerProxy) AsBinder() binder.IBinder
func (*StrongAuthTrackerProxy) OnIsNonStrongBiometricAllowedChanged ¶
func (p *StrongAuthTrackerProxy) OnIsNonStrongBiometricAllowedChanged( ctx context.Context, allowed bool, ) error
func (*StrongAuthTrackerProxy) OnStrongAuthRequiredChanged ¶
func (p *StrongAuthTrackerProxy) OnStrongAuthRequiredChanged( ctx context.Context, strongAuthRequired int32, ) error
type StrongAuthTrackerStub ¶
type StrongAuthTrackerStub struct {
Impl IStrongAuthTracker
Transport binder.VersionAwareTransport
}
StrongAuthTrackerStub dispatches incoming binder transactions to a typed IStrongAuthTracker implementation.
func (*StrongAuthTrackerStub) Descriptor ¶
func (s *StrongAuthTrackerStub) Descriptor() string
func (*StrongAuthTrackerStub) OnTransaction ¶
func (s *StrongAuthTrackerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type TrustListenerProxy ¶
func NewTrustListenerProxy ¶
func NewTrustListenerProxy( remote binder.IBinder, ) *TrustListenerProxy
func (*TrustListenerProxy) AsBinder ¶
func (p *TrustListenerProxy) AsBinder() binder.IBinder
func (*TrustListenerProxy) OnEnabledTrustAgentsChanged ¶
func (p *TrustListenerProxy) OnEnabledTrustAgentsChanged( ctx context.Context, ) error
func (*TrustListenerProxy) OnIsActiveUnlockRunningChanged ¶
func (p *TrustListenerProxy) OnIsActiveUnlockRunningChanged( ctx context.Context, isRunning bool, ) error
func (*TrustListenerProxy) OnTrustChanged ¶
func (*TrustListenerProxy) OnTrustError ¶
func (p *TrustListenerProxy) OnTrustError( ctx context.Context, message string, ) error
func (*TrustListenerProxy) OnTrustManagedChanged ¶
func (p *TrustListenerProxy) OnTrustManagedChanged( ctx context.Context, managed bool, ) error
type TrustListenerStub ¶
type TrustListenerStub struct {
Impl ITrustListener
Transport binder.VersionAwareTransport
}
TrustListenerStub dispatches incoming binder transactions to a typed ITrustListener implementation.
func (*TrustListenerStub) Descriptor ¶
func (s *TrustListenerStub) Descriptor() string
func (*TrustListenerStub) OnTransaction ¶
func (s *TrustListenerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type TrustManagerProxy ¶
func NewTrustManagerProxy ¶
func NewTrustManagerProxy( remote binder.IBinder, ) *TrustManagerProxy
func (*TrustManagerProxy) AsBinder ¶
func (p *TrustManagerProxy) AsBinder() binder.IBinder
func (*TrustManagerProxy) ClearAllBiometricRecognized ¶
func (p *TrustManagerProxy) ClearAllBiometricRecognized( ctx context.Context, target biometrics.BiometricSourceType, unlockedUser int32, ) error
func (*TrustManagerProxy) IsActiveUnlockRunning ¶
func (p *TrustManagerProxy) IsActiveUnlockRunning( ctx context.Context, ) (bool, error)
func (*TrustManagerProxy) IsDeviceLocked ¶
func (*TrustManagerProxy) IsDeviceSecure ¶
func (*TrustManagerProxy) IsTrustUsuallyManaged ¶
func (p *TrustManagerProxy) IsTrustUsuallyManaged( ctx context.Context, ) (bool, error)
func (*TrustManagerProxy) RegisterTrustListener ¶
func (p *TrustManagerProxy) RegisterTrustListener( ctx context.Context, trustListener ITrustListener, ) error
func (*TrustManagerProxy) ReportEnabledTrustAgentsChanged ¶
func (p *TrustManagerProxy) ReportEnabledTrustAgentsChanged( ctx context.Context, ) error
func (*TrustManagerProxy) ReportKeyguardShowingChanged ¶
func (p *TrustManagerProxy) ReportKeyguardShowingChanged( ctx context.Context, ) error
func (*TrustManagerProxy) ReportUnlockAttempt ¶
func (p *TrustManagerProxy) ReportUnlockAttempt( ctx context.Context, successful bool, ) error
func (*TrustManagerProxy) ReportUnlockLockout ¶
func (p *TrustManagerProxy) ReportUnlockLockout( ctx context.Context, timeoutMs int32, ) error
func (*TrustManagerProxy) ReportUserMayRequestUnlock ¶
func (p *TrustManagerProxy) ReportUserMayRequestUnlock( ctx context.Context, ) error
func (*TrustManagerProxy) ReportUserRequestedUnlock ¶
func (p *TrustManagerProxy) ReportUserRequestedUnlock( ctx context.Context, dismissKeyguard bool, ) error
func (*TrustManagerProxy) SetDeviceLockedForUser ¶
func (p *TrustManagerProxy) SetDeviceLockedForUser( ctx context.Context, locked bool, ) error
func (*TrustManagerProxy) UnlockedByBiometricForUser ¶
func (p *TrustManagerProxy) UnlockedByBiometricForUser( ctx context.Context, source biometrics.BiometricSourceType, ) error
func (*TrustManagerProxy) UnregisterTrustListener ¶
func (p *TrustManagerProxy) UnregisterTrustListener( ctx context.Context, trustListener ITrustListener, ) error
type TrustManagerStub ¶
type TrustManagerStub struct {
Impl ITrustManager
Transport binder.VersionAwareTransport
}
TrustManagerStub dispatches incoming binder transactions to a typed ITrustManager implementation.
func (*TrustManagerStub) Descriptor ¶
func (s *TrustManagerStub) Descriptor() string
func (*TrustManagerStub) OnTransaction ¶
func (s *TrustManagerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)