le

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIAdvertisingSetCallbackOnAdvertisingSetStarted                = binder.FirstCallTransaction + 0
	TransactionIAdvertisingSetCallbackOnOwnAddressRead                       = binder.FirstCallTransaction + 1
	TransactionIAdvertisingSetCallbackOnAdvertisingSetStopped                = binder.FirstCallTransaction + 2
	TransactionIAdvertisingSetCallbackOnAdvertisingEnabled                   = binder.FirstCallTransaction + 3
	TransactionIAdvertisingSetCallbackOnAdvertisingDataSet                   = binder.FirstCallTransaction + 4
	TransactionIAdvertisingSetCallbackOnScanResponseDataSet                  = binder.FirstCallTransaction + 5
	TransactionIAdvertisingSetCallbackOnAdvertisingParametersUpdated         = binder.FirstCallTransaction + 6
	TransactionIAdvertisingSetCallbackOnPeriodicAdvertisingParametersUpdated = binder.FirstCallTransaction + 7
	TransactionIAdvertisingSetCallbackOnPeriodicAdvertisingDataSet           = binder.FirstCallTransaction + 8
	TransactionIAdvertisingSetCallbackOnPeriodicAdvertisingEnabled           = binder.FirstCallTransaction + 9
)
const (
	MethodIAdvertisingSetCallbackOnAdvertisingSetStarted                = "onAdvertisingSetStarted"
	MethodIAdvertisingSetCallbackOnOwnAddressRead                       = "onOwnAddressRead"
	MethodIAdvertisingSetCallbackOnAdvertisingSetStopped                = "onAdvertisingSetStopped"
	MethodIAdvertisingSetCallbackOnAdvertisingEnabled                   = "onAdvertisingEnabled"
	MethodIAdvertisingSetCallbackOnAdvertisingDataSet                   = "onAdvertisingDataSet"
	MethodIAdvertisingSetCallbackOnScanResponseDataSet                  = "onScanResponseDataSet"
	MethodIAdvertisingSetCallbackOnAdvertisingParametersUpdated         = "onAdvertisingParametersUpdated"
	MethodIAdvertisingSetCallbackOnPeriodicAdvertisingParametersUpdated = "onPeriodicAdvertisingParametersUpdated"
	MethodIAdvertisingSetCallbackOnPeriodicAdvertisingDataSet           = "onPeriodicAdvertisingDataSet"
	MethodIAdvertisingSetCallbackOnPeriodicAdvertisingEnabled           = "onPeriodicAdvertisingEnabled"
)
const (
	TransactionIDistanceMeasurementCallbackOnStarted   = binder.FirstCallTransaction + 0
	TransactionIDistanceMeasurementCallbackOnStartFail = binder.FirstCallTransaction + 1
	TransactionIDistanceMeasurementCallbackOnStopped   = binder.FirstCallTransaction + 2
	TransactionIDistanceMeasurementCallbackOnResult    = binder.FirstCallTransaction + 3
)
const (
	MethodIDistanceMeasurementCallbackOnStarted   = "onStarted"
	MethodIDistanceMeasurementCallbackOnStartFail = "onStartFail"
	MethodIDistanceMeasurementCallbackOnStopped   = "onStopped"
	MethodIDistanceMeasurementCallbackOnResult    = "onResult"
)
const (
	TransactionIPeriodicAdvertisingCallbackOnSyncEstablished           = binder.FirstCallTransaction + 0
	TransactionIPeriodicAdvertisingCallbackOnPeriodicAdvertisingReport = binder.FirstCallTransaction + 1
	TransactionIPeriodicAdvertisingCallbackOnSyncLost                  = binder.FirstCallTransaction + 2
	TransactionIPeriodicAdvertisingCallbackOnSyncTransferred           = binder.FirstCallTransaction + 3
	TransactionIPeriodicAdvertisingCallbackOnBigInfoAdvertisingReport  = binder.FirstCallTransaction + 4
)
const (
	MethodIPeriodicAdvertisingCallbackOnSyncEstablished           = "onSyncEstablished"
	MethodIPeriodicAdvertisingCallbackOnPeriodicAdvertisingReport = "onPeriodicAdvertisingReport"
	MethodIPeriodicAdvertisingCallbackOnSyncLost                  = "onSyncLost"
	MethodIPeriodicAdvertisingCallbackOnSyncTransferred           = "onSyncTransferred"
	MethodIPeriodicAdvertisingCallbackOnBigInfoAdvertisingReport  = "onBigInfoAdvertisingReport"
)
const (
	TransactionIScannerCallbackOnScannerRegistered        = binder.FirstCallTransaction + 0
	TransactionIScannerCallbackOnScanResult               = binder.FirstCallTransaction + 1
	TransactionIScannerCallbackOnBatchScanResults         = binder.FirstCallTransaction + 2
	TransactionIScannerCallbackOnFoundOrLost              = binder.FirstCallTransaction + 3
	TransactionIScannerCallbackOnScanManagerErrorCallback = binder.FirstCallTransaction + 4
)
const (
	MethodIScannerCallbackOnScannerRegistered        = "onScannerRegistered"
	MethodIScannerCallbackOnScanResult               = "onScanResult"
	MethodIScannerCallbackOnBatchScanResults         = "onBatchScanResults"
	MethodIScannerCallbackOnFoundOrLost              = "onFoundOrLost"
	MethodIScannerCallbackOnScanManagerErrorCallback = "onScanManagerErrorCallback"
)
const DescriptorIAdvertisingSetCallback = "android.bluetooth.le.IAdvertisingSetCallback"
const DescriptorIDistanceMeasurementCallback = "android.bluetooth.le.IDistanceMeasurementCallback"
const DescriptorIPeriodicAdvertisingCallback = "android.bluetooth.le.IPeriodicAdvertisingCallback"
const DescriptorIScannerCallback = "android.bluetooth.le.IScannerCallback"

Variables

This section is empty.

Functions

This section is empty.

Types

type AdvertiseData

type AdvertiseData struct {
}

func (*AdvertiseData) MarshalParcel

func (s *AdvertiseData) MarshalParcel(
	p *parcel.Parcel,
) error

func (*AdvertiseData) UnmarshalParcel

func (s *AdvertiseData) UnmarshalParcel(
	p *parcel.Parcel,
) error

type AdvertiseSettings

type AdvertiseSettings struct {
}

func (*AdvertiseSettings) MarshalParcel

func (s *AdvertiseSettings) MarshalParcel(
	p *parcel.Parcel,
) error

func (*AdvertiseSettings) UnmarshalParcel

func (s *AdvertiseSettings) UnmarshalParcel(
	p *parcel.Parcel,
) error

type AdvertisingSetCallbackProxy

type AdvertisingSetCallbackProxy struct {
	Remote binder.IBinder
}

func NewAdvertisingSetCallbackProxy

func NewAdvertisingSetCallbackProxy(
	remote binder.IBinder,
) *AdvertisingSetCallbackProxy

func (*AdvertisingSetCallbackProxy) AsBinder

func (*AdvertisingSetCallbackProxy) OnAdvertisingDataSet

func (p *AdvertisingSetCallbackProxy) OnAdvertisingDataSet(
	ctx context.Context,
	advertiserId int32,
	status int32,
) error

func (*AdvertisingSetCallbackProxy) OnAdvertisingEnabled

func (p *AdvertisingSetCallbackProxy) OnAdvertisingEnabled(
	ctx context.Context,
	advertiserId int32,
	enable bool,
	status int32,
) error

func (*AdvertisingSetCallbackProxy) OnAdvertisingParametersUpdated

func (p *AdvertisingSetCallbackProxy) OnAdvertisingParametersUpdated(
	ctx context.Context,
	advertiserId int32,
	tx_power int32,
	status int32,
) error

func (*AdvertisingSetCallbackProxy) OnAdvertisingSetStarted

func (p *AdvertisingSetCallbackProxy) OnAdvertisingSetStarted(
	ctx context.Context,
	gattBinder binder.IBinder,
	advertiserId int32,
	tx_power int32,
	status int32,
) error

func (*AdvertisingSetCallbackProxy) OnAdvertisingSetStopped

func (p *AdvertisingSetCallbackProxy) OnAdvertisingSetStopped(
	ctx context.Context,
	advertiserId int32,
) error

func (*AdvertisingSetCallbackProxy) OnOwnAddressRead

func (p *AdvertisingSetCallbackProxy) OnOwnAddressRead(
	ctx context.Context,
	advertiserId int32,
	addressType int32,
	address string,
) error

func (*AdvertisingSetCallbackProxy) OnPeriodicAdvertisingDataSet

func (p *AdvertisingSetCallbackProxy) OnPeriodicAdvertisingDataSet(
	ctx context.Context,
	advertiserId int32,
	status int32,
) error

func (*AdvertisingSetCallbackProxy) OnPeriodicAdvertisingEnabled

func (p *AdvertisingSetCallbackProxy) OnPeriodicAdvertisingEnabled(
	ctx context.Context,
	advertiserId int32,
	enable bool,
	status int32,
) error

func (*AdvertisingSetCallbackProxy) OnPeriodicAdvertisingParametersUpdated

func (p *AdvertisingSetCallbackProxy) OnPeriodicAdvertisingParametersUpdated(
	ctx context.Context,
	advertiserId int32,
	status int32,
) error

func (*AdvertisingSetCallbackProxy) OnScanResponseDataSet

func (p *AdvertisingSetCallbackProxy) OnScanResponseDataSet(
	ctx context.Context,
	advertiserId int32,
	status int32,
) error

type AdvertisingSetCallbackStub

type AdvertisingSetCallbackStub struct {
	Impl      IAdvertisingSetCallback
	Transport binder.VersionAwareTransport
}

AdvertisingSetCallbackStub dispatches incoming binder transactions to a typed IAdvertisingSetCallback implementation.

func (*AdvertisingSetCallbackStub) Descriptor

func (s *AdvertisingSetCallbackStub) Descriptor() string

func (*AdvertisingSetCallbackStub) OnTransaction

func (s *AdvertisingSetCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type AdvertisingSetParameters

type AdvertisingSetParameters struct {
}

func (*AdvertisingSetParameters) MarshalParcel

func (s *AdvertisingSetParameters) MarshalParcel(
	p *parcel.Parcel,
) error

func (*AdvertisingSetParameters) UnmarshalParcel

func (s *AdvertisingSetParameters) UnmarshalParcel(
	p *parcel.Parcel,
) error

type DistanceMeasurementCallbackProxy

type DistanceMeasurementCallbackProxy struct {
	Remote binder.IBinder
}

func NewDistanceMeasurementCallbackProxy

func NewDistanceMeasurementCallbackProxy(
	remote binder.IBinder,
) *DistanceMeasurementCallbackProxy

func (*DistanceMeasurementCallbackProxy) AsBinder

func (*DistanceMeasurementCallbackProxy) OnResult

func (*DistanceMeasurementCallbackProxy) OnStartFail

func (p *DistanceMeasurementCallbackProxy) OnStartFail(
	ctx context.Context,
	device types.BluetoothDevice,
	reason int32,
) error

func (*DistanceMeasurementCallbackProxy) OnStarted

func (*DistanceMeasurementCallbackProxy) OnStopped

func (p *DistanceMeasurementCallbackProxy) OnStopped(
	ctx context.Context,
	device types.BluetoothDevice,
	reason int32,
) error

type DistanceMeasurementCallbackStub

type DistanceMeasurementCallbackStub struct {
	Impl      IDistanceMeasurementCallback
	Transport binder.VersionAwareTransport
}

DistanceMeasurementCallbackStub dispatches incoming binder transactions to a typed IDistanceMeasurementCallback implementation.

func (*DistanceMeasurementCallbackStub) Descriptor

func (s *DistanceMeasurementCallbackStub) Descriptor() string

func (*DistanceMeasurementCallbackStub) OnTransaction

type DistanceMeasurementMethod

type DistanceMeasurementMethod struct {
}

func (*DistanceMeasurementMethod) MarshalParcel

func (s *DistanceMeasurementMethod) MarshalParcel(
	p *parcel.Parcel,
) error

func (*DistanceMeasurementMethod) UnmarshalParcel

func (s *DistanceMeasurementMethod) UnmarshalParcel(
	p *parcel.Parcel,
) error

type DistanceMeasurementParams

type DistanceMeasurementParams struct {
}

func (*DistanceMeasurementParams) MarshalParcel

func (s *DistanceMeasurementParams) MarshalParcel(
	p *parcel.Parcel,
) error

func (*DistanceMeasurementParams) UnmarshalParcel

func (s *DistanceMeasurementParams) UnmarshalParcel(
	p *parcel.Parcel,
) error

type DistanceMeasurementResult

type DistanceMeasurementResult struct {
}

func (*DistanceMeasurementResult) MarshalParcel

func (s *DistanceMeasurementResult) MarshalParcel(
	p *parcel.Parcel,
) error

func (*DistanceMeasurementResult) UnmarshalParcel

func (s *DistanceMeasurementResult) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IAdvertisingSetCallback

type IAdvertisingSetCallback interface {
	AsBinder() binder.IBinder
	OnAdvertisingSetStarted(ctx context.Context, gattBinder binder.IBinder, advertiserId int32, tx_power int32, status int32) error
	OnOwnAddressRead(ctx context.Context, advertiserId int32, addressType int32, address string) error
	OnAdvertisingSetStopped(ctx context.Context, advertiserId int32) error
	OnAdvertisingEnabled(ctx context.Context, advertiserId int32, enable bool, status int32) error
	OnAdvertisingDataSet(ctx context.Context, advertiserId int32, status int32) error
	OnScanResponseDataSet(ctx context.Context, advertiserId int32, status int32) error
	OnAdvertisingParametersUpdated(ctx context.Context, advertiserId int32, tx_power int32, status int32) error
	OnPeriodicAdvertisingParametersUpdated(ctx context.Context, advertiserId int32, status int32) error
	OnPeriodicAdvertisingDataSet(ctx context.Context, advertiserId int32, status int32) error
	OnPeriodicAdvertisingEnabled(ctx context.Context, advertiserId int32, enable bool, status int32) error
}

func NewAdvertisingSetCallbackStub

func NewAdvertisingSetCallbackStub(
	impl IAdvertisingSetCallbackServer,
) IAdvertisingSetCallback

NewAdvertisingSetCallbackStub creates a server-side IAdvertisingSetCallback wrapping the given server implementation. The returned value satisfies IAdvertisingSetCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IAdvertisingSetCallbackServer

type IAdvertisingSetCallbackServer interface {
	OnAdvertisingSetStarted(ctx context.Context, gattBinder binder.IBinder, advertiserId int32, tx_power int32, status int32) error
	OnOwnAddressRead(ctx context.Context, advertiserId int32, addressType int32, address string) error
	OnAdvertisingSetStopped(ctx context.Context, advertiserId int32) error
	OnAdvertisingEnabled(ctx context.Context, advertiserId int32, enable bool, status int32) error
	OnAdvertisingDataSet(ctx context.Context, advertiserId int32, status int32) error
	OnScanResponseDataSet(ctx context.Context, advertiserId int32, status int32) error
	OnAdvertisingParametersUpdated(ctx context.Context, advertiserId int32, tx_power int32, status int32) error
	OnPeriodicAdvertisingParametersUpdated(ctx context.Context, advertiserId int32, status int32) error
	OnPeriodicAdvertisingDataSet(ctx context.Context, advertiserId int32, status int32) error
	OnPeriodicAdvertisingEnabled(ctx context.Context, advertiserId int32, enable bool, status int32) error
}

IAdvertisingSetCallbackServer is the server-side interface that user implementations provide to NewAdvertisingSetCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IDistanceMeasurementCallback

type IDistanceMeasurementCallback interface {
	AsBinder() binder.IBinder
	OnStarted(ctx context.Context, device types.BluetoothDevice) error
	OnStartFail(ctx context.Context, device types.BluetoothDevice, reason int32) error
	OnStopped(ctx context.Context, device types.BluetoothDevice, reason int32) error
	OnResult(ctx context.Context, device types.BluetoothDevice, result DistanceMeasurementResult) error
}

func NewDistanceMeasurementCallbackStub

func NewDistanceMeasurementCallbackStub(
	impl IDistanceMeasurementCallbackServer,
) IDistanceMeasurementCallback

NewDistanceMeasurementCallbackStub creates a server-side IDistanceMeasurementCallback wrapping the given server implementation. The returned value satisfies IDistanceMeasurementCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IDistanceMeasurementCallbackServer

type IDistanceMeasurementCallbackServer interface {
	OnStarted(ctx context.Context, device types.BluetoothDevice) error
	OnStartFail(ctx context.Context, device types.BluetoothDevice, reason int32) error
	OnStopped(ctx context.Context, device types.BluetoothDevice, reason int32) error
	OnResult(ctx context.Context, device types.BluetoothDevice, result DistanceMeasurementResult) error
}

IDistanceMeasurementCallbackServer is the server-side interface that user implementations provide to NewDistanceMeasurementCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IPeriodicAdvertisingCallback

type IPeriodicAdvertisingCallback interface {
	AsBinder() binder.IBinder
	OnSyncEstablished(ctx context.Context, syncHandle int32, device types.BluetoothDevice, advertisingSid int32, skip int32, timeout int32, status int32) error
	OnPeriodicAdvertisingReport(ctx context.Context, report PeriodicAdvertisingReport) error
	OnSyncLost(ctx context.Context, syncHandle int32) error
	OnSyncTransferred(ctx context.Context, device types.BluetoothDevice, status int32) error
	OnBigInfoAdvertisingReport(ctx context.Context, syncHandle int32, encrypted bool) error
}

func NewPeriodicAdvertisingCallbackStub

func NewPeriodicAdvertisingCallbackStub(
	impl IPeriodicAdvertisingCallbackServer,
) IPeriodicAdvertisingCallback

NewPeriodicAdvertisingCallbackStub creates a server-side IPeriodicAdvertisingCallback wrapping the given server implementation. The returned value satisfies IPeriodicAdvertisingCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IPeriodicAdvertisingCallbackServer

type IPeriodicAdvertisingCallbackServer interface {
	OnSyncEstablished(ctx context.Context, syncHandle int32, device types.BluetoothDevice, advertisingSid int32, skip int32, timeout int32, status int32) error
	OnPeriodicAdvertisingReport(ctx context.Context, report PeriodicAdvertisingReport) error
	OnSyncLost(ctx context.Context, syncHandle int32) error
	OnSyncTransferred(ctx context.Context, device types.BluetoothDevice, status int32) error
	OnBigInfoAdvertisingReport(ctx context.Context, syncHandle int32, encrypted bool) error
}

IPeriodicAdvertisingCallbackServer is the server-side interface that user implementations provide to NewPeriodicAdvertisingCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IScannerCallback

type IScannerCallback interface {
	AsBinder() binder.IBinder
	OnScannerRegistered(ctx context.Context, status int32, scannerId int32) error
	OnScanResult(ctx context.Context, scanResult ScanResult) error
	OnBatchScanResults(ctx context.Context, batchResults []ScanResult) error
	OnFoundOrLost(ctx context.Context, onFound bool, scanResult ScanResult) error
	OnScanManagerErrorCallback(ctx context.Context, errorCode int32) error
}

func NewScannerCallbackStub

func NewScannerCallbackStub(
	impl IScannerCallbackServer,
) IScannerCallback

NewScannerCallbackStub creates a server-side IScannerCallback wrapping the given server implementation. The returned value satisfies IScannerCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IScannerCallbackServer

type IScannerCallbackServer interface {
	OnScannerRegistered(ctx context.Context, status int32, scannerId int32) error
	OnScanResult(ctx context.Context, scanResult ScanResult) error
	OnBatchScanResults(ctx context.Context, batchResults []ScanResult) error
	OnFoundOrLost(ctx context.Context, onFound bool, scanResult ScanResult) error
	OnScanManagerErrorCallback(ctx context.Context, errorCode int32) error
}

IScannerCallbackServer is the server-side interface that user implementations provide to NewScannerCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type PeriodicAdvertisingCallbackProxy

type PeriodicAdvertisingCallbackProxy struct {
	Remote binder.IBinder
}

func NewPeriodicAdvertisingCallbackProxy

func NewPeriodicAdvertisingCallbackProxy(
	remote binder.IBinder,
) *PeriodicAdvertisingCallbackProxy

func (*PeriodicAdvertisingCallbackProxy) AsBinder

func (*PeriodicAdvertisingCallbackProxy) OnBigInfoAdvertisingReport

func (p *PeriodicAdvertisingCallbackProxy) OnBigInfoAdvertisingReport(
	ctx context.Context,
	syncHandle int32,
	encrypted bool,
) error

func (*PeriodicAdvertisingCallbackProxy) OnPeriodicAdvertisingReport

func (p *PeriodicAdvertisingCallbackProxy) OnPeriodicAdvertisingReport(
	ctx context.Context,
	report PeriodicAdvertisingReport,
) error

func (*PeriodicAdvertisingCallbackProxy) OnSyncEstablished

func (p *PeriodicAdvertisingCallbackProxy) OnSyncEstablished(
	ctx context.Context,
	syncHandle int32,
	device types.BluetoothDevice,
	advertisingSid int32,
	skip int32,
	timeout int32,
	status int32,
) error

func (*PeriodicAdvertisingCallbackProxy) OnSyncLost

func (p *PeriodicAdvertisingCallbackProxy) OnSyncLost(
	ctx context.Context,
	syncHandle int32,
) error

func (*PeriodicAdvertisingCallbackProxy) OnSyncTransferred

func (p *PeriodicAdvertisingCallbackProxy) OnSyncTransferred(
	ctx context.Context,
	device types.BluetoothDevice,
	status int32,
) error

type PeriodicAdvertisingCallbackStub

type PeriodicAdvertisingCallbackStub struct {
	Impl      IPeriodicAdvertisingCallback
	Transport binder.VersionAwareTransport
}

PeriodicAdvertisingCallbackStub dispatches incoming binder transactions to a typed IPeriodicAdvertisingCallback implementation.

func (*PeriodicAdvertisingCallbackStub) Descriptor

func (s *PeriodicAdvertisingCallbackStub) Descriptor() string

func (*PeriodicAdvertisingCallbackStub) OnTransaction

type PeriodicAdvertisingParameters

type PeriodicAdvertisingParameters struct {
}

func (*PeriodicAdvertisingParameters) MarshalParcel

func (s *PeriodicAdvertisingParameters) MarshalParcel(
	p *parcel.Parcel,
) error

func (*PeriodicAdvertisingParameters) UnmarshalParcel

func (s *PeriodicAdvertisingParameters) UnmarshalParcel(
	p *parcel.Parcel,
) error

type PeriodicAdvertisingReport

type PeriodicAdvertisingReport struct {
}

func (*PeriodicAdvertisingReport) MarshalParcel

func (s *PeriodicAdvertisingReport) MarshalParcel(
	p *parcel.Parcel,
) error

func (*PeriodicAdvertisingReport) UnmarshalParcel

func (s *PeriodicAdvertisingReport) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ResultStorageDescriptor

type ResultStorageDescriptor struct {
}

func (*ResultStorageDescriptor) MarshalParcel

func (s *ResultStorageDescriptor) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ResultStorageDescriptor) UnmarshalParcel

func (s *ResultStorageDescriptor) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ScanFilter

type ScanFilter struct {
}

func (*ScanFilter) MarshalParcel

func (s *ScanFilter) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ScanFilter) UnmarshalParcel

func (s *ScanFilter) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ScanResult

type ScanResult struct {
}

func (*ScanResult) MarshalParcel

func (s *ScanResult) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ScanResult) UnmarshalParcel

func (s *ScanResult) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ScanSettings

type ScanSettings struct {
}

func (*ScanSettings) MarshalParcel

func (s *ScanSettings) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ScanSettings) UnmarshalParcel

func (s *ScanSettings) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ScannerCallbackProxy

type ScannerCallbackProxy struct {
	Remote binder.IBinder
}

func NewScannerCallbackProxy

func NewScannerCallbackProxy(
	remote binder.IBinder,
) *ScannerCallbackProxy

func (*ScannerCallbackProxy) AsBinder

func (p *ScannerCallbackProxy) AsBinder() binder.IBinder

func (*ScannerCallbackProxy) OnBatchScanResults

func (p *ScannerCallbackProxy) OnBatchScanResults(
	ctx context.Context,
	batchResults []ScanResult,
) error

func (*ScannerCallbackProxy) OnFoundOrLost

func (p *ScannerCallbackProxy) OnFoundOrLost(
	ctx context.Context,
	onFound bool,
	scanResult ScanResult,
) error

func (*ScannerCallbackProxy) OnScanManagerErrorCallback

func (p *ScannerCallbackProxy) OnScanManagerErrorCallback(
	ctx context.Context,
	errorCode int32,
) error

func (*ScannerCallbackProxy) OnScanResult

func (p *ScannerCallbackProxy) OnScanResult(
	ctx context.Context,
	scanResult ScanResult,
) error

func (*ScannerCallbackProxy) OnScannerRegistered

func (p *ScannerCallbackProxy) OnScannerRegistered(
	ctx context.Context,
	status int32,
	scannerId int32,
) error

type ScannerCallbackStub

type ScannerCallbackStub struct {
	Impl      IScannerCallback
	Transport binder.VersionAwareTransport
}

ScannerCallbackStub dispatches incoming binder transactions to a typed IScannerCallback implementation.

func (*ScannerCallbackStub) Descriptor

func (s *ScannerCallbackStub) Descriptor() string

func (*ScannerCallbackStub) OnTransaction

func (s *ScannerCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to