dex

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIArtManagerSnapshotRuntimeProfile    = binder.FirstCallTransaction + 0
	TransactionIArtManagerIsRuntimeProfilingEnabled = binder.FirstCallTransaction + 1
)
const (
	MethodIArtManagerSnapshotRuntimeProfile    = "snapshotRuntimeProfile"
	MethodIArtManagerIsRuntimeProfilingEnabled = "isRuntimeProfilingEnabled"
)
const (
	TransactionISnapshotRuntimeProfileCallbackOnSuccess = binder.FirstCallTransaction + 0
	TransactionISnapshotRuntimeProfileCallbackOnError   = binder.FirstCallTransaction + 1
)
const (
	MethodISnapshotRuntimeProfileCallbackOnSuccess = "onSuccess"
	MethodISnapshotRuntimeProfileCallbackOnError   = "onError"
)
const DescriptorIArtManager = "android.content.pm.dex.IArtManager"
const DescriptorISnapshotRuntimeProfileCallback = "android.content.pm.dex.ISnapshotRuntimeProfileCallback"

Variables

This section is empty.

Functions

This section is empty.

Types

type ArtManagerProxy

type ArtManagerProxy struct {
	Remote binder.IBinder
}

func NewArtManagerProxy

func NewArtManagerProxy(
	remote binder.IBinder,
) *ArtManagerProxy

func (*ArtManagerProxy) AsBinder

func (p *ArtManagerProxy) AsBinder() binder.IBinder

func (*ArtManagerProxy) IsRuntimeProfilingEnabled

func (p *ArtManagerProxy) IsRuntimeProfilingEnabled(
	ctx context.Context,
	profileType int32,
) (bool, error)

func (*ArtManagerProxy) SnapshotRuntimeProfile

func (p *ArtManagerProxy) SnapshotRuntimeProfile(
	ctx context.Context,
	profileType int32,
	packageName string,
	codePath string,
	callback ISnapshotRuntimeProfileCallback,
) error

type ArtManagerStub

type ArtManagerStub struct {
	Impl      IArtManager
	Transport binder.VersionAwareTransport
}

ArtManagerStub dispatches incoming binder transactions to a typed IArtManager implementation.

func (*ArtManagerStub) Descriptor

func (s *ArtManagerStub) Descriptor() string

func (*ArtManagerStub) OnTransaction

func (s *ArtManagerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IArtManager

type IArtManager interface {
	AsBinder() binder.IBinder
	SnapshotRuntimeProfile(ctx context.Context, profileType int32, packageName string, codePath string, callback ISnapshotRuntimeProfileCallback) error
	IsRuntimeProfilingEnabled(ctx context.Context, profileType int32) (bool, error)
}

func NewArtManagerStub

func NewArtManagerStub(
	impl IArtManagerServer,
) IArtManager

NewArtManagerStub creates a server-side IArtManager wrapping the given server implementation. The returned value satisfies IArtManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IArtManagerServer

type IArtManagerServer interface {
	SnapshotRuntimeProfile(ctx context.Context, profileType int32, packageName string, codePath string, callback ISnapshotRuntimeProfileCallback) error
	IsRuntimeProfilingEnabled(ctx context.Context, profileType int32) (bool, error)
}

IArtManagerServer is the server-side interface that user implementations provide to NewArtManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type ISnapshotRuntimeProfileCallback

type ISnapshotRuntimeProfileCallback interface {
	AsBinder() binder.IBinder
	OnSuccess(ctx context.Context, profileReadFd int32) error
	OnError(ctx context.Context, errCode int32) error
}

func NewSnapshotRuntimeProfileCallbackStub

func NewSnapshotRuntimeProfileCallbackStub(
	impl ISnapshotRuntimeProfileCallbackServer,
) ISnapshotRuntimeProfileCallback

NewSnapshotRuntimeProfileCallbackStub creates a server-side ISnapshotRuntimeProfileCallback wrapping the given server implementation. The returned value satisfies ISnapshotRuntimeProfileCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type ISnapshotRuntimeProfileCallbackServer

type ISnapshotRuntimeProfileCallbackServer interface {
	OnSuccess(ctx context.Context, profileReadFd int32) error
	OnError(ctx context.Context, errCode int32) error
}

ISnapshotRuntimeProfileCallbackServer is the server-side interface that user implementations provide to NewSnapshotRuntimeProfileCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type SnapshotRuntimeProfileCallbackProxy

type SnapshotRuntimeProfileCallbackProxy struct {
	Remote binder.IBinder
}

func NewSnapshotRuntimeProfileCallbackProxy

func NewSnapshotRuntimeProfileCallbackProxy(
	remote binder.IBinder,
) *SnapshotRuntimeProfileCallbackProxy

func (*SnapshotRuntimeProfileCallbackProxy) AsBinder

func (*SnapshotRuntimeProfileCallbackProxy) OnError

func (p *SnapshotRuntimeProfileCallbackProxy) OnError(
	ctx context.Context,
	errCode int32,
) error

func (*SnapshotRuntimeProfileCallbackProxy) OnSuccess

func (p *SnapshotRuntimeProfileCallbackProxy) OnSuccess(
	ctx context.Context,
	profileReadFd int32,
) error

type SnapshotRuntimeProfileCallbackStub

type SnapshotRuntimeProfileCallbackStub struct {
	Impl      ISnapshotRuntimeProfileCallback
	Transport binder.VersionAwareTransport
}

SnapshotRuntimeProfileCallbackStub dispatches incoming binder transactions to a typed ISnapshotRuntimeProfileCallback implementation.

func (*SnapshotRuntimeProfileCallbackStub) Descriptor

func (*SnapshotRuntimeProfileCallbackStub) OnTransaction

Jump to