Documentation
¶
Index ¶
- Constants
- type BufferAttachment
- type BufferCacheUpdate
- func (u *BufferCacheUpdate) GetCacheBuffers() (BufferCacheUpdateCacheBuffers, bool)
- func (u *BufferCacheUpdate) GetForgetBuffers() (BufferCacheUpdateForgetBuffers, bool)
- func (u *BufferCacheUpdate) MarshalParcel(p *parcel.Parcel) error
- func (u *BufferCacheUpdate) SetCacheBuffers(v BufferCacheUpdateCacheBuffers)
- func (u *BufferCacheUpdate) SetForgetBuffers(v BufferCacheUpdateForgetBuffers)
- func (u *BufferCacheUpdate) UnmarshalParcel(p *parcel.Parcel) error
- type BufferCacheUpdateCacheBuffers
- type BufferCacheUpdateForgetBuffers
- type BufferOwnerProxy
- type BufferOwnerStub
- type BufferSubscriberProxy
- func (p *BufferSubscriberProxy) AsBinder() binder.IBinder
- func (p *BufferSubscriberProxy) OnBufferCacheUpdate(ctx context.Context, update BufferCacheUpdate) error
- func (p *BufferSubscriberProxy) OnComplete(ctx context.Context) error
- func (p *BufferSubscriberProxy) OnError(ctx context.Context) error
- func (p *BufferSubscriberProxy) OnNext(ctx context.Context, frame Frame) error
- func (p *BufferSubscriberProxy) OnSubscribe(ctx context.Context, subscription IBufferSubscription) error
- type BufferSubscriberStub
- type BufferSubscriptionProxy
- type BufferSubscriptionStub
- type Frame
- type IBufferOwner
- type IBufferOwnerServer
- type IBufferSubscriber
- type IBufferSubscriberServer
- type IBufferSubscription
- type IBufferSubscriptionServer
Constants ¶
const ( BufferCacheUpdateTagCacheBuffers int32 = 0 BufferCacheUpdateTagForgetBuffers int32 = 1 )
const ( TransactionIBufferSubscriberOnSubscribe = binder.FirstCallTransaction + 0 TransactionIBufferSubscriberOnBufferCacheUpdate = binder.FirstCallTransaction + 1 TransactionIBufferSubscriberOnNext = binder.FirstCallTransaction + 2 TransactionIBufferSubscriberOnError = binder.FirstCallTransaction + 3 TransactionIBufferSubscriberOnComplete = binder.FirstCallTransaction + 4 )
const ( MethodIBufferSubscriberOnSubscribe = "onSubscribe" MethodIBufferSubscriberOnBufferCacheUpdate = "onBufferCacheUpdate" MethodIBufferSubscriberOnNext = "onNext" MethodIBufferSubscriberOnError = "onError" MethodIBufferSubscriberOnComplete = "onComplete" )
const ( TransactionIBufferSubscriptionRequest = binder.FirstCallTransaction + 0 TransactionIBufferSubscriptionCancel = binder.FirstCallTransaction + 1 )
const ( MethodIBufferSubscriptionRequest = "request" MethodIBufferSubscriptionCancel = "cancel" )
const DescriptorIBufferOwner = "android.graphics.bufferstreams.IBufferOwner"
const DescriptorIBufferSubscriber = "android.graphics.bufferstreams.IBufferSubscriber"
const DescriptorIBufferSubscription = "android.graphics.bufferstreams.IBufferSubscription"
const (
MethodIBufferOwnerOnBufferReleased = "onBufferReleased"
)
const (
TransactionIBufferOwnerOnBufferReleased = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BufferAttachment ¶
type BufferAttachment struct {
Buffer *common.HardwareBuffer
Owner IBufferOwner
}
func (*BufferAttachment) MarshalParcel ¶
func (s *BufferAttachment) MarshalParcel( p *parcel.Parcel, ) error
func (*BufferAttachment) UnmarshalParcel ¶
func (s *BufferAttachment) UnmarshalParcel( p *parcel.Parcel, ) error
type BufferCacheUpdate ¶
type BufferCacheUpdate struct {
Tag int32
CacheBuffers BufferCacheUpdateCacheBuffers
ForgetBuffers BufferCacheUpdateForgetBuffers
}
func (*BufferCacheUpdate) GetCacheBuffers ¶
func (u *BufferCacheUpdate) GetCacheBuffers() (BufferCacheUpdateCacheBuffers, bool)
func (*BufferCacheUpdate) GetForgetBuffers ¶
func (u *BufferCacheUpdate) GetForgetBuffers() (BufferCacheUpdateForgetBuffers, bool)
func (*BufferCacheUpdate) MarshalParcel ¶
func (u *BufferCacheUpdate) MarshalParcel( p *parcel.Parcel, ) error
func (*BufferCacheUpdate) SetCacheBuffers ¶
func (u *BufferCacheUpdate) SetCacheBuffers( v BufferCacheUpdateCacheBuffers, )
func (*BufferCacheUpdate) SetForgetBuffers ¶
func (u *BufferCacheUpdate) SetForgetBuffers( v BufferCacheUpdateForgetBuffers, )
func (*BufferCacheUpdate) UnmarshalParcel ¶
func (u *BufferCacheUpdate) UnmarshalParcel( p *parcel.Parcel, ) error
type BufferCacheUpdateCacheBuffers ¶
type BufferCacheUpdateCacheBuffers struct {
Attachments []BufferAttachment
}
func (*BufferCacheUpdateCacheBuffers) MarshalParcel ¶
func (s *BufferCacheUpdateCacheBuffers) MarshalParcel( p *parcel.Parcel, ) error
func (*BufferCacheUpdateCacheBuffers) UnmarshalParcel ¶
func (s *BufferCacheUpdateCacheBuffers) UnmarshalParcel( p *parcel.Parcel, ) error
type BufferCacheUpdateForgetBuffers ¶
type BufferCacheUpdateForgetBuffers struct {
BufferIds []int64
}
func (*BufferCacheUpdateForgetBuffers) MarshalParcel ¶
func (s *BufferCacheUpdateForgetBuffers) MarshalParcel( p *parcel.Parcel, ) error
func (*BufferCacheUpdateForgetBuffers) UnmarshalParcel ¶
func (s *BufferCacheUpdateForgetBuffers) UnmarshalParcel( p *parcel.Parcel, ) error
type BufferOwnerProxy ¶
func NewBufferOwnerProxy ¶
func NewBufferOwnerProxy( remote binder.IBinder, ) *BufferOwnerProxy
func (*BufferOwnerProxy) AsBinder ¶
func (p *BufferOwnerProxy) AsBinder() binder.IBinder
func (*BufferOwnerProxy) OnBufferReleased ¶
type BufferOwnerStub ¶
type BufferOwnerStub struct {
Impl IBufferOwner
Transport binder.VersionAwareTransport
}
BufferOwnerStub dispatches incoming binder transactions to a typed IBufferOwner implementation.
func (*BufferOwnerStub) Descriptor ¶
func (s *BufferOwnerStub) Descriptor() string
func (*BufferOwnerStub) OnTransaction ¶
func (s *BufferOwnerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type BufferSubscriberProxy ¶
func NewBufferSubscriberProxy ¶
func NewBufferSubscriberProxy( remote binder.IBinder, ) *BufferSubscriberProxy
func (*BufferSubscriberProxy) AsBinder ¶
func (p *BufferSubscriberProxy) AsBinder() binder.IBinder
func (*BufferSubscriberProxy) OnBufferCacheUpdate ¶
func (p *BufferSubscriberProxy) OnBufferCacheUpdate( ctx context.Context, update BufferCacheUpdate, ) error
func (*BufferSubscriberProxy) OnComplete ¶
func (p *BufferSubscriberProxy) OnComplete( ctx context.Context, ) error
func (*BufferSubscriberProxy) OnError ¶
func (p *BufferSubscriberProxy) OnError( ctx context.Context, ) error
func (*BufferSubscriberProxy) OnNext ¶
func (p *BufferSubscriberProxy) OnNext( ctx context.Context, frame Frame, ) error
func (*BufferSubscriberProxy) OnSubscribe ¶
func (p *BufferSubscriberProxy) OnSubscribe( ctx context.Context, subscription IBufferSubscription, ) error
type BufferSubscriberStub ¶
type BufferSubscriberStub struct {
Impl IBufferSubscriber
Transport binder.VersionAwareTransport
}
BufferSubscriberStub dispatches incoming binder transactions to a typed IBufferSubscriber implementation.
func (*BufferSubscriberStub) Descriptor ¶
func (s *BufferSubscriberStub) Descriptor() string
func (*BufferSubscriberStub) OnTransaction ¶
func (s *BufferSubscriberStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type BufferSubscriptionProxy ¶
func NewBufferSubscriptionProxy ¶
func NewBufferSubscriptionProxy( remote binder.IBinder, ) *BufferSubscriptionProxy
func (*BufferSubscriptionProxy) AsBinder ¶
func (p *BufferSubscriptionProxy) AsBinder() binder.IBinder
type BufferSubscriptionStub ¶
type BufferSubscriptionStub struct {
Impl IBufferSubscription
Transport binder.VersionAwareTransport
}
BufferSubscriptionStub dispatches incoming binder transactions to a typed IBufferSubscription implementation.
func (*BufferSubscriptionStub) Descriptor ¶
func (s *BufferSubscriptionStub) Descriptor() string
func (*BufferSubscriptionStub) OnTransaction ¶
func (s *BufferSubscriptionStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type IBufferOwner ¶
type IBufferOwner interface {
AsBinder() binder.IBinder
OnBufferReleased(ctx context.Context, bufferId int64, releaseFence *int32) error
}
func NewBufferOwnerStub ¶
func NewBufferOwnerStub( impl IBufferOwnerServer, ) IBufferOwner
NewBufferOwnerStub creates a server-side IBufferOwner wrapping the given server implementation. The returned value satisfies IBufferOwner and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IBufferOwnerServer ¶
type IBufferOwnerServer interface {
OnBufferReleased(ctx context.Context, bufferId int64, releaseFence *int32) error
}
IBufferOwnerServer is the server-side interface that user implementations provide to NewBufferOwnerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IBufferSubscriber ¶
type IBufferSubscriber interface {
AsBinder() binder.IBinder
OnSubscribe(ctx context.Context, subscription IBufferSubscription) error
OnBufferCacheUpdate(ctx context.Context, update BufferCacheUpdate) error
OnNext(ctx context.Context, frame Frame) error
OnError(ctx context.Context) error
OnComplete(ctx context.Context) error
}
func NewBufferSubscriberStub ¶
func NewBufferSubscriberStub( impl IBufferSubscriberServer, ) IBufferSubscriber
NewBufferSubscriberStub creates a server-side IBufferSubscriber wrapping the given server implementation. The returned value satisfies IBufferSubscriber and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IBufferSubscriberServer ¶
type IBufferSubscriberServer interface {
OnSubscribe(ctx context.Context, subscription IBufferSubscription) error
OnBufferCacheUpdate(ctx context.Context, update BufferCacheUpdate) error
OnNext(ctx context.Context, frame Frame) error
OnError(ctx context.Context) error
OnComplete(ctx context.Context) error
}
IBufferSubscriberServer is the server-side interface that user implementations provide to NewBufferSubscriberStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IBufferSubscription ¶
type IBufferSubscription interface {
AsBinder() binder.IBinder
Request(ctx context.Context, n int64) error
Cancel(ctx context.Context) error
}
func NewBufferSubscriptionStub ¶
func NewBufferSubscriptionStub( impl IBufferSubscriptionServer, ) IBufferSubscription
NewBufferSubscriptionStub creates a server-side IBufferSubscription wrapping the given server implementation. The returned value satisfies IBufferSubscription and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IBufferSubscriptionServer ¶
type IBufferSubscriptionServer interface {
Request(ctx context.Context, n int64) error
Cancel(ctx context.Context) error
}
IBufferSubscriptionServer is the server-side interface that user implementations provide to NewBufferSubscriptionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).