Documentation
¶
Index ¶
- Constants
- type CameraClientProxy
- type CameraClientStub
- type CameraExtensionSessionStats
- type CameraExtensionSessionStatsType
- type CameraIdRemapping
- type CameraIdRemappingPackageIdRemapping
- type CameraInfo
- type CameraPrivacyAllowlistEntry
- type CameraProxy
- type CameraServiceListenerProxy
- func (p *CameraServiceListenerProxy) AsBinder() binder.IBinder
- func (p *CameraServiceListenerProxy) OnCameraAccessPrioritiesChanged(ctx context.Context) error
- func (p *CameraServiceListenerProxy) OnCameraClosed(ctx context.Context, cameraId string) error
- func (p *CameraServiceListenerProxy) OnCameraOpened(ctx context.Context, cameraId string, clientPackageId string) error
- func (p *CameraServiceListenerProxy) OnPhysicalCameraStatusChanged(ctx context.Context, status int32, cameraId string, physicalCameraId string) error
- func (p *CameraServiceListenerProxy) OnStatusChanged(ctx context.Context, status int32, cameraId string) error
- func (p *CameraServiceListenerProxy) OnTorchStatusChanged(ctx context.Context, status int32, cameraId string) error
- func (p *CameraServiceListenerProxy) OnTorchStrengthLevelChanged(ctx context.Context, cameraId string, newTorchStrength int32) error
- type CameraServiceListenerStub
- type CameraServiceProxy
- func (p *CameraServiceProxy) AddListener(ctx context.Context, listener ICameraServiceListener) ([]CameraStatus, error)
- func (p *CameraServiceProxy) AsBinder() binder.IBinder
- func (p *CameraServiceProxy) Connect(ctx context.Context, client ICameraClient, cameraId int32, clientUid int32, ...) (ICamera, error)
- func (p *CameraServiceProxy) ConnectDevice(ctx context.Context, callbacks camera2.ICameraDeviceCallbacks, cameraId string, ...) (camera2.ICameraDeviceUser, error)
- func (p *CameraServiceProxy) CreateDefaultRequest(ctx context.Context, cameraId string, templateId int32) (impl.CameraMetadataNative, error)
- func (p *CameraServiceProxy) GetCameraCharacteristics(ctx context.Context, cameraId string, targetSdkVersion int32, ...) (impl.CameraMetadataNative, error)
- func (p *CameraServiceProxy) GetCameraInfo(ctx context.Context, cameraId int32, overrideToPortrait bool) (CameraInfo, error)
- func (p *CameraServiceProxy) GetCameraVendorTagCache(ctx context.Context) (params.VendorTagDescriptorCache, error)
- func (p *CameraServiceProxy) GetCameraVendorTagDescriptor(ctx context.Context) (params.VendorTagDescriptor, error)
- func (p *CameraServiceProxy) GetConcurrentCameraIds(ctx context.Context) ([]provider.ConcurrentCameraIdCombination, error)
- func (p *CameraServiceProxy) GetLegacyParameters(ctx context.Context, cameraId int32) (string, error)
- func (p *CameraServiceProxy) GetNumberOfCameras(ctx context.Context, type_ int32) (int32, error)
- func (p *CameraServiceProxy) GetSessionCharacteristics(ctx context.Context, cameraId string, targetSdkVersion int32, ...) (impl.CameraMetadataNative, error)
- func (p *CameraServiceProxy) GetTorchStrengthLevel(ctx context.Context, cameraId string) (int32, error)
- func (p *CameraServiceProxy) InjectCamera(ctx context.Context, packageName string, internalCamId string, ...) (camera2.ICameraInjectionSession, error)
- func (p *CameraServiceProxy) InjectSessionParams(ctx context.Context, cameraId string, sessionParams impl.CameraMetadataNative) error
- func (p *CameraServiceProxy) IsConcurrentSessionConfigurationSupported(ctx context.Context, sessions []utils.CameraIdAndSessionConfiguration, ...) (bool, error)
- func (p *CameraServiceProxy) IsHiddenPhysicalCamera(ctx context.Context, cameraId string) (bool, error)
- func (p *CameraServiceProxy) IsSessionConfigurationWithParametersSupported(ctx context.Context, cameraId string, ...) (bool, error)
- func (p *CameraServiceProxy) NotifyDeviceStateChange(ctx context.Context, newState int64) error
- func (p *CameraServiceProxy) NotifyDisplayConfigurationChange(ctx context.Context) error
- func (p *CameraServiceProxy) NotifySystemEvent(ctx context.Context, eventId int32, args []int32) error
- func (p *CameraServiceProxy) RemapCameraIds(ctx context.Context, cameraIdRemapping CameraIdRemapping) error
- func (p *CameraServiceProxy) RemoveListener(ctx context.Context, listener ICameraServiceListener) error
- func (p *CameraServiceProxy) ReportExtensionSessionStats(ctx context.Context, stats CameraExtensionSessionStats) (string, error)
- func (p *CameraServiceProxy) SetTorchMode(ctx context.Context, cameraId string, enabled bool, ...) error
- func (p *CameraServiceProxy) SupportsCameraApi(ctx context.Context, cameraId string, apiVersion int32) (bool, error)
- func (p *CameraServiceProxy) TurnOnTorchWithStrengthLevel(ctx context.Context, cameraId string, strengthLevel int32, ...) error
- type CameraServiceProxyProxy
- func (p *CameraServiceProxyProxy) AsBinder() binder.IBinder
- func (p *CameraServiceProxyProxy) GetAutoframingOverride(ctx context.Context, packageName string) (int32, error)
- func (p *CameraServiceProxyProxy) GetRotateAndCropOverride(ctx context.Context, packageName string, lensFacing int32) (int32, error)
- func (p *CameraServiceProxyProxy) IsCameraDisabled(ctx context.Context) (bool, error)
- func (p *CameraServiceProxyProxy) NotifyCameraState(ctx context.Context, cameraSessionStats CameraSessionStats) error
- func (p *CameraServiceProxyProxy) PingForUserUpdate(ctx context.Context) error
- type CameraServiceProxyStub
- type CameraServiceStub
- type CameraSessionStats
- type CameraStatus
- type CameraStub
- type ConsumerIrServiceProxy
- func (p *ConsumerIrServiceProxy) AsBinder() binder.IBinder
- func (p *ConsumerIrServiceProxy) GetCarrierFrequencies(ctx context.Context) ([]int32, error)
- func (p *ConsumerIrServiceProxy) HasIrEmitter(ctx context.Context) (bool, error)
- func (p *ConsumerIrServiceProxy) Transmit(ctx context.Context, packageName string, carrierFrequency int32, ...) error
- type ConsumerIrServiceStub
- type HardwareBuffer
- type ICamera
- type ICameraClient
- type ICameraClientServer
- type ICameraServer
- type ICameraService
- type ICameraServiceListener
- type ICameraServiceListenerServer
- type ICameraServiceProxy
- type ICameraServiceProxyServer
- type ICameraServiceServer
- type IConsumerIrService
- type IConsumerIrServiceServer
- type ISensorPrivacyListener
- type ISensorPrivacyListenerServer
- type ISensorPrivacyManager
- type ISensorPrivacyManagerServer
- type ISerialManager
- type ISerialManagerServer
- type OverlayProperties
- type SensorPrivacyListenerProxy
- func (p *SensorPrivacyListenerProxy) AsBinder() binder.IBinder
- func (p *SensorPrivacyListenerProxy) OnSensorPrivacyChanged(ctx context.Context, toggleType int32, sensor int32, enabled bool) error
- func (p *SensorPrivacyListenerProxy) OnSensorPrivacyStateChanged(ctx context.Context, toggleType int32, sensor int32, state int32) error
- type SensorPrivacyListenerStub
- type SensorPrivacyManagerProxy
- func (p *SensorPrivacyManagerProxy) AddSensorPrivacyListener(ctx context.Context, listener ISensorPrivacyListener) error
- func (p *SensorPrivacyManagerProxy) AddToggleSensorPrivacyListener(ctx context.Context, listener ISensorPrivacyListener) error
- func (p *SensorPrivacyManagerProxy) AsBinder() binder.IBinder
- func (p *SensorPrivacyManagerProxy) GetCameraPrivacyAllowlist(ctx context.Context) ([]CameraPrivacyAllowlistEntry, error)
- func (p *SensorPrivacyManagerProxy) GetToggleSensorPrivacyState(ctx context.Context, toggleType int32, sensor int32) (int32, error)
- func (p *SensorPrivacyManagerProxy) IsCameraPrivacyEnabled(ctx context.Context, packageName string) (bool, error)
- func (p *SensorPrivacyManagerProxy) IsCombinedToggleSensorPrivacyEnabled(ctx context.Context, sensor int32) (bool, error)
- func (p *SensorPrivacyManagerProxy) IsSensorPrivacyEnabled(ctx context.Context) (bool, error)
- func (p *SensorPrivacyManagerProxy) IsToggleSensorPrivacyEnabled(ctx context.Context, toggleType int32, sensor int32) (bool, error)
- func (p *SensorPrivacyManagerProxy) RemoveSensorPrivacyListener(ctx context.Context, listener ISensorPrivacyListener) error
- func (p *SensorPrivacyManagerProxy) RemoveToggleSensorPrivacyListener(ctx context.Context, listener ISensorPrivacyListener) error
- func (p *SensorPrivacyManagerProxy) SetSensorPrivacy(ctx context.Context, enable bool) error
- func (p *SensorPrivacyManagerProxy) SetToggleSensorPrivacy(ctx context.Context, source int32, sensor int32, enable bool) error
- func (p *SensorPrivacyManagerProxy) SetToggleSensorPrivacyForProfileGroup(ctx context.Context, source int32, sensor int32, enable bool) error
- func (p *SensorPrivacyManagerProxy) SetToggleSensorPrivacyState(ctx context.Context, source int32, sensor int32, state int32) error
- func (p *SensorPrivacyManagerProxy) SetToggleSensorPrivacyStateForProfileGroup(ctx context.Context, source int32, sensor int32, state int32) error
- func (p *SensorPrivacyManagerProxy) SupportsSensorToggle(ctx context.Context, toggleType int32, sensor int32) (bool, error)
- type SensorPrivacyManagerStub
- type SerialManagerProxy
- type SerialManagerStub
Constants ¶
const ( TransactionICameraServiceGetNumberOfCameras = binder.FirstCallTransaction + 0 TransactionICameraServiceGetCameraInfo = binder.FirstCallTransaction + 1 TransactionICameraServiceConnect = binder.FirstCallTransaction + 2 TransactionICameraServiceConnectDevice = binder.FirstCallTransaction + 3 TransactionICameraServiceAddListener = binder.FirstCallTransaction + 4 TransactionICameraServiceGetConcurrentCameraIds = binder.FirstCallTransaction + 5 TransactionICameraServiceIsConcurrentSessionConfigurationSupported = binder.FirstCallTransaction + 6 TransactionICameraServiceRemapCameraIds = binder.FirstCallTransaction + 7 TransactionICameraServiceInjectSessionParams = binder.FirstCallTransaction + 8 TransactionICameraServiceRemoveListener = binder.FirstCallTransaction + 9 TransactionICameraServiceGetCameraCharacteristics = binder.FirstCallTransaction + 10 TransactionICameraServiceGetCameraVendorTagDescriptor = binder.FirstCallTransaction + 11 TransactionICameraServiceGetCameraVendorTagCache = binder.FirstCallTransaction + 12 TransactionICameraServiceGetLegacyParameters = binder.FirstCallTransaction + 13 TransactionICameraServiceSupportsCameraApi = binder.FirstCallTransaction + 14 TransactionICameraServiceIsHiddenPhysicalCamera = binder.FirstCallTransaction + 15 TransactionICameraServiceInjectCamera = binder.FirstCallTransaction + 16 TransactionICameraServiceSetTorchMode = binder.FirstCallTransaction + 17 TransactionICameraServiceTurnOnTorchWithStrengthLevel = binder.FirstCallTransaction + 18 TransactionICameraServiceGetTorchStrengthLevel = binder.FirstCallTransaction + 19 TransactionICameraServiceNotifySystemEvent = binder.FirstCallTransaction + 20 TransactionICameraServiceNotifyDisplayConfigurationChange = binder.FirstCallTransaction + 21 TransactionICameraServiceNotifyDeviceStateChange = binder.FirstCallTransaction + 22 TransactionICameraServiceReportExtensionSessionStats = binder.FirstCallTransaction + 23 TransactionICameraServiceCreateDefaultRequest = binder.FirstCallTransaction + 24 TransactionICameraServiceIsSessionConfigurationWithParametersSupported = binder.FirstCallTransaction + 25 TransactionICameraServiceGetSessionCharacteristics = binder.FirstCallTransaction + 26 )
const ( MethodICameraServiceGetNumberOfCameras = "getNumberOfCameras" MethodICameraServiceGetCameraInfo = "getCameraInfo" MethodICameraServiceConnect = "connect" MethodICameraServiceConnectDevice = "connectDevice" MethodICameraServiceAddListener = "addListener" MethodICameraServiceGetConcurrentCameraIds = "getConcurrentCameraIds" MethodICameraServiceIsConcurrentSessionConfigurationSupported = "isConcurrentSessionConfigurationSupported" MethodICameraServiceRemapCameraIds = "remapCameraIds" MethodICameraServiceInjectSessionParams = "injectSessionParams" MethodICameraServiceRemoveListener = "removeListener" MethodICameraServiceGetCameraCharacteristics = "getCameraCharacteristics" MethodICameraServiceGetCameraVendorTagDescriptor = "getCameraVendorTagDescriptor" MethodICameraServiceGetCameraVendorTagCache = "getCameraVendorTagCache" MethodICameraServiceGetLegacyParameters = "getLegacyParameters" MethodICameraServiceSupportsCameraApi = "supportsCameraApi" MethodICameraServiceIsHiddenPhysicalCamera = "isHiddenPhysicalCamera" MethodICameraServiceInjectCamera = "injectCamera" MethodICameraServiceSetTorchMode = "setTorchMode" MethodICameraServiceTurnOnTorchWithStrengthLevel = "turnOnTorchWithStrengthLevel" MethodICameraServiceGetTorchStrengthLevel = "getTorchStrengthLevel" MethodICameraServiceNotifySystemEvent = "notifySystemEvent" MethodICameraServiceNotifyDisplayConfigurationChange = "notifyDisplayConfigurationChange" MethodICameraServiceNotifyDeviceStateChange = "notifyDeviceStateChange" MethodICameraServiceReportExtensionSessionStats = "reportExtensionSessionStats" MethodICameraServiceCreateDefaultRequest = "createDefaultRequest" MethodICameraServiceIsSessionConfigurationWithParametersSupported = "isSessionConfigurationWithParametersSupported" MethodICameraServiceGetSessionCharacteristics = "getSessionCharacteristics" )
const ( ICameraServiceErrorPermissionDenied int32 = 1 ICameraServiceErrorAlreadyExists int32 = 2 ICameraServiceErrorIllegalArgument int32 = 3 ICameraServiceErrorDisconnected int32 = 4 ICameraServiceErrorTimedOut int32 = 5 ICameraServiceErrorDisabled int32 = 6 ICameraServiceErrorCameraInUse int32 = 7 ICameraServiceErrorMaxCamerasInUse int32 = 8 ICameraServiceErrorDeprecatedHal int32 = 9 ICameraServiceErrorInvalidOperation int32 = 10 ICameraServiceCameraTypeBackwardCompatible int32 = 0 ICameraServiceCameraTypeAll int32 = 1 ICameraServiceUseCallingUid int32 = -1 ICameraServiceUseCallingPid int32 = -1 ICameraServiceApiVersion1 int32 = 1 ICameraServiceApiVersion2 int32 = 2 ICameraServiceEventNone int32 = 0 ICameraServiceEventUserSwitched int32 = 1 ICameraServiceEventUsbDeviceAttached int32 = 2 ICameraServiceEventUsbDeviceDetached int32 = 3 ICameraServiceDeviceStateNormal int32 = 0 ICameraServiceDeviceStateBackCovered int32 = 1 ICameraServiceDeviceStateFrontCovered int32 = 2 ICameraServiceDeviceStateFolded int32 = 4 ICameraServiceDeviceStateLastFrameworkBit int32 = -2147483648 )
const ( TransactionICameraServiceListenerOnStatusChanged = binder.FirstCallTransaction + 0 TransactionICameraServiceListenerOnPhysicalCameraStatusChanged = binder.FirstCallTransaction + 1 TransactionICameraServiceListenerOnTorchStatusChanged = binder.FirstCallTransaction + 2 TransactionICameraServiceListenerOnTorchStrengthLevelChanged = binder.FirstCallTransaction + 3 TransactionICameraServiceListenerOnCameraAccessPrioritiesChanged = binder.FirstCallTransaction + 4 TransactionICameraServiceListenerOnCameraOpened = binder.FirstCallTransaction + 5 TransactionICameraServiceListenerOnCameraClosed = binder.FirstCallTransaction + 6 )
const ( MethodICameraServiceListenerOnStatusChanged = "onStatusChanged" MethodICameraServiceListenerOnPhysicalCameraStatusChanged = "onPhysicalCameraStatusChanged" MethodICameraServiceListenerOnTorchStatusChanged = "onTorchStatusChanged" MethodICameraServiceListenerOnTorchStrengthLevelChanged = "onTorchStrengthLevelChanged" MethodICameraServiceListenerOnCameraAccessPrioritiesChanged = "onCameraAccessPrioritiesChanged" MethodICameraServiceListenerOnCameraOpened = "onCameraOpened" MethodICameraServiceListenerOnCameraClosed = "onCameraClosed" )
const ( ICameraServiceListenerStatusNotPresent int32 = 0 ICameraServiceListenerStatusPresent int32 = 1 ICameraServiceListenerStatusEnumerating int32 = 2 ICameraServiceListenerStatusNotAvailable int32 = -2 ICameraServiceListenerStatusUnknown int32 = -1 ICameraServiceListenerTorchStatusNotAvailable int32 = 0 ICameraServiceListenerTorchStatusAvailableOff int32 = 1 ICameraServiceListenerTorchStatusAvailableOn int32 = 2 ICameraServiceListenerTorchStatusUnknown int32 = -1 )
const ( TransactionICameraServiceProxyPingForUserUpdate = binder.FirstCallTransaction + 0 TransactionICameraServiceProxyNotifyCameraState = binder.FirstCallTransaction + 1 TransactionICameraServiceProxyGetRotateAndCropOverride = binder.FirstCallTransaction + 2 TransactionICameraServiceProxyGetAutoframingOverride = binder.FirstCallTransaction + 3 TransactionICameraServiceProxyIsCameraDisabled = binder.FirstCallTransaction + 4 )
const ( MethodICameraServiceProxyPingForUserUpdate = "pingForUserUpdate" MethodICameraServiceProxyNotifyCameraState = "notifyCameraState" MethodICameraServiceProxyGetRotateAndCropOverride = "getRotateAndCropOverride" MethodICameraServiceProxyGetAutoframingOverride = "getAutoframingOverride" MethodICameraServiceProxyIsCameraDisabled = "isCameraDisabled" )
const ( TransactionIConsumerIrServiceHasIrEmitter = binder.FirstCallTransaction + 0 TransactionIConsumerIrServiceTransmit = binder.FirstCallTransaction + 1 TransactionIConsumerIrServiceGetCarrierFrequencies = binder.FirstCallTransaction + 2 )
const ( MethodIConsumerIrServiceHasIrEmitter = "hasIrEmitter" MethodIConsumerIrServiceTransmit = "transmit" MethodIConsumerIrServiceGetCarrierFrequencies = "getCarrierFrequencies" )
const ( TransactionISensorPrivacyListenerOnSensorPrivacyChanged = binder.FirstCallTransaction + 0 TransactionISensorPrivacyListenerOnSensorPrivacyStateChanged = binder.FirstCallTransaction + 1 )
const ( MethodISensorPrivacyListenerOnSensorPrivacyChanged = "onSensorPrivacyChanged" MethodISensorPrivacyListenerOnSensorPrivacyStateChanged = "onSensorPrivacyStateChanged" )
const ( TransactionISensorPrivacyManagerSupportsSensorToggle = binder.FirstCallTransaction + 0 TransactionISensorPrivacyManagerAddSensorPrivacyListener = binder.FirstCallTransaction + 1 TransactionISensorPrivacyManagerAddToggleSensorPrivacyListener = binder.FirstCallTransaction + 2 TransactionISensorPrivacyManagerRemoveSensorPrivacyListener = binder.FirstCallTransaction + 3 TransactionISensorPrivacyManagerRemoveToggleSensorPrivacyListener = binder.FirstCallTransaction + 4 TransactionISensorPrivacyManagerIsSensorPrivacyEnabled = binder.FirstCallTransaction + 5 TransactionISensorPrivacyManagerIsCombinedToggleSensorPrivacyEnabled = binder.FirstCallTransaction + 6 TransactionISensorPrivacyManagerIsToggleSensorPrivacyEnabled = binder.FirstCallTransaction + 7 TransactionISensorPrivacyManagerSetSensorPrivacy = binder.FirstCallTransaction + 8 TransactionISensorPrivacyManagerSetToggleSensorPrivacy = binder.FirstCallTransaction + 9 TransactionISensorPrivacyManagerSetToggleSensorPrivacyForProfileGroup = binder.FirstCallTransaction + 10 TransactionISensorPrivacyManagerGetCameraPrivacyAllowlist = binder.FirstCallTransaction + 11 TransactionISensorPrivacyManagerGetToggleSensorPrivacyState = binder.FirstCallTransaction + 12 TransactionISensorPrivacyManagerSetToggleSensorPrivacyState = binder.FirstCallTransaction + 13 TransactionISensorPrivacyManagerSetToggleSensorPrivacyStateForProfileGroup = binder.FirstCallTransaction + 14 TransactionISensorPrivacyManagerIsCameraPrivacyEnabled = binder.FirstCallTransaction + 15 )
const ( MethodISensorPrivacyManagerSupportsSensorToggle = "supportsSensorToggle" MethodISensorPrivacyManagerAddSensorPrivacyListener = "addSensorPrivacyListener" MethodISensorPrivacyManagerAddToggleSensorPrivacyListener = "addToggleSensorPrivacyListener" MethodISensorPrivacyManagerRemoveSensorPrivacyListener = "removeSensorPrivacyListener" MethodISensorPrivacyManagerRemoveToggleSensorPrivacyListener = "removeToggleSensorPrivacyListener" MethodISensorPrivacyManagerIsSensorPrivacyEnabled = "isSensorPrivacyEnabled" MethodISensorPrivacyManagerIsCombinedToggleSensorPrivacyEnabled = "isCombinedToggleSensorPrivacyEnabled" MethodISensorPrivacyManagerIsToggleSensorPrivacyEnabled = "isToggleSensorPrivacyEnabled" MethodISensorPrivacyManagerSetSensorPrivacy = "setSensorPrivacy" MethodISensorPrivacyManagerSetToggleSensorPrivacy = "setToggleSensorPrivacy" MethodISensorPrivacyManagerSetToggleSensorPrivacyForProfileGroup = "setToggleSensorPrivacyForProfileGroup" MethodISensorPrivacyManagerGetCameraPrivacyAllowlist = "getCameraPrivacyAllowlist" MethodISensorPrivacyManagerGetToggleSensorPrivacyState = "getToggleSensorPrivacyState" MethodISensorPrivacyManagerSetToggleSensorPrivacyState = "setToggleSensorPrivacyState" MethodISensorPrivacyManagerSetToggleSensorPrivacyStateForProfileGroup = "setToggleSensorPrivacyStateForProfileGroup" MethodISensorPrivacyManagerIsCameraPrivacyEnabled = "isCameraPrivacyEnabled" )
const ( TransactionISerialManagerGetSerialPorts = binder.FirstCallTransaction + 0 TransactionISerialManagerOpenSerialPort = binder.FirstCallTransaction + 1 )
const ( MethodISerialManagerGetSerialPorts = "getSerialPorts" MethodISerialManagerOpenSerialPort = "openSerialPort" )
const DescriptorICamera = "android.hardware.ICamera"
const DescriptorICameraClient = "android.hardware.ICameraClient"
const DescriptorICameraService = "android.hardware.ICameraService"
const DescriptorICameraServiceListener = "android.hardware.ICameraServiceListener"
const DescriptorICameraServiceProxy = "android.hardware.ICameraServiceProxy"
const DescriptorIConsumerIrService = "android.hardware.IConsumerIrService"
const DescriptorISensorPrivacyListener = "android.hardware.ISensorPrivacyListener"
const DescriptorISensorPrivacyManager = "android.hardware.ISensorPrivacyManager"
const DescriptorISerialManager = "android.hardware.ISerialManager"
const (
MethodICameraDisconnect = "disconnect"
)
const (
TransactionICameraDisconnect = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CameraClientProxy ¶
func NewCameraClientProxy ¶
func NewCameraClientProxy( remote binder.IBinder, ) *CameraClientProxy
func (*CameraClientProxy) AsBinder ¶
func (p *CameraClientProxy) AsBinder() binder.IBinder
type CameraClientStub ¶
type CameraClientStub struct {
Impl ICameraClient
Transport binder.VersionAwareTransport
}
CameraClientStub dispatches incoming binder transactions to a typed ICameraClient implementation.
func (*CameraClientStub) Descriptor ¶
func (s *CameraClientStub) Descriptor() string
func (*CameraClientStub) OnTransaction ¶
func (s *CameraClientStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type CameraExtensionSessionStats ¶
type CameraExtensionSessionStats struct {
Key string
CameraId string
ClientName string
Type CameraExtensionSessionStatsType
IsAdvanced bool
}
func (*CameraExtensionSessionStats) MarshalParcel ¶
func (s *CameraExtensionSessionStats) MarshalParcel( p *parcel.Parcel, ) error
func (*CameraExtensionSessionStats) UnmarshalParcel ¶
func (s *CameraExtensionSessionStats) UnmarshalParcel( p *parcel.Parcel, ) error
type CameraExtensionSessionStatsType ¶
type CameraExtensionSessionStatsType int32
const ( CameraExtensionSessionStatsTypeExtensionNone CameraExtensionSessionStatsType = -1 CameraExtensionSessionStatsTypeExtensionAutomatic CameraExtensionSessionStatsType = 0 CameraExtensionSessionStatsTypeExtensionFaceRetouch CameraExtensionSessionStatsType = 1 CameraExtensionSessionStatsTypeExtensionBokeh CameraExtensionSessionStatsType = 2 CameraExtensionSessionStatsTypeExtensionHdr CameraExtensionSessionStatsType = 3 CameraExtensionSessionStatsTypeExtensionNight CameraExtensionSessionStatsType = 4 )
type CameraIdRemapping ¶
type CameraIdRemapping struct {
PackageIdRemappings []CameraIdRemappingPackageIdRemapping
}
func (*CameraIdRemapping) MarshalParcel ¶
func (s *CameraIdRemapping) MarshalParcel( p *parcel.Parcel, ) error
func (*CameraIdRemapping) UnmarshalParcel ¶
func (s *CameraIdRemapping) UnmarshalParcel( p *parcel.Parcel, ) error
type CameraIdRemappingPackageIdRemapping ¶
type CameraIdRemappingPackageIdRemapping struct {
PackageName string
CameraIdsToReplace []string
UpdatedCameraIds []string
}
func (*CameraIdRemappingPackageIdRemapping) MarshalParcel ¶
func (s *CameraIdRemappingPackageIdRemapping) MarshalParcel( p *parcel.Parcel, ) error
func (*CameraIdRemappingPackageIdRemapping) UnmarshalParcel ¶
func (s *CameraIdRemappingPackageIdRemapping) UnmarshalParcel( p *parcel.Parcel, ) error
type CameraInfo ¶
type CameraInfo struct {
}
func (*CameraInfo) MarshalParcel ¶
func (s *CameraInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*CameraInfo) UnmarshalParcel ¶
func (s *CameraInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type CameraPrivacyAllowlistEntry ¶
func (*CameraPrivacyAllowlistEntry) MarshalParcel ¶
func (s *CameraPrivacyAllowlistEntry) MarshalParcel( p *parcel.Parcel, ) error
func (*CameraPrivacyAllowlistEntry) UnmarshalParcel ¶
func (s *CameraPrivacyAllowlistEntry) UnmarshalParcel( p *parcel.Parcel, ) error
type CameraProxy ¶
func NewCameraProxy ¶
func NewCameraProxy( remote binder.IBinder, ) *CameraProxy
func (*CameraProxy) AsBinder ¶
func (p *CameraProxy) AsBinder() binder.IBinder
func (*CameraProxy) Disconnect ¶
func (p *CameraProxy) Disconnect( ctx context.Context, ) error
type CameraServiceListenerProxy ¶
func NewCameraServiceListenerProxy ¶
func NewCameraServiceListenerProxy( remote binder.IBinder, ) *CameraServiceListenerProxy
func (*CameraServiceListenerProxy) AsBinder ¶
func (p *CameraServiceListenerProxy) AsBinder() binder.IBinder
func (*CameraServiceListenerProxy) OnCameraAccessPrioritiesChanged ¶
func (p *CameraServiceListenerProxy) OnCameraAccessPrioritiesChanged( ctx context.Context, ) error
func (*CameraServiceListenerProxy) OnCameraClosed ¶
func (p *CameraServiceListenerProxy) OnCameraClosed( ctx context.Context, cameraId string, ) error
func (*CameraServiceListenerProxy) OnCameraOpened ¶
func (*CameraServiceListenerProxy) OnPhysicalCameraStatusChanged ¶
func (*CameraServiceListenerProxy) OnStatusChanged ¶
func (*CameraServiceListenerProxy) OnTorchStatusChanged ¶
func (*CameraServiceListenerProxy) OnTorchStrengthLevelChanged ¶
type CameraServiceListenerStub ¶
type CameraServiceListenerStub struct {
Impl ICameraServiceListener
Transport binder.VersionAwareTransport
}
CameraServiceListenerStub dispatches incoming binder transactions to a typed ICameraServiceListener implementation.
func (*CameraServiceListenerStub) Descriptor ¶
func (s *CameraServiceListenerStub) Descriptor() string
func (*CameraServiceListenerStub) OnTransaction ¶
func (s *CameraServiceListenerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type CameraServiceProxy ¶
func NewCameraServiceProxy ¶
func NewCameraServiceProxy( remote binder.IBinder, ) *CameraServiceProxy
func (*CameraServiceProxy) AddListener ¶
func (p *CameraServiceProxy) AddListener( ctx context.Context, listener ICameraServiceListener, ) ([]CameraStatus, error)
func (*CameraServiceProxy) AsBinder ¶
func (p *CameraServiceProxy) AsBinder() binder.IBinder
func (*CameraServiceProxy) ConnectDevice ¶
func (p *CameraServiceProxy) ConnectDevice( ctx context.Context, callbacks camera2.ICameraDeviceCallbacks, cameraId string, featureId string, clientUid int32, oomScoreOffset int32, targetSdkVersion int32, overrideToPortrait bool, ) (camera2.ICameraDeviceUser, error)
func (*CameraServiceProxy) CreateDefaultRequest ¶
func (p *CameraServiceProxy) CreateDefaultRequest( ctx context.Context, cameraId string, templateId int32, ) (impl.CameraMetadataNative, error)
func (*CameraServiceProxy) GetCameraCharacteristics ¶
func (p *CameraServiceProxy) GetCameraCharacteristics( ctx context.Context, cameraId string, targetSdkVersion int32, overrideToPortrait bool, ) (impl.CameraMetadataNative, error)
func (*CameraServiceProxy) GetCameraInfo ¶
func (p *CameraServiceProxy) GetCameraInfo( ctx context.Context, cameraId int32, overrideToPortrait bool, ) (CameraInfo, error)
func (*CameraServiceProxy) GetCameraVendorTagCache ¶
func (p *CameraServiceProxy) GetCameraVendorTagCache( ctx context.Context, ) (params.VendorTagDescriptorCache, error)
func (*CameraServiceProxy) GetCameraVendorTagDescriptor ¶
func (p *CameraServiceProxy) GetCameraVendorTagDescriptor( ctx context.Context, ) (params.VendorTagDescriptor, error)
func (*CameraServiceProxy) GetConcurrentCameraIds ¶
func (p *CameraServiceProxy) GetConcurrentCameraIds( ctx context.Context, ) ([]provider.ConcurrentCameraIdCombination, error)
func (*CameraServiceProxy) GetLegacyParameters ¶
func (*CameraServiceProxy) GetNumberOfCameras ¶
func (*CameraServiceProxy) GetSessionCharacteristics ¶
func (p *CameraServiceProxy) GetSessionCharacteristics( ctx context.Context, cameraId string, targetSdkVersion int32, overrideToPortrait bool, sessionConfiguration params.SessionConfiguration, ) (impl.CameraMetadataNative, error)
func (*CameraServiceProxy) GetTorchStrengthLevel ¶
func (*CameraServiceProxy) InjectCamera ¶
func (p *CameraServiceProxy) InjectCamera( ctx context.Context, packageName string, internalCamId string, externalCamId string, CameraInjectionCallback camera2.ICameraInjectionCallback, ) (camera2.ICameraInjectionSession, error)
func (*CameraServiceProxy) InjectSessionParams ¶
func (p *CameraServiceProxy) InjectSessionParams( ctx context.Context, cameraId string, sessionParams impl.CameraMetadataNative, ) error
func (*CameraServiceProxy) IsConcurrentSessionConfigurationSupported ¶
func (p *CameraServiceProxy) IsConcurrentSessionConfigurationSupported( ctx context.Context, sessions []utils.CameraIdAndSessionConfiguration, targetSdkVersion int32, ) (bool, error)
func (*CameraServiceProxy) IsHiddenPhysicalCamera ¶
func (*CameraServiceProxy) IsSessionConfigurationWithParametersSupported ¶
func (p *CameraServiceProxy) IsSessionConfigurationWithParametersSupported( ctx context.Context, cameraId string, sessionConfiguration params.SessionConfiguration, ) (bool, error)
func (*CameraServiceProxy) NotifyDeviceStateChange ¶
func (p *CameraServiceProxy) NotifyDeviceStateChange( ctx context.Context, newState int64, ) error
func (*CameraServiceProxy) NotifyDisplayConfigurationChange ¶
func (p *CameraServiceProxy) NotifyDisplayConfigurationChange( ctx context.Context, ) error
func (*CameraServiceProxy) NotifySystemEvent ¶
func (*CameraServiceProxy) RemapCameraIds ¶
func (p *CameraServiceProxy) RemapCameraIds( ctx context.Context, cameraIdRemapping CameraIdRemapping, ) error
func (*CameraServiceProxy) RemoveListener ¶
func (p *CameraServiceProxy) RemoveListener( ctx context.Context, listener ICameraServiceListener, ) error
func (*CameraServiceProxy) ReportExtensionSessionStats ¶
func (p *CameraServiceProxy) ReportExtensionSessionStats( ctx context.Context, stats CameraExtensionSessionStats, ) (string, error)
func (*CameraServiceProxy) SetTorchMode ¶
func (*CameraServiceProxy) SupportsCameraApi ¶
func (*CameraServiceProxy) TurnOnTorchWithStrengthLevel ¶
type CameraServiceProxyProxy ¶
func NewCameraServiceProxyProxy ¶
func NewCameraServiceProxyProxy( remote binder.IBinder, ) *CameraServiceProxyProxy
func (*CameraServiceProxyProxy) AsBinder ¶
func (p *CameraServiceProxyProxy) AsBinder() binder.IBinder
func (*CameraServiceProxyProxy) GetAutoframingOverride ¶
func (*CameraServiceProxyProxy) GetRotateAndCropOverride ¶
func (*CameraServiceProxyProxy) IsCameraDisabled ¶
func (p *CameraServiceProxyProxy) IsCameraDisabled( ctx context.Context, ) (bool, error)
func (*CameraServiceProxyProxy) NotifyCameraState ¶
func (p *CameraServiceProxyProxy) NotifyCameraState( ctx context.Context, cameraSessionStats CameraSessionStats, ) error
func (*CameraServiceProxyProxy) PingForUserUpdate ¶
func (p *CameraServiceProxyProxy) PingForUserUpdate( ctx context.Context, ) error
type CameraServiceProxyStub ¶
type CameraServiceProxyStub struct {
Impl ICameraServiceProxy
Transport binder.VersionAwareTransport
}
CameraServiceProxyStub dispatches incoming binder transactions to a typed ICameraServiceProxy implementation.
func (*CameraServiceProxyStub) Descriptor ¶
func (s *CameraServiceProxyStub) Descriptor() string
func (*CameraServiceProxyStub) OnTransaction ¶
func (s *CameraServiceProxyStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type CameraServiceStub ¶
type CameraServiceStub struct {
Impl ICameraService
Transport binder.VersionAwareTransport
}
CameraServiceStub dispatches incoming binder transactions to a typed ICameraService implementation.
func (*CameraServiceStub) Descriptor ¶
func (s *CameraServiceStub) Descriptor() string
func (*CameraServiceStub) OnTransaction ¶
func (s *CameraServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type CameraSessionStats ¶
type CameraSessionStats struct {
CameraId string
Facing int32
NewCameraState int32
ClientName string
ApiLevel int32
IsNdk bool
LatencyMs int32
LogId int64
MaxPreviewFps float32
SessionType int32
InternalReconfigure int32
RequestCount int64
ResultErrorCount int64
DeviceError bool
UserTag string
VideoStabilizationMode int32
UsedUltraWide bool
UsedZoomOverride bool
SessionIndex int32
}
func (*CameraSessionStats) MarshalParcel ¶
func (s *CameraSessionStats) MarshalParcel( p *parcel.Parcel, ) error
func (*CameraSessionStats) UnmarshalParcel ¶
func (s *CameraSessionStats) UnmarshalParcel( p *parcel.Parcel, ) error
type CameraStatus ¶
func (*CameraStatus) MarshalParcel ¶
func (s *CameraStatus) MarshalParcel( p *parcel.Parcel, ) error
func (*CameraStatus) UnmarshalParcel ¶
func (s *CameraStatus) UnmarshalParcel( p *parcel.Parcel, ) error
type CameraStub ¶
type CameraStub struct {
Impl ICamera
Transport binder.VersionAwareTransport
}
CameraStub dispatches incoming binder transactions to a typed ICamera implementation.
func (*CameraStub) Descriptor ¶
func (s *CameraStub) Descriptor() string
func (*CameraStub) OnTransaction ¶
func (s *CameraStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ConsumerIrServiceProxy ¶
func NewConsumerIrServiceProxy ¶
func NewConsumerIrServiceProxy( remote binder.IBinder, ) *ConsumerIrServiceProxy
func (*ConsumerIrServiceProxy) AsBinder ¶
func (p *ConsumerIrServiceProxy) AsBinder() binder.IBinder
func (*ConsumerIrServiceProxy) GetCarrierFrequencies ¶
func (p *ConsumerIrServiceProxy) GetCarrierFrequencies( ctx context.Context, ) ([]int32, error)
func (*ConsumerIrServiceProxy) HasIrEmitter ¶
func (p *ConsumerIrServiceProxy) HasIrEmitter( ctx context.Context, ) (bool, error)
type ConsumerIrServiceStub ¶
type ConsumerIrServiceStub struct {
Impl IConsumerIrService
Transport binder.VersionAwareTransport
}
ConsumerIrServiceStub dispatches incoming binder transactions to a typed IConsumerIrService implementation.
func (*ConsumerIrServiceStub) Descriptor ¶
func (s *ConsumerIrServiceStub) Descriptor() string
func (*ConsumerIrServiceStub) OnTransaction ¶
func (s *ConsumerIrServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type HardwareBuffer ¶
type HardwareBuffer struct {
}
func (*HardwareBuffer) MarshalParcel ¶
func (s *HardwareBuffer) MarshalParcel( p *parcel.Parcel, ) error
func (*HardwareBuffer) UnmarshalParcel ¶
func (s *HardwareBuffer) UnmarshalParcel( p *parcel.Parcel, ) error
type ICamera ¶
func NewCameraStub ¶
func NewCameraStub( impl ICameraServer, ) ICamera
NewCameraStub creates a server-side ICamera wrapping the given server implementation. The returned value satisfies ICamera and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ICameraClient ¶
func NewCameraClientStub ¶
func NewCameraClientStub( impl ICameraClientServer, ) ICameraClient
NewCameraClientStub creates a server-side ICameraClient wrapping the given server implementation. The returned value satisfies ICameraClient and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ICameraClientServer ¶
type ICameraClientServer interface {
}
ICameraClientServer is the server-side interface that user implementations provide to NewCameraClientStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ICameraServer ¶
ICameraServer is the server-side interface that user implementations provide to NewCameraStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ICameraService ¶
type ICameraService interface {
AsBinder() binder.IBinder
GetNumberOfCameras(ctx context.Context, type_ int32) (int32, error)
GetCameraInfo(ctx context.Context, cameraId int32, overrideToPortrait bool) (CameraInfo, error)
Connect(ctx context.Context, client ICameraClient, cameraId int32, clientUid int32, clientPid int32, targetSdkVersion int32, overrideToPortrait bool, forceSlowJpegMode bool) (ICamera, error)
ConnectDevice(ctx context.Context, callbacks camera2.ICameraDeviceCallbacks, cameraId string, featureId string, clientUid int32, oomScoreOffset int32, targetSdkVersion int32, overrideToPortrait bool) (camera2.ICameraDeviceUser, error)
AddListener(ctx context.Context, listener ICameraServiceListener) ([]CameraStatus, error)
GetConcurrentCameraIds(ctx context.Context) ([]provider.ConcurrentCameraIdCombination, error)
IsConcurrentSessionConfigurationSupported(ctx context.Context, sessions []utils.CameraIdAndSessionConfiguration, targetSdkVersion int32) (bool, error)
RemapCameraIds(ctx context.Context, cameraIdRemapping CameraIdRemapping) error
InjectSessionParams(ctx context.Context, cameraId string, sessionParams impl.CameraMetadataNative) error
RemoveListener(ctx context.Context, listener ICameraServiceListener) error
GetCameraCharacteristics(ctx context.Context, cameraId string, targetSdkVersion int32, overrideToPortrait bool) (impl.CameraMetadataNative, error)
GetCameraVendorTagDescriptor(ctx context.Context) (params.VendorTagDescriptor, error)
GetCameraVendorTagCache(ctx context.Context) (params.VendorTagDescriptorCache, error)
GetLegacyParameters(ctx context.Context, cameraId int32) (string, error)
SupportsCameraApi(ctx context.Context, cameraId string, apiVersion int32) (bool, error)
IsHiddenPhysicalCamera(ctx context.Context, cameraId string) (bool, error)
InjectCamera(ctx context.Context, packageName string, internalCamId string, externalCamId string, CameraInjectionCallback camera2.ICameraInjectionCallback) (camera2.ICameraInjectionSession, error)
SetTorchMode(ctx context.Context, cameraId string, enabled bool, clientBinder binder.IBinder) error
TurnOnTorchWithStrengthLevel(ctx context.Context, cameraId string, strengthLevel int32, clientBinder binder.IBinder) error
GetTorchStrengthLevel(ctx context.Context, cameraId string) (int32, error)
NotifySystemEvent(ctx context.Context, eventId int32, args []int32) error
NotifyDisplayConfigurationChange(ctx context.Context) error
NotifyDeviceStateChange(ctx context.Context, newState int64) error
ReportExtensionSessionStats(ctx context.Context, stats CameraExtensionSessionStats) (string, error)
CreateDefaultRequest(ctx context.Context, cameraId string, templateId int32) (impl.CameraMetadataNative, error)
IsSessionConfigurationWithParametersSupported(ctx context.Context, cameraId string, sessionConfiguration params.SessionConfiguration) (bool, error)
GetSessionCharacteristics(ctx context.Context, cameraId string, targetSdkVersion int32, overrideToPortrait bool, sessionConfiguration params.SessionConfiguration) (impl.CameraMetadataNative, error)
}
func NewCameraServiceStub ¶
func NewCameraServiceStub( impl ICameraServiceServer, ) ICameraService
NewCameraServiceStub creates a server-side ICameraService wrapping the given server implementation. The returned value satisfies ICameraService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ICameraServiceListener ¶
type ICameraServiceListener interface {
AsBinder() binder.IBinder
OnStatusChanged(ctx context.Context, status int32, cameraId string) error
OnPhysicalCameraStatusChanged(ctx context.Context, status int32, cameraId string, physicalCameraId string) error
OnTorchStatusChanged(ctx context.Context, status int32, cameraId string) error
OnTorchStrengthLevelChanged(ctx context.Context, cameraId string, newTorchStrength int32) error
OnCameraAccessPrioritiesChanged(ctx context.Context) error
OnCameraOpened(ctx context.Context, cameraId string, clientPackageId string) error
OnCameraClosed(ctx context.Context, cameraId string) error
}
func NewCameraServiceListenerStub ¶
func NewCameraServiceListenerStub( impl ICameraServiceListenerServer, ) ICameraServiceListener
NewCameraServiceListenerStub creates a server-side ICameraServiceListener wrapping the given server implementation. The returned value satisfies ICameraServiceListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ICameraServiceListenerServer ¶
type ICameraServiceListenerServer interface {
OnStatusChanged(ctx context.Context, status int32, cameraId string) error
OnPhysicalCameraStatusChanged(ctx context.Context, status int32, cameraId string, physicalCameraId string) error
OnTorchStatusChanged(ctx context.Context, status int32, cameraId string) error
OnTorchStrengthLevelChanged(ctx context.Context, cameraId string, newTorchStrength int32) error
OnCameraAccessPrioritiesChanged(ctx context.Context) error
OnCameraOpened(ctx context.Context, cameraId string, clientPackageId string) error
OnCameraClosed(ctx context.Context, cameraId string) error
}
ICameraServiceListenerServer is the server-side interface that user implementations provide to NewCameraServiceListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ICameraServiceProxy ¶
type ICameraServiceProxy interface {
AsBinder() binder.IBinder
PingForUserUpdate(ctx context.Context) error
NotifyCameraState(ctx context.Context, cameraSessionStats CameraSessionStats) error
GetRotateAndCropOverride(ctx context.Context, packageName string, lensFacing int32) (int32, error)
GetAutoframingOverride(ctx context.Context, packageName string) (int32, error)
IsCameraDisabled(ctx context.Context) (bool, error)
}
func NewCameraServiceProxyStub ¶
func NewCameraServiceProxyStub( impl ICameraServiceProxyServer, ) ICameraServiceProxy
NewCameraServiceProxyStub creates a server-side ICameraServiceProxy wrapping the given server implementation. The returned value satisfies ICameraServiceProxy and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ICameraServiceProxyServer ¶
type ICameraServiceProxyServer interface {
PingForUserUpdate(ctx context.Context) error
NotifyCameraState(ctx context.Context, cameraSessionStats CameraSessionStats) error
GetRotateAndCropOverride(ctx context.Context, packageName string, lensFacing int32) (int32, error)
GetAutoframingOverride(ctx context.Context, packageName string) (int32, error)
IsCameraDisabled(ctx context.Context) (bool, error)
}
ICameraServiceProxyServer is the server-side interface that user implementations provide to NewCameraServiceProxyStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ICameraServiceServer ¶
type ICameraServiceServer interface {
GetNumberOfCameras(ctx context.Context, type_ int32) (int32, error)
GetCameraInfo(ctx context.Context, cameraId int32, overrideToPortrait bool) (CameraInfo, error)
Connect(ctx context.Context, client ICameraClient, cameraId int32, clientUid int32, clientPid int32, targetSdkVersion int32, overrideToPortrait bool, forceSlowJpegMode bool) (ICamera, error)
ConnectDevice(ctx context.Context, callbacks camera2.ICameraDeviceCallbacks, cameraId string, featureId string, clientUid int32, oomScoreOffset int32, targetSdkVersion int32, overrideToPortrait bool) (camera2.ICameraDeviceUser, error)
AddListener(ctx context.Context, listener ICameraServiceListener) ([]CameraStatus, error)
GetConcurrentCameraIds(ctx context.Context) ([]provider.ConcurrentCameraIdCombination, error)
IsConcurrentSessionConfigurationSupported(ctx context.Context, sessions []utils.CameraIdAndSessionConfiguration, targetSdkVersion int32) (bool, error)
RemapCameraIds(ctx context.Context, cameraIdRemapping CameraIdRemapping) error
InjectSessionParams(ctx context.Context, cameraId string, sessionParams impl.CameraMetadataNative) error
RemoveListener(ctx context.Context, listener ICameraServiceListener) error
GetCameraCharacteristics(ctx context.Context, cameraId string, targetSdkVersion int32, overrideToPortrait bool) (impl.CameraMetadataNative, error)
GetCameraVendorTagDescriptor(ctx context.Context) (params.VendorTagDescriptor, error)
GetCameraVendorTagCache(ctx context.Context) (params.VendorTagDescriptorCache, error)
GetLegacyParameters(ctx context.Context, cameraId int32) (string, error)
SupportsCameraApi(ctx context.Context, cameraId string, apiVersion int32) (bool, error)
IsHiddenPhysicalCamera(ctx context.Context, cameraId string) (bool, error)
InjectCamera(ctx context.Context, packageName string, internalCamId string, externalCamId string, CameraInjectionCallback camera2.ICameraInjectionCallback) (camera2.ICameraInjectionSession, error)
SetTorchMode(ctx context.Context, cameraId string, enabled bool, clientBinder binder.IBinder) error
TurnOnTorchWithStrengthLevel(ctx context.Context, cameraId string, strengthLevel int32, clientBinder binder.IBinder) error
GetTorchStrengthLevel(ctx context.Context, cameraId string) (int32, error)
NotifySystemEvent(ctx context.Context, eventId int32, args []int32) error
NotifyDisplayConfigurationChange(ctx context.Context) error
NotifyDeviceStateChange(ctx context.Context, newState int64) error
ReportExtensionSessionStats(ctx context.Context, stats CameraExtensionSessionStats) (string, error)
CreateDefaultRequest(ctx context.Context, cameraId string, templateId int32) (impl.CameraMetadataNative, error)
IsSessionConfigurationWithParametersSupported(ctx context.Context, cameraId string, sessionConfiguration params.SessionConfiguration) (bool, error)
GetSessionCharacteristics(ctx context.Context, cameraId string, targetSdkVersion int32, overrideToPortrait bool, sessionConfiguration params.SessionConfiguration) (impl.CameraMetadataNative, error)
}
ICameraServiceServer is the server-side interface that user implementations provide to NewCameraServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IConsumerIrService ¶
type IConsumerIrService interface {
AsBinder() binder.IBinder
HasIrEmitter(ctx context.Context) (bool, error)
Transmit(ctx context.Context, packageName string, carrierFrequency int32, pattern []int32) error
GetCarrierFrequencies(ctx context.Context) ([]int32, error)
}
func NewConsumerIrServiceStub ¶
func NewConsumerIrServiceStub( impl IConsumerIrServiceServer, ) IConsumerIrService
NewConsumerIrServiceStub creates a server-side IConsumerIrService wrapping the given server implementation. The returned value satisfies IConsumerIrService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IConsumerIrServiceServer ¶
type IConsumerIrServiceServer interface {
HasIrEmitter(ctx context.Context) (bool, error)
Transmit(ctx context.Context, packageName string, carrierFrequency int32, pattern []int32) error
GetCarrierFrequencies(ctx context.Context) ([]int32, error)
}
IConsumerIrServiceServer is the server-side interface that user implementations provide to NewConsumerIrServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ISensorPrivacyListener ¶
type ISensorPrivacyListener interface {
AsBinder() binder.IBinder
OnSensorPrivacyChanged(ctx context.Context, toggleType int32, sensor int32, enabled bool) error
OnSensorPrivacyStateChanged(ctx context.Context, toggleType int32, sensor int32, state int32) error
}
func NewSensorPrivacyListenerStub ¶
func NewSensorPrivacyListenerStub( impl ISensorPrivacyListenerServer, ) ISensorPrivacyListener
NewSensorPrivacyListenerStub creates a server-side ISensorPrivacyListener wrapping the given server implementation. The returned value satisfies ISensorPrivacyListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ISensorPrivacyListenerServer ¶
type ISensorPrivacyListenerServer interface {
OnSensorPrivacyChanged(ctx context.Context, toggleType int32, sensor int32, enabled bool) error
OnSensorPrivacyStateChanged(ctx context.Context, toggleType int32, sensor int32, state int32) error
}
ISensorPrivacyListenerServer is the server-side interface that user implementations provide to NewSensorPrivacyListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ISensorPrivacyManager ¶
type ISensorPrivacyManager interface {
AsBinder() binder.IBinder
SupportsSensorToggle(ctx context.Context, toggleType int32, sensor int32) (bool, error)
AddSensorPrivacyListener(ctx context.Context, listener ISensorPrivacyListener) error
AddToggleSensorPrivacyListener(ctx context.Context, listener ISensorPrivacyListener) error
RemoveSensorPrivacyListener(ctx context.Context, listener ISensorPrivacyListener) error
RemoveToggleSensorPrivacyListener(ctx context.Context, listener ISensorPrivacyListener) error
IsSensorPrivacyEnabled(ctx context.Context) (bool, error)
IsCombinedToggleSensorPrivacyEnabled(ctx context.Context, sensor int32) (bool, error)
IsToggleSensorPrivacyEnabled(ctx context.Context, toggleType int32, sensor int32) (bool, error)
SetSensorPrivacy(ctx context.Context, enable bool) error
SetToggleSensorPrivacy(ctx context.Context, source int32, sensor int32, enable bool) error
SetToggleSensorPrivacyForProfileGroup(ctx context.Context, source int32, sensor int32, enable bool) error
GetCameraPrivacyAllowlist(ctx context.Context) ([]CameraPrivacyAllowlistEntry, error)
GetToggleSensorPrivacyState(ctx context.Context, toggleType int32, sensor int32) (int32, error)
SetToggleSensorPrivacyState(ctx context.Context, source int32, sensor int32, state int32) error
SetToggleSensorPrivacyStateForProfileGroup(ctx context.Context, source int32, sensor int32, state int32) error
IsCameraPrivacyEnabled(ctx context.Context, packageName string) (bool, error)
}
func NewSensorPrivacyManagerStub ¶
func NewSensorPrivacyManagerStub( impl ISensorPrivacyManagerServer, ) ISensorPrivacyManager
NewSensorPrivacyManagerStub creates a server-side ISensorPrivacyManager wrapping the given server implementation. The returned value satisfies ISensorPrivacyManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ISensorPrivacyManagerServer ¶
type ISensorPrivacyManagerServer interface {
SupportsSensorToggle(ctx context.Context, toggleType int32, sensor int32) (bool, error)
AddSensorPrivacyListener(ctx context.Context, listener ISensorPrivacyListener) error
AddToggleSensorPrivacyListener(ctx context.Context, listener ISensorPrivacyListener) error
RemoveSensorPrivacyListener(ctx context.Context, listener ISensorPrivacyListener) error
RemoveToggleSensorPrivacyListener(ctx context.Context, listener ISensorPrivacyListener) error
IsSensorPrivacyEnabled(ctx context.Context) (bool, error)
IsCombinedToggleSensorPrivacyEnabled(ctx context.Context, sensor int32) (bool, error)
IsToggleSensorPrivacyEnabled(ctx context.Context, toggleType int32, sensor int32) (bool, error)
SetSensorPrivacy(ctx context.Context, enable bool) error
SetToggleSensorPrivacy(ctx context.Context, source int32, sensor int32, enable bool) error
SetToggleSensorPrivacyForProfileGroup(ctx context.Context, source int32, sensor int32, enable bool) error
GetCameraPrivacyAllowlist(ctx context.Context) ([]CameraPrivacyAllowlistEntry, error)
GetToggleSensorPrivacyState(ctx context.Context, toggleType int32, sensor int32) (int32, error)
SetToggleSensorPrivacyState(ctx context.Context, source int32, sensor int32, state int32) error
SetToggleSensorPrivacyStateForProfileGroup(ctx context.Context, source int32, sensor int32, state int32) error
IsCameraPrivacyEnabled(ctx context.Context, packageName string) (bool, error)
}
ISensorPrivacyManagerServer is the server-side interface that user implementations provide to NewSensorPrivacyManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ISerialManager ¶
type ISerialManager interface {
AsBinder() binder.IBinder
GetSerialPorts(ctx context.Context) ([]string, error)
OpenSerialPort(ctx context.Context, name string) (int32, error)
}
func NewSerialManagerStub ¶
func NewSerialManagerStub( impl ISerialManagerServer, ) ISerialManager
NewSerialManagerStub creates a server-side ISerialManager wrapping the given server implementation. The returned value satisfies ISerialManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ISerialManagerServer ¶
type ISerialManagerServer interface {
GetSerialPorts(ctx context.Context) ([]string, error)
OpenSerialPort(ctx context.Context, name string) (int32, error)
}
ISerialManagerServer is the server-side interface that user implementations provide to NewSerialManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type OverlayProperties ¶
type OverlayProperties struct {
}
func (*OverlayProperties) MarshalParcel ¶
func (s *OverlayProperties) MarshalParcel( p *parcel.Parcel, ) error
func (*OverlayProperties) UnmarshalParcel ¶
func (s *OverlayProperties) UnmarshalParcel( p *parcel.Parcel, ) error
type SensorPrivacyListenerProxy ¶
func NewSensorPrivacyListenerProxy ¶
func NewSensorPrivacyListenerProxy( remote binder.IBinder, ) *SensorPrivacyListenerProxy
func (*SensorPrivacyListenerProxy) AsBinder ¶
func (p *SensorPrivacyListenerProxy) AsBinder() binder.IBinder
func (*SensorPrivacyListenerProxy) OnSensorPrivacyChanged ¶
func (*SensorPrivacyListenerProxy) OnSensorPrivacyStateChanged ¶
type SensorPrivacyListenerStub ¶
type SensorPrivacyListenerStub struct {
Impl ISensorPrivacyListener
Transport binder.VersionAwareTransport
}
SensorPrivacyListenerStub dispatches incoming binder transactions to a typed ISensorPrivacyListener implementation.
func (*SensorPrivacyListenerStub) Descriptor ¶
func (s *SensorPrivacyListenerStub) Descriptor() string
func (*SensorPrivacyListenerStub) OnTransaction ¶
func (s *SensorPrivacyListenerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type SensorPrivacyManagerProxy ¶
func NewSensorPrivacyManagerProxy ¶
func NewSensorPrivacyManagerProxy( remote binder.IBinder, ) *SensorPrivacyManagerProxy
func (*SensorPrivacyManagerProxy) AddSensorPrivacyListener ¶
func (p *SensorPrivacyManagerProxy) AddSensorPrivacyListener( ctx context.Context, listener ISensorPrivacyListener, ) error
func (*SensorPrivacyManagerProxy) AddToggleSensorPrivacyListener ¶
func (p *SensorPrivacyManagerProxy) AddToggleSensorPrivacyListener( ctx context.Context, listener ISensorPrivacyListener, ) error
func (*SensorPrivacyManagerProxy) AsBinder ¶
func (p *SensorPrivacyManagerProxy) AsBinder() binder.IBinder
func (*SensorPrivacyManagerProxy) GetCameraPrivacyAllowlist ¶
func (p *SensorPrivacyManagerProxy) GetCameraPrivacyAllowlist( ctx context.Context, ) ([]CameraPrivacyAllowlistEntry, error)
func (*SensorPrivacyManagerProxy) GetToggleSensorPrivacyState ¶
func (*SensorPrivacyManagerProxy) IsCameraPrivacyEnabled ¶
func (*SensorPrivacyManagerProxy) IsCombinedToggleSensorPrivacyEnabled ¶
func (*SensorPrivacyManagerProxy) IsSensorPrivacyEnabled ¶
func (p *SensorPrivacyManagerProxy) IsSensorPrivacyEnabled( ctx context.Context, ) (bool, error)
func (*SensorPrivacyManagerProxy) IsToggleSensorPrivacyEnabled ¶
func (*SensorPrivacyManagerProxy) RemoveSensorPrivacyListener ¶
func (p *SensorPrivacyManagerProxy) RemoveSensorPrivacyListener( ctx context.Context, listener ISensorPrivacyListener, ) error
func (*SensorPrivacyManagerProxy) RemoveToggleSensorPrivacyListener ¶
func (p *SensorPrivacyManagerProxy) RemoveToggleSensorPrivacyListener( ctx context.Context, listener ISensorPrivacyListener, ) error
func (*SensorPrivacyManagerProxy) SetSensorPrivacy ¶
func (p *SensorPrivacyManagerProxy) SetSensorPrivacy( ctx context.Context, enable bool, ) error
func (*SensorPrivacyManagerProxy) SetToggleSensorPrivacy ¶
func (*SensorPrivacyManagerProxy) SetToggleSensorPrivacyForProfileGroup ¶
func (*SensorPrivacyManagerProxy) SetToggleSensorPrivacyState ¶
func (*SensorPrivacyManagerProxy) SetToggleSensorPrivacyStateForProfileGroup ¶
func (*SensorPrivacyManagerProxy) SupportsSensorToggle ¶
type SensorPrivacyManagerStub ¶
type SensorPrivacyManagerStub struct {
Impl ISensorPrivacyManager
Transport binder.VersionAwareTransport
}
SensorPrivacyManagerStub dispatches incoming binder transactions to a typed ISensorPrivacyManager implementation.
func (*SensorPrivacyManagerStub) Descriptor ¶
func (s *SensorPrivacyManagerStub) Descriptor() string
func (*SensorPrivacyManagerStub) OnTransaction ¶
func (s *SensorPrivacyManagerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type SerialManagerProxy ¶
func GetSerialManager ¶
func GetSerialManager( ctx context.Context, sm *servicemanager.ServiceManager, ) (*SerialManagerProxy, error)
GetSerialManager retrieves the SerialService service and returns a typed proxy.
func NewSerialManagerProxy ¶
func NewSerialManagerProxy( remote binder.IBinder, ) *SerialManagerProxy
func (*SerialManagerProxy) AsBinder ¶
func (p *SerialManagerProxy) AsBinder() binder.IBinder
func (*SerialManagerProxy) GetSerialPorts ¶
func (p *SerialManagerProxy) GetSerialPorts( ctx context.Context, ) ([]string, error)
func (*SerialManagerProxy) OpenSerialPort ¶
type SerialManagerStub ¶
type SerialManagerStub struct {
Impl ISerialManager
Transport binder.VersionAwareTransport
}
SerialManagerStub dispatches incoming binder transactions to a typed ISerialManager implementation.
func (*SerialManagerStub) Descriptor ¶
func (s *SerialManagerStub) Descriptor() string
func (*SerialManagerStub) OnTransaction ¶
func (s *SerialManagerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
Source Files
¶
- cameraextensionsessionstats.go
- cameraextensionsessionstats.type.go
- cameraidremapping.go
- cameraidremapping.packageidremapping.go
- camerainfo.go
- cameraprivacyallowlistentry.go
- camerasessionstats.go
- camerastatus.go
- get_serial.go
- hardwarebuffer.go
- icamera.go
- icameraclient.go
- icameraservice.go
- icameraservicelistener.go
- icameraserviceproxy.go
- iconsumerirservice.go
- isensorprivacylistener.go
- isensorprivacymanager.go
- iserialmanager.go
- overlayproperties.go