Documentation
¶
Index ¶
- Constants
- type BaseBlock
- func (u *BaseBlock) GetHwbBlock() (graphicsCommon.HardwareBuffer, bool)
- func (u *BaseBlock) GetNativeBlock() (common.NativeHandle, bool)
- func (u *BaseBlock) GetPooledBlock() (bufferpool2.BufferStatusMessage, bool)
- func (u *BaseBlock) MarshalParcel(p *parcel.Parcel) error
- func (u *BaseBlock) SetHwbBlock(v graphicsCommon.HardwareBuffer)
- func (u *BaseBlock) SetNativeBlock(v common.NativeHandle)
- func (u *BaseBlock) SetPooledBlock(v bufferpool2.BufferStatusMessage)
- func (u *BaseBlock) UnmarshalParcel(p *parcel.Parcel) error
- type Block
- type Buffer
- type ComponentInterfaceProxy
- type ComponentInterfaceStub
- type ComponentListenerProxy
- func (p *ComponentListenerProxy) AsBinder() binder.IBinder
- func (p *ComponentListenerProxy) OnError(ctx context.Context, status Status, errorCode int32) error
- func (p *ComponentListenerProxy) OnFramesRendered(ctx context.Context, renderedFrames []IComponentListenerRenderedFrame) error
- func (p *ComponentListenerProxy) OnInputBuffersReleased(ctx context.Context, inputBuffers []IComponentListenerInputBuffer) error
- func (p *ComponentListenerProxy) OnTripped(ctx context.Context, settingResults []SettingResult) error
- func (p *ComponentListenerProxy) OnWorkDone(ctx context.Context, workBundle WorkBundle) error
- type ComponentListenerStub
- type ComponentProxy
- func (p *ComponentProxy) AsBinder() binder.IBinder
- func (p *ComponentProxy) AsInputSink(ctx context.Context) (IInputSink, error)
- func (p *ComponentProxy) ConfigureVideoTunnel(ctx context.Context, avSyncHwId int32) (common.NativeHandle, error)
- func (p *ComponentProxy) ConnectToInputSurface(ctx context.Context, inputSurface IInputSurface) (IInputSurfaceConnection, error)
- func (p *ComponentProxy) CreateBlockPool(ctx context.Context, allocator IComponentBlockPoolAllocator) (IComponentBlockPool, error)
- func (p *ComponentProxy) DestroyBlockPool(ctx context.Context, blockPoolId int64) error
- func (p *ComponentProxy) Drain(ctx context.Context, withEos bool) error
- func (p *ComponentProxy) Flush(ctx context.Context) (WorkBundle, error)
- func (p *ComponentProxy) GetInterface(ctx context.Context) (IComponentInterface, error)
- func (p *ComponentProxy) Queue(ctx context.Context, workBundle WorkBundle) error
- func (p *ComponentProxy) Release(ctx context.Context) error
- func (p *ComponentProxy) Reset(ctx context.Context) error
- func (p *ComponentProxy) Start(ctx context.Context) error
- func (p *ComponentProxy) Stop(ctx context.Context) error
- type ComponentStoreProxy
- func (p *ComponentStoreProxy) AsBinder() binder.IBinder
- func (p *ComponentStoreProxy) CopyBuffer(ctx context.Context, src Buffer, dst Buffer) error
- func (p *ComponentStoreProxy) CreateComponent(ctx context.Context, name string, listener IComponentListener, ...) (IComponent, error)
- func (p *ComponentStoreProxy) CreateInputSurface(ctx context.Context) (IInputSurface, error)
- func (p *ComponentStoreProxy) CreateInterface(ctx context.Context, name string) (IComponentInterface, error)
- func (p *ComponentStoreProxy) GetConfigurable(ctx context.Context) (IConfigurable, error)
- func (p *ComponentStoreProxy) GetPoolClientManager(ctx context.Context) (bufferpool2.IClientManager, error)
- func (p *ComponentStoreProxy) GetStructDescriptors(ctx context.Context, indices []int32) ([]StructDescriptor, error)
- func (p *ComponentStoreProxy) ListComponents(ctx context.Context) ([]IComponentStoreComponentTraits, error)
- type ComponentStoreStub
- type ComponentStub
- type ConfigurableProxy
- func (p *ConfigurableProxy) AsBinder() binder.IBinder
- func (p *ConfigurableProxy) Config(ctx context.Context, inParams Params, mayBlock bool) (IConfigurableConfigResult, error)
- func (p *ConfigurableProxy) GetId(ctx context.Context) (int32, error)
- func (p *ConfigurableProxy) GetName(ctx context.Context) (string, error)
- func (p *ConfigurableProxy) Query(ctx context.Context, indices []int32, mayBlock bool) (IConfigurableQueryResult, error)
- func (p *ConfigurableProxy) QuerySupportedParams(ctx context.Context, start int32, count int32) ([]ParamDescriptor, error)
- func (p *ConfigurableProxy) QuerySupportedValues(ctx context.Context, inFields []FieldSupportedValuesQuery, mayBlock bool) (IConfigurableQuerySupportedValuesResult, error)
- type ConfigurableStub
- type FieldDescriptor
- type FieldDescriptorNamedValue
- type FieldDescriptorType
- type FieldId
- type FieldSupportedValues
- func (u *FieldSupportedValues) GetEmpty() (bool, bool)
- func (u *FieldSupportedValues) GetFlags() ([]int64, bool)
- func (u *FieldSupportedValues) GetRange() (ValueRange, bool)
- func (u *FieldSupportedValues) GetValues() ([]int64, bool)
- func (u *FieldSupportedValues) MarshalParcel(p *parcel.Parcel) error
- func (u *FieldSupportedValues) SetEmpty(v bool)
- func (u *FieldSupportedValues) SetFlags(v []int64)
- func (u *FieldSupportedValues) SetRange(v ValueRange)
- func (u *FieldSupportedValues) SetValues(v []int64)
- func (u *FieldSupportedValues) UnmarshalParcel(p *parcel.Parcel) error
- type FieldSupportedValuesQuery
- type FieldSupportedValuesQueryResult
- type FieldSupportedValuesQueryType
- type FrameData
- type GraphicBufferAllocatorProxy
- func (p *GraphicBufferAllocatorProxy) Allocate(ctx context.Context, desc IGraphicBufferAllocatorDescription) (IGraphicBufferAllocatorAllocation, error)
- func (p *GraphicBufferAllocatorProxy) AsBinder() binder.IBinder
- func (p *GraphicBufferAllocatorProxy) Deallocate(ctx context.Context, id int64) (bool, error)
- func (p *GraphicBufferAllocatorProxy) GetWaitableFd(ctx context.Context) (int32, error)
- type GraphicBufferAllocatorStub
- type IComponent
- type IComponentBlockPool
- type IComponentBlockPoolAllocator
- type IComponentGbAllocator
- type IComponentInterface
- type IComponentInterfaceServer
- type IComponentListener
- type IComponentListenerInputBuffer
- type IComponentListenerRenderedFrame
- type IComponentListenerServer
- type IComponentPooledGbAllocator
- type IComponentServer
- type IComponentStore
- type IComponentStoreComponentTraits
- type IComponentStoreComponentTraitsDomain
- type IComponentStoreComponentTraitsKind
- type IComponentStoreServer
- type IConfigurable
- type IConfigurableConfigResult
- type IConfigurableQueryResult
- type IConfigurableQuerySupportedValuesResult
- type IConfigurableServer
- type IGraphicBufferAllocator
- type IGraphicBufferAllocatorAllocation
- type IGraphicBufferAllocatorDescription
- type IGraphicBufferAllocatorServer
- type IInputSink
- type IInputSinkServer
- type IInputSurface
- type IInputSurfaceConnection
- type IInputSurfaceConnectionServer
- type IInputSurfaceServer
- type IPooledGraphicBufferAllocator
- type IPooledGraphicBufferAllocatorAllocation
- type IPooledGraphicBufferAllocatorDescription
- type IPooledGraphicBufferAllocatorServer
- type InfoBuffer
- type InputSinkProxy
- type InputSinkStub
- type InputSurfaceConnectionProxy
- type InputSurfaceConnectionStub
- type InputSurfaceProxy
- func (p *InputSurfaceProxy) AsBinder() binder.IBinder
- func (p *InputSurfaceProxy) Connect(ctx context.Context, sink IInputSink) (IInputSurfaceConnection, error)
- func (p *InputSurfaceProxy) GetConfigurable(ctx context.Context) (IConfigurable, error)
- func (p *InputSurfaceProxy) GetSurface(ctx context.Context) (view.Surface, error)
- type InputSurfaceStub
- type ParamDescriptor
- type ParamField
- type ParamFieldValues
- type Params
- type PooledGraphicBufferAllocatorProxy
- func (p *PooledGraphicBufferAllocatorProxy) Allocate(ctx context.Context, desc IPooledGraphicBufferAllocatorDescription) (IPooledGraphicBufferAllocatorAllocation, error)
- func (p *PooledGraphicBufferAllocatorProxy) AsBinder() binder.IBinder
- func (p *PooledGraphicBufferAllocatorProxy) Deallocate(ctx context.Context, id int32) (bool, error)
- type PooledGraphicBufferAllocatorStub
- type SettingResult
- type SettingResultFailure
- type Status
- type StructDescriptor
- type ValueRange
- type Work
- type WorkBundle
- type WorkOrdinal
- type Worklet
Constants ¶
const ( BaseBlockTagNativeBlock int32 = 0 BaseBlockTagHwbBlock int32 = 1 BaseBlockTagPooledBlock int32 = 2 )
const ( FieldSupportedValuesTagEmpty int32 = 0 FieldSupportedValuesTagRange int32 = 1 FieldSupportedValuesTagValues int32 = 2 FieldSupportedValuesTagFlags int32 = 3 )
const ( FrameDataDropFrame int32 = (1 << 0) FrameDataEndOfStream int32 = (1 << 1) FrameDataDiscardFrame int32 = (1 << 2) FrameDataFlagIncomplete int32 = (1 << 3) FrameDataCodecConfig int32 = -2147483648 )
const ( TransactionIComponentConfigureVideoTunnel = binder.FirstCallTransaction + 0 TransactionIComponentCreateBlockPool = binder.FirstCallTransaction + 1 TransactionIComponentDestroyBlockPool = binder.FirstCallTransaction + 2 TransactionIComponentDrain = binder.FirstCallTransaction + 3 TransactionIComponentFlush = binder.FirstCallTransaction + 4 TransactionIComponentGetInterface = binder.FirstCallTransaction + 5 TransactionIComponentQueue = binder.FirstCallTransaction + 6 TransactionIComponentRelease = binder.FirstCallTransaction + 7 TransactionIComponentReset = binder.FirstCallTransaction + 8 TransactionIComponentStart = binder.FirstCallTransaction + 9 TransactionIComponentStop = binder.FirstCallTransaction + 10 TransactionIComponentConnectToInputSurface = binder.FirstCallTransaction + 11 TransactionIComponentAsInputSink = binder.FirstCallTransaction + 12 )
const ( MethodIComponentConfigureVideoTunnel = "configureVideoTunnel" MethodIComponentCreateBlockPool = "createBlockPool" MethodIComponentDestroyBlockPool = "destroyBlockPool" MethodIComponentDrain = "drain" MethodIComponentFlush = "flush" MethodIComponentGetInterface = "getInterface" MethodIComponentQueue = "queue" MethodIComponentRelease = "release" MethodIComponentReset = "reset" MethodIComponentStart = "start" MethodIComponentStop = "stop" MethodIComponentConnectToInputSurface = "connectToInputSurface" MethodIComponentAsInputSink = "asInputSink" )
const ( TransactionIComponentListenerOnError = binder.FirstCallTransaction + 0 TransactionIComponentListenerOnFramesRendered = binder.FirstCallTransaction + 1 TransactionIComponentListenerOnInputBuffersReleased = binder.FirstCallTransaction + 2 TransactionIComponentListenerOnTripped = binder.FirstCallTransaction + 3 TransactionIComponentListenerOnWorkDone = binder.FirstCallTransaction + 4 )
const ( MethodIComponentListenerOnError = "onError" MethodIComponentListenerOnFramesRendered = "onFramesRendered" MethodIComponentListenerOnInputBuffersReleased = "onInputBuffersReleased" MethodIComponentListenerOnTripped = "onTripped" MethodIComponentListenerOnWorkDone = "onWorkDone" )
const ( TransactionIComponentStoreCopyBuffer = binder.FirstCallTransaction + 0 TransactionIComponentStoreCreateComponent = binder.FirstCallTransaction + 1 TransactionIComponentStoreCreateInterface = binder.FirstCallTransaction + 2 TransactionIComponentStoreGetConfigurable = binder.FirstCallTransaction + 3 TransactionIComponentStoreGetPoolClientManager = binder.FirstCallTransaction + 4 TransactionIComponentStoreGetStructDescriptors = binder.FirstCallTransaction + 5 TransactionIComponentStoreListComponents = binder.FirstCallTransaction + 6 TransactionIComponentStoreCreateInputSurface = binder.FirstCallTransaction + 7 )
const ( MethodIComponentStoreCopyBuffer = "copyBuffer" MethodIComponentStoreCreateComponent = "createComponent" MethodIComponentStoreCreateInterface = "createInterface" MethodIComponentStoreGetConfigurable = "getConfigurable" MethodIComponentStoreGetPoolClientManager = "getPoolClientManager" MethodIComponentStoreGetStructDescriptors = "getStructDescriptors" MethodIComponentStoreListComponents = "listComponents" MethodIComponentStoreCreateInputSurface = "createInputSurface" )
const ( TransactionIConfigurableConfig = binder.FirstCallTransaction + 0 TransactionIConfigurableGetId = binder.FirstCallTransaction + 1 TransactionIConfigurableGetName = binder.FirstCallTransaction + 2 TransactionIConfigurableQuery = binder.FirstCallTransaction + 3 TransactionIConfigurableQuerySupportedParams = binder.FirstCallTransaction + 4 TransactionIConfigurableQuerySupportedValues = binder.FirstCallTransaction + 5 )
const ( MethodIConfigurableConfig = "config" MethodIConfigurableGetId = "getId" MethodIConfigurableGetName = "getName" MethodIConfigurableQuery = "query" MethodIConfigurableQuerySupportedParams = "querySupportedParams" MethodIConfigurableQuerySupportedValues = "querySupportedValues" )
const ( TransactionIGraphicBufferAllocatorAllocate = binder.FirstCallTransaction + 0 TransactionIGraphicBufferAllocatorDeallocate = binder.FirstCallTransaction + 1 TransactionIGraphicBufferAllocatorGetWaitableFd = binder.FirstCallTransaction + 2 )
const ( MethodIGraphicBufferAllocatorAllocate = "allocate" MethodIGraphicBufferAllocatorDeallocate = "deallocate" MethodIGraphicBufferAllocatorGetWaitableFd = "getWaitableFd" )
const ( TransactionIInputSurfaceGetSurface = binder.FirstCallTransaction + 0 TransactionIInputSurfaceGetConfigurable = binder.FirstCallTransaction + 1 TransactionIInputSurfaceConnect = binder.FirstCallTransaction + 2 )
const ( MethodIInputSurfaceGetSurface = "getSurface" MethodIInputSurfaceGetConfigurable = "getConfigurable" MethodIInputSurfaceConnect = "connect" )
const ( TransactionIInputSurfaceConnectionDisconnect = binder.FirstCallTransaction + 0 TransactionIInputSurfaceConnectionSignalEndOfStream = binder.FirstCallTransaction + 1 )
const ( MethodIInputSurfaceConnectionDisconnect = "disconnect" MethodIInputSurfaceConnectionSignalEndOfStream = "signalEndOfStream" )
const ( TransactionIPooledGraphicBufferAllocatorAllocate = binder.FirstCallTransaction + 0 TransactionIPooledGraphicBufferAllocatorDeallocate = binder.FirstCallTransaction + 1 )
const ( MethodIPooledGraphicBufferAllocatorAllocate = "allocate" MethodIPooledGraphicBufferAllocatorDeallocate = "deallocate" )
const ( ParamDescriptorAttributeRequired int32 = (1 << 0) ParamDescriptorAttributePersistent int32 = (1 << 1) ParamDescriptorAttributeStrict int32 = (1 << 2) ParamDescriptorAttributeReadOnly int32 = (1 << 3) ParamDescriptorAttributeHidden int32 = (1 << 4) ParamDescriptorAttributeInternal int32 = (1 << 5) ParamDescriptorAttributeConst int32 = (1 << 6) )
const ( StatusOK int32 = 0 StatusBadValue int32 = -22 StatusBadIndex int32 = -75 StatusCannotDo int32 = -2147483646 StatusDUPLICATE int32 = -17 StatusNotFound int32 = -2 StatusBadState int32 = -38 StatusBLOCKING int32 = -9930 StatusNoMemory int32 = -12 StatusREFUSED int32 = -1 StatusTimedOut int32 = -110 StatusOMITTED int32 = -74 StatusCORRUPTED int32 = -2147483648 StatusNoInit int32 = -19 )
const DescriptorIComponent = "android.hardware.media.c2.IComponent"
const DescriptorIComponentInterface = "android.hardware.media.c2.IComponentInterface"
const DescriptorIComponentListener = "android.hardware.media.c2.IComponentListener"
const DescriptorIComponentStore = "android.hardware.media.c2.IComponentStore"
const DescriptorIConfigurable = "android.hardware.media.c2.IConfigurable"
const DescriptorIGraphicBufferAllocator = "android.hardware.media.c2.IGraphicBufferAllocator"
const DescriptorIInputSink = "android.hardware.media.c2.IInputSink"
const DescriptorIInputSurface = "android.hardware.media.c2.IInputSurface"
const DescriptorIInputSurfaceConnection = "android.hardware.media.c2.IInputSurfaceConnection"
const DescriptorIPooledGraphicBufferAllocator = "android.hardware.media.c2.IPooledGraphicBufferAllocator"
const (
MethodIComponentInterfaceGetConfigurable = "getConfigurable"
)
const (
MethodIInputSinkQueue = "queue"
)
const (
TransactionIComponentInterfaceGetConfigurable = binder.FirstCallTransaction + 0
)
const (
TransactionIInputSinkQueue = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BaseBlock ¶
type BaseBlock struct {
Tag int32
NativeBlock common.NativeHandle
HwbBlock graphicsCommon.HardwareBuffer
PooledBlock bufferpool2.BufferStatusMessage
}
func (*BaseBlock) GetHwbBlock ¶
func (u *BaseBlock) GetHwbBlock() (graphicsCommon.HardwareBuffer, bool)
func (*BaseBlock) GetNativeBlock ¶
func (u *BaseBlock) GetNativeBlock() (common.NativeHandle, bool)
func (*BaseBlock) GetPooledBlock ¶
func (u *BaseBlock) GetPooledBlock() (bufferpool2.BufferStatusMessage, bool)
func (*BaseBlock) SetHwbBlock ¶
func (u *BaseBlock) SetHwbBlock( v graphicsCommon.HardwareBuffer, )
func (*BaseBlock) SetNativeBlock ¶
func (u *BaseBlock) SetNativeBlock( v common.NativeHandle, )
func (*BaseBlock) SetPooledBlock ¶
func (u *BaseBlock) SetPooledBlock( v bufferpool2.BufferStatusMessage, )
type ComponentInterfaceProxy ¶
func NewComponentInterfaceProxy ¶
func NewComponentInterfaceProxy( remote binder.IBinder, ) *ComponentInterfaceProxy
func (*ComponentInterfaceProxy) AsBinder ¶
func (p *ComponentInterfaceProxy) AsBinder() binder.IBinder
func (*ComponentInterfaceProxy) GetConfigurable ¶
func (p *ComponentInterfaceProxy) GetConfigurable( ctx context.Context, ) (IConfigurable, error)
type ComponentInterfaceStub ¶
type ComponentInterfaceStub struct {
Impl IComponentInterface
Transport binder.VersionAwareTransport
}
ComponentInterfaceStub dispatches incoming binder transactions to a typed IComponentInterface implementation.
func (*ComponentInterfaceStub) Descriptor ¶
func (s *ComponentInterfaceStub) Descriptor() string
func (*ComponentInterfaceStub) OnTransaction ¶
func (s *ComponentInterfaceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ComponentListenerProxy ¶
func NewComponentListenerProxy ¶
func NewComponentListenerProxy( remote binder.IBinder, ) *ComponentListenerProxy
func (*ComponentListenerProxy) AsBinder ¶
func (p *ComponentListenerProxy) AsBinder() binder.IBinder
func (*ComponentListenerProxy) OnFramesRendered ¶
func (p *ComponentListenerProxy) OnFramesRendered( ctx context.Context, renderedFrames []IComponentListenerRenderedFrame, ) error
func (*ComponentListenerProxy) OnInputBuffersReleased ¶
func (p *ComponentListenerProxy) OnInputBuffersReleased( ctx context.Context, inputBuffers []IComponentListenerInputBuffer, ) error
func (*ComponentListenerProxy) OnTripped ¶
func (p *ComponentListenerProxy) OnTripped( ctx context.Context, settingResults []SettingResult, ) error
func (*ComponentListenerProxy) OnWorkDone ¶
func (p *ComponentListenerProxy) OnWorkDone( ctx context.Context, workBundle WorkBundle, ) error
type ComponentListenerStub ¶
type ComponentListenerStub struct {
Impl IComponentListener
Transport binder.VersionAwareTransport
}
ComponentListenerStub dispatches incoming binder transactions to a typed IComponentListener implementation.
func (*ComponentListenerStub) Descriptor ¶
func (s *ComponentListenerStub) Descriptor() string
func (*ComponentListenerStub) OnTransaction ¶
func (s *ComponentListenerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ComponentProxy ¶
func NewComponentProxy ¶
func NewComponentProxy( remote binder.IBinder, ) *ComponentProxy
func (*ComponentProxy) AsBinder ¶
func (p *ComponentProxy) AsBinder() binder.IBinder
func (*ComponentProxy) AsInputSink ¶
func (p *ComponentProxy) AsInputSink( ctx context.Context, ) (IInputSink, error)
func (*ComponentProxy) ConfigureVideoTunnel ¶
func (p *ComponentProxy) ConfigureVideoTunnel( ctx context.Context, avSyncHwId int32, ) (common.NativeHandle, error)
func (*ComponentProxy) ConnectToInputSurface ¶
func (p *ComponentProxy) ConnectToInputSurface( ctx context.Context, inputSurface IInputSurface, ) (IInputSurfaceConnection, error)
func (*ComponentProxy) CreateBlockPool ¶
func (p *ComponentProxy) CreateBlockPool( ctx context.Context, allocator IComponentBlockPoolAllocator, ) (IComponentBlockPool, error)
func (*ComponentProxy) DestroyBlockPool ¶
func (p *ComponentProxy) DestroyBlockPool( ctx context.Context, blockPoolId int64, ) error
func (*ComponentProxy) Drain ¶
func (p *ComponentProxy) Drain( ctx context.Context, withEos bool, ) error
func (*ComponentProxy) Flush ¶
func (p *ComponentProxy) Flush( ctx context.Context, ) (WorkBundle, error)
func (*ComponentProxy) GetInterface ¶
func (p *ComponentProxy) GetInterface( ctx context.Context, ) (IComponentInterface, error)
func (*ComponentProxy) Queue ¶
func (p *ComponentProxy) Queue( ctx context.Context, workBundle WorkBundle, ) error
type ComponentStoreProxy ¶
func NewComponentStoreProxy ¶
func NewComponentStoreProxy( remote binder.IBinder, ) *ComponentStoreProxy
func (*ComponentStoreProxy) AsBinder ¶
func (p *ComponentStoreProxy) AsBinder() binder.IBinder
func (*ComponentStoreProxy) CopyBuffer ¶
func (*ComponentStoreProxy) CreateComponent ¶
func (p *ComponentStoreProxy) CreateComponent( ctx context.Context, name string, listener IComponentListener, pool bufferpool2.IClientManager, ) (IComponent, error)
func (*ComponentStoreProxy) CreateInputSurface ¶
func (p *ComponentStoreProxy) CreateInputSurface( ctx context.Context, ) (IInputSurface, error)
func (*ComponentStoreProxy) CreateInterface ¶
func (p *ComponentStoreProxy) CreateInterface( ctx context.Context, name string, ) (IComponentInterface, error)
func (*ComponentStoreProxy) GetConfigurable ¶
func (p *ComponentStoreProxy) GetConfigurable( ctx context.Context, ) (IConfigurable, error)
func (*ComponentStoreProxy) GetPoolClientManager ¶
func (p *ComponentStoreProxy) GetPoolClientManager( ctx context.Context, ) (bufferpool2.IClientManager, error)
func (*ComponentStoreProxy) GetStructDescriptors ¶
func (p *ComponentStoreProxy) GetStructDescriptors( ctx context.Context, indices []int32, ) ([]StructDescriptor, error)
func (*ComponentStoreProxy) ListComponents ¶
func (p *ComponentStoreProxy) ListComponents( ctx context.Context, ) ([]IComponentStoreComponentTraits, error)
type ComponentStoreStub ¶
type ComponentStoreStub struct {
Impl IComponentStore
Transport binder.VersionAwareTransport
}
ComponentStoreStub dispatches incoming binder transactions to a typed IComponentStore implementation.
func (*ComponentStoreStub) Descriptor ¶
func (s *ComponentStoreStub) Descriptor() string
func (*ComponentStoreStub) OnTransaction ¶
func (s *ComponentStoreStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ComponentStub ¶
type ComponentStub struct {
Impl IComponent
Transport binder.VersionAwareTransport
}
ComponentStub dispatches incoming binder transactions to a typed IComponent implementation.
func (*ComponentStub) Descriptor ¶
func (s *ComponentStub) Descriptor() string
func (*ComponentStub) OnTransaction ¶
func (s *ComponentStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ConfigurableProxy ¶
func NewConfigurableProxy ¶
func NewConfigurableProxy( remote binder.IBinder, ) *ConfigurableProxy
func (*ConfigurableProxy) AsBinder ¶
func (p *ConfigurableProxy) AsBinder() binder.IBinder
func (*ConfigurableProxy) Config ¶
func (p *ConfigurableProxy) Config( ctx context.Context, inParams Params, mayBlock bool, ) (IConfigurableConfigResult, error)
func (*ConfigurableProxy) GetId ¶
func (p *ConfigurableProxy) GetId( ctx context.Context, ) (int32, error)
func (*ConfigurableProxy) GetName ¶
func (p *ConfigurableProxy) GetName( ctx context.Context, ) (string, error)
func (*ConfigurableProxy) Query ¶
func (p *ConfigurableProxy) Query( ctx context.Context, indices []int32, mayBlock bool, ) (IConfigurableQueryResult, error)
func (*ConfigurableProxy) QuerySupportedParams ¶
func (p *ConfigurableProxy) QuerySupportedParams( ctx context.Context, start int32, count int32, ) ([]ParamDescriptor, error)
func (*ConfigurableProxy) QuerySupportedValues ¶
func (p *ConfigurableProxy) QuerySupportedValues( ctx context.Context, inFields []FieldSupportedValuesQuery, mayBlock bool, ) (IConfigurableQuerySupportedValuesResult, error)
type ConfigurableStub ¶
type ConfigurableStub struct {
Impl IConfigurable
Transport binder.VersionAwareTransport
}
ConfigurableStub dispatches incoming binder transactions to a typed IConfigurable implementation.
func (*ConfigurableStub) Descriptor ¶
func (s *ConfigurableStub) Descriptor() string
func (*ConfigurableStub) OnTransaction ¶
func (s *ConfigurableStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type FieldDescriptor ¶
type FieldDescriptor struct {
FieldId FieldId
Type FieldDescriptorType
StructIndex int32
Extent int32
Name string
NamedValues []FieldDescriptorNamedValue
}
func (*FieldDescriptor) MarshalParcel ¶
func (s *FieldDescriptor) MarshalParcel( p *parcel.Parcel, ) error
func (*FieldDescriptor) UnmarshalParcel ¶
func (s *FieldDescriptor) UnmarshalParcel( p *parcel.Parcel, ) error
type FieldDescriptorNamedValue ¶
func (*FieldDescriptorNamedValue) MarshalParcel ¶
func (s *FieldDescriptorNamedValue) MarshalParcel( p *parcel.Parcel, ) error
func (*FieldDescriptorNamedValue) UnmarshalParcel ¶
func (s *FieldDescriptorNamedValue) UnmarshalParcel( p *parcel.Parcel, ) error
type FieldDescriptorType ¶
type FieldDescriptorType int32
const ( FieldDescriptorTypeNoInit FieldDescriptorType = 0 FieldDescriptorTypeINT32 FieldDescriptorType = 1 FieldDescriptorTypeUINT32 FieldDescriptorType = 2 FieldDescriptorTypeCNTR32 FieldDescriptorType = 3 FieldDescriptorTypeINT64 FieldDescriptorType = 4 FieldDescriptorTypeUINT64 FieldDescriptorType = 5 FieldDescriptorTypeCNTR64 FieldDescriptorType = 6 FieldDescriptorTypeFLOAT FieldDescriptorType = 7 FieldDescriptorTypeSTRING FieldDescriptorType = 256 FieldDescriptorTypeBLOB FieldDescriptorType = 257 FieldDescriptorTypeSTRUCT FieldDescriptorType = 131072 )
type FieldSupportedValues ¶
type FieldSupportedValues struct {
Tag int32
Empty bool
Range ValueRange
Values []int64
Flags []int64
}
func (*FieldSupportedValues) GetEmpty ¶
func (u *FieldSupportedValues) GetEmpty() (bool, bool)
func (*FieldSupportedValues) GetFlags ¶
func (u *FieldSupportedValues) GetFlags() ([]int64, bool)
func (*FieldSupportedValues) GetRange ¶
func (u *FieldSupportedValues) GetRange() (ValueRange, bool)
func (*FieldSupportedValues) GetValues ¶
func (u *FieldSupportedValues) GetValues() ([]int64, bool)
func (*FieldSupportedValues) MarshalParcel ¶
func (u *FieldSupportedValues) MarshalParcel( p *parcel.Parcel, ) error
func (*FieldSupportedValues) SetEmpty ¶
func (u *FieldSupportedValues) SetEmpty( v bool, )
func (*FieldSupportedValues) SetFlags ¶
func (u *FieldSupportedValues) SetFlags( v []int64, )
func (*FieldSupportedValues) SetRange ¶
func (u *FieldSupportedValues) SetRange( v ValueRange, )
func (*FieldSupportedValues) SetValues ¶
func (u *FieldSupportedValues) SetValues( v []int64, )
func (*FieldSupportedValues) UnmarshalParcel ¶
func (u *FieldSupportedValues) UnmarshalParcel( p *parcel.Parcel, ) error
type FieldSupportedValuesQuery ¶
type FieldSupportedValuesQuery struct {
Field ParamField
Type FieldSupportedValuesQueryType
}
func (*FieldSupportedValuesQuery) MarshalParcel ¶
func (s *FieldSupportedValuesQuery) MarshalParcel( p *parcel.Parcel, ) error
func (*FieldSupportedValuesQuery) UnmarshalParcel ¶
func (s *FieldSupportedValuesQuery) UnmarshalParcel( p *parcel.Parcel, ) error
type FieldSupportedValuesQueryResult ¶
type FieldSupportedValuesQueryResult struct {
Status Status
Values FieldSupportedValues
}
func (*FieldSupportedValuesQueryResult) MarshalParcel ¶
func (s *FieldSupportedValuesQueryResult) MarshalParcel( p *parcel.Parcel, ) error
func (*FieldSupportedValuesQueryResult) UnmarshalParcel ¶
func (s *FieldSupportedValuesQueryResult) UnmarshalParcel( p *parcel.Parcel, ) error
type FieldSupportedValuesQueryType ¶
type FieldSupportedValuesQueryType int32
const ( FieldSupportedValuesQueryTypePOSSIBLE FieldSupportedValuesQueryType = 0 FieldSupportedValuesQueryTypeCURRENT FieldSupportedValuesQueryType = 1 )
type FrameData ¶
type FrameData struct {
Flags int32
Ordinal WorkOrdinal
Buffers []Buffer
ConfigUpdate Params
InfoBuffers []InfoBuffer
}
type GraphicBufferAllocatorProxy ¶
func NewGraphicBufferAllocatorProxy ¶
func NewGraphicBufferAllocatorProxy( remote binder.IBinder, ) *GraphicBufferAllocatorProxy
func (*GraphicBufferAllocatorProxy) Allocate ¶
func (p *GraphicBufferAllocatorProxy) Allocate( ctx context.Context, desc IGraphicBufferAllocatorDescription, ) (IGraphicBufferAllocatorAllocation, error)
func (*GraphicBufferAllocatorProxy) AsBinder ¶
func (p *GraphicBufferAllocatorProxy) AsBinder() binder.IBinder
func (*GraphicBufferAllocatorProxy) Deallocate ¶
func (*GraphicBufferAllocatorProxy) GetWaitableFd ¶
func (p *GraphicBufferAllocatorProxy) GetWaitableFd( ctx context.Context, ) (int32, error)
type GraphicBufferAllocatorStub ¶
type GraphicBufferAllocatorStub struct {
Impl IGraphicBufferAllocator
Transport binder.VersionAwareTransport
}
GraphicBufferAllocatorStub dispatches incoming binder transactions to a typed IGraphicBufferAllocator implementation.
func (*GraphicBufferAllocatorStub) Descriptor ¶
func (s *GraphicBufferAllocatorStub) Descriptor() string
func (*GraphicBufferAllocatorStub) OnTransaction ¶
func (s *GraphicBufferAllocatorStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type IComponent ¶
type IComponent interface {
AsBinder() binder.IBinder
ConfigureVideoTunnel(ctx context.Context, avSyncHwId int32) (common.NativeHandle, error)
CreateBlockPool(ctx context.Context, allocator IComponentBlockPoolAllocator) (IComponentBlockPool, error)
DestroyBlockPool(ctx context.Context, blockPoolId int64) error
Drain(ctx context.Context, withEos bool) error
Flush(ctx context.Context) (WorkBundle, error)
GetInterface(ctx context.Context) (IComponentInterface, error)
Queue(ctx context.Context, workBundle WorkBundle) error
Release(ctx context.Context) error
Reset(ctx context.Context) error
Start(ctx context.Context) error
Stop(ctx context.Context) error
ConnectToInputSurface(ctx context.Context, inputSurface IInputSurface) (IInputSurfaceConnection, error)
AsInputSink(ctx context.Context) (IInputSink, error)
}
func NewComponentStub ¶
func NewComponentStub( impl IComponentServer, ) IComponent
NewComponentStub creates a server-side IComponent wrapping the given server implementation. The returned value satisfies IComponent and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IComponentBlockPool ¶
type IComponentBlockPool struct {
BlockPoolId int64
Configurable IConfigurable
}
func (*IComponentBlockPool) MarshalParcel ¶
func (s *IComponentBlockPool) MarshalParcel( p *parcel.Parcel, ) error
func (*IComponentBlockPool) UnmarshalParcel ¶
func (s *IComponentBlockPool) UnmarshalParcel( p *parcel.Parcel, ) error
type IComponentBlockPoolAllocator ¶
type IComponentBlockPoolAllocator struct {
AllocatorId int32
GbAllocator *IComponentGbAllocator
PooledGbAllocator *IComponentPooledGbAllocator
}
func (*IComponentBlockPoolAllocator) MarshalParcel ¶
func (s *IComponentBlockPoolAllocator) MarshalParcel( p *parcel.Parcel, ) error
func (*IComponentBlockPoolAllocator) UnmarshalParcel ¶
func (s *IComponentBlockPoolAllocator) UnmarshalParcel( p *parcel.Parcel, ) error
type IComponentGbAllocator ¶
type IComponentGbAllocator struct {
WaitableFd int32
Igba IGraphicBufferAllocator
}
func (*IComponentGbAllocator) MarshalParcel ¶
func (s *IComponentGbAllocator) MarshalParcel( p *parcel.Parcel, ) error
func (*IComponentGbAllocator) UnmarshalParcel ¶
func (s *IComponentGbAllocator) UnmarshalParcel( p *parcel.Parcel, ) error
type IComponentInterface ¶
type IComponentInterface interface {
AsBinder() binder.IBinder
GetConfigurable(ctx context.Context) (IConfigurable, error)
}
func NewComponentInterfaceStub ¶
func NewComponentInterfaceStub( impl IComponentInterfaceServer, ) IComponentInterface
NewComponentInterfaceStub creates a server-side IComponentInterface wrapping the given server implementation. The returned value satisfies IComponentInterface and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IComponentInterfaceServer ¶
type IComponentInterfaceServer interface {
GetConfigurable(ctx context.Context) (IConfigurable, error)
}
IComponentInterfaceServer is the server-side interface that user implementations provide to NewComponentInterfaceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IComponentListener ¶
type IComponentListener interface {
AsBinder() binder.IBinder
OnError(ctx context.Context, status Status, errorCode int32) error
OnFramesRendered(ctx context.Context, renderedFrames []IComponentListenerRenderedFrame) error
OnInputBuffersReleased(ctx context.Context, inputBuffers []IComponentListenerInputBuffer) error
OnTripped(ctx context.Context, settingResults []SettingResult) error
OnWorkDone(ctx context.Context, workBundle WorkBundle) error
}
func NewComponentListenerStub ¶
func NewComponentListenerStub( impl IComponentListenerServer, ) IComponentListener
NewComponentListenerStub creates a server-side IComponentListener wrapping the given server implementation. The returned value satisfies IComponentListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IComponentListenerInputBuffer ¶
func (*IComponentListenerInputBuffer) MarshalParcel ¶
func (s *IComponentListenerInputBuffer) MarshalParcel( p *parcel.Parcel, ) error
func (*IComponentListenerInputBuffer) UnmarshalParcel ¶
func (s *IComponentListenerInputBuffer) UnmarshalParcel( p *parcel.Parcel, ) error
type IComponentListenerRenderedFrame ¶
func (*IComponentListenerRenderedFrame) MarshalParcel ¶
func (s *IComponentListenerRenderedFrame) MarshalParcel( p *parcel.Parcel, ) error
func (*IComponentListenerRenderedFrame) UnmarshalParcel ¶
func (s *IComponentListenerRenderedFrame) UnmarshalParcel( p *parcel.Parcel, ) error
type IComponentListenerServer ¶
type IComponentListenerServer interface {
OnError(ctx context.Context, status Status, errorCode int32) error
OnFramesRendered(ctx context.Context, renderedFrames []IComponentListenerRenderedFrame) error
OnInputBuffersReleased(ctx context.Context, inputBuffers []IComponentListenerInputBuffer) error
OnTripped(ctx context.Context, settingResults []SettingResult) error
OnWorkDone(ctx context.Context, workBundle WorkBundle) error
}
IComponentListenerServer is the server-side interface that user implementations provide to NewComponentListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IComponentPooledGbAllocator ¶
type IComponentPooledGbAllocator struct {
WaitableFd int32
ReceiverId int64
Ipgba IPooledGraphicBufferAllocator
}
func (*IComponentPooledGbAllocator) MarshalParcel ¶
func (s *IComponentPooledGbAllocator) MarshalParcel( p *parcel.Parcel, ) error
func (*IComponentPooledGbAllocator) UnmarshalParcel ¶
func (s *IComponentPooledGbAllocator) UnmarshalParcel( p *parcel.Parcel, ) error
type IComponentServer ¶
type IComponentServer interface {
ConfigureVideoTunnel(ctx context.Context, avSyncHwId int32) (common.NativeHandle, error)
CreateBlockPool(ctx context.Context, allocator IComponentBlockPoolAllocator) (IComponentBlockPool, error)
DestroyBlockPool(ctx context.Context, blockPoolId int64) error
Drain(ctx context.Context, withEos bool) error
Flush(ctx context.Context) (WorkBundle, error)
GetInterface(ctx context.Context) (IComponentInterface, error)
Queue(ctx context.Context, workBundle WorkBundle) error
Release(ctx context.Context) error
Reset(ctx context.Context) error
Start(ctx context.Context) error
Stop(ctx context.Context) error
ConnectToInputSurface(ctx context.Context, inputSurface IInputSurface) (IInputSurfaceConnection, error)
AsInputSink(ctx context.Context) (IInputSink, error)
}
IComponentServer is the server-side interface that user implementations provide to NewComponentStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IComponentStore ¶
type IComponentStore interface {
AsBinder() binder.IBinder
CopyBuffer(ctx context.Context, src Buffer, dst Buffer) error
CreateComponent(ctx context.Context, name string, listener IComponentListener, pool bufferpool2.IClientManager) (IComponent, error)
CreateInterface(ctx context.Context, name string) (IComponentInterface, error)
GetConfigurable(ctx context.Context) (IConfigurable, error)
GetPoolClientManager(ctx context.Context) (bufferpool2.IClientManager, error)
GetStructDescriptors(ctx context.Context, indices []int32) ([]StructDescriptor, error)
ListComponents(ctx context.Context) ([]IComponentStoreComponentTraits, error)
CreateInputSurface(ctx context.Context) (IInputSurface, error)
}
func NewComponentStoreStub ¶
func NewComponentStoreStub( impl IComponentStoreServer, ) IComponentStore
NewComponentStoreStub creates a server-side IComponentStore wrapping the given server implementation. The returned value satisfies IComponentStore and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IComponentStoreComponentTraits ¶
type IComponentStoreComponentTraits struct {
Name string
Domain IComponentStoreComponentTraitsDomain
Kind IComponentStoreComponentTraitsKind
Rank int32
MediaType string
Aliases []string
}
func (*IComponentStoreComponentTraits) MarshalParcel ¶
func (s *IComponentStoreComponentTraits) MarshalParcel( p *parcel.Parcel, ) error
func (*IComponentStoreComponentTraits) UnmarshalParcel ¶
func (s *IComponentStoreComponentTraits) UnmarshalParcel( p *parcel.Parcel, ) error
type IComponentStoreComponentTraitsDomain ¶
type IComponentStoreComponentTraitsDomain int32
const ( IComponentStoreComponentTraitsDomainOTHER IComponentStoreComponentTraitsDomain = 0 IComponentStoreComponentTraitsDomainVIDEO IComponentStoreComponentTraitsDomain = 1 IComponentStoreComponentTraitsDomainAUDIO IComponentStoreComponentTraitsDomain = 2 IComponentStoreComponentTraitsDomainIMAGE IComponentStoreComponentTraitsDomain = 3 )
type IComponentStoreComponentTraitsKind ¶
type IComponentStoreComponentTraitsKind int32
const ( IComponentStoreComponentTraitsKindOTHER IComponentStoreComponentTraitsKind = 0 IComponentStoreComponentTraitsKindDECODER IComponentStoreComponentTraitsKind = 1 IComponentStoreComponentTraitsKindENCODER IComponentStoreComponentTraitsKind = 2 )
type IComponentStoreServer ¶
type IComponentStoreServer interface {
CopyBuffer(ctx context.Context, src Buffer, dst Buffer) error
CreateComponent(ctx context.Context, name string, listener IComponentListener, pool bufferpool2.IClientManager) (IComponent, error)
CreateInterface(ctx context.Context, name string) (IComponentInterface, error)
GetConfigurable(ctx context.Context) (IConfigurable, error)
GetPoolClientManager(ctx context.Context) (bufferpool2.IClientManager, error)
GetStructDescriptors(ctx context.Context, indices []int32) ([]StructDescriptor, error)
ListComponents(ctx context.Context) ([]IComponentStoreComponentTraits, error)
CreateInputSurface(ctx context.Context) (IInputSurface, error)
}
IComponentStoreServer is the server-side interface that user implementations provide to NewComponentStoreStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IConfigurable ¶
type IConfigurable interface {
AsBinder() binder.IBinder
Config(ctx context.Context, inParams Params, mayBlock bool) (IConfigurableConfigResult, error)
GetId(ctx context.Context) (int32, error)
GetName(ctx context.Context) (string, error)
Query(ctx context.Context, indices []int32, mayBlock bool) (IConfigurableQueryResult, error)
QuerySupportedParams(ctx context.Context, start int32, count int32) ([]ParamDescriptor, error)
QuerySupportedValues(ctx context.Context, inFields []FieldSupportedValuesQuery, mayBlock bool) (IConfigurableQuerySupportedValuesResult, error)
}
func NewConfigurableStub ¶
func NewConfigurableStub( impl IConfigurableServer, ) IConfigurable
NewConfigurableStub creates a server-side IConfigurable wrapping the given server implementation. The returned value satisfies IConfigurable and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IConfigurableConfigResult ¶
type IConfigurableConfigResult struct {
Params Params
Failures []SettingResult
Status Status
}
func (*IConfigurableConfigResult) MarshalParcel ¶
func (s *IConfigurableConfigResult) MarshalParcel( p *parcel.Parcel, ) error
func (*IConfigurableConfigResult) UnmarshalParcel ¶
func (s *IConfigurableConfigResult) UnmarshalParcel( p *parcel.Parcel, ) error
type IConfigurableQueryResult ¶
func (*IConfigurableQueryResult) MarshalParcel ¶
func (s *IConfigurableQueryResult) MarshalParcel( p *parcel.Parcel, ) error
func (*IConfigurableQueryResult) UnmarshalParcel ¶
func (s *IConfigurableQueryResult) UnmarshalParcel( p *parcel.Parcel, ) error
type IConfigurableQuerySupportedValuesResult ¶
type IConfigurableQuerySupportedValuesResult struct {
Values []FieldSupportedValuesQueryResult
Status Status
}
func (*IConfigurableQuerySupportedValuesResult) MarshalParcel ¶
func (s *IConfigurableQuerySupportedValuesResult) MarshalParcel( p *parcel.Parcel, ) error
func (*IConfigurableQuerySupportedValuesResult) UnmarshalParcel ¶
func (s *IConfigurableQuerySupportedValuesResult) UnmarshalParcel( p *parcel.Parcel, ) error
type IConfigurableServer ¶
type IConfigurableServer interface {
Config(ctx context.Context, inParams Params, mayBlock bool) (IConfigurableConfigResult, error)
GetId(ctx context.Context) (int32, error)
GetName(ctx context.Context) (string, error)
Query(ctx context.Context, indices []int32, mayBlock bool) (IConfigurableQueryResult, error)
QuerySupportedParams(ctx context.Context, start int32, count int32) ([]ParamDescriptor, error)
QuerySupportedValues(ctx context.Context, inFields []FieldSupportedValuesQuery, mayBlock bool) (IConfigurableQuerySupportedValuesResult, error)
}
IConfigurableServer is the server-side interface that user implementations provide to NewConfigurableStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IGraphicBufferAllocator ¶
type IGraphicBufferAllocator interface {
AsBinder() binder.IBinder
Allocate(ctx context.Context, desc IGraphicBufferAllocatorDescription) (IGraphicBufferAllocatorAllocation, error)
Deallocate(ctx context.Context, id int64) (bool, error)
GetWaitableFd(ctx context.Context) (int32, error)
}
func NewGraphicBufferAllocatorStub ¶
func NewGraphicBufferAllocatorStub( impl IGraphicBufferAllocatorServer, ) IGraphicBufferAllocator
NewGraphicBufferAllocatorStub creates a server-side IGraphicBufferAllocator wrapping the given server implementation. The returned value satisfies IGraphicBufferAllocator and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IGraphicBufferAllocatorAllocation ¶
type IGraphicBufferAllocatorAllocation struct {
Buffer common.HardwareBuffer
Fence int32
}
func (*IGraphicBufferAllocatorAllocation) MarshalParcel ¶
func (s *IGraphicBufferAllocatorAllocation) MarshalParcel( p *parcel.Parcel, ) error
func (*IGraphicBufferAllocatorAllocation) UnmarshalParcel ¶
func (s *IGraphicBufferAllocatorAllocation) UnmarshalParcel( p *parcel.Parcel, ) error
type IGraphicBufferAllocatorDescription ¶
type IGraphicBufferAllocatorDescription struct {
Width int32
Height int32
Format int32
Usage int64
}
func (*IGraphicBufferAllocatorDescription) MarshalParcel ¶
func (s *IGraphicBufferAllocatorDescription) MarshalParcel( p *parcel.Parcel, ) error
func (*IGraphicBufferAllocatorDescription) UnmarshalParcel ¶
func (s *IGraphicBufferAllocatorDescription) UnmarshalParcel( p *parcel.Parcel, ) error
type IGraphicBufferAllocatorServer ¶
type IGraphicBufferAllocatorServer interface {
Allocate(ctx context.Context, desc IGraphicBufferAllocatorDescription) (IGraphicBufferAllocatorAllocation, error)
Deallocate(ctx context.Context, id int64) (bool, error)
GetWaitableFd(ctx context.Context) (int32, error)
}
IGraphicBufferAllocatorServer is the server-side interface that user implementations provide to NewGraphicBufferAllocatorStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IInputSink ¶
type IInputSink interface {
AsBinder() binder.IBinder
Queue(ctx context.Context, workBundle WorkBundle) error
}
func NewInputSinkStub ¶
func NewInputSinkStub( impl IInputSinkServer, ) IInputSink
NewInputSinkStub creates a server-side IInputSink wrapping the given server implementation. The returned value satisfies IInputSink and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IInputSinkServer ¶
type IInputSinkServer interface {
Queue(ctx context.Context, workBundle WorkBundle) error
}
IInputSinkServer is the server-side interface that user implementations provide to NewInputSinkStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IInputSurface ¶
type IInputSurface interface {
AsBinder() binder.IBinder
GetSurface(ctx context.Context) (view.Surface, error)
GetConfigurable(ctx context.Context) (IConfigurable, error)
Connect(ctx context.Context, sink IInputSink) (IInputSurfaceConnection, error)
}
func NewInputSurfaceStub ¶
func NewInputSurfaceStub( impl IInputSurfaceServer, ) IInputSurface
NewInputSurfaceStub creates a server-side IInputSurface wrapping the given server implementation. The returned value satisfies IInputSurface and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IInputSurfaceConnection ¶
type IInputSurfaceConnection interface {
AsBinder() binder.IBinder
Disconnect(ctx context.Context) error
SignalEndOfStream(ctx context.Context) error
}
func NewInputSurfaceConnectionStub ¶
func NewInputSurfaceConnectionStub( impl IInputSurfaceConnectionServer, ) IInputSurfaceConnection
NewInputSurfaceConnectionStub creates a server-side IInputSurfaceConnection wrapping the given server implementation. The returned value satisfies IInputSurfaceConnection and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IInputSurfaceConnectionServer ¶
type IInputSurfaceConnectionServer interface {
Disconnect(ctx context.Context) error
SignalEndOfStream(ctx context.Context) error
}
IInputSurfaceConnectionServer is the server-side interface that user implementations provide to NewInputSurfaceConnectionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IInputSurfaceServer ¶
type IInputSurfaceServer interface {
GetSurface(ctx context.Context) (view.Surface, error)
GetConfigurable(ctx context.Context) (IConfigurable, error)
Connect(ctx context.Context, sink IInputSink) (IInputSurfaceConnection, error)
}
IInputSurfaceServer is the server-side interface that user implementations provide to NewInputSurfaceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IPooledGraphicBufferAllocator ¶
type IPooledGraphicBufferAllocator interface {
AsBinder() binder.IBinder
Allocate(ctx context.Context, desc IPooledGraphicBufferAllocatorDescription) (IPooledGraphicBufferAllocatorAllocation, error)
Deallocate(ctx context.Context, id int32) (bool, error)
}
func NewPooledGraphicBufferAllocatorStub ¶
func NewPooledGraphicBufferAllocatorStub( impl IPooledGraphicBufferAllocatorServer, ) IPooledGraphicBufferAllocator
NewPooledGraphicBufferAllocatorStub creates a server-side IPooledGraphicBufferAllocator wrapping the given server implementation. The returned value satisfies IPooledGraphicBufferAllocator and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IPooledGraphicBufferAllocatorAllocation ¶
func (*IPooledGraphicBufferAllocatorAllocation) MarshalParcel ¶
func (s *IPooledGraphicBufferAllocatorAllocation) MarshalParcel( p *parcel.Parcel, ) error
func (*IPooledGraphicBufferAllocatorAllocation) UnmarshalParcel ¶
func (s *IPooledGraphicBufferAllocatorAllocation) UnmarshalParcel( p *parcel.Parcel, ) error
type IPooledGraphicBufferAllocatorDescription ¶
type IPooledGraphicBufferAllocatorDescription struct {
WidthPixels int32
HeightPixels int32
Format int32
Usage int64
}
func (*IPooledGraphicBufferAllocatorDescription) MarshalParcel ¶
func (s *IPooledGraphicBufferAllocatorDescription) MarshalParcel( p *parcel.Parcel, ) error
func (*IPooledGraphicBufferAllocatorDescription) UnmarshalParcel ¶
func (s *IPooledGraphicBufferAllocatorDescription) UnmarshalParcel( p *parcel.Parcel, ) error
type IPooledGraphicBufferAllocatorServer ¶
type IPooledGraphicBufferAllocatorServer interface {
Allocate(ctx context.Context, desc IPooledGraphicBufferAllocatorDescription) (IPooledGraphicBufferAllocatorAllocation, error)
Deallocate(ctx context.Context, id int32) (bool, error)
}
IPooledGraphicBufferAllocatorServer is the server-side interface that user implementations provide to NewPooledGraphicBufferAllocatorStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type InfoBuffer ¶
func (*InfoBuffer) MarshalParcel ¶
func (s *InfoBuffer) MarshalParcel( p *parcel.Parcel, ) error
func (*InfoBuffer) UnmarshalParcel ¶
func (s *InfoBuffer) UnmarshalParcel( p *parcel.Parcel, ) error
type InputSinkProxy ¶
func NewInputSinkProxy ¶
func NewInputSinkProxy( remote binder.IBinder, ) *InputSinkProxy
func (*InputSinkProxy) AsBinder ¶
func (p *InputSinkProxy) AsBinder() binder.IBinder
func (*InputSinkProxy) Queue ¶
func (p *InputSinkProxy) Queue( ctx context.Context, workBundle WorkBundle, ) error
type InputSinkStub ¶
type InputSinkStub struct {
Impl IInputSink
Transport binder.VersionAwareTransport
}
InputSinkStub dispatches incoming binder transactions to a typed IInputSink implementation.
func (*InputSinkStub) Descriptor ¶
func (s *InputSinkStub) Descriptor() string
func (*InputSinkStub) OnTransaction ¶
func (s *InputSinkStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type InputSurfaceConnectionProxy ¶
func NewInputSurfaceConnectionProxy ¶
func NewInputSurfaceConnectionProxy( remote binder.IBinder, ) *InputSurfaceConnectionProxy
func (*InputSurfaceConnectionProxy) AsBinder ¶
func (p *InputSurfaceConnectionProxy) AsBinder() binder.IBinder
func (*InputSurfaceConnectionProxy) Disconnect ¶
func (p *InputSurfaceConnectionProxy) Disconnect( ctx context.Context, ) error
func (*InputSurfaceConnectionProxy) SignalEndOfStream ¶
func (p *InputSurfaceConnectionProxy) SignalEndOfStream( ctx context.Context, ) error
type InputSurfaceConnectionStub ¶
type InputSurfaceConnectionStub struct {
Impl IInputSurfaceConnection
Transport binder.VersionAwareTransport
}
InputSurfaceConnectionStub dispatches incoming binder transactions to a typed IInputSurfaceConnection implementation.
func (*InputSurfaceConnectionStub) Descriptor ¶
func (s *InputSurfaceConnectionStub) Descriptor() string
func (*InputSurfaceConnectionStub) OnTransaction ¶
func (s *InputSurfaceConnectionStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type InputSurfaceProxy ¶
func NewInputSurfaceProxy ¶
func NewInputSurfaceProxy( remote binder.IBinder, ) *InputSurfaceProxy
func (*InputSurfaceProxy) AsBinder ¶
func (p *InputSurfaceProxy) AsBinder() binder.IBinder
func (*InputSurfaceProxy) Connect ¶
func (p *InputSurfaceProxy) Connect( ctx context.Context, sink IInputSink, ) (IInputSurfaceConnection, error)
func (*InputSurfaceProxy) GetConfigurable ¶
func (p *InputSurfaceProxy) GetConfigurable( ctx context.Context, ) (IConfigurable, error)
func (*InputSurfaceProxy) GetSurface ¶
type InputSurfaceStub ¶
type InputSurfaceStub struct {
Impl IInputSurface
Transport binder.VersionAwareTransport
}
InputSurfaceStub dispatches incoming binder transactions to a typed IInputSurface implementation.
func (*InputSurfaceStub) Descriptor ¶
func (s *InputSurfaceStub) Descriptor() string
func (*InputSurfaceStub) OnTransaction ¶
func (s *InputSurfaceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ParamDescriptor ¶
func (*ParamDescriptor) MarshalParcel ¶
func (s *ParamDescriptor) MarshalParcel( p *parcel.Parcel, ) error
func (*ParamDescriptor) UnmarshalParcel ¶
func (s *ParamDescriptor) UnmarshalParcel( p *parcel.Parcel, ) error
type ParamField ¶
func (*ParamField) MarshalParcel ¶
func (s *ParamField) MarshalParcel( p *parcel.Parcel, ) error
func (*ParamField) UnmarshalParcel ¶
func (s *ParamField) UnmarshalParcel( p *parcel.Parcel, ) error
type ParamFieldValues ¶
type ParamFieldValues struct {
ParamOrField ParamField
Values []FieldSupportedValues
}
func (*ParamFieldValues) MarshalParcel ¶
func (s *ParamFieldValues) MarshalParcel( p *parcel.Parcel, ) error
func (*ParamFieldValues) UnmarshalParcel ¶
func (s *ParamFieldValues) UnmarshalParcel( p *parcel.Parcel, ) error
type PooledGraphicBufferAllocatorProxy ¶
func NewPooledGraphicBufferAllocatorProxy ¶
func NewPooledGraphicBufferAllocatorProxy( remote binder.IBinder, ) *PooledGraphicBufferAllocatorProxy
func (*PooledGraphicBufferAllocatorProxy) Allocate ¶
func (p *PooledGraphicBufferAllocatorProxy) Allocate( ctx context.Context, desc IPooledGraphicBufferAllocatorDescription, ) (IPooledGraphicBufferAllocatorAllocation, error)
func (*PooledGraphicBufferAllocatorProxy) AsBinder ¶
func (p *PooledGraphicBufferAllocatorProxy) AsBinder() binder.IBinder
func (*PooledGraphicBufferAllocatorProxy) Deallocate ¶
type PooledGraphicBufferAllocatorStub ¶
type PooledGraphicBufferAllocatorStub struct {
Impl IPooledGraphicBufferAllocator
Transport binder.VersionAwareTransport
}
PooledGraphicBufferAllocatorStub dispatches incoming binder transactions to a typed IPooledGraphicBufferAllocator implementation.
func (*PooledGraphicBufferAllocatorStub) Descriptor ¶
func (s *PooledGraphicBufferAllocatorStub) Descriptor() string
func (*PooledGraphicBufferAllocatorStub) OnTransaction ¶
func (s *PooledGraphicBufferAllocatorStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type SettingResult ¶
type SettingResult struct {
Failure SettingResultFailure
Field ParamFieldValues
Conflicts []ParamFieldValues
}
func (*SettingResult) MarshalParcel ¶
func (s *SettingResult) MarshalParcel( p *parcel.Parcel, ) error
func (*SettingResult) UnmarshalParcel ¶
func (s *SettingResult) UnmarshalParcel( p *parcel.Parcel, ) error
type SettingResultFailure ¶
type SettingResultFailure int32
const ( SettingResultFailureBadType SettingResultFailure = 0 SettingResultFailureBadPort SettingResultFailure = 1 SettingResultFailureBadIndex SettingResultFailure = 2 SettingResultFailureReadOnly SettingResultFailure = 3 SettingResultFailureMISMATCH SettingResultFailure = 4 SettingResultFailureBadValue SettingResultFailure = 5 SettingResultFailureCONFLICT SettingResultFailure = 6 SettingResultFailureUNSUPPORTED SettingResultFailure = 7 SettingResultFailureInfoBadValue SettingResultFailure = 8 SettingResultFailureInfoConflict SettingResultFailure = 9 )
type StructDescriptor ¶
type StructDescriptor struct {
Type int32
Fields []FieldDescriptor
}
func (*StructDescriptor) MarshalParcel ¶
func (s *StructDescriptor) MarshalParcel( p *parcel.Parcel, ) error
func (*StructDescriptor) UnmarshalParcel ¶
func (s *StructDescriptor) UnmarshalParcel( p *parcel.Parcel, ) error
type ValueRange ¶
func (*ValueRange) MarshalParcel ¶
func (s *ValueRange) MarshalParcel( p *parcel.Parcel, ) error
func (*ValueRange) UnmarshalParcel ¶
func (s *ValueRange) UnmarshalParcel( p *parcel.Parcel, ) error
type Work ¶
type WorkBundle ¶
func (*WorkBundle) MarshalParcel ¶
func (s *WorkBundle) MarshalParcel( p *parcel.Parcel, ) error
func (*WorkBundle) UnmarshalParcel ¶
func (s *WorkBundle) UnmarshalParcel( p *parcel.Parcel, ) error
type WorkOrdinal ¶
func (*WorkOrdinal) MarshalParcel ¶
func (s *WorkOrdinal) MarshalParcel( p *parcel.Parcel, ) error
func (*WorkOrdinal) UnmarshalParcel ¶
func (s *WorkOrdinal) UnmarshalParcel( p *parcel.Parcel, ) error
Source Files
¶
- baseblock.go
- block.go
- buffer.go
- fielddescriptor.go
- fielddescriptor.namedvalue.go
- fielddescriptor.type.go
- fieldid.go
- fieldsupportedvalues.go
- fieldsupportedvaluesquery.go
- fieldsupportedvaluesquery.type.go
- fieldsupportedvaluesqueryresult.go
- framedata.go
- icomponent.blockpool.go
- icomponent.blockpoolallocator.go
- icomponent.gballocator.go
- icomponent.go
- icomponent.pooledgballocator.go
- icomponentinterface.go
- icomponentlistener.go
- icomponentlistener.inputbuffer.go
- icomponentlistener.renderedframe.go
- icomponentstore.componenttraits.domain.go
- icomponentstore.componenttraits.go
- icomponentstore.componenttraits.kind.go
- icomponentstore.go
- iconfigurable.configresult.go
- iconfigurable.go
- iconfigurable.queryresult.go
- iconfigurable.querysupportedvaluesresult.go
- igraphicbufferallocator.allocation.go
- igraphicbufferallocator.description.go
- igraphicbufferallocator.go
- iinputsink.go
- iinputsurface.go
- iinputsurfaceconnection.go
- infobuffer.go
- ipooledgraphicbufferallocator.allocation.go
- ipooledgraphicbufferallocator.description.go
- ipooledgraphicbufferallocator.go
- paramdescriptor.go
- paramfield.go
- paramfieldvalues.go
- params.go
- settingresult.failure.go
- settingresult.go
- status.go
- structdescriptor.go
- valuerange.go
- work.go
- workbundle.go
- worklet.go
- workordinal.go