Documentation
¶
Index ¶
- Constants
- type AccessNetwork
- type Announcement
- type AnnouncementListenerProxy
- type AnnouncementListenerStub
- type CloseHandleProxy
- type CloseHandleStub
- type IAnnouncementListener
- type IAnnouncementListenerServer
- type ICloseHandle
- type ICloseHandleServer
- type IRadioService
- type IRadioServiceServer
- type ITuner
- type ITunerCallback
- type ITunerCallbackServer
- type ITunerServer
- type ProgramListChunk
- type ProgramListFilter
- type ProgramSelector
- type RadioAccessFamily
- type RadioConst
- type RadioError
- type RadioIndicationType
- type RadioManagerBandConfig
- type RadioManagerBandDescriptor
- type RadioManagerModuleProperties
- type RadioManagerProgramInfo
- type RadioMetadata
- type RadioResponseInfo
- type RadioResponseInfoModem
- type RadioResponseType
- type RadioServiceProxy
- func (p *RadioServiceProxy) AddAnnouncementListener(ctx context.Context, enabledTypes []int32, listener IAnnouncementListener) (ICloseHandle, error)
- func (p *RadioServiceProxy) AsBinder() binder.IBinder
- func (p *RadioServiceProxy) ListModules(ctx context.Context) ([]RadioManagerModuleProperties, error)
- func (p *RadioServiceProxy) OpenTuner(ctx context.Context, moduleId int32, bandConfig RadioManagerBandConfig, ...) (ITuner, error)
- type RadioServiceStub
- type RadioTechnology
- type RadioTechnologyFamily
- type TunerCallbackProxy
- func (p *TunerCallbackProxy) AsBinder() binder.IBinder
- func (p *TunerCallbackProxy) OnAntennaState(ctx context.Context, connected bool) error
- func (p *TunerCallbackProxy) OnBackgroundScanAvailabilityChange(ctx context.Context, isAvailable bool) error
- func (p *TunerCallbackProxy) OnBackgroundScanComplete(ctx context.Context) error
- func (p *TunerCallbackProxy) OnConfigFlagUpdated(ctx context.Context, flag int32, value bool) error
- func (p *TunerCallbackProxy) OnConfigurationChanged(ctx context.Context, config RadioManagerBandConfig) error
- func (p *TunerCallbackProxy) OnCurrentProgramInfoChanged(ctx context.Context, info RadioManagerProgramInfo) error
- func (p *TunerCallbackProxy) OnEmergencyAnnouncement(ctx context.Context, active bool) error
- func (p *TunerCallbackProxy) OnError(ctx context.Context, status int32) error
- func (p *TunerCallbackProxy) OnParametersUpdated(ctx context.Context, parameters map[string]string) error
- func (p *TunerCallbackProxy) OnProgramListChanged(ctx context.Context) error
- func (p *TunerCallbackProxy) OnProgramListUpdated(ctx context.Context, chunk ProgramListChunk) error
- func (p *TunerCallbackProxy) OnTrafficAnnouncement(ctx context.Context, active bool) error
- func (p *TunerCallbackProxy) OnTuneFailed(ctx context.Context, result int32, selector ProgramSelector) error
- type TunerCallbackStub
- type TunerProxy
- func (p *TunerProxy) AsBinder() binder.IBinder
- func (p *TunerProxy) Cancel(ctx context.Context) error
- func (p *TunerProxy) CancelAnnouncement(ctx context.Context) error
- func (p *TunerProxy) Close(ctx context.Context) error
- func (p *TunerProxy) GetConfiguration(ctx context.Context) (RadioManagerBandConfig, error)
- func (p *TunerProxy) GetImage(ctx context.Context, id int32) (graphics.Bitmap, error)
- func (p *TunerProxy) GetParameters(ctx context.Context, keys []string) (map[string]string, error)
- func (p *TunerProxy) IsClosed(ctx context.Context) (bool, error)
- func (p *TunerProxy) IsConfigFlagSet(ctx context.Context, flag int32) (bool, error)
- func (p *TunerProxy) IsConfigFlagSupported(ctx context.Context, flag int32) (bool, error)
- func (p *TunerProxy) IsMuted(ctx context.Context) (bool, error)
- func (p *TunerProxy) Seek(ctx context.Context, directionDown bool, skipSubChannel bool) error
- func (p *TunerProxy) SetConfigFlag(ctx context.Context, flag int32, value bool) error
- func (p *TunerProxy) SetConfiguration(ctx context.Context, config RadioManagerBandConfig) error
- func (p *TunerProxy) SetMuted(ctx context.Context, mute bool) error
- func (p *TunerProxy) SetParameters(ctx context.Context, parameters map[string]string) (map[string]string, error)
- func (p *TunerProxy) StartBackgroundScan(ctx context.Context) (bool, error)
- func (p *TunerProxy) StartProgramListUpdates(ctx context.Context, filter ProgramListFilter) error
- func (p *TunerProxy) Step(ctx context.Context, directionDown bool, skipSubChannel bool) error
- func (p *TunerProxy) StopProgramListUpdates(ctx context.Context) error
- func (p *TunerProxy) Tune(ctx context.Context, selector ProgramSelector) error
- type TunerStub
- type UniqueProgramIdentifier
Constants ¶
const ( TransactionIRadioServiceListModules = binder.FirstCallTransaction + 0 TransactionIRadioServiceOpenTuner = binder.FirstCallTransaction + 1 TransactionIRadioServiceAddAnnouncementListener = binder.FirstCallTransaction + 2 )
const ( MethodIRadioServiceListModules = "listModules" MethodIRadioServiceOpenTuner = "openTuner" MethodIRadioServiceAddAnnouncementListener = "addAnnouncementListener" )
const ( TransactionITunerClose = binder.FirstCallTransaction + 0 TransactionITunerIsClosed = binder.FirstCallTransaction + 1 TransactionITunerSetConfiguration = binder.FirstCallTransaction + 2 TransactionITunerGetConfiguration = binder.FirstCallTransaction + 3 TransactionITunerSetMuted = binder.FirstCallTransaction + 4 TransactionITunerIsMuted = binder.FirstCallTransaction + 5 TransactionITunerStep = binder.FirstCallTransaction + 6 TransactionITunerSeek = binder.FirstCallTransaction + 7 TransactionITunerTune = binder.FirstCallTransaction + 8 TransactionITunerCancel = binder.FirstCallTransaction + 9 TransactionITunerCancelAnnouncement = binder.FirstCallTransaction + 10 TransactionITunerGetImage = binder.FirstCallTransaction + 11 TransactionITunerStartBackgroundScan = binder.FirstCallTransaction + 12 TransactionITunerStartProgramListUpdates = binder.FirstCallTransaction + 13 TransactionITunerStopProgramListUpdates = binder.FirstCallTransaction + 14 TransactionITunerIsConfigFlagSupported = binder.FirstCallTransaction + 15 TransactionITunerIsConfigFlagSet = binder.FirstCallTransaction + 16 TransactionITunerSetConfigFlag = binder.FirstCallTransaction + 17 TransactionITunerSetParameters = binder.FirstCallTransaction + 18 TransactionITunerGetParameters = binder.FirstCallTransaction + 19 )
const ( MethodITunerClose = "close" MethodITunerIsClosed = "isClosed" MethodITunerSetConfiguration = "setConfiguration" MethodITunerGetConfiguration = "getConfiguration" MethodITunerSetMuted = "setMuted" MethodITunerIsMuted = "isMuted" MethodITunerStep = "step" MethodITunerSeek = "seek" MethodITunerTune = "tune" MethodITunerCancel = "cancel" MethodITunerCancelAnnouncement = "cancelAnnouncement" MethodITunerGetImage = "getImage" MethodITunerStartBackgroundScan = "startBackgroundScan" MethodITunerStartProgramListUpdates = "startProgramListUpdates" MethodITunerStopProgramListUpdates = "stopProgramListUpdates" MethodITunerIsConfigFlagSupported = "isConfigFlagSupported" MethodITunerIsConfigFlagSet = "isConfigFlagSet" MethodITunerSetConfigFlag = "setConfigFlag" MethodITunerSetParameters = "setParameters" MethodITunerGetParameters = "getParameters" )
const ( TransactionITunerCallbackOnError = binder.FirstCallTransaction + 0 TransactionITunerCallbackOnTuneFailed = binder.FirstCallTransaction + 1 TransactionITunerCallbackOnConfigurationChanged = binder.FirstCallTransaction + 2 TransactionITunerCallbackOnCurrentProgramInfoChanged = binder.FirstCallTransaction + 3 TransactionITunerCallbackOnTrafficAnnouncement = binder.FirstCallTransaction + 4 TransactionITunerCallbackOnEmergencyAnnouncement = binder.FirstCallTransaction + 5 TransactionITunerCallbackOnAntennaState = binder.FirstCallTransaction + 6 TransactionITunerCallbackOnBackgroundScanAvailabilityChange = binder.FirstCallTransaction + 7 TransactionITunerCallbackOnBackgroundScanComplete = binder.FirstCallTransaction + 8 TransactionITunerCallbackOnProgramListChanged = binder.FirstCallTransaction + 9 TransactionITunerCallbackOnProgramListUpdated = binder.FirstCallTransaction + 10 TransactionITunerCallbackOnConfigFlagUpdated = binder.FirstCallTransaction + 11 TransactionITunerCallbackOnParametersUpdated = binder.FirstCallTransaction + 12 )
const ( MethodITunerCallbackOnError = "onError" MethodITunerCallbackOnTuneFailed = "onTuneFailed" MethodITunerCallbackOnConfigurationChanged = "onConfigurationChanged" MethodITunerCallbackOnCurrentProgramInfoChanged = "onCurrentProgramInfoChanged" MethodITunerCallbackOnTrafficAnnouncement = "onTrafficAnnouncement" MethodITunerCallbackOnEmergencyAnnouncement = "onEmergencyAnnouncement" MethodITunerCallbackOnAntennaState = "onAntennaState" MethodITunerCallbackOnBackgroundScanAvailabilityChange = "onBackgroundScanAvailabilityChange" MethodITunerCallbackOnBackgroundScanComplete = "onBackgroundScanComplete" MethodITunerCallbackOnProgramListChanged = "onProgramListChanged" MethodITunerCallbackOnProgramListUpdated = "onProgramListUpdated" MethodITunerCallbackOnConfigFlagUpdated = "onConfigFlagUpdated" MethodITunerCallbackOnParametersUpdated = "onParametersUpdated" )
const ( RadioConstMaxRilds int32 = 3 RadioConstMaxUuidLength int32 = 64 RadioConstCardMaxApps int32 = 8 RadioConstP2ConstantNoP2 int32 = -1 )
const DescriptorIAnnouncementListener = "android.hardware.radio.IAnnouncementListener"
const DescriptorICloseHandle = "android.hardware.radio.ICloseHandle"
const DescriptorIRadioService = "android.hardware.radio.IRadioService"
const DescriptorITuner = "android.hardware.radio.ITuner"
const DescriptorITunerCallback = "android.hardware.radio.ITunerCallback"
const (
MethodIAnnouncementListenerOnListUpdated = "onListUpdated"
)
const (
MethodICloseHandleClose = "close"
)
const (
TransactionIAnnouncementListenerOnListUpdated = binder.FirstCallTransaction + 0
)
const (
TransactionICloseHandleClose = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccessNetwork ¶
type AccessNetwork int32
const ( AccessNetworkUNKNOWN AccessNetwork = 0 AccessNetworkGERAN AccessNetwork = 1 AccessNetworkUTRAN AccessNetwork = 2 AccessNetworkEUTRAN AccessNetwork = 3 AccessNetworkCDMA2000 AccessNetwork = 4 AccessNetworkIWLAN AccessNetwork = 5 AccessNetworkNGRAN AccessNetwork = 6 )
type Announcement ¶
type Announcement struct {
Type int32
}
func (*Announcement) MarshalParcel ¶
func (s *Announcement) MarshalParcel( p *parcel.Parcel, ) error
func (*Announcement) UnmarshalParcel ¶
func (s *Announcement) UnmarshalParcel( p *parcel.Parcel, ) error
type AnnouncementListenerProxy ¶
func NewAnnouncementListenerProxy ¶
func NewAnnouncementListenerProxy( remote binder.IBinder, ) *AnnouncementListenerProxy
func (*AnnouncementListenerProxy) AsBinder ¶
func (p *AnnouncementListenerProxy) AsBinder() binder.IBinder
func (*AnnouncementListenerProxy) OnListUpdated ¶
func (p *AnnouncementListenerProxy) OnListUpdated( ctx context.Context, activeAnnouncements []Announcement, ) error
type AnnouncementListenerStub ¶
type AnnouncementListenerStub struct {
Impl IAnnouncementListener
Transport binder.VersionAwareTransport
}
AnnouncementListenerStub dispatches incoming binder transactions to a typed IAnnouncementListener implementation.
func (*AnnouncementListenerStub) Descriptor ¶
func (s *AnnouncementListenerStub) Descriptor() string
func (*AnnouncementListenerStub) OnTransaction ¶
func (s *AnnouncementListenerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type CloseHandleProxy ¶
func NewCloseHandleProxy ¶
func NewCloseHandleProxy( remote binder.IBinder, ) *CloseHandleProxy
func (*CloseHandleProxy) AsBinder ¶
func (p *CloseHandleProxy) AsBinder() binder.IBinder
type CloseHandleStub ¶
type CloseHandleStub struct {
Impl ICloseHandle
Transport binder.VersionAwareTransport
}
CloseHandleStub dispatches incoming binder transactions to a typed ICloseHandle implementation.
func (*CloseHandleStub) Descriptor ¶
func (s *CloseHandleStub) Descriptor() string
func (*CloseHandleStub) OnTransaction ¶
func (s *CloseHandleStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type IAnnouncementListener ¶
type IAnnouncementListener interface {
AsBinder() binder.IBinder
OnListUpdated(ctx context.Context, activeAnnouncements []Announcement) error
}
func NewAnnouncementListenerStub ¶
func NewAnnouncementListenerStub( impl IAnnouncementListenerServer, ) IAnnouncementListener
NewAnnouncementListenerStub creates a server-side IAnnouncementListener wrapping the given server implementation. The returned value satisfies IAnnouncementListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IAnnouncementListenerServer ¶
type IAnnouncementListenerServer interface {
OnListUpdated(ctx context.Context, activeAnnouncements []Announcement) error
}
IAnnouncementListenerServer is the server-side interface that user implementations provide to NewAnnouncementListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ICloseHandle ¶
func NewCloseHandleStub ¶
func NewCloseHandleStub( impl ICloseHandleServer, ) ICloseHandle
NewCloseHandleStub creates a server-side ICloseHandle wrapping the given server implementation. The returned value satisfies ICloseHandle and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ICloseHandleServer ¶
ICloseHandleServer is the server-side interface that user implementations provide to NewCloseHandleStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IRadioService ¶
type IRadioService interface {
AsBinder() binder.IBinder
ListModules(ctx context.Context) ([]RadioManagerModuleProperties, error)
OpenTuner(ctx context.Context, moduleId int32, bandConfig RadioManagerBandConfig, withAudio bool, callback ITunerCallback) (ITuner, error)
AddAnnouncementListener(ctx context.Context, enabledTypes []int32, listener IAnnouncementListener) (ICloseHandle, error)
}
func NewRadioServiceStub ¶
func NewRadioServiceStub( impl IRadioServiceServer, ) IRadioService
NewRadioServiceStub creates a server-side IRadioService wrapping the given server implementation. The returned value satisfies IRadioService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IRadioServiceServer ¶
type IRadioServiceServer interface {
ListModules(ctx context.Context) ([]RadioManagerModuleProperties, error)
OpenTuner(ctx context.Context, moduleId int32, bandConfig RadioManagerBandConfig, withAudio bool, callback ITunerCallback) (ITuner, error)
AddAnnouncementListener(ctx context.Context, enabledTypes []int32, listener IAnnouncementListener) (ICloseHandle, error)
}
IRadioServiceServer is the server-side interface that user implementations provide to NewRadioServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ITuner ¶
type ITuner interface {
AsBinder() binder.IBinder
Close(ctx context.Context) error
IsClosed(ctx context.Context) (bool, error)
SetConfiguration(ctx context.Context, config RadioManagerBandConfig) error
GetConfiguration(ctx context.Context) (RadioManagerBandConfig, error)
SetMuted(ctx context.Context, mute bool) error
IsMuted(ctx context.Context) (bool, error)
Step(ctx context.Context, directionDown bool, skipSubChannel bool) error
Seek(ctx context.Context, directionDown bool, skipSubChannel bool) error
Tune(ctx context.Context, selector ProgramSelector) error
Cancel(ctx context.Context) error
CancelAnnouncement(ctx context.Context) error
GetImage(ctx context.Context, id int32) (graphics.Bitmap, error)
StartBackgroundScan(ctx context.Context) (bool, error)
StartProgramListUpdates(ctx context.Context, filter ProgramListFilter) error
StopProgramListUpdates(ctx context.Context) error
IsConfigFlagSupported(ctx context.Context, flag int32) (bool, error)
IsConfigFlagSet(ctx context.Context, flag int32) (bool, error)
SetConfigFlag(ctx context.Context, flag int32, value bool) error
SetParameters(ctx context.Context, parameters map[string]string) (map[string]string, error)
GetParameters(ctx context.Context, keys []string) (map[string]string, error)
}
func NewTunerStub ¶
func NewTunerStub( impl ITunerServer, ) ITuner
NewTunerStub creates a server-side ITuner wrapping the given server implementation. The returned value satisfies ITuner and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITunerCallback ¶
type ITunerCallback interface {
AsBinder() binder.IBinder
OnError(ctx context.Context, status int32) error
OnTuneFailed(ctx context.Context, result int32, selector ProgramSelector) error
OnConfigurationChanged(ctx context.Context, config RadioManagerBandConfig) error
OnCurrentProgramInfoChanged(ctx context.Context, info RadioManagerProgramInfo) error
OnTrafficAnnouncement(ctx context.Context, active bool) error
OnEmergencyAnnouncement(ctx context.Context, active bool) error
OnAntennaState(ctx context.Context, connected bool) error
OnBackgroundScanAvailabilityChange(ctx context.Context, isAvailable bool) error
OnBackgroundScanComplete(ctx context.Context) error
OnProgramListChanged(ctx context.Context) error
OnProgramListUpdated(ctx context.Context, chunk ProgramListChunk) error
OnConfigFlagUpdated(ctx context.Context, flag int32, value bool) error
OnParametersUpdated(ctx context.Context, parameters map[string]string) error
}
func NewTunerCallbackStub ¶
func NewTunerCallbackStub( impl ITunerCallbackServer, ) ITunerCallback
NewTunerCallbackStub creates a server-side ITunerCallback wrapping the given server implementation. The returned value satisfies ITunerCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITunerCallbackServer ¶
type ITunerCallbackServer interface {
OnError(ctx context.Context, status int32) error
OnTuneFailed(ctx context.Context, result int32, selector ProgramSelector) error
OnConfigurationChanged(ctx context.Context, config RadioManagerBandConfig) error
OnCurrentProgramInfoChanged(ctx context.Context, info RadioManagerProgramInfo) error
OnTrafficAnnouncement(ctx context.Context, active bool) error
OnEmergencyAnnouncement(ctx context.Context, active bool) error
OnAntennaState(ctx context.Context, connected bool) error
OnBackgroundScanAvailabilityChange(ctx context.Context, isAvailable bool) error
OnBackgroundScanComplete(ctx context.Context) error
OnProgramListChanged(ctx context.Context) error
OnProgramListUpdated(ctx context.Context, chunk ProgramListChunk) error
OnConfigFlagUpdated(ctx context.Context, flag int32, value bool) error
OnParametersUpdated(ctx context.Context, parameters map[string]string) error
}
ITunerCallbackServer is the server-side interface that user implementations provide to NewTunerCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ITunerServer ¶
type ITunerServer interface {
Close(ctx context.Context) error
IsClosed(ctx context.Context) (bool, error)
SetConfiguration(ctx context.Context, config RadioManagerBandConfig) error
GetConfiguration(ctx context.Context) (RadioManagerBandConfig, error)
SetMuted(ctx context.Context, mute bool) error
IsMuted(ctx context.Context) (bool, error)
Step(ctx context.Context, directionDown bool, skipSubChannel bool) error
Seek(ctx context.Context, directionDown bool, skipSubChannel bool) error
Tune(ctx context.Context, selector ProgramSelector) error
Cancel(ctx context.Context) error
CancelAnnouncement(ctx context.Context) error
GetImage(ctx context.Context, id int32) (graphics.Bitmap, error)
StartBackgroundScan(ctx context.Context) (bool, error)
StartProgramListUpdates(ctx context.Context, filter ProgramListFilter) error
StopProgramListUpdates(ctx context.Context) error
IsConfigFlagSupported(ctx context.Context, flag int32) (bool, error)
IsConfigFlagSet(ctx context.Context, flag int32) (bool, error)
SetConfigFlag(ctx context.Context, flag int32, value bool) error
SetParameters(ctx context.Context, parameters map[string]string) (map[string]string, error)
GetParameters(ctx context.Context, keys []string) (map[string]string, error)
}
ITunerServer is the server-side interface that user implementations provide to NewTunerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ProgramListChunk ¶
type ProgramListChunk struct {
}
func (*ProgramListChunk) MarshalParcel ¶
func (s *ProgramListChunk) MarshalParcel( p *parcel.Parcel, ) error
func (*ProgramListChunk) UnmarshalParcel ¶
func (s *ProgramListChunk) UnmarshalParcel( p *parcel.Parcel, ) error
type ProgramListFilter ¶
type ProgramListFilter struct {
}
func (*ProgramListFilter) MarshalParcel ¶
func (s *ProgramListFilter) MarshalParcel( p *parcel.Parcel, ) error
func (*ProgramListFilter) UnmarshalParcel ¶
func (s *ProgramListFilter) UnmarshalParcel( p *parcel.Parcel, ) error
type ProgramSelector ¶
type ProgramSelector struct {
ProgramType int32
}
func (*ProgramSelector) MarshalParcel ¶
func (s *ProgramSelector) MarshalParcel( p *parcel.Parcel, ) error
func (*ProgramSelector) UnmarshalParcel ¶
func (s *ProgramSelector) UnmarshalParcel( p *parcel.Parcel, ) error
type RadioAccessFamily ¶
type RadioAccessFamily int32
const ( RadioAccessFamilyUNKNOWN RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyUNKNOWN)) RadioAccessFamilyGPRS RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyGPRS)) RadioAccessFamilyEDGE RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyEDGE)) RadioAccessFamilyUMTS RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyUMTS)) RadioAccessFamilyIS95A RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyIS95A)) RadioAccessFamilyIS95B RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyIS95B)) RadioAccessFamilyOneXRtt RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyOneXRtt)) RadioAccessFamilyEvdo0 RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyEvdo0)) RadioAccessFamilyEvdoA RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyEvdoA)) RadioAccessFamilyHSDPA RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyHSDPA)) RadioAccessFamilyHSUPA RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyHSUPA)) RadioAccessFamilyHSPA RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyHSPA)) RadioAccessFamilyEvdoB RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyEvdoB)) RadioAccessFamilyEHRPD RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyEHRPD)) RadioAccessFamilyLTE RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyLTE)) RadioAccessFamilyHSPAP RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyHSPAP)) RadioAccessFamilyGSM RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyGSM)) RadioAccessFamilyTdScdma RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyTdScdma)) RadioAccessFamilyIWLAN RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyIWLAN)) RadioAccessFamilyLteCa RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyLteCa)) RadioAccessFamilyNR RadioAccessFamily = (1 << RadioAccessFamily(RadioTechnologyNR)) )
type RadioConst ¶
type RadioConst struct {
}
func (*RadioConst) MarshalParcel ¶
func (s *RadioConst) MarshalParcel( p *parcel.Parcel, ) error
func (*RadioConst) UnmarshalParcel ¶
func (s *RadioConst) UnmarshalParcel( p *parcel.Parcel, ) error
type RadioError ¶
type RadioError int32
const ( RadioErrorNONE RadioError = 0 RadioErrorRadioNotAvailable RadioError = 1 RadioErrorGenericFailure RadioError = 2 RadioErrorPasswordIncorrect RadioError = 3 RadioErrorSimPin2 RadioError = 4 RadioErrorSimPuk2 RadioError = 5 RadioErrorRequestNotSupported RadioError = 6 RadioErrorCANCELLED RadioError = 7 RadioErrorOpNotAllowedDuringVoiceCall RadioError = 8 RadioErrorOpNotAllowedBeforeRegToNw RadioError = 9 RadioErrorSmsSendFailRetry RadioError = 10 RadioErrorSimAbsent RadioError = 11 RadioErrorSubscriptionNotAvailable RadioError = 12 RadioErrorModeNotSupported RadioError = 13 RadioErrorFdnCheckFailure RadioError = 14 RadioErrorIllegalSimOrMe RadioError = 15 RadioErrorMissingResource RadioError = 16 RadioErrorNoSuchElement RadioError = 17 RadioErrorDialModifiedToUssd RadioError = 18 RadioErrorDialModifiedToSs RadioError = 19 RadioErrorDialModifiedToDial RadioError = 20 RadioErrorUssdModifiedToDial RadioError = 21 RadioErrorUssdModifiedToSs RadioError = 22 RadioErrorUssdModifiedToUssd RadioError = 23 RadioErrorSsModifiedToDial RadioError = 24 RadioErrorSsModifiedToUssd RadioError = 25 RadioErrorSubscriptionNotSupported RadioError = 26 RadioErrorSsModifiedToSs RadioError = 27 RadioErrorLceNotSupported RadioError = 36 RadioErrorNoMemory RadioError = 37 RadioErrorInternalErr RadioError = 38 RadioErrorSystemErr RadioError = 39 RadioErrorModemErr RadioError = 40 RadioErrorInvalidState RadioError = 41 RadioErrorNoResources RadioError = 42 RadioErrorSimErr RadioError = 43 RadioErrorInvalidArguments RadioError = 44 RadioErrorInvalidSimState RadioError = 45 RadioErrorInvalidModemState RadioError = 46 RadioErrorInvalidCallId RadioError = 47 RadioErrorNoSmsToAck RadioError = 48 RadioErrorNetworkErr RadioError = 49 RadioErrorRequestRateLimited RadioError = 50 RadioErrorSimBusy RadioError = 51 RadioErrorSimFull RadioError = 52 RadioErrorNetworkReject RadioError = 53 RadioErrorOperationNotAllowed RadioError = 54 RadioErrorEmptyRecord RadioError = 55 RadioErrorInvalidSmsFormat RadioError = 56 RadioErrorEncodingErr RadioError = 57 RadioErrorInvalidSmscAddress RadioError = 58 RadioErrorNoSuchEntry RadioError = 59 RadioErrorNetworkNotReady RadioError = 60 RadioErrorNotProvisioned RadioError = 61 RadioErrorNoSubscription RadioError = 62 RadioErrorNoNetworkFound RadioError = 63 RadioErrorDeviceInUse RadioError = 64 RadioErrorABORTED RadioError = 65 RadioErrorInvalidResponse RadioError = 66 RadioErrorOemError1 RadioError = 501 RadioErrorOemError2 RadioError = 502 RadioErrorOemError3 RadioError = 503 RadioErrorOemError4 RadioError = 504 RadioErrorOemError5 RadioError = 505 RadioErrorOemError6 RadioError = 506 RadioErrorOemError7 RadioError = 507 RadioErrorOemError8 RadioError = 508 RadioErrorOemError9 RadioError = 509 RadioErrorOemError10 RadioError = 510 RadioErrorOemError11 RadioError = 511 RadioErrorOemError12 RadioError = 512 RadioErrorOemError13 RadioError = 513 RadioErrorOemError14 RadioError = 514 RadioErrorOemError15 RadioError = 515 RadioErrorOemError16 RadioError = 516 RadioErrorOemError17 RadioError = 517 RadioErrorOemError18 RadioError = 518 RadioErrorOemError19 RadioError = 519 RadioErrorOemError20 RadioError = 520 RadioErrorOemError21 RadioError = 521 RadioErrorOemError22 RadioError = 522 RadioErrorOemError23 RadioError = 523 RadioErrorOemError24 RadioError = 524 RadioErrorOemError25 RadioError = 525 RadioErrorSimultaneousSmsAndCallNotAllowed RadioError = 67 RadioErrorAccessBarred RadioError = 68 RadioErrorBlockedDueToCall RadioError = 69 RadioErrorRfHardwareIssue RadioError = 70 RadioErrorNoRfCalibrationInfo RadioError = 71 )
type RadioIndicationType ¶
type RadioIndicationType int32
const ( RadioIndicationTypeUNSOLICITED RadioIndicationType = 0 RadioIndicationTypeUnsolicitedAckExp RadioIndicationType = 1 )
type RadioManagerBandConfig ¶
type RadioManagerBandConfig struct {
}
func (*RadioManagerBandConfig) MarshalParcel ¶
func (s *RadioManagerBandConfig) MarshalParcel( p *parcel.Parcel, ) error
func (*RadioManagerBandConfig) UnmarshalParcel ¶
func (s *RadioManagerBandConfig) UnmarshalParcel( p *parcel.Parcel, ) error
type RadioManagerBandDescriptor ¶
type RadioManagerBandDescriptor struct {
}
func (*RadioManagerBandDescriptor) MarshalParcel ¶
func (s *RadioManagerBandDescriptor) MarshalParcel( p *parcel.Parcel, ) error
func (*RadioManagerBandDescriptor) UnmarshalParcel ¶
func (s *RadioManagerBandDescriptor) UnmarshalParcel( p *parcel.Parcel, ) error
type RadioManagerModuleProperties ¶
type RadioManagerModuleProperties struct {
}
func (*RadioManagerModuleProperties) MarshalParcel ¶
func (s *RadioManagerModuleProperties) MarshalParcel( p *parcel.Parcel, ) error
func (*RadioManagerModuleProperties) UnmarshalParcel ¶
func (s *RadioManagerModuleProperties) UnmarshalParcel( p *parcel.Parcel, ) error
type RadioManagerProgramInfo ¶
type RadioManagerProgramInfo struct {
}
func (*RadioManagerProgramInfo) MarshalParcel ¶
func (s *RadioManagerProgramInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*RadioManagerProgramInfo) UnmarshalParcel ¶
func (s *RadioManagerProgramInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type RadioMetadata ¶
type RadioMetadata struct {
}
func (*RadioMetadata) MarshalParcel ¶
func (s *RadioMetadata) MarshalParcel( p *parcel.Parcel, ) error
func (*RadioMetadata) UnmarshalParcel ¶
func (s *RadioMetadata) UnmarshalParcel( p *parcel.Parcel, ) error
type RadioResponseInfo ¶
type RadioResponseInfo struct {
Type RadioResponseType
Serial int32
Error RadioError
}
func (*RadioResponseInfo) MarshalParcel ¶
func (s *RadioResponseInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*RadioResponseInfo) UnmarshalParcel ¶
func (s *RadioResponseInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type RadioResponseInfoModem ¶
type RadioResponseInfoModem struct {
Type RadioResponseType
Serial int32
Error RadioError
IsEnabled bool
}
func (*RadioResponseInfoModem) MarshalParcel ¶
func (s *RadioResponseInfoModem) MarshalParcel( p *parcel.Parcel, ) error
func (*RadioResponseInfoModem) UnmarshalParcel ¶
func (s *RadioResponseInfoModem) UnmarshalParcel( p *parcel.Parcel, ) error
type RadioResponseType ¶
type RadioResponseType int32
const ( RadioResponseTypeSOLICITED RadioResponseType = 0 RadioResponseTypeSolicitedAck RadioResponseType = 1 RadioResponseTypeSolicitedAckExp RadioResponseType = 2 )
type RadioServiceProxy ¶
func NewRadioServiceProxy ¶
func NewRadioServiceProxy( remote binder.IBinder, ) *RadioServiceProxy
func (*RadioServiceProxy) AddAnnouncementListener ¶
func (p *RadioServiceProxy) AddAnnouncementListener( ctx context.Context, enabledTypes []int32, listener IAnnouncementListener, ) (ICloseHandle, error)
func (*RadioServiceProxy) AsBinder ¶
func (p *RadioServiceProxy) AsBinder() binder.IBinder
func (*RadioServiceProxy) ListModules ¶
func (p *RadioServiceProxy) ListModules( ctx context.Context, ) ([]RadioManagerModuleProperties, error)
func (*RadioServiceProxy) OpenTuner ¶
func (p *RadioServiceProxy) OpenTuner( ctx context.Context, moduleId int32, bandConfig RadioManagerBandConfig, withAudio bool, callback ITunerCallback, ) (ITuner, error)
type RadioServiceStub ¶
type RadioServiceStub struct {
Impl IRadioService
Transport binder.VersionAwareTransport
}
RadioServiceStub dispatches incoming binder transactions to a typed IRadioService implementation.
func (*RadioServiceStub) Descriptor ¶
func (s *RadioServiceStub) Descriptor() string
func (*RadioServiceStub) OnTransaction ¶
func (s *RadioServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type RadioTechnology ¶
type RadioTechnology int32
const ( RadioTechnologyUNKNOWN RadioTechnology = 0 RadioTechnologyGPRS RadioTechnology = 1 RadioTechnologyEDGE RadioTechnology = 2 RadioTechnologyUMTS RadioTechnology = 3 RadioTechnologyIS95A RadioTechnology = 4 RadioTechnologyIS95B RadioTechnology = 5 RadioTechnologyOneXRtt RadioTechnology = 6 RadioTechnologyEvdo0 RadioTechnology = 7 RadioTechnologyEvdoA RadioTechnology = 8 RadioTechnologyHSDPA RadioTechnology = 9 RadioTechnologyHSUPA RadioTechnology = 10 RadioTechnologyHSPA RadioTechnology = 11 RadioTechnologyEvdoB RadioTechnology = 12 RadioTechnologyEHRPD RadioTechnology = 13 RadioTechnologyLTE RadioTechnology = 14 RadioTechnologyHSPAP RadioTechnology = 15 RadioTechnologyGSM RadioTechnology = 16 RadioTechnologyTdScdma RadioTechnology = 17 RadioTechnologyIWLAN RadioTechnology = 18 RadioTechnologyLteCa RadioTechnology = 19 RadioTechnologyNR RadioTechnology = 20 )
type RadioTechnologyFamily ¶
type RadioTechnologyFamily int32
const ( RadioTechnologyFamilyThreeGpp RadioTechnologyFamily = 0 RadioTechnologyFamilyThreeGpp2 RadioTechnologyFamily = 1 )
type TunerCallbackProxy ¶
func NewTunerCallbackProxy ¶
func NewTunerCallbackProxy( remote binder.IBinder, ) *TunerCallbackProxy
func (*TunerCallbackProxy) AsBinder ¶
func (p *TunerCallbackProxy) AsBinder() binder.IBinder
func (*TunerCallbackProxy) OnAntennaState ¶
func (p *TunerCallbackProxy) OnAntennaState( ctx context.Context, connected bool, ) error
func (*TunerCallbackProxy) OnBackgroundScanAvailabilityChange ¶
func (p *TunerCallbackProxy) OnBackgroundScanAvailabilityChange( ctx context.Context, isAvailable bool, ) error
func (*TunerCallbackProxy) OnBackgroundScanComplete ¶
func (p *TunerCallbackProxy) OnBackgroundScanComplete( ctx context.Context, ) error
func (*TunerCallbackProxy) OnConfigFlagUpdated ¶
func (*TunerCallbackProxy) OnConfigurationChanged ¶
func (p *TunerCallbackProxy) OnConfigurationChanged( ctx context.Context, config RadioManagerBandConfig, ) error
func (*TunerCallbackProxy) OnCurrentProgramInfoChanged ¶
func (p *TunerCallbackProxy) OnCurrentProgramInfoChanged( ctx context.Context, info RadioManagerProgramInfo, ) error
func (*TunerCallbackProxy) OnEmergencyAnnouncement ¶
func (p *TunerCallbackProxy) OnEmergencyAnnouncement( ctx context.Context, active bool, ) error
func (*TunerCallbackProxy) OnError ¶
func (p *TunerCallbackProxy) OnError( ctx context.Context, status int32, ) error
func (*TunerCallbackProxy) OnParametersUpdated ¶
func (*TunerCallbackProxy) OnProgramListChanged ¶
func (p *TunerCallbackProxy) OnProgramListChanged( ctx context.Context, ) error
func (*TunerCallbackProxy) OnProgramListUpdated ¶
func (p *TunerCallbackProxy) OnProgramListUpdated( ctx context.Context, chunk ProgramListChunk, ) error
func (*TunerCallbackProxy) OnTrafficAnnouncement ¶
func (p *TunerCallbackProxy) OnTrafficAnnouncement( ctx context.Context, active bool, ) error
func (*TunerCallbackProxy) OnTuneFailed ¶
func (p *TunerCallbackProxy) OnTuneFailed( ctx context.Context, result int32, selector ProgramSelector, ) error
type TunerCallbackStub ¶
type TunerCallbackStub struct {
Impl ITunerCallback
Transport binder.VersionAwareTransport
}
TunerCallbackStub dispatches incoming binder transactions to a typed ITunerCallback implementation.
func (*TunerCallbackStub) Descriptor ¶
func (s *TunerCallbackStub) Descriptor() string
func (*TunerCallbackStub) OnTransaction ¶
func (s *TunerCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type TunerProxy ¶
func NewTunerProxy ¶
func NewTunerProxy( remote binder.IBinder, ) *TunerProxy
func (*TunerProxy) AsBinder ¶
func (p *TunerProxy) AsBinder() binder.IBinder
func (*TunerProxy) CancelAnnouncement ¶
func (p *TunerProxy) CancelAnnouncement( ctx context.Context, ) error
func (*TunerProxy) GetConfiguration ¶
func (p *TunerProxy) GetConfiguration( ctx context.Context, ) (RadioManagerBandConfig, error)
func (*TunerProxy) GetParameters ¶
func (*TunerProxy) IsConfigFlagSet ¶
func (*TunerProxy) IsConfigFlagSupported ¶
func (*TunerProxy) SetConfigFlag ¶
func (*TunerProxy) SetConfiguration ¶
func (p *TunerProxy) SetConfiguration( ctx context.Context, config RadioManagerBandConfig, ) error
func (*TunerProxy) SetMuted ¶
func (p *TunerProxy) SetMuted( ctx context.Context, mute bool, ) error
func (*TunerProxy) SetParameters ¶
func (*TunerProxy) StartBackgroundScan ¶
func (p *TunerProxy) StartBackgroundScan( ctx context.Context, ) (bool, error)
func (*TunerProxy) StartProgramListUpdates ¶
func (p *TunerProxy) StartProgramListUpdates( ctx context.Context, filter ProgramListFilter, ) error
func (*TunerProxy) StopProgramListUpdates ¶
func (p *TunerProxy) StopProgramListUpdates( ctx context.Context, ) error
func (*TunerProxy) Tune ¶
func (p *TunerProxy) Tune( ctx context.Context, selector ProgramSelector, ) error
type TunerStub ¶
type TunerStub struct {
Impl ITuner
Transport binder.VersionAwareTransport
}
TunerStub dispatches incoming binder transactions to a typed ITuner implementation.
func (*TunerStub) Descriptor ¶
type UniqueProgramIdentifier ¶
type UniqueProgramIdentifier struct {
}
func (*UniqueProgramIdentifier) MarshalParcel ¶
func (s *UniqueProgramIdentifier) MarshalParcel( p *parcel.Parcel, ) error
func (*UniqueProgramIdentifier) UnmarshalParcel ¶
func (s *UniqueProgramIdentifier) UnmarshalParcel( p *parcel.Parcel, ) error
Source Files
¶
- accessnetwork.go
- announcement.go
- iannouncementlistener.go
- iclosehandle.go
- iradioservice.go
- ituner.go
- itunercallback.go
- programlist.chunk.go
- programlist.filter.go
- programselector.go
- radioaccessfamily.go
- radioconst.go
- radioerror.go
- radioindicationtype.go
- radiomanager.bandconfig.go
- radiomanager.banddescriptor.go
- radiomanager.moduleproperties.go
- radiomanager.programinfo.go
- radiometadata.go
- radioresponseinfo.go
- radioresponseinfomodem.go
- radioresponsetype.go
- radiotechnology.go
- radiotechnologyfamily.go
- uniqueprogramidentifier.go