Documentation
¶
Index ¶
- Constants
- type ConnectionFailureInfo
- type ConnectionFailureInfoConnectionFailureReason
- type EpsFallbackReason
- type IRadioIms
- type IRadioImsIndication
- type IRadioImsIndicationServer
- type IRadioImsResponse
- type IRadioImsResponseServer
- type IRadioImsServer
- type ImsCall
- type ImsCallCallState
- type ImsCallCallType
- type ImsCallDirection
- type ImsDeregistrationReason
- type ImsRegistration
- type ImsRegistrationState
- type ImsStreamDirection
- type ImsStreamType
- type ImsTrafficType
- type RadioImsIndicationProxy
- func (p *RadioImsIndicationProxy) AsBinder() binder.IBinder
- func (p *RadioImsIndicationProxy) NotifyAnbr(ctx context.Context, type_ radio.RadioIndicationType, mediaType ImsStreamType, ...) error
- func (p *RadioImsIndicationProxy) OnConnectionSetupFailure(ctx context.Context, type_ radio.RadioIndicationType, token int32, ...) error
- func (p *RadioImsIndicationProxy) TriggerImsDeregistration(ctx context.Context, type_ radio.RadioIndicationType, ...) error
- type RadioImsIndicationStub
- type RadioImsProxy
- func (p *RadioImsProxy) AsBinder() binder.IBinder
- func (p *RadioImsProxy) SendAnbrQuery(ctx context.Context, serial int32, mediaType ImsStreamType, ...) error
- func (p *RadioImsProxy) SetResponseFunctions(ctx context.Context, radioImsResponse IRadioImsResponse, ...) error
- func (p *RadioImsProxy) SetSrvccCallInfo(ctx context.Context, serial int32, srvccCalls []SrvccCall) error
- func (p *RadioImsProxy) StartImsTraffic(ctx context.Context, serial int32, token int32, imsTrafficType ImsTrafficType, ...) error
- func (p *RadioImsProxy) StopImsTraffic(ctx context.Context, serial int32, token int32) error
- func (p *RadioImsProxy) TriggerEpsFallback(ctx context.Context, serial int32, reason EpsFallbackReason) error
- func (p *RadioImsProxy) UpdateImsCallStatus(ctx context.Context, serial int32, imsCalls []ImsCall) error
- func (p *RadioImsProxy) UpdateImsRegistrationInfo(ctx context.Context, serial int32, imsRegistration ImsRegistration) error
- type RadioImsResponseProxy
- func (p *RadioImsResponseProxy) AsBinder() binder.IBinder
- func (p *RadioImsResponseProxy) SendAnbrQueryResponse(ctx context.Context, info radio.RadioResponseInfo) error
- func (p *RadioImsResponseProxy) SetSrvccCallInfoResponse(ctx context.Context, info radio.RadioResponseInfo) error
- func (p *RadioImsResponseProxy) StartImsTrafficResponse(ctx context.Context, info radio.RadioResponseInfo, ...) error
- func (p *RadioImsResponseProxy) StopImsTrafficResponse(ctx context.Context, info radio.RadioResponseInfo) error
- func (p *RadioImsResponseProxy) TriggerEpsFallbackResponse(ctx context.Context, info radio.RadioResponseInfo) error
- func (p *RadioImsResponseProxy) UpdateImsCallStatusResponse(ctx context.Context, info radio.RadioResponseInfo) error
- func (p *RadioImsResponseProxy) UpdateImsRegistrationInfoResponse(ctx context.Context, info radio.RadioResponseInfo) error
- type RadioImsResponseStub
- type RadioImsStub
- type SrvccCall
- type SrvccCallCallSubState
- type SrvccCallCallType
- type SrvccCallToneType
- type SuggestedAction
Constants ¶
const ( ImsRegistrationImsMmtelCapabilityNone int32 = 0 ImsRegistrationImsMmtelCapabilityVoice int32 = (1 << 0) ImsRegistrationImsMmtelCapabilityVideo int32 = (1 << 1) ImsRegistrationImsMmtelCapabilitySms int32 = (1 << 2) ImsRegistrationImsRcsCapabilities int32 = (1 << 3) )
const ( TransactionIRadioImsSetSrvccCallInfo = binder.FirstCallTransaction + 0 TransactionIRadioImsUpdateImsRegistrationInfo = binder.FirstCallTransaction + 1 TransactionIRadioImsStartImsTraffic = binder.FirstCallTransaction + 2 TransactionIRadioImsStopImsTraffic = binder.FirstCallTransaction + 3 TransactionIRadioImsTriggerEpsFallback = binder.FirstCallTransaction + 4 TransactionIRadioImsSetResponseFunctions = binder.FirstCallTransaction + 5 TransactionIRadioImsSendAnbrQuery = binder.FirstCallTransaction + 6 TransactionIRadioImsUpdateImsCallStatus = binder.FirstCallTransaction + 7 )
const ( MethodIRadioImsSetSrvccCallInfo = "setSrvccCallInfo" MethodIRadioImsUpdateImsRegistrationInfo = "updateImsRegistrationInfo" MethodIRadioImsStartImsTraffic = "startImsTraffic" MethodIRadioImsStopImsTraffic = "stopImsTraffic" MethodIRadioImsTriggerEpsFallback = "triggerEpsFallback" MethodIRadioImsSetResponseFunctions = "setResponseFunctions" MethodIRadioImsSendAnbrQuery = "sendAnbrQuery" MethodIRadioImsUpdateImsCallStatus = "updateImsCallStatus" )
const ( TransactionIRadioImsIndicationOnConnectionSetupFailure = binder.FirstCallTransaction + 0 TransactionIRadioImsIndicationNotifyAnbr = binder.FirstCallTransaction + 1 TransactionIRadioImsIndicationTriggerImsDeregistration = binder.FirstCallTransaction + 2 )
const ( MethodIRadioImsIndicationOnConnectionSetupFailure = "onConnectionSetupFailure" MethodIRadioImsIndicationNotifyAnbr = "notifyAnbr" MethodIRadioImsIndicationTriggerImsDeregistration = "triggerImsDeregistration" )
const ( TransactionIRadioImsResponseSetSrvccCallInfoResponse = binder.FirstCallTransaction + 0 TransactionIRadioImsResponseUpdateImsRegistrationInfoResponse = binder.FirstCallTransaction + 1 TransactionIRadioImsResponseStartImsTrafficResponse = binder.FirstCallTransaction + 2 TransactionIRadioImsResponseStopImsTrafficResponse = binder.FirstCallTransaction + 3 TransactionIRadioImsResponseTriggerEpsFallbackResponse = binder.FirstCallTransaction + 4 TransactionIRadioImsResponseSendAnbrQueryResponse = binder.FirstCallTransaction + 5 TransactionIRadioImsResponseUpdateImsCallStatusResponse = binder.FirstCallTransaction + 6 )
const ( MethodIRadioImsResponseSetSrvccCallInfoResponse = "setSrvccCallInfoResponse" MethodIRadioImsResponseUpdateImsRegistrationInfoResponse = "updateImsRegistrationInfoResponse" MethodIRadioImsResponseStartImsTrafficResponse = "startImsTrafficResponse" MethodIRadioImsResponseStopImsTrafficResponse = "stopImsTrafficResponse" MethodIRadioImsResponseTriggerEpsFallbackResponse = "triggerEpsFallbackResponse" MethodIRadioImsResponseSendAnbrQueryResponse = "sendAnbrQueryResponse" MethodIRadioImsResponseUpdateImsCallStatusResponse = "updateImsCallStatusResponse" )
const DescriptorIRadioIms = "android.hardware.radio.ims.IRadioIms"
const DescriptorIRadioImsIndication = "android.hardware.radio.ims.IRadioImsIndication"
const DescriptorIRadioImsResponse = "android.hardware.radio.ims.IRadioImsResponse"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConnectionFailureInfo ¶
type ConnectionFailureInfo struct {
FailureReason ConnectionFailureInfoConnectionFailureReason
CauseCode int32
WaitTimeMillis int32
}
func (*ConnectionFailureInfo) MarshalParcel ¶
func (s *ConnectionFailureInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*ConnectionFailureInfo) UnmarshalParcel ¶
func (s *ConnectionFailureInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type ConnectionFailureInfoConnectionFailureReason ¶
type ConnectionFailureInfoConnectionFailureReason int32
const ( ConnectionFailureInfoConnectionFailureReasonReasonAccessDenied ConnectionFailureInfoConnectionFailureReason = 1 ConnectionFailureInfoConnectionFailureReasonReasonNasFailure ConnectionFailureInfoConnectionFailureReason = 2 ConnectionFailureInfoConnectionFailureReasonReasonRachFailure ConnectionFailureInfoConnectionFailureReason = 3 ConnectionFailureInfoConnectionFailureReasonReasonRlcFailure ConnectionFailureInfoConnectionFailureReason = 4 ConnectionFailureInfoConnectionFailureReasonReasonRrcReject ConnectionFailureInfoConnectionFailureReason = 5 ConnectionFailureInfoConnectionFailureReasonReasonRrcTimeout ConnectionFailureInfoConnectionFailureReason = 6 ConnectionFailureInfoConnectionFailureReasonReasonNoService ConnectionFailureInfoConnectionFailureReason = 7 ConnectionFailureInfoConnectionFailureReasonReasonPdnNotAvailable ConnectionFailureInfoConnectionFailureReason = 8 ConnectionFailureInfoConnectionFailureReasonReasonRfBusy ConnectionFailureInfoConnectionFailureReason = 9 ConnectionFailureInfoConnectionFailureReasonReasonUnspecified ConnectionFailureInfoConnectionFailureReason = 65535 )
type EpsFallbackReason ¶
type EpsFallbackReason int32
const ( EpsFallbackReasonNoNetworkTrigger EpsFallbackReason = 1 EpsFallbackReasonNoNetworkResponse EpsFallbackReason = 2 )
type IRadioIms ¶
type IRadioIms interface {
AsBinder() binder.IBinder
SetSrvccCallInfo(ctx context.Context, serial int32, srvccCalls []SrvccCall) error
UpdateImsRegistrationInfo(ctx context.Context, serial int32, imsRegistration ImsRegistration) error
StartImsTraffic(ctx context.Context, serial int32, token int32, imsTrafficType ImsTrafficType, accessNetworkType radio.AccessNetwork, trafficDirection ImsCallDirection) error
StopImsTraffic(ctx context.Context, serial int32, token int32) error
TriggerEpsFallback(ctx context.Context, serial int32, reason EpsFallbackReason) error
SetResponseFunctions(ctx context.Context, radioImsResponse IRadioImsResponse, radioImsIndication IRadioImsIndication) error
SendAnbrQuery(ctx context.Context, serial int32, mediaType ImsStreamType, direction ImsStreamDirection, bitsPerSecond int32) error
UpdateImsCallStatus(ctx context.Context, serial int32, imsCalls []ImsCall) error
}
func NewRadioImsStub ¶
func NewRadioImsStub( impl IRadioImsServer, ) IRadioIms
NewRadioImsStub creates a server-side IRadioIms wrapping the given server implementation. The returned value satisfies IRadioIms and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IRadioImsIndication ¶
type IRadioImsIndication interface {
AsBinder() binder.IBinder
OnConnectionSetupFailure(ctx context.Context, type_ radio.RadioIndicationType, token int32, info ConnectionFailureInfo) error
NotifyAnbr(ctx context.Context, type_ radio.RadioIndicationType, mediaType ImsStreamType, direction ImsStreamDirection, bitsPerSecond int32) error
TriggerImsDeregistration(ctx context.Context, type_ radio.RadioIndicationType, reason ImsDeregistrationReason) error
}
func NewRadioImsIndicationStub ¶
func NewRadioImsIndicationStub( impl IRadioImsIndicationServer, ) IRadioImsIndication
NewRadioImsIndicationStub creates a server-side IRadioImsIndication wrapping the given server implementation. The returned value satisfies IRadioImsIndication and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IRadioImsIndicationServer ¶
type IRadioImsIndicationServer interface {
OnConnectionSetupFailure(ctx context.Context, type_ radio.RadioIndicationType, token int32, info ConnectionFailureInfo) error
NotifyAnbr(ctx context.Context, type_ radio.RadioIndicationType, mediaType ImsStreamType, direction ImsStreamDirection, bitsPerSecond int32) error
TriggerImsDeregistration(ctx context.Context, type_ radio.RadioIndicationType, reason ImsDeregistrationReason) error
}
IRadioImsIndicationServer is the server-side interface that user implementations provide to NewRadioImsIndicationStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IRadioImsResponse ¶
type IRadioImsResponse interface {
AsBinder() binder.IBinder
SetSrvccCallInfoResponse(ctx context.Context, info radio.RadioResponseInfo) error
UpdateImsRegistrationInfoResponse(ctx context.Context, info radio.RadioResponseInfo) error
StartImsTrafficResponse(ctx context.Context, info radio.RadioResponseInfo, failureInfo *ConnectionFailureInfo) error
StopImsTrafficResponse(ctx context.Context, info radio.RadioResponseInfo) error
TriggerEpsFallbackResponse(ctx context.Context, info radio.RadioResponseInfo) error
SendAnbrQueryResponse(ctx context.Context, info radio.RadioResponseInfo) error
UpdateImsCallStatusResponse(ctx context.Context, info radio.RadioResponseInfo) error
}
func NewRadioImsResponseStub ¶
func NewRadioImsResponseStub( impl IRadioImsResponseServer, ) IRadioImsResponse
NewRadioImsResponseStub creates a server-side IRadioImsResponse wrapping the given server implementation. The returned value satisfies IRadioImsResponse and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IRadioImsResponseServer ¶
type IRadioImsResponseServer interface {
SetSrvccCallInfoResponse(ctx context.Context, info radio.RadioResponseInfo) error
UpdateImsRegistrationInfoResponse(ctx context.Context, info radio.RadioResponseInfo) error
StartImsTrafficResponse(ctx context.Context, info radio.RadioResponseInfo, failureInfo *ConnectionFailureInfo) error
StopImsTrafficResponse(ctx context.Context, info radio.RadioResponseInfo) error
TriggerEpsFallbackResponse(ctx context.Context, info radio.RadioResponseInfo) error
SendAnbrQueryResponse(ctx context.Context, info radio.RadioResponseInfo) error
UpdateImsCallStatusResponse(ctx context.Context, info radio.RadioResponseInfo) error
}
IRadioImsResponseServer is the server-side interface that user implementations provide to NewRadioImsResponseStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IRadioImsServer ¶
type IRadioImsServer interface {
SetSrvccCallInfo(ctx context.Context, serial int32, srvccCalls []SrvccCall) error
UpdateImsRegistrationInfo(ctx context.Context, serial int32, imsRegistration ImsRegistration) error
StartImsTraffic(ctx context.Context, serial int32, token int32, imsTrafficType ImsTrafficType, accessNetworkType radio.AccessNetwork, trafficDirection ImsCallDirection) error
StopImsTraffic(ctx context.Context, serial int32, token int32) error
TriggerEpsFallback(ctx context.Context, serial int32, reason EpsFallbackReason) error
SetResponseFunctions(ctx context.Context, radioImsResponse IRadioImsResponse, radioImsIndication IRadioImsIndication) error
SendAnbrQuery(ctx context.Context, serial int32, mediaType ImsStreamType, direction ImsStreamDirection, bitsPerSecond int32) error
UpdateImsCallStatus(ctx context.Context, serial int32, imsCalls []ImsCall) error
}
IRadioImsServer is the server-side interface that user implementations provide to NewRadioImsStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ImsCall ¶
type ImsCall struct {
Index int32
CallType ImsCallCallType
AccessNetwork radio.AccessNetwork
CallState ImsCallCallState
Direction ImsCallDirection
IsHeldByRemote bool
}
type ImsCallCallState ¶
type ImsCallCallState int32
const ( ImsCallCallStateACTIVE ImsCallCallState = 0 ImsCallCallStateHOLDING ImsCallCallState = 1 ImsCallCallStateDIALING ImsCallCallState = 2 ImsCallCallStateALERTING ImsCallCallState = 3 ImsCallCallStateINCOMING ImsCallCallState = 4 ImsCallCallStateWAITING ImsCallCallState = 5 ImsCallCallStateDISCONNECTING ImsCallCallState = 6 ImsCallCallStateDISCONNECTED ImsCallCallState = 7 )
type ImsCallCallType ¶
type ImsCallCallType int32
const ( ImsCallCallTypeNORMAL ImsCallCallType = 0 ImsCallCallTypeEMERGENCY ImsCallCallType = 1 )
type ImsCallDirection ¶
type ImsCallDirection int32
const ( ImsCallDirectionINCOMING ImsCallDirection = 0 ImsCallDirectionOUTGOING ImsCallDirection = 1 )
type ImsDeregistrationReason ¶
type ImsDeregistrationReason int32
const ( ImsDeregistrationReasonReasonSimRemoved ImsDeregistrationReason = 1 ImsDeregistrationReasonReasonSimRefresh ImsDeregistrationReason = 2 ImsDeregistrationReasonReasonAllowedNetworkTypesChanged ImsDeregistrationReason = 3 )
type ImsRegistration ¶
type ImsRegistration struct {
RegState ImsRegistrationState
AccessNetworkType radio.AccessNetwork
SuggestedAction SuggestedAction
Capabilities int32
}
func (*ImsRegistration) MarshalParcel ¶
func (s *ImsRegistration) MarshalParcel( p *parcel.Parcel, ) error
func (*ImsRegistration) UnmarshalParcel ¶
func (s *ImsRegistration) UnmarshalParcel( p *parcel.Parcel, ) error
type ImsRegistrationState ¶
type ImsRegistrationState int32
const ( ImsRegistrationStateNotRegistered ImsRegistrationState = 0 ImsRegistrationStateREGISTERED ImsRegistrationState = 1 )
type ImsStreamDirection ¶
type ImsStreamDirection int32
const ( ImsStreamDirectionUPLINK ImsStreamDirection = 1 ImsStreamDirectionDOWNLINK ImsStreamDirection = 2 )
type ImsStreamType ¶
type ImsStreamType int32
const ( ImsStreamTypeAUDIO ImsStreamType = 1 ImsStreamTypeVIDEO ImsStreamType = 2 )
type ImsTrafficType ¶
type ImsTrafficType int32
const ( ImsTrafficTypeEMERGENCY ImsTrafficType = 0 ImsTrafficTypeEmergencySms ImsTrafficType = 1 ImsTrafficTypeVOICE ImsTrafficType = 2 ImsTrafficTypeVIDEO ImsTrafficType = 3 ImsTrafficTypeSMS ImsTrafficType = 4 ImsTrafficTypeREGISTRATION ImsTrafficType = 5 ImsTrafficTypeUtXcap ImsTrafficType = 6 )
type RadioImsIndicationProxy ¶
func NewRadioImsIndicationProxy ¶
func NewRadioImsIndicationProxy( remote binder.IBinder, ) *RadioImsIndicationProxy
func (*RadioImsIndicationProxy) AsBinder ¶
func (p *RadioImsIndicationProxy) AsBinder() binder.IBinder
func (*RadioImsIndicationProxy) NotifyAnbr ¶
func (p *RadioImsIndicationProxy) NotifyAnbr( ctx context.Context, type_ radio.RadioIndicationType, mediaType ImsStreamType, direction ImsStreamDirection, bitsPerSecond int32, ) error
func (*RadioImsIndicationProxy) OnConnectionSetupFailure ¶
func (p *RadioImsIndicationProxy) OnConnectionSetupFailure( ctx context.Context, type_ radio.RadioIndicationType, token int32, info ConnectionFailureInfo, ) error
func (*RadioImsIndicationProxy) TriggerImsDeregistration ¶
func (p *RadioImsIndicationProxy) TriggerImsDeregistration( ctx context.Context, type_ radio.RadioIndicationType, reason ImsDeregistrationReason, ) error
type RadioImsIndicationStub ¶
type RadioImsIndicationStub struct {
Impl IRadioImsIndication
Transport binder.VersionAwareTransport
}
RadioImsIndicationStub dispatches incoming binder transactions to a typed IRadioImsIndication implementation.
func (*RadioImsIndicationStub) Descriptor ¶
func (s *RadioImsIndicationStub) Descriptor() string
func (*RadioImsIndicationStub) OnTransaction ¶
func (s *RadioImsIndicationStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type RadioImsProxy ¶
func NewRadioImsProxy ¶
func NewRadioImsProxy( remote binder.IBinder, ) *RadioImsProxy
func (*RadioImsProxy) AsBinder ¶
func (p *RadioImsProxy) AsBinder() binder.IBinder
func (*RadioImsProxy) SendAnbrQuery ¶
func (p *RadioImsProxy) SendAnbrQuery( ctx context.Context, serial int32, mediaType ImsStreamType, direction ImsStreamDirection, bitsPerSecond int32, ) error
func (*RadioImsProxy) SetResponseFunctions ¶
func (p *RadioImsProxy) SetResponseFunctions( ctx context.Context, radioImsResponse IRadioImsResponse, radioImsIndication IRadioImsIndication, ) error
func (*RadioImsProxy) SetSrvccCallInfo ¶
func (*RadioImsProxy) StartImsTraffic ¶
func (p *RadioImsProxy) StartImsTraffic( ctx context.Context, serial int32, token int32, imsTrafficType ImsTrafficType, accessNetworkType radio.AccessNetwork, trafficDirection ImsCallDirection, ) error
func (*RadioImsProxy) StopImsTraffic ¶
func (*RadioImsProxy) TriggerEpsFallback ¶
func (p *RadioImsProxy) TriggerEpsFallback( ctx context.Context, serial int32, reason EpsFallbackReason, ) error
func (*RadioImsProxy) UpdateImsCallStatus ¶
func (*RadioImsProxy) UpdateImsRegistrationInfo ¶
func (p *RadioImsProxy) UpdateImsRegistrationInfo( ctx context.Context, serial int32, imsRegistration ImsRegistration, ) error
type RadioImsResponseProxy ¶
func NewRadioImsResponseProxy ¶
func NewRadioImsResponseProxy( remote binder.IBinder, ) *RadioImsResponseProxy
func (*RadioImsResponseProxy) AsBinder ¶
func (p *RadioImsResponseProxy) AsBinder() binder.IBinder
func (*RadioImsResponseProxy) SendAnbrQueryResponse ¶
func (p *RadioImsResponseProxy) SendAnbrQueryResponse( ctx context.Context, info radio.RadioResponseInfo, ) error
func (*RadioImsResponseProxy) SetSrvccCallInfoResponse ¶
func (p *RadioImsResponseProxy) SetSrvccCallInfoResponse( ctx context.Context, info radio.RadioResponseInfo, ) error
func (*RadioImsResponseProxy) StartImsTrafficResponse ¶
func (p *RadioImsResponseProxy) StartImsTrafficResponse( ctx context.Context, info radio.RadioResponseInfo, failureInfo *ConnectionFailureInfo, ) error
func (*RadioImsResponseProxy) StopImsTrafficResponse ¶
func (p *RadioImsResponseProxy) StopImsTrafficResponse( ctx context.Context, info radio.RadioResponseInfo, ) error
func (*RadioImsResponseProxy) TriggerEpsFallbackResponse ¶
func (p *RadioImsResponseProxy) TriggerEpsFallbackResponse( ctx context.Context, info radio.RadioResponseInfo, ) error
func (*RadioImsResponseProxy) UpdateImsCallStatusResponse ¶
func (p *RadioImsResponseProxy) UpdateImsCallStatusResponse( ctx context.Context, info radio.RadioResponseInfo, ) error
func (*RadioImsResponseProxy) UpdateImsRegistrationInfoResponse ¶
func (p *RadioImsResponseProxy) UpdateImsRegistrationInfoResponse( ctx context.Context, info radio.RadioResponseInfo, ) error
type RadioImsResponseStub ¶
type RadioImsResponseStub struct {
Impl IRadioImsResponse
Transport binder.VersionAwareTransport
}
RadioImsResponseStub dispatches incoming binder transactions to a typed IRadioImsResponse implementation.
func (*RadioImsResponseStub) Descriptor ¶
func (s *RadioImsResponseStub) Descriptor() string
func (*RadioImsResponseStub) OnTransaction ¶
func (s *RadioImsResponseStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type RadioImsStub ¶
type RadioImsStub struct {
Impl IRadioIms
Transport binder.VersionAwareTransport
}
RadioImsStub dispatches incoming binder transactions to a typed IRadioIms implementation.
func (*RadioImsStub) Descriptor ¶
func (s *RadioImsStub) Descriptor() string
func (*RadioImsStub) OnTransaction ¶
func (s *RadioImsStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type SrvccCall ¶
type SrvccCall struct {
Index int32
CallType SrvccCallCallType
CallState int32
CallSubstate SrvccCallCallSubState
RingbackToneType SrvccCallToneType
IsMpty bool
IsMT bool
Number string
NumPresentation int32
Name string
NamePresentation int32
}
type SrvccCallCallSubState ¶
type SrvccCallCallSubState int32
const ( SrvccCallCallSubStateNONE SrvccCallCallSubState = 0 SrvccCallCallSubStatePREALERTING SrvccCallCallSubState = 1 )
type SrvccCallCallType ¶
type SrvccCallCallType int32
const ( SrvccCallCallTypeNORMAL SrvccCallCallType = 0 SrvccCallCallTypeEMERGENCY SrvccCallCallType = 1 )
type SrvccCallToneType ¶
type SrvccCallToneType int32
const ( SrvccCallToneTypeNONE SrvccCallToneType = 0 SrvccCallToneTypeLOCAL SrvccCallToneType = 1 SrvccCallToneTypeNETWORK SrvccCallToneType = 2 )
type SuggestedAction ¶
type SuggestedAction int32
const ( SuggestedActionNONE SuggestedAction = 0 SuggestedActionTriggerPlmnBlock SuggestedAction = 1 SuggestedActionTriggerPlmnBlockWithTimeout SuggestedAction = 2 SuggestedActionTriggerRatBlock SuggestedAction = 3 SuggestedActionTriggerClearRatBlocks SuggestedAction = 4 )
Source Files
¶
- connectionfailureinfo.connectionfailurereason.go
- connectionfailureinfo.go
- epsfallbackreason.go
- imscall.callstate.go
- imscall.calltype.go
- imscall.direction.go
- imscall.go
- imsderegistrationreason.go
- imsregistration.go
- imsregistrationstate.go
- imsstreamdirection.go
- imsstreamtype.go
- imstraffictype.go
- iradioims.go
- iradioimsindication.go
- iradioimsresponse.go
- srvcccall.callsubstate.go
- srvcccall.calltype.go
- srvcccall.go
- srvcccall.tonetype.go
- suggestedaction.go