Documentation
¶
Index ¶
- Constants
- type ActivityStatsInfo
- type ActivityStatsTechSpecificInfo
- type DeviceStateType
- type HardwareConfig
- type HardwareConfigModem
- type HardwareConfigSim
- type IRadioModem
- type IRadioModemIndication
- type IRadioModemIndicationServer
- type IRadioModemResponse
- type IRadioModemResponseServer
- type IRadioModemServer
- type ImeiInfo
- type ImeiInfoImeiType
- type NvItem
- type NvWriteItem
- type RadioCapability
- type RadioModemIndicationProxy
- func (p *RadioModemIndicationProxy) AsBinder() binder.IBinder
- func (p *RadioModemIndicationProxy) HardwareConfigChanged(ctx context.Context, type_ radio.RadioIndicationType, configs []HardwareConfig) error
- func (p *RadioModemIndicationProxy) ModemReset(ctx context.Context, type_ radio.RadioIndicationType, reason string) error
- func (p *RadioModemIndicationProxy) OnImeiMappingChanged(ctx context.Context, type_ radio.RadioIndicationType, imeiInfo ImeiInfo) error
- func (p *RadioModemIndicationProxy) RadioCapabilityIndication(ctx context.Context, type_ radio.RadioIndicationType, rc RadioCapability) error
- func (p *RadioModemIndicationProxy) RadioStateChanged(ctx context.Context, type_ radio.RadioIndicationType, radioState RadioState) error
- func (p *RadioModemIndicationProxy) RilConnected(ctx context.Context, type_ radio.RadioIndicationType) error
- type RadioModemIndicationStub
- type RadioModemProxy
- func (p *RadioModemProxy) AsBinder() binder.IBinder
- func (p *RadioModemProxy) EnableModem(ctx context.Context, serial int32, on bool) error
- func (p *RadioModemProxy) GetBasebandVersion(ctx context.Context, serial int32) error
- func (p *RadioModemProxy) GetDeviceIdentity(ctx context.Context, serial int32) error
- func (p *RadioModemProxy) GetHardwareConfig(ctx context.Context, serial int32) error
- func (p *RadioModemProxy) GetImei(ctx context.Context, serial int32) error
- func (p *RadioModemProxy) GetModemActivityInfo(ctx context.Context, serial int32) error
- func (p *RadioModemProxy) GetModemStackStatus(ctx context.Context, serial int32) error
- func (p *RadioModemProxy) GetRadioCapability(ctx context.Context, serial int32) error
- func (p *RadioModemProxy) NvReadItem(ctx context.Context, serial int32, itemId NvItem) error
- func (p *RadioModemProxy) NvResetConfig(ctx context.Context, serial int32, resetType ResetNvType) error
- func (p *RadioModemProxy) NvWriteCdmaPrl(ctx context.Context, serial int32, prl []byte) error
- func (p *RadioModemProxy) NvWriteItem(ctx context.Context, serial int32, item NvWriteItem) error
- func (p *RadioModemProxy) RequestShutdown(ctx context.Context, serial int32) error
- func (p *RadioModemProxy) ResponseAcknowledgement(ctx context.Context) error
- func (p *RadioModemProxy) SendDeviceState(ctx context.Context, serial int32, deviceStateType DeviceStateType, state bool) error
- func (p *RadioModemProxy) SetRadioCapability(ctx context.Context, serial int32, rc RadioCapability) error
- func (p *RadioModemProxy) SetRadioPower(ctx context.Context, serial int32, powerOn bool, forEmergencyCall bool, ...) error
- func (p *RadioModemProxy) SetResponseFunctions(ctx context.Context, radioModemResponse IRadioModemResponse, ...) error
- type RadioModemResponseProxy
- func (p *RadioModemResponseProxy) AcknowledgeRequest(ctx context.Context, serial int32) error
- func (p *RadioModemResponseProxy) AsBinder() binder.IBinder
- func (p *RadioModemResponseProxy) EnableModemResponse(ctx context.Context, info radio.RadioResponseInfo) error
- func (p *RadioModemResponseProxy) GetBasebandVersionResponse(ctx context.Context, info radio.RadioResponseInfo, version string) error
- func (p *RadioModemResponseProxy) GetDeviceIdentityResponse(ctx context.Context, info radio.RadioResponseInfo, imei string, imeisv string, ...) error
- func (p *RadioModemResponseProxy) GetHardwareConfigResponse(ctx context.Context, info radio.RadioResponseInfo, config []HardwareConfig) error
- func (p *RadioModemResponseProxy) GetImeiResponse(ctx context.Context, responseInfo radio.RadioResponseInfo, imeiInfo *ImeiInfo) error
- func (p *RadioModemResponseProxy) GetModemActivityInfoResponse(ctx context.Context, info radio.RadioResponseInfo, ...) error
- func (p *RadioModemResponseProxy) GetModemStackStatusResponse(ctx context.Context, info radio.RadioResponseInfo, isEnabled bool) error
- func (p *RadioModemResponseProxy) GetRadioCapabilityResponse(ctx context.Context, info radio.RadioResponseInfo, rc RadioCapability) error
- func (p *RadioModemResponseProxy) NvReadItemResponse(ctx context.Context, info radio.RadioResponseInfo, result string) error
- func (p *RadioModemResponseProxy) NvResetConfigResponse(ctx context.Context, info radio.RadioResponseInfo) error
- func (p *RadioModemResponseProxy) NvWriteCdmaPrlResponse(ctx context.Context, info radio.RadioResponseInfo) error
- func (p *RadioModemResponseProxy) NvWriteItemResponse(ctx context.Context, info radio.RadioResponseInfo) error
- func (p *RadioModemResponseProxy) RequestShutdownResponse(ctx context.Context, info radio.RadioResponseInfo) error
- func (p *RadioModemResponseProxy) SendDeviceStateResponse(ctx context.Context, info radio.RadioResponseInfo) error
- func (p *RadioModemResponseProxy) SetRadioCapabilityResponse(ctx context.Context, info radio.RadioResponseInfo, rc RadioCapability) error
- func (p *RadioModemResponseProxy) SetRadioPowerResponse(ctx context.Context, info radio.RadioResponseInfo) error
- type RadioModemResponseStub
- type RadioModemStub
- type RadioState
- type ResetNvType
Constants ¶
const ( ActivityStatsTechSpecificInfoFrequencyRangeUnknown int32 = 0 ActivityStatsTechSpecificInfoFrequencyRangeLow int32 = 1 ActivityStatsTechSpecificInfoFrequencyRangeMid int32 = 2 ActivityStatsTechSpecificInfoFrequencyRangeHigh int32 = 3 ActivityStatsTechSpecificInfoFrequencyRangeMmwave int32 = 4 )
const ( HardwareConfigStateEnabled int32 = 0 HardwareConfigStateStandby int32 = 1 HardwareConfigStateDisabled int32 = 2 HardwareConfigTypeModem int32 = 0 HardwareConfigTypeSim int32 = 1 )
const ( TransactionIRadioModemEnableModem = binder.FirstCallTransaction + 0 TransactionIRadioModemGetBasebandVersion = binder.FirstCallTransaction + 1 TransactionIRadioModemGetDeviceIdentity = binder.FirstCallTransaction + 2 TransactionIRadioModemGetHardwareConfig = binder.FirstCallTransaction + 3 TransactionIRadioModemGetModemActivityInfo = binder.FirstCallTransaction + 4 TransactionIRadioModemGetModemStackStatus = binder.FirstCallTransaction + 5 TransactionIRadioModemGetRadioCapability = binder.FirstCallTransaction + 6 TransactionIRadioModemNvReadItem = binder.FirstCallTransaction + 7 TransactionIRadioModemNvResetConfig = binder.FirstCallTransaction + 8 TransactionIRadioModemNvWriteCdmaPrl = binder.FirstCallTransaction + 9 TransactionIRadioModemNvWriteItem = binder.FirstCallTransaction + 10 TransactionIRadioModemRequestShutdown = binder.FirstCallTransaction + 11 TransactionIRadioModemResponseAcknowledgement = binder.FirstCallTransaction + 12 TransactionIRadioModemSendDeviceState = binder.FirstCallTransaction + 13 TransactionIRadioModemSetRadioCapability = binder.FirstCallTransaction + 14 TransactionIRadioModemSetRadioPower = binder.FirstCallTransaction + 15 TransactionIRadioModemSetResponseFunctions = binder.FirstCallTransaction + 16 TransactionIRadioModemGetImei = binder.FirstCallTransaction + 17 )
const ( MethodIRadioModemEnableModem = "enableModem" MethodIRadioModemGetBasebandVersion = "getBasebandVersion" MethodIRadioModemGetDeviceIdentity = "getDeviceIdentity" MethodIRadioModemGetHardwareConfig = "getHardwareConfig" MethodIRadioModemGetModemActivityInfo = "getModemActivityInfo" MethodIRadioModemGetModemStackStatus = "getModemStackStatus" MethodIRadioModemGetRadioCapability = "getRadioCapability" MethodIRadioModemNvReadItem = "nvReadItem" MethodIRadioModemNvResetConfig = "nvResetConfig" MethodIRadioModemNvWriteCdmaPrl = "nvWriteCdmaPrl" MethodIRadioModemNvWriteItem = "nvWriteItem" MethodIRadioModemRequestShutdown = "requestShutdown" MethodIRadioModemResponseAcknowledgement = "responseAcknowledgement" MethodIRadioModemSendDeviceState = "sendDeviceState" MethodIRadioModemSetRadioCapability = "setRadioCapability" MethodIRadioModemSetRadioPower = "setRadioPower" MethodIRadioModemSetResponseFunctions = "setResponseFunctions" MethodIRadioModemGetImei = "getImei" )
const ( TransactionIRadioModemIndicationHardwareConfigChanged = binder.FirstCallTransaction + 0 TransactionIRadioModemIndicationModemReset = binder.FirstCallTransaction + 1 TransactionIRadioModemIndicationRadioCapabilityIndication = binder.FirstCallTransaction + 2 TransactionIRadioModemIndicationRadioStateChanged = binder.FirstCallTransaction + 3 TransactionIRadioModemIndicationRilConnected = binder.FirstCallTransaction + 4 TransactionIRadioModemIndicationOnImeiMappingChanged = binder.FirstCallTransaction + 5 )
const ( MethodIRadioModemIndicationHardwareConfigChanged = "hardwareConfigChanged" MethodIRadioModemIndicationModemReset = "modemReset" MethodIRadioModemIndicationRadioCapabilityIndication = "radioCapabilityIndication" MethodIRadioModemIndicationRadioStateChanged = "radioStateChanged" MethodIRadioModemIndicationRilConnected = "rilConnected" MethodIRadioModemIndicationOnImeiMappingChanged = "onImeiMappingChanged" )
const ( TransactionIRadioModemResponseAcknowledgeRequest = binder.FirstCallTransaction + 0 TransactionIRadioModemResponseEnableModemResponse = binder.FirstCallTransaction + 1 TransactionIRadioModemResponseGetBasebandVersionResponse = binder.FirstCallTransaction + 2 TransactionIRadioModemResponseGetDeviceIdentityResponse = binder.FirstCallTransaction + 3 TransactionIRadioModemResponseGetHardwareConfigResponse = binder.FirstCallTransaction + 4 TransactionIRadioModemResponseGetModemActivityInfoResponse = binder.FirstCallTransaction + 5 TransactionIRadioModemResponseGetModemStackStatusResponse = binder.FirstCallTransaction + 6 TransactionIRadioModemResponseGetRadioCapabilityResponse = binder.FirstCallTransaction + 7 TransactionIRadioModemResponseNvReadItemResponse = binder.FirstCallTransaction + 8 TransactionIRadioModemResponseNvResetConfigResponse = binder.FirstCallTransaction + 9 TransactionIRadioModemResponseNvWriteCdmaPrlResponse = binder.FirstCallTransaction + 10 TransactionIRadioModemResponseNvWriteItemResponse = binder.FirstCallTransaction + 11 TransactionIRadioModemResponseRequestShutdownResponse = binder.FirstCallTransaction + 12 TransactionIRadioModemResponseSendDeviceStateResponse = binder.FirstCallTransaction + 13 TransactionIRadioModemResponseSetRadioCapabilityResponse = binder.FirstCallTransaction + 14 TransactionIRadioModemResponseSetRadioPowerResponse = binder.FirstCallTransaction + 15 TransactionIRadioModemResponseGetImeiResponse = binder.FirstCallTransaction + 16 )
const ( MethodIRadioModemResponseAcknowledgeRequest = "acknowledgeRequest" MethodIRadioModemResponseEnableModemResponse = "enableModemResponse" MethodIRadioModemResponseGetBasebandVersionResponse = "getBasebandVersionResponse" MethodIRadioModemResponseGetDeviceIdentityResponse = "getDeviceIdentityResponse" MethodIRadioModemResponseGetHardwareConfigResponse = "getHardwareConfigResponse" MethodIRadioModemResponseGetModemActivityInfoResponse = "getModemActivityInfoResponse" MethodIRadioModemResponseGetModemStackStatusResponse = "getModemStackStatusResponse" MethodIRadioModemResponseGetRadioCapabilityResponse = "getRadioCapabilityResponse" MethodIRadioModemResponseNvReadItemResponse = "nvReadItemResponse" MethodIRadioModemResponseNvResetConfigResponse = "nvResetConfigResponse" MethodIRadioModemResponseNvWriteCdmaPrlResponse = "nvWriteCdmaPrlResponse" MethodIRadioModemResponseNvWriteItemResponse = "nvWriteItemResponse" MethodIRadioModemResponseRequestShutdownResponse = "requestShutdownResponse" MethodIRadioModemResponseSendDeviceStateResponse = "sendDeviceStateResponse" MethodIRadioModemResponseSetRadioCapabilityResponse = "setRadioCapabilityResponse" MethodIRadioModemResponseSetRadioPowerResponse = "setRadioPowerResponse" MethodIRadioModemResponseGetImeiResponse = "getImeiResponse" )
const ( RadioCapabilityPhaseConfigured int32 = 0 RadioCapabilityPhaseStart int32 = 1 RadioCapabilityPhaseApply int32 = 2 RadioCapabilityPhaseUnsolRsp int32 = 3 RadioCapabilityPhaseFinish int32 = 4 RadioCapabilityStatusNone int32 = 0 RadioCapabilityStatusSuccess int32 = 1 RadioCapabilityStatusFail int32 = 2 )
const DescriptorIRadioModem = "android.hardware.radio.modem.IRadioModem"
const DescriptorIRadioModemIndication = "android.hardware.radio.modem.IRadioModemIndication"
const DescriptorIRadioModemResponse = "android.hardware.radio.modem.IRadioModemResponse"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ActivityStatsInfo ¶
type ActivityStatsInfo struct {
SleepModeTimeMs int32
IdleModeTimeMs int32
TechSpecificInfo []ActivityStatsTechSpecificInfo
}
func (*ActivityStatsInfo) MarshalParcel ¶
func (s *ActivityStatsInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*ActivityStatsInfo) UnmarshalParcel ¶
func (s *ActivityStatsInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type ActivityStatsTechSpecificInfo ¶
type ActivityStatsTechSpecificInfo struct {
Rat radio.AccessNetwork
FrequencyRange int32
TxmModetimeMs []int32
RxModeTimeMs int32
}
func (*ActivityStatsTechSpecificInfo) MarshalParcel ¶
func (s *ActivityStatsTechSpecificInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*ActivityStatsTechSpecificInfo) UnmarshalParcel ¶
func (s *ActivityStatsTechSpecificInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type DeviceStateType ¶
type DeviceStateType int32
const ( DeviceStateTypePowerSaveMode DeviceStateType = 0 DeviceStateTypeChargingState DeviceStateType = 1 DeviceStateTypeLowDataExpected DeviceStateType = 2 )
type HardwareConfig ¶
type HardwareConfig struct {
Type int32
Uuid string
State int32
Modem []HardwareConfigModem
Sim []HardwareConfigSim
}
func (*HardwareConfig) MarshalParcel ¶
func (s *HardwareConfig) MarshalParcel( p *parcel.Parcel, ) error
func (*HardwareConfig) UnmarshalParcel ¶
func (s *HardwareConfig) UnmarshalParcel( p *parcel.Parcel, ) error
type HardwareConfigModem ¶
type HardwareConfigModem struct {
RilModel int32
Rat radio.RadioTechnology
MaxVoiceCalls int32
MaxDataCalls int32
MaxStandby int32
}
func (*HardwareConfigModem) MarshalParcel ¶
func (s *HardwareConfigModem) MarshalParcel( p *parcel.Parcel, ) error
func (*HardwareConfigModem) UnmarshalParcel ¶
func (s *HardwareConfigModem) UnmarshalParcel( p *parcel.Parcel, ) error
type HardwareConfigSim ¶
type HardwareConfigSim struct {
ModemUuid string
}
func (*HardwareConfigSim) MarshalParcel ¶
func (s *HardwareConfigSim) MarshalParcel( p *parcel.Parcel, ) error
func (*HardwareConfigSim) UnmarshalParcel ¶
func (s *HardwareConfigSim) UnmarshalParcel( p *parcel.Parcel, ) error
type IRadioModem ¶
type IRadioModem interface {
AsBinder() binder.IBinder
EnableModem(ctx context.Context, serial int32, on bool) error
GetBasebandVersion(ctx context.Context, serial int32) error
GetDeviceIdentity(ctx context.Context, serial int32) error
GetHardwareConfig(ctx context.Context, serial int32) error
GetModemActivityInfo(ctx context.Context, serial int32) error
GetModemStackStatus(ctx context.Context, serial int32) error
GetRadioCapability(ctx context.Context, serial int32) error
NvReadItem(ctx context.Context, serial int32, itemId NvItem) error
NvResetConfig(ctx context.Context, serial int32, resetType ResetNvType) error
NvWriteCdmaPrl(ctx context.Context, serial int32, prl []byte) error
NvWriteItem(ctx context.Context, serial int32, item NvWriteItem) error
RequestShutdown(ctx context.Context, serial int32) error
ResponseAcknowledgement(ctx context.Context) error
SendDeviceState(ctx context.Context, serial int32, deviceStateType DeviceStateType, state bool) error
SetRadioCapability(ctx context.Context, serial int32, rc RadioCapability) error
SetRadioPower(ctx context.Context, serial int32, powerOn bool, forEmergencyCall bool, preferredForEmergencyCall bool) error
SetResponseFunctions(ctx context.Context, radioModemResponse IRadioModemResponse, radioModemIndication IRadioModemIndication) error
GetImei(ctx context.Context, serial int32) error
}
func NewRadioModemStub ¶
func NewRadioModemStub( impl IRadioModemServer, ) IRadioModem
NewRadioModemStub creates a server-side IRadioModem wrapping the given server implementation. The returned value satisfies IRadioModem and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IRadioModemIndication ¶
type IRadioModemIndication interface {
AsBinder() binder.IBinder
HardwareConfigChanged(ctx context.Context, type_ radio.RadioIndicationType, configs []HardwareConfig) error
ModemReset(ctx context.Context, type_ radio.RadioIndicationType, reason string) error
RadioCapabilityIndication(ctx context.Context, type_ radio.RadioIndicationType, rc RadioCapability) error
RadioStateChanged(ctx context.Context, type_ radio.RadioIndicationType, radioState RadioState) error
RilConnected(ctx context.Context, type_ radio.RadioIndicationType) error
OnImeiMappingChanged(ctx context.Context, type_ radio.RadioIndicationType, imeiInfo ImeiInfo) error
}
func NewRadioModemIndicationStub ¶
func NewRadioModemIndicationStub( impl IRadioModemIndicationServer, ) IRadioModemIndication
NewRadioModemIndicationStub creates a server-side IRadioModemIndication wrapping the given server implementation. The returned value satisfies IRadioModemIndication and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IRadioModemIndicationServer ¶
type IRadioModemIndicationServer interface {
HardwareConfigChanged(ctx context.Context, type_ radio.RadioIndicationType, configs []HardwareConfig) error
ModemReset(ctx context.Context, type_ radio.RadioIndicationType, reason string) error
RadioCapabilityIndication(ctx context.Context, type_ radio.RadioIndicationType, rc RadioCapability) error
RadioStateChanged(ctx context.Context, type_ radio.RadioIndicationType, radioState RadioState) error
RilConnected(ctx context.Context, type_ radio.RadioIndicationType) error
OnImeiMappingChanged(ctx context.Context, type_ radio.RadioIndicationType, imeiInfo ImeiInfo) error
}
IRadioModemIndicationServer is the server-side interface that user implementations provide to NewRadioModemIndicationStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IRadioModemResponse ¶
type IRadioModemResponse interface {
AsBinder() binder.IBinder
AcknowledgeRequest(ctx context.Context, serial int32) error
EnableModemResponse(ctx context.Context, info radio.RadioResponseInfo) error
GetBasebandVersionResponse(ctx context.Context, info radio.RadioResponseInfo, version string) error
GetDeviceIdentityResponse(ctx context.Context, info radio.RadioResponseInfo, imei string, imeisv string, esn string, meid string) error
GetHardwareConfigResponse(ctx context.Context, info radio.RadioResponseInfo, config []HardwareConfig) error
GetModemActivityInfoResponse(ctx context.Context, info radio.RadioResponseInfo, activityInfo ActivityStatsInfo) error
GetModemStackStatusResponse(ctx context.Context, info radio.RadioResponseInfo, isEnabled bool) error
GetRadioCapabilityResponse(ctx context.Context, info radio.RadioResponseInfo, rc RadioCapability) error
NvReadItemResponse(ctx context.Context, info radio.RadioResponseInfo, result string) error
NvResetConfigResponse(ctx context.Context, info radio.RadioResponseInfo) error
NvWriteCdmaPrlResponse(ctx context.Context, info radio.RadioResponseInfo) error
NvWriteItemResponse(ctx context.Context, info radio.RadioResponseInfo) error
RequestShutdownResponse(ctx context.Context, info radio.RadioResponseInfo) error
SendDeviceStateResponse(ctx context.Context, info radio.RadioResponseInfo) error
SetRadioCapabilityResponse(ctx context.Context, info radio.RadioResponseInfo, rc RadioCapability) error
SetRadioPowerResponse(ctx context.Context, info radio.RadioResponseInfo) error
GetImeiResponse(ctx context.Context, responseInfo radio.RadioResponseInfo, imeiInfo *ImeiInfo) error
}
func NewRadioModemResponseStub ¶
func NewRadioModemResponseStub( impl IRadioModemResponseServer, ) IRadioModemResponse
NewRadioModemResponseStub creates a server-side IRadioModemResponse wrapping the given server implementation. The returned value satisfies IRadioModemResponse and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IRadioModemResponseServer ¶
type IRadioModemResponseServer interface {
AcknowledgeRequest(ctx context.Context, serial int32) error
EnableModemResponse(ctx context.Context, info radio.RadioResponseInfo) error
GetBasebandVersionResponse(ctx context.Context, info radio.RadioResponseInfo, version string) error
GetDeviceIdentityResponse(ctx context.Context, info radio.RadioResponseInfo, imei string, imeisv string, esn string, meid string) error
GetHardwareConfigResponse(ctx context.Context, info radio.RadioResponseInfo, config []HardwareConfig) error
GetModemActivityInfoResponse(ctx context.Context, info radio.RadioResponseInfo, activityInfo ActivityStatsInfo) error
GetModemStackStatusResponse(ctx context.Context, info radio.RadioResponseInfo, isEnabled bool) error
GetRadioCapabilityResponse(ctx context.Context, info radio.RadioResponseInfo, rc RadioCapability) error
NvReadItemResponse(ctx context.Context, info radio.RadioResponseInfo, result string) error
NvResetConfigResponse(ctx context.Context, info radio.RadioResponseInfo) error
NvWriteCdmaPrlResponse(ctx context.Context, info radio.RadioResponseInfo) error
NvWriteItemResponse(ctx context.Context, info radio.RadioResponseInfo) error
RequestShutdownResponse(ctx context.Context, info radio.RadioResponseInfo) error
SendDeviceStateResponse(ctx context.Context, info radio.RadioResponseInfo) error
SetRadioCapabilityResponse(ctx context.Context, info radio.RadioResponseInfo, rc RadioCapability) error
SetRadioPowerResponse(ctx context.Context, info radio.RadioResponseInfo) error
GetImeiResponse(ctx context.Context, responseInfo radio.RadioResponseInfo, imeiInfo *ImeiInfo) error
}
IRadioModemResponseServer is the server-side interface that user implementations provide to NewRadioModemResponseStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IRadioModemServer ¶
type IRadioModemServer interface {
EnableModem(ctx context.Context, serial int32, on bool) error
GetBasebandVersion(ctx context.Context, serial int32) error
GetDeviceIdentity(ctx context.Context, serial int32) error
GetHardwareConfig(ctx context.Context, serial int32) error
GetModemActivityInfo(ctx context.Context, serial int32) error
GetModemStackStatus(ctx context.Context, serial int32) error
GetRadioCapability(ctx context.Context, serial int32) error
NvReadItem(ctx context.Context, serial int32, itemId NvItem) error
NvResetConfig(ctx context.Context, serial int32, resetType ResetNvType) error
NvWriteCdmaPrl(ctx context.Context, serial int32, prl []byte) error
NvWriteItem(ctx context.Context, serial int32, item NvWriteItem) error
RequestShutdown(ctx context.Context, serial int32) error
ResponseAcknowledgement(ctx context.Context) error
SendDeviceState(ctx context.Context, serial int32, deviceStateType DeviceStateType, state bool) error
SetRadioCapability(ctx context.Context, serial int32, rc RadioCapability) error
SetRadioPower(ctx context.Context, serial int32, powerOn bool, forEmergencyCall bool, preferredForEmergencyCall bool) error
SetResponseFunctions(ctx context.Context, radioModemResponse IRadioModemResponse, radioModemIndication IRadioModemIndication) error
GetImei(ctx context.Context, serial int32) error
}
IRadioModemServer is the server-side interface that user implementations provide to NewRadioModemStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ImeiInfo ¶
type ImeiInfo struct {
Type ImeiInfoImeiType
Imei string
Svn string
}
type ImeiInfoImeiType ¶
type ImeiInfoImeiType int32
const ( ImeiInfoImeiTypePRIMARY ImeiInfoImeiType = 1 ImeiInfoImeiTypeSECONDARY ImeiInfoImeiType = 2 )
type NvItem ¶
type NvItem int32
const ( NvItemCdmaMeid NvItem = 1 NvItemCdmaMin NvItem = 2 NvItemCdmaMdn NvItem = 3 NvItemCdmaAccolc NvItem = 4 NvItemDeviceMsl NvItem = 11 NvItemRtnReconditionedStatus NvItem = 12 NvItemRtnActivationDate NvItem = 13 NvItemRtnLifeTimer NvItem = 14 NvItemRtnLifeCalls NvItem = 15 NvItemRtnLifeDataTx NvItem = 16 NvItemRtnLifeDataRx NvItem = 17 NvItemOmadmHfaLevel NvItem = 18 NvItemMipProfileNai NvItem = 31 NvItemMipProfileHomeAddress NvItem = 32 NvItemMipProfileAaaAuth NvItem = 33 NvItemMipProfileHaAuth NvItem = 34 NvItemMipProfilePriHaAddr NvItem = 35 NvItemMipProfileSecHaAddr NvItem = 36 NvItemMipProfileRevTunPref NvItem = 37 NvItemMipProfileHaSpi NvItem = 38 NvItemMipProfileAaaSpi NvItem = 39 NvItemMipProfileMnHaSs NvItem = 40 NvItemMipProfileMnAaaSs NvItem = 41 NvItemCdmaPrlVersion NvItem = 51 NvItemCdmaBc10 NvItem = 52 NvItemCdmaBc14 NvItem = 53 NvItemCdmaSo68 NvItem = 54 NvItemCdmaSo73Cop0 NvItem = 55 NvItemCdmaSo73Cop1to7 NvItem = 56 NvItemCdma1xAdvancedEnabled NvItem = 57 NvItemCdmaEhrpdEnabled NvItem = 58 NvItemCdmaEhrpdForced NvItem = 59 NvItemLteBandEnable25 NvItem = 71 NvItemLteBandEnable26 NvItem = 72 NvItemLteBandEnable41 NvItem = 73 NvItemLteScanPriority25 NvItem = 74 NvItemLteScanPriority26 NvItem = 75 NvItemLteScanPriority41 NvItem = 76 NvItemLteHiddenBandPriority25 NvItem = 77 NvItemLteHiddenBandPriority26 NvItem = 78 NvItemLteHiddenBandPriority41 NvItem = 79 )
type NvWriteItem ¶
func (*NvWriteItem) MarshalParcel ¶
func (s *NvWriteItem) MarshalParcel( p *parcel.Parcel, ) error
func (*NvWriteItem) UnmarshalParcel ¶
func (s *NvWriteItem) UnmarshalParcel( p *parcel.Parcel, ) error
type RadioCapability ¶
type RadioCapability struct {
Session int32
Phase int32
Raf int32
LogicalModemUuid string
Status int32
}
func (*RadioCapability) MarshalParcel ¶
func (s *RadioCapability) MarshalParcel( p *parcel.Parcel, ) error
func (*RadioCapability) UnmarshalParcel ¶
func (s *RadioCapability) UnmarshalParcel( p *parcel.Parcel, ) error
type RadioModemIndicationProxy ¶
func NewRadioModemIndicationProxy ¶
func NewRadioModemIndicationProxy( remote binder.IBinder, ) *RadioModemIndicationProxy
func (*RadioModemIndicationProxy) AsBinder ¶
func (p *RadioModemIndicationProxy) AsBinder() binder.IBinder
func (*RadioModemIndicationProxy) HardwareConfigChanged ¶
func (p *RadioModemIndicationProxy) HardwareConfigChanged( ctx context.Context, type_ radio.RadioIndicationType, configs []HardwareConfig, ) error
func (*RadioModemIndicationProxy) ModemReset ¶
func (p *RadioModemIndicationProxy) ModemReset( ctx context.Context, type_ radio.RadioIndicationType, reason string, ) error
func (*RadioModemIndicationProxy) OnImeiMappingChanged ¶
func (p *RadioModemIndicationProxy) OnImeiMappingChanged( ctx context.Context, type_ radio.RadioIndicationType, imeiInfo ImeiInfo, ) error
func (*RadioModemIndicationProxy) RadioCapabilityIndication ¶
func (p *RadioModemIndicationProxy) RadioCapabilityIndication( ctx context.Context, type_ radio.RadioIndicationType, rc RadioCapability, ) error
func (*RadioModemIndicationProxy) RadioStateChanged ¶
func (p *RadioModemIndicationProxy) RadioStateChanged( ctx context.Context, type_ radio.RadioIndicationType, radioState RadioState, ) error
func (*RadioModemIndicationProxy) RilConnected ¶
func (p *RadioModemIndicationProxy) RilConnected( ctx context.Context, type_ radio.RadioIndicationType, ) error
type RadioModemIndicationStub ¶
type RadioModemIndicationStub struct {
Impl IRadioModemIndication
Transport binder.VersionAwareTransport
}
RadioModemIndicationStub dispatches incoming binder transactions to a typed IRadioModemIndication implementation.
func (*RadioModemIndicationStub) Descriptor ¶
func (s *RadioModemIndicationStub) Descriptor() string
func (*RadioModemIndicationStub) OnTransaction ¶
func (s *RadioModemIndicationStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type RadioModemProxy ¶
func NewRadioModemProxy ¶
func NewRadioModemProxy( remote binder.IBinder, ) *RadioModemProxy
func (*RadioModemProxy) AsBinder ¶
func (p *RadioModemProxy) AsBinder() binder.IBinder
func (*RadioModemProxy) EnableModem ¶
func (*RadioModemProxy) GetBasebandVersion ¶
func (p *RadioModemProxy) GetBasebandVersion( ctx context.Context, serial int32, ) error
func (*RadioModemProxy) GetDeviceIdentity ¶
func (p *RadioModemProxy) GetDeviceIdentity( ctx context.Context, serial int32, ) error
func (*RadioModemProxy) GetHardwareConfig ¶
func (p *RadioModemProxy) GetHardwareConfig( ctx context.Context, serial int32, ) error
func (*RadioModemProxy) GetImei ¶
func (p *RadioModemProxy) GetImei( ctx context.Context, serial int32, ) error
func (*RadioModemProxy) GetModemActivityInfo ¶
func (p *RadioModemProxy) GetModemActivityInfo( ctx context.Context, serial int32, ) error
func (*RadioModemProxy) GetModemStackStatus ¶
func (p *RadioModemProxy) GetModemStackStatus( ctx context.Context, serial int32, ) error
func (*RadioModemProxy) GetRadioCapability ¶
func (p *RadioModemProxy) GetRadioCapability( ctx context.Context, serial int32, ) error
func (*RadioModemProxy) NvReadItem ¶
func (*RadioModemProxy) NvResetConfig ¶
func (p *RadioModemProxy) NvResetConfig( ctx context.Context, serial int32, resetType ResetNvType, ) error
func (*RadioModemProxy) NvWriteCdmaPrl ¶
func (*RadioModemProxy) NvWriteItem ¶
func (p *RadioModemProxy) NvWriteItem( ctx context.Context, serial int32, item NvWriteItem, ) error
func (*RadioModemProxy) RequestShutdown ¶
func (p *RadioModemProxy) RequestShutdown( ctx context.Context, serial int32, ) error
func (*RadioModemProxy) ResponseAcknowledgement ¶
func (p *RadioModemProxy) ResponseAcknowledgement( ctx context.Context, ) error
func (*RadioModemProxy) SendDeviceState ¶
func (p *RadioModemProxy) SendDeviceState( ctx context.Context, serial int32, deviceStateType DeviceStateType, state bool, ) error
func (*RadioModemProxy) SetRadioCapability ¶
func (p *RadioModemProxy) SetRadioCapability( ctx context.Context, serial int32, rc RadioCapability, ) error
func (*RadioModemProxy) SetRadioPower ¶
func (*RadioModemProxy) SetResponseFunctions ¶
func (p *RadioModemProxy) SetResponseFunctions( ctx context.Context, radioModemResponse IRadioModemResponse, radioModemIndication IRadioModemIndication, ) error
type RadioModemResponseProxy ¶
func NewRadioModemResponseProxy ¶
func NewRadioModemResponseProxy( remote binder.IBinder, ) *RadioModemResponseProxy
func (*RadioModemResponseProxy) AcknowledgeRequest ¶
func (p *RadioModemResponseProxy) AcknowledgeRequest( ctx context.Context, serial int32, ) error
func (*RadioModemResponseProxy) AsBinder ¶
func (p *RadioModemResponseProxy) AsBinder() binder.IBinder
func (*RadioModemResponseProxy) EnableModemResponse ¶
func (p *RadioModemResponseProxy) EnableModemResponse( ctx context.Context, info radio.RadioResponseInfo, ) error
func (*RadioModemResponseProxy) GetBasebandVersionResponse ¶
func (p *RadioModemResponseProxy) GetBasebandVersionResponse( ctx context.Context, info radio.RadioResponseInfo, version string, ) error
func (*RadioModemResponseProxy) GetDeviceIdentityResponse ¶
func (p *RadioModemResponseProxy) GetDeviceIdentityResponse( ctx context.Context, info radio.RadioResponseInfo, imei string, imeisv string, esn string, meid string, ) error
func (*RadioModemResponseProxy) GetHardwareConfigResponse ¶
func (p *RadioModemResponseProxy) GetHardwareConfigResponse( ctx context.Context, info radio.RadioResponseInfo, config []HardwareConfig, ) error
func (*RadioModemResponseProxy) GetImeiResponse ¶
func (p *RadioModemResponseProxy) GetImeiResponse( ctx context.Context, responseInfo radio.RadioResponseInfo, imeiInfo *ImeiInfo, ) error
func (*RadioModemResponseProxy) GetModemActivityInfoResponse ¶
func (p *RadioModemResponseProxy) GetModemActivityInfoResponse( ctx context.Context, info radio.RadioResponseInfo, activityInfo ActivityStatsInfo, ) error
func (*RadioModemResponseProxy) GetModemStackStatusResponse ¶
func (p *RadioModemResponseProxy) GetModemStackStatusResponse( ctx context.Context, info radio.RadioResponseInfo, isEnabled bool, ) error
func (*RadioModemResponseProxy) GetRadioCapabilityResponse ¶
func (p *RadioModemResponseProxy) GetRadioCapabilityResponse( ctx context.Context, info radio.RadioResponseInfo, rc RadioCapability, ) error
func (*RadioModemResponseProxy) NvReadItemResponse ¶
func (p *RadioModemResponseProxy) NvReadItemResponse( ctx context.Context, info radio.RadioResponseInfo, result string, ) error
func (*RadioModemResponseProxy) NvResetConfigResponse ¶
func (p *RadioModemResponseProxy) NvResetConfigResponse( ctx context.Context, info radio.RadioResponseInfo, ) error
func (*RadioModemResponseProxy) NvWriteCdmaPrlResponse ¶
func (p *RadioModemResponseProxy) NvWriteCdmaPrlResponse( ctx context.Context, info radio.RadioResponseInfo, ) error
func (*RadioModemResponseProxy) NvWriteItemResponse ¶
func (p *RadioModemResponseProxy) NvWriteItemResponse( ctx context.Context, info radio.RadioResponseInfo, ) error
func (*RadioModemResponseProxy) RequestShutdownResponse ¶
func (p *RadioModemResponseProxy) RequestShutdownResponse( ctx context.Context, info radio.RadioResponseInfo, ) error
func (*RadioModemResponseProxy) SendDeviceStateResponse ¶
func (p *RadioModemResponseProxy) SendDeviceStateResponse( ctx context.Context, info radio.RadioResponseInfo, ) error
func (*RadioModemResponseProxy) SetRadioCapabilityResponse ¶
func (p *RadioModemResponseProxy) SetRadioCapabilityResponse( ctx context.Context, info radio.RadioResponseInfo, rc RadioCapability, ) error
func (*RadioModemResponseProxy) SetRadioPowerResponse ¶
func (p *RadioModemResponseProxy) SetRadioPowerResponse( ctx context.Context, info radio.RadioResponseInfo, ) error
type RadioModemResponseStub ¶
type RadioModemResponseStub struct {
Impl IRadioModemResponse
Transport binder.VersionAwareTransport
}
RadioModemResponseStub dispatches incoming binder transactions to a typed IRadioModemResponse implementation.
func (*RadioModemResponseStub) Descriptor ¶
func (s *RadioModemResponseStub) Descriptor() string
func (*RadioModemResponseStub) OnTransaction ¶
func (s *RadioModemResponseStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type RadioModemStub ¶
type RadioModemStub struct {
Impl IRadioModem
Transport binder.VersionAwareTransport
}
RadioModemStub dispatches incoming binder transactions to a typed IRadioModem implementation.
func (*RadioModemStub) Descriptor ¶
func (s *RadioModemStub) Descriptor() string
func (*RadioModemStub) OnTransaction ¶
func (s *RadioModemStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type RadioState ¶
type RadioState int32
const ( RadioStateOFF RadioState = 0 RadioStateUNAVAILABLE RadioState = 1 RadioStateON RadioState = 10 )
type ResetNvType ¶
type ResetNvType int32
const ( ResetNvTypeRELOAD ResetNvType = 0 ResetNvTypeERASE ResetNvType = 1 ResetNvTypeFactoryReset ResetNvType = 2 )