Documentation
¶
Index ¶
- Constants
- type IThreadChip
- type IThreadChipCallback
- type IThreadChipCallbackServer
- type IThreadChipServer
- type ThreadChipCallbackProxy
- type ThreadChipCallbackStub
- type ThreadChipProxy
- func (p *ThreadChipProxy) AsBinder() binder.IBinder
- func (p *ThreadChipProxy) Close(ctx context.Context) error
- func (p *ThreadChipProxy) HardwareReset(ctx context.Context) error
- func (p *ThreadChipProxy) Open(ctx context.Context, callback IThreadChipCallback) error
- func (p *ThreadChipProxy) SendSpinelFrame(ctx context.Context, frame []byte) error
- type ThreadChipStub
Constants ¶
const ( TransactionIThreadChipOpen = binder.FirstCallTransaction + 0 TransactionIThreadChipClose = binder.FirstCallTransaction + 1 TransactionIThreadChipHardwareReset = binder.FirstCallTransaction + 2 TransactionIThreadChipSendSpinelFrame = binder.FirstCallTransaction + 3 )
const ( MethodIThreadChipOpen = "open" MethodIThreadChipClose = "close" MethodIThreadChipHardwareReset = "hardwareReset" MethodIThreadChipSendSpinelFrame = "sendSpinelFrame" )
const ( IThreadChipErrorFailed int32 = 1 IThreadChipErrorNoBufs int32 = 2 IThreadChipErrorBusy int32 = 3 )
const DescriptorIThreadChip = "android.hardware.threadnetwork.IThreadChip"
const DescriptorIThreadChipCallback = "android.hardware.threadnetwork.IThreadChipCallback"
const (
MethodIThreadChipCallbackOnReceiveSpinelFrame = "onReceiveSpinelFrame"
)
const (
TransactionIThreadChipCallbackOnReceiveSpinelFrame = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IThreadChip ¶
type IThreadChip interface {
AsBinder() binder.IBinder
Open(ctx context.Context, callback IThreadChipCallback) error
Close(ctx context.Context) error
HardwareReset(ctx context.Context) error
SendSpinelFrame(ctx context.Context, frame []byte) error
}
func NewThreadChipStub ¶
func NewThreadChipStub( impl IThreadChipServer, ) IThreadChip
NewThreadChipStub creates a server-side IThreadChip wrapping the given server implementation. The returned value satisfies IThreadChip and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IThreadChipCallback ¶
type IThreadChipCallback interface {
AsBinder() binder.IBinder
OnReceiveSpinelFrame(ctx context.Context, frame []byte) error
}
func NewThreadChipCallbackStub ¶
func NewThreadChipCallbackStub( impl IThreadChipCallbackServer, ) IThreadChipCallback
NewThreadChipCallbackStub creates a server-side IThreadChipCallback wrapping the given server implementation. The returned value satisfies IThreadChipCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IThreadChipCallbackServer ¶
type IThreadChipCallbackServer interface {
OnReceiveSpinelFrame(ctx context.Context, frame []byte) error
}
IThreadChipCallbackServer is the server-side interface that user implementations provide to NewThreadChipCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IThreadChipServer ¶
type IThreadChipServer interface {
Open(ctx context.Context, callback IThreadChipCallback) error
Close(ctx context.Context) error
HardwareReset(ctx context.Context) error
SendSpinelFrame(ctx context.Context, frame []byte) error
}
IThreadChipServer is the server-side interface that user implementations provide to NewThreadChipStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ThreadChipCallbackProxy ¶
func NewThreadChipCallbackProxy ¶
func NewThreadChipCallbackProxy( remote binder.IBinder, ) *ThreadChipCallbackProxy
func (*ThreadChipCallbackProxy) AsBinder ¶
func (p *ThreadChipCallbackProxy) AsBinder() binder.IBinder
func (*ThreadChipCallbackProxy) OnReceiveSpinelFrame ¶
func (p *ThreadChipCallbackProxy) OnReceiveSpinelFrame( ctx context.Context, frame []byte, ) error
type ThreadChipCallbackStub ¶
type ThreadChipCallbackStub struct {
Impl IThreadChipCallback
Transport binder.VersionAwareTransport
}
ThreadChipCallbackStub dispatches incoming binder transactions to a typed IThreadChipCallback implementation.
func (*ThreadChipCallbackStub) Descriptor ¶
func (s *ThreadChipCallbackStub) Descriptor() string
func (*ThreadChipCallbackStub) OnTransaction ¶
func (s *ThreadChipCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ThreadChipProxy ¶
func NewThreadChipProxy ¶
func NewThreadChipProxy( remote binder.IBinder, ) *ThreadChipProxy
func (*ThreadChipProxy) AsBinder ¶
func (p *ThreadChipProxy) AsBinder() binder.IBinder
func (*ThreadChipProxy) HardwareReset ¶
func (p *ThreadChipProxy) HardwareReset( ctx context.Context, ) error
func (*ThreadChipProxy) Open ¶
func (p *ThreadChipProxy) Open( ctx context.Context, callback IThreadChipCallback, ) error
func (*ThreadChipProxy) SendSpinelFrame ¶
func (p *ThreadChipProxy) SendSpinelFrame( ctx context.Context, frame []byte, ) error
type ThreadChipStub ¶
type ThreadChipStub struct {
Impl IThreadChip
Transport binder.VersionAwareTransport
}
ThreadChipStub dispatches incoming binder transactions to a typed IThreadChip implementation.
func (*ThreadChipStub) Descriptor ¶
func (s *ThreadChipStub) Descriptor() string
func (*ThreadChipStub) OnTransaction ¶
func (s *ThreadChipStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)