Documentation
¶
Index ¶
- Constants
- type ActivePwle
- type Braking
- type BrakingPwle
- type CompositeEffect
- type CompositePrimitive
- type Effect
- type EffectStrength
- type IVibrator
- type IVibratorCallback
- type IVibratorCallbackServer
- type IVibratorManager
- type IVibratorManagerServer
- type IVibratorServer
- type PrimitivePwle
- func (u *PrimitivePwle) GetActive() (ActivePwle, bool)
- func (u *PrimitivePwle) GetBraking() (BrakingPwle, bool)
- func (u *PrimitivePwle) MarshalParcel(p *parcel.Parcel) error
- func (u *PrimitivePwle) SetActive(v ActivePwle)
- func (u *PrimitivePwle) SetBraking(v BrakingPwle)
- func (u *PrimitivePwle) UnmarshalParcel(p *parcel.Parcel) error
- type VibratorCallbackProxy
- type VibratorCallbackStub
- type VibratorManagerProxy
- func (p *VibratorManagerProxy) AsBinder() binder.IBinder
- func (p *VibratorManagerProxy) CancelSynced(ctx context.Context) error
- func (p *VibratorManagerProxy) GetCapabilities(ctx context.Context) (int32, error)
- func (p *VibratorManagerProxy) GetVibrator(ctx context.Context, vibratorId int32) (IVibrator, error)
- func (p *VibratorManagerProxy) GetVibratorIds(ctx context.Context) ([]int32, error)
- func (p *VibratorManagerProxy) PrepareSynced(ctx context.Context, vibratorIds []int32) error
- func (p *VibratorManagerProxy) TriggerSynced(ctx context.Context, callback IVibratorCallback) error
- type VibratorManagerStub
- type VibratorProxy
- func (p *VibratorProxy) AlwaysOnDisable(ctx context.Context, id int32) error
- func (p *VibratorProxy) AlwaysOnEnable(ctx context.Context, id int32, effect Effect, strength EffectStrength) error
- func (p *VibratorProxy) AsBinder() binder.IBinder
- func (p *VibratorProxy) Compose(ctx context.Context, composite []CompositeEffect, callback IVibratorCallback) error
- func (p *VibratorProxy) ComposePwle(ctx context.Context, composite []PrimitivePwle, callback IVibratorCallback) error
- func (p *VibratorProxy) GetBandwidthAmplitudeMap(ctx context.Context) ([]float32, error)
- func (p *VibratorProxy) GetCapabilities(ctx context.Context) (int32, error)
- func (p *VibratorProxy) GetCompositionDelayMax(ctx context.Context) (int32, error)
- func (p *VibratorProxy) GetCompositionSizeMax(ctx context.Context) (int32, error)
- func (p *VibratorProxy) GetFrequencyMinimum(ctx context.Context) (float32, error)
- func (p *VibratorProxy) GetFrequencyResolution(ctx context.Context) (float32, error)
- func (p *VibratorProxy) GetPrimitiveDuration(ctx context.Context, primitive CompositePrimitive) (int32, error)
- func (p *VibratorProxy) GetPwleCompositionSizeMax(ctx context.Context) (int32, error)
- func (p *VibratorProxy) GetPwlePrimitiveDurationMax(ctx context.Context) (int32, error)
- func (p *VibratorProxy) GetQFactor(ctx context.Context) (float32, error)
- func (p *VibratorProxy) GetResonantFrequency(ctx context.Context) (float32, error)
- func (p *VibratorProxy) GetSupportedAlwaysOnEffects(ctx context.Context) ([]Effect, error)
- func (p *VibratorProxy) GetSupportedBraking(ctx context.Context) ([]Braking, error)
- func (p *VibratorProxy) GetSupportedEffects(ctx context.Context) ([]Effect, error)
- func (p *VibratorProxy) GetSupportedPrimitives(ctx context.Context) ([]CompositePrimitive, error)
- func (p *VibratorProxy) Off(ctx context.Context) error
- func (p *VibratorProxy) On(ctx context.Context, timeoutMs int32, callback IVibratorCallback) error
- func (p *VibratorProxy) Perform(ctx context.Context, effect Effect, strength EffectStrength, ...) (int32, error)
- func (p *VibratorProxy) SetAmplitude(ctx context.Context, amplitude float32) error
- func (p *VibratorProxy) SetExternalControl(ctx context.Context, enabled bool) error
- type VibratorStub
Constants ¶
const ( TransactionIVibratorGetCapabilities = binder.FirstCallTransaction + 0 TransactionIVibratorOff = binder.FirstCallTransaction + 1 TransactionIVibratorOn = binder.FirstCallTransaction + 2 TransactionIVibratorPerform = binder.FirstCallTransaction + 3 TransactionIVibratorGetSupportedEffects = binder.FirstCallTransaction + 4 TransactionIVibratorSetAmplitude = binder.FirstCallTransaction + 5 TransactionIVibratorSetExternalControl = binder.FirstCallTransaction + 6 TransactionIVibratorGetCompositionDelayMax = binder.FirstCallTransaction + 7 TransactionIVibratorGetCompositionSizeMax = binder.FirstCallTransaction + 8 TransactionIVibratorGetSupportedPrimitives = binder.FirstCallTransaction + 9 TransactionIVibratorGetPrimitiveDuration = binder.FirstCallTransaction + 10 TransactionIVibratorCompose = binder.FirstCallTransaction + 11 TransactionIVibratorGetSupportedAlwaysOnEffects = binder.FirstCallTransaction + 12 TransactionIVibratorAlwaysOnEnable = binder.FirstCallTransaction + 13 TransactionIVibratorAlwaysOnDisable = binder.FirstCallTransaction + 14 TransactionIVibratorGetResonantFrequency = binder.FirstCallTransaction + 15 TransactionIVibratorGetQFactor = binder.FirstCallTransaction + 16 TransactionIVibratorGetFrequencyResolution = binder.FirstCallTransaction + 17 TransactionIVibratorGetFrequencyMinimum = binder.FirstCallTransaction + 18 TransactionIVibratorGetBandwidthAmplitudeMap = binder.FirstCallTransaction + 19 TransactionIVibratorGetPwlePrimitiveDurationMax = binder.FirstCallTransaction + 20 TransactionIVibratorGetPwleCompositionSizeMax = binder.FirstCallTransaction + 21 TransactionIVibratorGetSupportedBraking = binder.FirstCallTransaction + 22 TransactionIVibratorComposePwle = binder.FirstCallTransaction + 23 )
const ( MethodIVibratorGetCapabilities = "getCapabilities" MethodIVibratorOff = "off" MethodIVibratorOn = "on" MethodIVibratorPerform = "perform" MethodIVibratorGetSupportedEffects = "getSupportedEffects" MethodIVibratorSetAmplitude = "setAmplitude" MethodIVibratorSetExternalControl = "setExternalControl" MethodIVibratorGetCompositionDelayMax = "getCompositionDelayMax" MethodIVibratorGetCompositionSizeMax = "getCompositionSizeMax" MethodIVibratorGetSupportedPrimitives = "getSupportedPrimitives" MethodIVibratorGetPrimitiveDuration = "getPrimitiveDuration" MethodIVibratorCompose = "compose" MethodIVibratorGetSupportedAlwaysOnEffects = "getSupportedAlwaysOnEffects" MethodIVibratorAlwaysOnEnable = "alwaysOnEnable" MethodIVibratorAlwaysOnDisable = "alwaysOnDisable" MethodIVibratorGetResonantFrequency = "getResonantFrequency" MethodIVibratorGetQFactor = "getQFactor" MethodIVibratorGetFrequencyResolution = "getFrequencyResolution" MethodIVibratorGetFrequencyMinimum = "getFrequencyMinimum" MethodIVibratorGetBandwidthAmplitudeMap = "getBandwidthAmplitudeMap" MethodIVibratorGetPwlePrimitiveDurationMax = "getPwlePrimitiveDurationMax" MethodIVibratorGetPwleCompositionSizeMax = "getPwleCompositionSizeMax" MethodIVibratorGetSupportedBraking = "getSupportedBraking" MethodIVibratorComposePwle = "composePwle" )
const ( IVibratorCapOnCallback int32 = (1 << 0) IVibratorCapPerformCallback int32 = (1 << 1) IVibratorCapAmplitudeControl int32 = (1 << 2) IVibratorCapExternalControl int32 = (1 << 3) IVibratorCapExternalAmplitudeControl int32 = (1 << 4) IVibratorCapComposeEffects int32 = (1 << 5) IVibratorCapAlwaysOnControl int32 = (1 << 6) IVibratorCapGetResonantFrequency int32 = (1 << 7) IVibratorCapGetQFactor int32 = (1 << 8) IVibratorCapFrequencyControl int32 = (1 << 9) IVibratorCapComposePwleEffects int32 = (1 << 10) )
const ( TransactionIVibratorManagerGetCapabilities = binder.FirstCallTransaction + 0 TransactionIVibratorManagerGetVibratorIds = binder.FirstCallTransaction + 1 TransactionIVibratorManagerGetVibrator = binder.FirstCallTransaction + 2 TransactionIVibratorManagerPrepareSynced = binder.FirstCallTransaction + 3 TransactionIVibratorManagerTriggerSynced = binder.FirstCallTransaction + 4 TransactionIVibratorManagerCancelSynced = binder.FirstCallTransaction + 5 )
const ( MethodIVibratorManagerGetCapabilities = "getCapabilities" MethodIVibratorManagerGetVibratorIds = "getVibratorIds" MethodIVibratorManagerGetVibrator = "getVibrator" MethodIVibratorManagerPrepareSynced = "prepareSynced" MethodIVibratorManagerTriggerSynced = "triggerSynced" MethodIVibratorManagerCancelSynced = "cancelSynced" )
const ( IVibratorManagerCapSync int32 = (1 << 0) IVibratorManagerCapPrepareOn int32 = (1 << 1) IVibratorManagerCapPreparePerform int32 = (1 << 2) IVibratorManagerCapPrepareCompose int32 = (1 << 3) IVibratorManagerCapMixedTriggerOn int32 = (1 << 4) IVibratorManagerCapMixedTriggerPerform int32 = (1 << 5) IVibratorManagerCapMixedTriggerCompose int32 = (1 << 6) IVibratorManagerCapTriggerCallback int32 = (1 << 7) )
const ( PrimitivePwleTagActive int32 = 0 PrimitivePwleTagBraking int32 = 1 )
const DescriptorIVibrator = "android.hardware.vibrator.IVibrator"
const DescriptorIVibratorCallback = "android.hardware.vibrator.IVibratorCallback"
const DescriptorIVibratorManager = "android.hardware.vibrator.IVibratorManager"
const (
MethodIVibratorCallbackOnComplete = "onComplete"
)
const (
TransactionIVibratorCallbackOnComplete = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ActivePwle ¶
type ActivePwle struct {
StartAmplitude float32
StartFrequency float32
EndAmplitude float32
EndFrequency float32
Duration int32
}
func (*ActivePwle) MarshalParcel ¶
func (s *ActivePwle) MarshalParcel( p *parcel.Parcel, ) error
func (*ActivePwle) UnmarshalParcel ¶
func (s *ActivePwle) UnmarshalParcel( p *parcel.Parcel, ) error
type BrakingPwle ¶
func (*BrakingPwle) MarshalParcel ¶
func (s *BrakingPwle) MarshalParcel( p *parcel.Parcel, ) error
func (*BrakingPwle) UnmarshalParcel ¶
func (s *BrakingPwle) UnmarshalParcel( p *parcel.Parcel, ) error
type CompositeEffect ¶
type CompositeEffect struct {
DelayMs int32
Primitive CompositePrimitive
Scale float32
}
func (*CompositeEffect) MarshalParcel ¶
func (s *CompositeEffect) MarshalParcel( p *parcel.Parcel, ) error
func (*CompositeEffect) UnmarshalParcel ¶
func (s *CompositeEffect) UnmarshalParcel( p *parcel.Parcel, ) error
type CompositePrimitive ¶
type CompositePrimitive int32
const ( CompositePrimitiveNOOP CompositePrimitive = 0 CompositePrimitiveCLICK CompositePrimitive = 1 CompositePrimitiveTHUD CompositePrimitive = 2 CompositePrimitiveSPIN CompositePrimitive = 3 CompositePrimitiveQuickRise CompositePrimitive = 4 CompositePrimitiveSlowRise CompositePrimitive = 5 CompositePrimitiveQuickFall CompositePrimitive = 6 CompositePrimitiveLightTick CompositePrimitive = 7 CompositePrimitiveLowTick CompositePrimitive = 8 )
type Effect ¶
type Effect int32
const ( EffectCLICK Effect = 0 EffectDoubleClick Effect = 1 EffectTICK Effect = 2 EffectTHUD Effect = 3 EffectPOP Effect = 4 EffectHeavyClick Effect = 5 EffectRingtone1 Effect = 6 EffectRingtone2 Effect = 7 EffectRingtone3 Effect = 8 EffectRingtone4 Effect = 9 EffectRingtone5 Effect = 10 EffectRingtone6 Effect = 11 EffectRingtone7 Effect = 12 EffectRingtone8 Effect = 13 EffectRingtone9 Effect = 14 EffectRingtone10 Effect = 15 EffectRingtone11 Effect = 16 EffectRingtone12 Effect = 17 EffectRingtone13 Effect = 18 EffectRingtone14 Effect = 19 EffectRingtone15 Effect = 20 EffectTextureTick Effect = 21 )
type EffectStrength ¶
type EffectStrength byte
const ( EffectStrengthLIGHT EffectStrength = 0 EffectStrengthMEDIUM EffectStrength = 1 EffectStrengthSTRONG EffectStrength = 2 )
type IVibrator ¶
type IVibrator interface {
AsBinder() binder.IBinder
GetCapabilities(ctx context.Context) (int32, error)
Off(ctx context.Context) error
On(ctx context.Context, timeoutMs int32, callback IVibratorCallback) error
Perform(ctx context.Context, effect Effect, strength EffectStrength, callback IVibratorCallback) (int32, error)
GetSupportedEffects(ctx context.Context) ([]Effect, error)
SetAmplitude(ctx context.Context, amplitude float32) error
SetExternalControl(ctx context.Context, enabled bool) error
GetCompositionDelayMax(ctx context.Context) (int32, error)
GetCompositionSizeMax(ctx context.Context) (int32, error)
GetSupportedPrimitives(ctx context.Context) ([]CompositePrimitive, error)
GetPrimitiveDuration(ctx context.Context, primitive CompositePrimitive) (int32, error)
Compose(ctx context.Context, composite []CompositeEffect, callback IVibratorCallback) error
GetSupportedAlwaysOnEffects(ctx context.Context) ([]Effect, error)
AlwaysOnEnable(ctx context.Context, id int32, effect Effect, strength EffectStrength) error
AlwaysOnDisable(ctx context.Context, id int32) error
GetResonantFrequency(ctx context.Context) (float32, error)
GetQFactor(ctx context.Context) (float32, error)
GetFrequencyResolution(ctx context.Context) (float32, error)
GetFrequencyMinimum(ctx context.Context) (float32, error)
GetBandwidthAmplitudeMap(ctx context.Context) ([]float32, error)
GetPwlePrimitiveDurationMax(ctx context.Context) (int32, error)
GetPwleCompositionSizeMax(ctx context.Context) (int32, error)
GetSupportedBraking(ctx context.Context) ([]Braking, error)
ComposePwle(ctx context.Context, composite []PrimitivePwle, callback IVibratorCallback) error
}
func NewVibratorStub ¶
func NewVibratorStub( impl IVibratorServer, ) IVibrator
NewVibratorStub creates a server-side IVibrator wrapping the given server implementation. The returned value satisfies IVibrator and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IVibratorCallback ¶
type IVibratorCallback interface {
AsBinder() binder.IBinder
OnComplete(ctx context.Context) error
}
func NewVibratorCallbackStub ¶
func NewVibratorCallbackStub( impl IVibratorCallbackServer, ) IVibratorCallback
NewVibratorCallbackStub creates a server-side IVibratorCallback wrapping the given server implementation. The returned value satisfies IVibratorCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IVibratorCallbackServer ¶
IVibratorCallbackServer is the server-side interface that user implementations provide to NewVibratorCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IVibratorManager ¶
type IVibratorManager interface {
AsBinder() binder.IBinder
GetCapabilities(ctx context.Context) (int32, error)
GetVibratorIds(ctx context.Context) ([]int32, error)
GetVibrator(ctx context.Context, vibratorId int32) (IVibrator, error)
PrepareSynced(ctx context.Context, vibratorIds []int32) error
TriggerSynced(ctx context.Context, callback IVibratorCallback) error
CancelSynced(ctx context.Context) error
}
func NewVibratorManagerStub ¶
func NewVibratorManagerStub( impl IVibratorManagerServer, ) IVibratorManager
NewVibratorManagerStub creates a server-side IVibratorManager wrapping the given server implementation. The returned value satisfies IVibratorManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IVibratorManagerServer ¶
type IVibratorManagerServer interface {
GetCapabilities(ctx context.Context) (int32, error)
GetVibratorIds(ctx context.Context) ([]int32, error)
GetVibrator(ctx context.Context, vibratorId int32) (IVibrator, error)
PrepareSynced(ctx context.Context, vibratorIds []int32) error
TriggerSynced(ctx context.Context, callback IVibratorCallback) error
CancelSynced(ctx context.Context) error
}
IVibratorManagerServer is the server-side interface that user implementations provide to NewVibratorManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IVibratorServer ¶
type IVibratorServer interface {
GetCapabilities(ctx context.Context) (int32, error)
Off(ctx context.Context) error
On(ctx context.Context, timeoutMs int32, callback IVibratorCallback) error
Perform(ctx context.Context, effect Effect, strength EffectStrength, callback IVibratorCallback) (int32, error)
GetSupportedEffects(ctx context.Context) ([]Effect, error)
SetAmplitude(ctx context.Context, amplitude float32) error
SetExternalControl(ctx context.Context, enabled bool) error
GetCompositionDelayMax(ctx context.Context) (int32, error)
GetCompositionSizeMax(ctx context.Context) (int32, error)
GetSupportedPrimitives(ctx context.Context) ([]CompositePrimitive, error)
GetPrimitiveDuration(ctx context.Context, primitive CompositePrimitive) (int32, error)
Compose(ctx context.Context, composite []CompositeEffect, callback IVibratorCallback) error
GetSupportedAlwaysOnEffects(ctx context.Context) ([]Effect, error)
AlwaysOnEnable(ctx context.Context, id int32, effect Effect, strength EffectStrength) error
AlwaysOnDisable(ctx context.Context, id int32) error
GetResonantFrequency(ctx context.Context) (float32, error)
GetQFactor(ctx context.Context) (float32, error)
GetFrequencyResolution(ctx context.Context) (float32, error)
GetFrequencyMinimum(ctx context.Context) (float32, error)
GetBandwidthAmplitudeMap(ctx context.Context) ([]float32, error)
GetPwlePrimitiveDurationMax(ctx context.Context) (int32, error)
GetPwleCompositionSizeMax(ctx context.Context) (int32, error)
GetSupportedBraking(ctx context.Context) ([]Braking, error)
ComposePwle(ctx context.Context, composite []PrimitivePwle, callback IVibratorCallback) error
}
IVibratorServer is the server-side interface that user implementations provide to NewVibratorStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type PrimitivePwle ¶
type PrimitivePwle struct {
Tag int32
Active ActivePwle
Braking BrakingPwle
}
func (*PrimitivePwle) GetActive ¶
func (u *PrimitivePwle) GetActive() (ActivePwle, bool)
func (*PrimitivePwle) GetBraking ¶
func (u *PrimitivePwle) GetBraking() (BrakingPwle, bool)
func (*PrimitivePwle) MarshalParcel ¶
func (u *PrimitivePwle) MarshalParcel( p *parcel.Parcel, ) error
func (*PrimitivePwle) SetActive ¶
func (u *PrimitivePwle) SetActive( v ActivePwle, )
func (*PrimitivePwle) SetBraking ¶
func (u *PrimitivePwle) SetBraking( v BrakingPwle, )
func (*PrimitivePwle) UnmarshalParcel ¶
func (u *PrimitivePwle) UnmarshalParcel( p *parcel.Parcel, ) error
type VibratorCallbackProxy ¶
func NewVibratorCallbackProxy ¶
func NewVibratorCallbackProxy( remote binder.IBinder, ) *VibratorCallbackProxy
func (*VibratorCallbackProxy) AsBinder ¶
func (p *VibratorCallbackProxy) AsBinder() binder.IBinder
func (*VibratorCallbackProxy) OnComplete ¶
func (p *VibratorCallbackProxy) OnComplete( ctx context.Context, ) error
type VibratorCallbackStub ¶
type VibratorCallbackStub struct {
Impl IVibratorCallback
Transport binder.VersionAwareTransport
}
VibratorCallbackStub dispatches incoming binder transactions to a typed IVibratorCallback implementation.
func (*VibratorCallbackStub) Descriptor ¶
func (s *VibratorCallbackStub) Descriptor() string
func (*VibratorCallbackStub) OnTransaction ¶
func (s *VibratorCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type VibratorManagerProxy ¶
func NewVibratorManagerProxy ¶
func NewVibratorManagerProxy( remote binder.IBinder, ) *VibratorManagerProxy
func (*VibratorManagerProxy) AsBinder ¶
func (p *VibratorManagerProxy) AsBinder() binder.IBinder
func (*VibratorManagerProxy) CancelSynced ¶
func (p *VibratorManagerProxy) CancelSynced( ctx context.Context, ) error
func (*VibratorManagerProxy) GetCapabilities ¶
func (p *VibratorManagerProxy) GetCapabilities( ctx context.Context, ) (int32, error)
func (*VibratorManagerProxy) GetVibrator ¶
func (*VibratorManagerProxy) GetVibratorIds ¶
func (p *VibratorManagerProxy) GetVibratorIds( ctx context.Context, ) ([]int32, error)
func (*VibratorManagerProxy) PrepareSynced ¶
func (p *VibratorManagerProxy) PrepareSynced( ctx context.Context, vibratorIds []int32, ) error
func (*VibratorManagerProxy) TriggerSynced ¶
func (p *VibratorManagerProxy) TriggerSynced( ctx context.Context, callback IVibratorCallback, ) error
type VibratorManagerStub ¶
type VibratorManagerStub struct {
Impl IVibratorManager
Transport binder.VersionAwareTransport
}
VibratorManagerStub dispatches incoming binder transactions to a typed IVibratorManager implementation.
func (*VibratorManagerStub) Descriptor ¶
func (s *VibratorManagerStub) Descriptor() string
func (*VibratorManagerStub) OnTransaction ¶
func (s *VibratorManagerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type VibratorProxy ¶
func NewVibratorProxy ¶
func NewVibratorProxy( remote binder.IBinder, ) *VibratorProxy
func (*VibratorProxy) AlwaysOnDisable ¶
func (p *VibratorProxy) AlwaysOnDisable( ctx context.Context, id int32, ) error
func (*VibratorProxy) AlwaysOnEnable ¶
func (p *VibratorProxy) AlwaysOnEnable( ctx context.Context, id int32, effect Effect, strength EffectStrength, ) error
func (*VibratorProxy) AsBinder ¶
func (p *VibratorProxy) AsBinder() binder.IBinder
func (*VibratorProxy) Compose ¶
func (p *VibratorProxy) Compose( ctx context.Context, composite []CompositeEffect, callback IVibratorCallback, ) error
func (*VibratorProxy) ComposePwle ¶
func (p *VibratorProxy) ComposePwle( ctx context.Context, composite []PrimitivePwle, callback IVibratorCallback, ) error
func (*VibratorProxy) GetBandwidthAmplitudeMap ¶
func (p *VibratorProxy) GetBandwidthAmplitudeMap( ctx context.Context, ) ([]float32, error)
func (*VibratorProxy) GetCapabilities ¶
func (p *VibratorProxy) GetCapabilities( ctx context.Context, ) (int32, error)
func (*VibratorProxy) GetCompositionDelayMax ¶
func (p *VibratorProxy) GetCompositionDelayMax( ctx context.Context, ) (int32, error)
func (*VibratorProxy) GetCompositionSizeMax ¶
func (p *VibratorProxy) GetCompositionSizeMax( ctx context.Context, ) (int32, error)
func (*VibratorProxy) GetFrequencyMinimum ¶
func (p *VibratorProxy) GetFrequencyMinimum( ctx context.Context, ) (float32, error)
func (*VibratorProxy) GetFrequencyResolution ¶
func (p *VibratorProxy) GetFrequencyResolution( ctx context.Context, ) (float32, error)
func (*VibratorProxy) GetPrimitiveDuration ¶
func (p *VibratorProxy) GetPrimitiveDuration( ctx context.Context, primitive CompositePrimitive, ) (int32, error)
func (*VibratorProxy) GetPwleCompositionSizeMax ¶
func (p *VibratorProxy) GetPwleCompositionSizeMax( ctx context.Context, ) (int32, error)
func (*VibratorProxy) GetPwlePrimitiveDurationMax ¶
func (p *VibratorProxy) GetPwlePrimitiveDurationMax( ctx context.Context, ) (int32, error)
func (*VibratorProxy) GetQFactor ¶
func (p *VibratorProxy) GetQFactor( ctx context.Context, ) (float32, error)
func (*VibratorProxy) GetResonantFrequency ¶
func (p *VibratorProxy) GetResonantFrequency( ctx context.Context, ) (float32, error)
func (*VibratorProxy) GetSupportedAlwaysOnEffects ¶
func (p *VibratorProxy) GetSupportedAlwaysOnEffects( ctx context.Context, ) ([]Effect, error)
func (*VibratorProxy) GetSupportedBraking ¶
func (p *VibratorProxy) GetSupportedBraking( ctx context.Context, ) ([]Braking, error)
func (*VibratorProxy) GetSupportedEffects ¶
func (p *VibratorProxy) GetSupportedEffects( ctx context.Context, ) ([]Effect, error)
func (*VibratorProxy) GetSupportedPrimitives ¶
func (p *VibratorProxy) GetSupportedPrimitives( ctx context.Context, ) ([]CompositePrimitive, error)
func (*VibratorProxy) On ¶
func (p *VibratorProxy) On( ctx context.Context, timeoutMs int32, callback IVibratorCallback, ) error
func (*VibratorProxy) Perform ¶
func (p *VibratorProxy) Perform( ctx context.Context, effect Effect, strength EffectStrength, callback IVibratorCallback, ) (int32, error)
func (*VibratorProxy) SetAmplitude ¶
func (p *VibratorProxy) SetAmplitude( ctx context.Context, amplitude float32, ) error
func (*VibratorProxy) SetExternalControl ¶
func (p *VibratorProxy) SetExternalControl( ctx context.Context, enabled bool, ) error
type VibratorStub ¶
type VibratorStub struct {
Impl IVibrator
Transport binder.VersionAwareTransport
}
VibratorStub dispatches incoming binder transactions to a typed IVibrator implementation.
func (*VibratorStub) Descriptor ¶
func (s *VibratorStub) Descriptor() string
func (*VibratorStub) OnTransaction ¶
func (s *VibratorStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)