midi

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIMidiDeviceListenerOnDeviceAdded         = binder.FirstCallTransaction + 0
	TransactionIMidiDeviceListenerOnDeviceRemoved       = binder.FirstCallTransaction + 1
	TransactionIMidiDeviceListenerOnDeviceStatusChanged = binder.FirstCallTransaction + 2
)
const (
	MethodIMidiDeviceListenerOnDeviceAdded         = "onDeviceAdded"
	MethodIMidiDeviceListenerOnDeviceRemoved       = "onDeviceRemoved"
	MethodIMidiDeviceListenerOnDeviceStatusChanged = "onDeviceStatusChanged"
)
const (
	TransactionIMidiDeviceServerOpenInputPort  = binder.FirstCallTransaction + 0
	TransactionIMidiDeviceServerOpenOutputPort = binder.FirstCallTransaction + 1
	TransactionIMidiDeviceServerClosePort      = binder.FirstCallTransaction + 2
	TransactionIMidiDeviceServerCloseDevice    = binder.FirstCallTransaction + 3
	TransactionIMidiDeviceServerConnectPorts   = binder.FirstCallTransaction + 4
	TransactionIMidiDeviceServerGetDeviceInfo  = binder.FirstCallTransaction + 5
	TransactionIMidiDeviceServerSetDeviceInfo  = binder.FirstCallTransaction + 6
)
const (
	MethodIMidiDeviceServerOpenInputPort  = "openInputPort"
	MethodIMidiDeviceServerOpenOutputPort = "openOutputPort"
	MethodIMidiDeviceServerClosePort      = "closePort"
	MethodIMidiDeviceServerCloseDevice    = "closeDevice"
	MethodIMidiDeviceServerConnectPorts   = "connectPorts"
	MethodIMidiDeviceServerGetDeviceInfo  = "getDeviceInfo"
	MethodIMidiDeviceServerSetDeviceInfo  = "setDeviceInfo"
)
const (
	TransactionIMidiManagerGetDevices             = binder.FirstCallTransaction + 0
	TransactionIMidiManagerGetDevicesForTransport = binder.FirstCallTransaction + 1
	TransactionIMidiManagerRegisterListener       = binder.FirstCallTransaction + 2
	TransactionIMidiManagerUnregisterListener     = binder.FirstCallTransaction + 3
	TransactionIMidiManagerOpenDevice             = binder.FirstCallTransaction + 4
	TransactionIMidiManagerOpenBluetoothDevice    = binder.FirstCallTransaction + 5
	TransactionIMidiManagerCloseDevice            = binder.FirstCallTransaction + 6
	TransactionIMidiManagerRegisterDeviceServer   = binder.FirstCallTransaction + 7
	TransactionIMidiManagerUnregisterDeviceServer = binder.FirstCallTransaction + 8
	TransactionIMidiManagerGetServiceDeviceInfo   = binder.FirstCallTransaction + 9
	TransactionIMidiManagerGetDeviceStatus        = binder.FirstCallTransaction + 10
	TransactionIMidiManagerSetDeviceStatus        = binder.FirstCallTransaction + 11
	TransactionIMidiManagerUpdateTotalBytes       = binder.FirstCallTransaction + 12
)
const (
	MethodIMidiManagerGetDevices             = "getDevices"
	MethodIMidiManagerGetDevicesForTransport = "getDevicesForTransport"
	MethodIMidiManagerRegisterListener       = "registerListener"
	MethodIMidiManagerUnregisterListener     = "unregisterListener"
	MethodIMidiManagerOpenDevice             = "openDevice"
	MethodIMidiManagerOpenBluetoothDevice    = "openBluetoothDevice"
	MethodIMidiManagerCloseDevice            = "closeDevice"
	MethodIMidiManagerRegisterDeviceServer   = "registerDeviceServer"
	MethodIMidiManagerUnregisterDeviceServer = "unregisterDeviceServer"
	MethodIMidiManagerGetServiceDeviceInfo   = "getServiceDeviceInfo"
	MethodIMidiManagerGetDeviceStatus        = "getDeviceStatus"
	MethodIMidiManagerSetDeviceStatus        = "setDeviceStatus"
	MethodIMidiManagerUpdateTotalBytes       = "updateTotalBytes"
)
const DescriptorIBluetoothMidiService = "android.media.midi.IBluetoothMidiService"
const DescriptorIMidiDeviceListener = "android.media.midi.IMidiDeviceListener"
const DescriptorIMidiDeviceOpenCallback = "android.media.midi.IMidiDeviceOpenCallback"
const DescriptorIMidiDeviceServer = "android.media.midi.IMidiDeviceServer"
const DescriptorIMidiManager = "android.media.midi.IMidiManager"
const (
	MethodIBluetoothMidiServiceAddBluetoothDevice = "addBluetoothDevice"
)
const (
	MethodIMidiDeviceOpenCallbackOnDeviceOpened = "onDeviceOpened"
)
const (
	TransactionIBluetoothMidiServiceAddBluetoothDevice = binder.FirstCallTransaction + 0
)
const (
	TransactionIMidiDeviceOpenCallbackOnDeviceOpened = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type BluetoothMidiServiceProxy

type BluetoothMidiServiceProxy struct {
	Remote binder.IBinder
}

func NewBluetoothMidiServiceProxy

func NewBluetoothMidiServiceProxy(
	remote binder.IBinder,
) *BluetoothMidiServiceProxy

func (*BluetoothMidiServiceProxy) AddBluetoothDevice

func (p *BluetoothMidiServiceProxy) AddBluetoothDevice(
	ctx context.Context,
	bluetoothDevice bluetooth.BluetoothDevice,
) (binder.IBinder, error)

func (*BluetoothMidiServiceProxy) AsBinder

type BluetoothMidiServiceStub

type BluetoothMidiServiceStub struct {
	Impl      IBluetoothMidiService
	Transport binder.VersionAwareTransport
}

BluetoothMidiServiceStub dispatches incoming binder transactions to a typed IBluetoothMidiService implementation.

func (*BluetoothMidiServiceStub) Descriptor

func (s *BluetoothMidiServiceStub) Descriptor() string

func (*BluetoothMidiServiceStub) OnTransaction

func (s *BluetoothMidiServiceStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type IBluetoothMidiService

type IBluetoothMidiService interface {
	AsBinder() binder.IBinder
	AddBluetoothDevice(ctx context.Context, bluetoothDevice bluetooth.BluetoothDevice) (binder.IBinder, error)
}

func NewBluetoothMidiServiceStub

func NewBluetoothMidiServiceStub(
	impl IBluetoothMidiServiceServer,
) IBluetoothMidiService

NewBluetoothMidiServiceStub creates a server-side IBluetoothMidiService wrapping the given server implementation. The returned value satisfies IBluetoothMidiService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IBluetoothMidiServiceServer

type IBluetoothMidiServiceServer interface {
	AddBluetoothDevice(ctx context.Context, bluetoothDevice bluetooth.BluetoothDevice) (binder.IBinder, error)
}

IBluetoothMidiServiceServer is the server-side interface that user implementations provide to NewBluetoothMidiServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IMidiDeviceListener

type IMidiDeviceListener interface {
	AsBinder() binder.IBinder
	OnDeviceAdded(ctx context.Context, device MidiDeviceInfo) error
	OnDeviceRemoved(ctx context.Context, device MidiDeviceInfo) error
	OnDeviceStatusChanged(ctx context.Context, status MidiDeviceStatus) error
}

func NewMidiDeviceListenerStub

func NewMidiDeviceListenerStub(
	impl IMidiDeviceListenerServer,
) IMidiDeviceListener

NewMidiDeviceListenerStub creates a server-side IMidiDeviceListener wrapping the given server implementation. The returned value satisfies IMidiDeviceListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IMidiDeviceListenerServer

type IMidiDeviceListenerServer interface {
	OnDeviceAdded(ctx context.Context, device MidiDeviceInfo) error
	OnDeviceRemoved(ctx context.Context, device MidiDeviceInfo) error
	OnDeviceStatusChanged(ctx context.Context, status MidiDeviceStatus) error
}

IMidiDeviceListenerServer is the server-side interface that user implementations provide to NewMidiDeviceListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IMidiDeviceOpenCallback

type IMidiDeviceOpenCallback interface {
	AsBinder() binder.IBinder
	OnDeviceOpened(ctx context.Context, server IMidiDeviceServer, token binder.IBinder) error
}

func NewMidiDeviceOpenCallbackStub

func NewMidiDeviceOpenCallbackStub(
	impl IMidiDeviceOpenCallbackServer,
) IMidiDeviceOpenCallback

NewMidiDeviceOpenCallbackStub creates a server-side IMidiDeviceOpenCallback wrapping the given server implementation. The returned value satisfies IMidiDeviceOpenCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IMidiDeviceOpenCallbackServer

type IMidiDeviceOpenCallbackServer interface {
	OnDeviceOpened(ctx context.Context, server IMidiDeviceServer, token binder.IBinder) error
}

IMidiDeviceOpenCallbackServer is the server-side interface that user implementations provide to NewMidiDeviceOpenCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IMidiDeviceServer

type IMidiDeviceServer interface {
	AsBinder() binder.IBinder
	OpenInputPort(ctx context.Context, token binder.IBinder, portNumber int32) (int32, error)
	OpenOutputPort(ctx context.Context, token binder.IBinder, portNumber int32) (int32, error)
	ClosePort(ctx context.Context, token binder.IBinder) error
	CloseDevice(ctx context.Context) error
	ConnectPorts(ctx context.Context, token binder.IBinder, fd int32, outputPortNumber int32) (int32, error)
	GetDeviceInfo(ctx context.Context) (MidiDeviceInfo, error)
	SetDeviceInfo(ctx context.Context, deviceInfo MidiDeviceInfo) error
}

func NewMidiDeviceServerStub

func NewMidiDeviceServerStub(
	impl IMidiDeviceServerServer,
) IMidiDeviceServer

NewMidiDeviceServerStub creates a server-side IMidiDeviceServer wrapping the given server implementation. The returned value satisfies IMidiDeviceServer and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IMidiDeviceServerServer

type IMidiDeviceServerServer interface {
	OpenInputPort(ctx context.Context, token binder.IBinder, portNumber int32) (int32, error)
	OpenOutputPort(ctx context.Context, token binder.IBinder, portNumber int32) (int32, error)
	ClosePort(ctx context.Context, token binder.IBinder) error
	CloseDevice(ctx context.Context) error
	ConnectPorts(ctx context.Context, token binder.IBinder, fd int32, outputPortNumber int32) (int32, error)
	GetDeviceInfo(ctx context.Context) (MidiDeviceInfo, error)
	SetDeviceInfo(ctx context.Context, deviceInfo MidiDeviceInfo) error
}

IMidiDeviceServerServer is the server-side interface that user implementations provide to NewMidiDeviceServerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IMidiManager

type IMidiManager interface {
	AsBinder() binder.IBinder
	GetDevices(ctx context.Context) ([]MidiDeviceInfo, error)
	GetDevicesForTransport(ctx context.Context, transport int32) ([]MidiDeviceInfo, error)
	RegisterListener(ctx context.Context, clientToken binder.IBinder, listener IMidiDeviceListener) error
	UnregisterListener(ctx context.Context, clientToken binder.IBinder, listener IMidiDeviceListener) error
	OpenDevice(ctx context.Context, clientToken binder.IBinder, device MidiDeviceInfo, callback IMidiDeviceOpenCallback) error
	OpenBluetoothDevice(ctx context.Context, clientToken binder.IBinder, bluetoothDevice bluetooth.BluetoothDevice, callback IMidiDeviceOpenCallback) error
	CloseDevice(ctx context.Context, clientToken binder.IBinder, deviceToken binder.IBinder) error
	RegisterDeviceServer(ctx context.Context, server IMidiDeviceServer, numInputPorts int32, numOutputPorts int32, inputPortNames []string, outputPortNames []string, properties os.Bundle, type_ int32, defaultProtocol int32) (MidiDeviceInfo, error)
	UnregisterDeviceServer(ctx context.Context, server IMidiDeviceServer) error
	GetServiceDeviceInfo(ctx context.Context, packageName string, className string) (MidiDeviceInfo, error)
	GetDeviceStatus(ctx context.Context, deviceInfo MidiDeviceInfo) (MidiDeviceStatus, error)
	SetDeviceStatus(ctx context.Context, server IMidiDeviceServer, status MidiDeviceStatus) error
	UpdateTotalBytes(ctx context.Context, server IMidiDeviceServer, inputBytes int32, outputBytes int32) error
}

func NewMidiManagerStub

func NewMidiManagerStub(
	impl IMidiManagerServer,
) IMidiManager

NewMidiManagerStub creates a server-side IMidiManager wrapping the given server implementation. The returned value satisfies IMidiManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IMidiManagerServer

type IMidiManagerServer interface {
	GetDevices(ctx context.Context) ([]MidiDeviceInfo, error)
	GetDevicesForTransport(ctx context.Context, transport int32) ([]MidiDeviceInfo, error)
	RegisterListener(ctx context.Context, clientToken binder.IBinder, listener IMidiDeviceListener) error
	UnregisterListener(ctx context.Context, clientToken binder.IBinder, listener IMidiDeviceListener) error
	OpenDevice(ctx context.Context, clientToken binder.IBinder, device MidiDeviceInfo, callback IMidiDeviceOpenCallback) error
	OpenBluetoothDevice(ctx context.Context, clientToken binder.IBinder, bluetoothDevice bluetooth.BluetoothDevice, callback IMidiDeviceOpenCallback) error
	CloseDevice(ctx context.Context, clientToken binder.IBinder, deviceToken binder.IBinder) error
	RegisterDeviceServer(ctx context.Context, server IMidiDeviceServer, numInputPorts int32, numOutputPorts int32, inputPortNames []string, outputPortNames []string, properties os.Bundle, type_ int32, defaultProtocol int32) (MidiDeviceInfo, error)
	UnregisterDeviceServer(ctx context.Context, server IMidiDeviceServer) error
	GetServiceDeviceInfo(ctx context.Context, packageName string, className string) (MidiDeviceInfo, error)
	GetDeviceStatus(ctx context.Context, deviceInfo MidiDeviceInfo) (MidiDeviceStatus, error)
	SetDeviceStatus(ctx context.Context, server IMidiDeviceServer, status MidiDeviceStatus) error
	UpdateTotalBytes(ctx context.Context, server IMidiDeviceServer, inputBytes int32, outputBytes int32) error
}

IMidiManagerServer is the server-side interface that user implementations provide to NewMidiManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type MidiDeviceInfo

type MidiDeviceInfo struct {
	Type            int32
	Id              int32
	InputPortCount  int32
	OutputPortCount int32
	DefaultProtocol int32
}

func (*MidiDeviceInfo) MarshalParcel

func (s *MidiDeviceInfo) MarshalParcel(
	p *parcel.Parcel,
) error

func (*MidiDeviceInfo) UnmarshalParcel

func (s *MidiDeviceInfo) UnmarshalParcel(
	p *parcel.Parcel,
) error

type MidiDeviceListenerProxy

type MidiDeviceListenerProxy struct {
	Remote binder.IBinder
}

func NewMidiDeviceListenerProxy

func NewMidiDeviceListenerProxy(
	remote binder.IBinder,
) *MidiDeviceListenerProxy

func (*MidiDeviceListenerProxy) AsBinder

func (p *MidiDeviceListenerProxy) AsBinder() binder.IBinder

func (*MidiDeviceListenerProxy) OnDeviceAdded

func (p *MidiDeviceListenerProxy) OnDeviceAdded(
	ctx context.Context,
	device MidiDeviceInfo,
) error

func (*MidiDeviceListenerProxy) OnDeviceRemoved

func (p *MidiDeviceListenerProxy) OnDeviceRemoved(
	ctx context.Context,
	device MidiDeviceInfo,
) error

func (*MidiDeviceListenerProxy) OnDeviceStatusChanged

func (p *MidiDeviceListenerProxy) OnDeviceStatusChanged(
	ctx context.Context,
	status MidiDeviceStatus,
) error

type MidiDeviceListenerStub

type MidiDeviceListenerStub struct {
	Impl      IMidiDeviceListener
	Transport binder.VersionAwareTransport
}

MidiDeviceListenerStub dispatches incoming binder transactions to a typed IMidiDeviceListener implementation.

func (*MidiDeviceListenerStub) Descriptor

func (s *MidiDeviceListenerStub) Descriptor() string

func (*MidiDeviceListenerStub) OnTransaction

func (s *MidiDeviceListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type MidiDeviceOpenCallbackProxy

type MidiDeviceOpenCallbackProxy struct {
	Remote binder.IBinder
}

func NewMidiDeviceOpenCallbackProxy

func NewMidiDeviceOpenCallbackProxy(
	remote binder.IBinder,
) *MidiDeviceOpenCallbackProxy

func (*MidiDeviceOpenCallbackProxy) AsBinder

func (*MidiDeviceOpenCallbackProxy) OnDeviceOpened

func (p *MidiDeviceOpenCallbackProxy) OnDeviceOpened(
	ctx context.Context,
	server IMidiDeviceServer,
	token binder.IBinder,
) error

type MidiDeviceOpenCallbackStub

type MidiDeviceOpenCallbackStub struct {
	Impl      IMidiDeviceOpenCallback
	Transport binder.VersionAwareTransport
}

MidiDeviceOpenCallbackStub dispatches incoming binder transactions to a typed IMidiDeviceOpenCallback implementation.

func (*MidiDeviceOpenCallbackStub) Descriptor

func (s *MidiDeviceOpenCallbackStub) Descriptor() string

func (*MidiDeviceOpenCallbackStub) OnTransaction

func (s *MidiDeviceOpenCallbackStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type MidiDeviceServerProxy

type MidiDeviceServerProxy struct {
	Remote binder.IBinder
}

func NewMidiDeviceServerProxy

func NewMidiDeviceServerProxy(
	remote binder.IBinder,
) *MidiDeviceServerProxy

func (*MidiDeviceServerProxy) AsBinder

func (p *MidiDeviceServerProxy) AsBinder() binder.IBinder

func (*MidiDeviceServerProxy) CloseDevice

func (p *MidiDeviceServerProxy) CloseDevice(
	ctx context.Context,
) error

func (*MidiDeviceServerProxy) ClosePort

func (p *MidiDeviceServerProxy) ClosePort(
	ctx context.Context,
	token binder.IBinder,
) error

func (*MidiDeviceServerProxy) ConnectPorts

func (p *MidiDeviceServerProxy) ConnectPorts(
	ctx context.Context,
	token binder.IBinder,
	fd int32,
	outputPortNumber int32,
) (int32, error)

func (*MidiDeviceServerProxy) GetDeviceInfo

func (p *MidiDeviceServerProxy) GetDeviceInfo(
	ctx context.Context,
) (MidiDeviceInfo, error)

func (*MidiDeviceServerProxy) OpenInputPort

func (p *MidiDeviceServerProxy) OpenInputPort(
	ctx context.Context,
	token binder.IBinder,
	portNumber int32,
) (int32, error)

func (*MidiDeviceServerProxy) OpenOutputPort

func (p *MidiDeviceServerProxy) OpenOutputPort(
	ctx context.Context,
	token binder.IBinder,
	portNumber int32,
) (int32, error)

func (*MidiDeviceServerProxy) SetDeviceInfo

func (p *MidiDeviceServerProxy) SetDeviceInfo(
	ctx context.Context,
	deviceInfo MidiDeviceInfo,
) error

type MidiDeviceServerStub

type MidiDeviceServerStub struct {
	Impl      IMidiDeviceServer
	Transport binder.VersionAwareTransport
}

MidiDeviceServerStub dispatches incoming binder transactions to a typed IMidiDeviceServer implementation.

func (*MidiDeviceServerStub) Descriptor

func (s *MidiDeviceServerStub) Descriptor() string

func (*MidiDeviceServerStub) OnTransaction

func (s *MidiDeviceServerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type MidiDeviceStatus

type MidiDeviceStatus struct {
}

func (*MidiDeviceStatus) MarshalParcel

func (s *MidiDeviceStatus) MarshalParcel(
	p *parcel.Parcel,
) error

func (*MidiDeviceStatus) UnmarshalParcel

func (s *MidiDeviceStatus) UnmarshalParcel(
	p *parcel.Parcel,
) error

type MidiManagerProxy

type MidiManagerProxy struct {
	Remote binder.IBinder
}

func GetMidiManager

func GetMidiManager(
	ctx context.Context,
	sm *servicemanager.ServiceManager,
) (*MidiManagerProxy, error)

GetMidiManager retrieves the MidiService service and returns a typed proxy.

func NewMidiManagerProxy

func NewMidiManagerProxy(
	remote binder.IBinder,
) *MidiManagerProxy

func (*MidiManagerProxy) AsBinder

func (p *MidiManagerProxy) AsBinder() binder.IBinder

func (*MidiManagerProxy) CloseDevice

func (p *MidiManagerProxy) CloseDevice(
	ctx context.Context,
	clientToken binder.IBinder,
	deviceToken binder.IBinder,
) error

func (*MidiManagerProxy) GetDeviceStatus

func (p *MidiManagerProxy) GetDeviceStatus(
	ctx context.Context,
	deviceInfo MidiDeviceInfo,
) (MidiDeviceStatus, error)

func (*MidiManagerProxy) GetDevices

func (p *MidiManagerProxy) GetDevices(
	ctx context.Context,
) ([]MidiDeviceInfo, error)

func (*MidiManagerProxy) GetDevicesForTransport

func (p *MidiManagerProxy) GetDevicesForTransport(
	ctx context.Context,
	transport int32,
) ([]MidiDeviceInfo, error)

func (*MidiManagerProxy) GetServiceDeviceInfo

func (p *MidiManagerProxy) GetServiceDeviceInfo(
	ctx context.Context,
	packageName string,
	className string,
) (MidiDeviceInfo, error)

func (*MidiManagerProxy) OpenBluetoothDevice

func (p *MidiManagerProxy) OpenBluetoothDevice(
	ctx context.Context,
	clientToken binder.IBinder,
	bluetoothDevice bluetooth.BluetoothDevice,
	callback IMidiDeviceOpenCallback,
) error

func (*MidiManagerProxy) OpenDevice

func (p *MidiManagerProxy) OpenDevice(
	ctx context.Context,
	clientToken binder.IBinder,
	device MidiDeviceInfo,
	callback IMidiDeviceOpenCallback,
) error

func (*MidiManagerProxy) RegisterDeviceServer

func (p *MidiManagerProxy) RegisterDeviceServer(
	ctx context.Context,
	server IMidiDeviceServer,
	numInputPorts int32,
	numOutputPorts int32,
	inputPortNames []string,
	outputPortNames []string,
	properties os.Bundle,
	type_ int32,
	defaultProtocol int32,
) (MidiDeviceInfo, error)

func (*MidiManagerProxy) RegisterListener

func (p *MidiManagerProxy) RegisterListener(
	ctx context.Context,
	clientToken binder.IBinder,
	listener IMidiDeviceListener,
) error

func (*MidiManagerProxy) SetDeviceStatus

func (p *MidiManagerProxy) SetDeviceStatus(
	ctx context.Context,
	server IMidiDeviceServer,
	status MidiDeviceStatus,
) error

func (*MidiManagerProxy) UnregisterDeviceServer

func (p *MidiManagerProxy) UnregisterDeviceServer(
	ctx context.Context,
	server IMidiDeviceServer,
) error

func (*MidiManagerProxy) UnregisterListener

func (p *MidiManagerProxy) UnregisterListener(
	ctx context.Context,
	clientToken binder.IBinder,
	listener IMidiDeviceListener,
) error

func (*MidiManagerProxy) UpdateTotalBytes

func (p *MidiManagerProxy) UpdateTotalBytes(
	ctx context.Context,
	server IMidiDeviceServer,
	inputBytes int32,
	outputBytes int32,
) error

type MidiManagerStub

type MidiManagerStub struct {
	Impl      IMidiManager
	Transport binder.VersionAwareTransport
}

MidiManagerStub dispatches incoming binder transactions to a typed IMidiManager implementation.

func (*MidiManagerStub) Descriptor

func (s *MidiManagerStub) Descriptor() string

func (*MidiManagerStub) OnTransaction

func (s *MidiManagerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

Jump to