Documentation
¶
Index ¶
- Constants
- type IMediaProjection
- type IMediaProjectionCallback
- type IMediaProjectionCallbackServer
- type IMediaProjectionManager
- type IMediaProjectionManagerServer
- type IMediaProjectionServer
- type IMediaProjectionWatcherCallback
- type IMediaProjectionWatcherCallbackServer
- type MediaProjectionCallbackProxy
- func (p *MediaProjectionCallbackProxy) AsBinder() binder.IBinder
- func (p *MediaProjectionCallbackProxy) OnCapturedContentResize(ctx context.Context, width int32, height int32) error
- func (p *MediaProjectionCallbackProxy) OnCapturedContentVisibilityChanged(ctx context.Context, isVisible bool) error
- func (p *MediaProjectionCallbackProxy) OnStop(ctx context.Context) error
- type MediaProjectionCallbackStub
- type MediaProjectionConfig
- type MediaProjectionInfo
- type MediaProjectionManagerProxy
- func (p *MediaProjectionManagerProxy) AddCallback(ctx context.Context, callback IMediaProjectionWatcherCallback) (MediaProjectionInfo, error)
- func (p *MediaProjectionManagerProxy) AsBinder() binder.IBinder
- func (p *MediaProjectionManagerProxy) CreateProjection(ctx context.Context, processUid int32, packageName string, type_ int32, ...) (IMediaProjection, error)
- func (p *MediaProjectionManagerProxy) GetActiveProjectionInfo(ctx context.Context) (MediaProjectionInfo, error)
- func (p *MediaProjectionManagerProxy) GetProjection(ctx context.Context, processUid int32, packageName string) (IMediaProjection, error)
- func (p *MediaProjectionManagerProxy) HasProjectionPermission(ctx context.Context, processUid int32, packageName string) (bool, error)
- func (p *MediaProjectionManagerProxy) IsCurrentProjection(ctx context.Context, projection IMediaProjection) (bool, error)
- func (p *MediaProjectionManagerProxy) NotifyActiveProjectionCapturedContentResized(ctx context.Context, width int32, height int32) error
- func (p *MediaProjectionManagerProxy) NotifyActiveProjectionCapturedContentVisibilityChanged(ctx context.Context, isVisible bool) error
- func (p *MediaProjectionManagerProxy) NotifyAppSelectorDisplayed(ctx context.Context, hostProcessUid int32) error
- func (p *MediaProjectionManagerProxy) NotifyPermissionRequestCancelled(ctx context.Context, hostProcessUid int32) error
- func (p *MediaProjectionManagerProxy) NotifyPermissionRequestDisplayed(ctx context.Context, hostProcessUid int32) error
- func (p *MediaProjectionManagerProxy) NotifyPermissionRequestInitiated(ctx context.Context, hostProcessUid int32, sessionCreationSource int32) error
- func (p *MediaProjectionManagerProxy) NotifyWindowingModeChanged(ctx context.Context, contentToRecord int32, targetProcessUid int32, ...) error
- func (p *MediaProjectionManagerProxy) RemoveCallback(ctx context.Context, callback IMediaProjectionWatcherCallback) error
- func (p *MediaProjectionManagerProxy) RequestConsentForInvalidProjection(ctx context.Context, projection IMediaProjection) error
- func (p *MediaProjectionManagerProxy) SetContentRecordingSession(ctx context.Context, incomingSession view.ContentRecordingSession, ...) (bool, error)
- func (p *MediaProjectionManagerProxy) SetUserReviewGrantedConsentResult(ctx context.Context, consentResult ReviewGrantedConsentResult, ...) error
- func (p *MediaProjectionManagerProxy) StopActiveProjection(ctx context.Context) error
- type MediaProjectionManagerStub
- type MediaProjectionProxy
- func (p *MediaProjectionProxy) ApplyVirtualDisplayFlags(ctx context.Context, flags int32) (int32, error)
- func (p *MediaProjectionProxy) AsBinder() binder.IBinder
- func (p *MediaProjectionProxy) CanProjectAudio(ctx context.Context) (bool, error)
- func (p *MediaProjectionProxy) CanProjectSecureVideo(ctx context.Context) (bool, error)
- func (p *MediaProjectionProxy) CanProjectVideo(ctx context.Context) (bool, error)
- func (p *MediaProjectionProxy) GetLaunchCookie(ctx context.Context) (types.ActivityOptionsLaunchCookie, error)
- func (p *MediaProjectionProxy) IsValid(ctx context.Context) (bool, error)
- func (p *MediaProjectionProxy) NotifyVirtualDisplayCreated(ctx context.Context, displayId int32) error
- func (p *MediaProjectionProxy) RegisterCallback(ctx context.Context, callback IMediaProjectionCallback) error
- func (p *MediaProjectionProxy) SetLaunchCookie(ctx context.Context, launchCookie types.ActivityOptionsLaunchCookie) error
- func (p *MediaProjectionProxy) Start(ctx context.Context, callback IMediaProjectionCallback) error
- func (p *MediaProjectionProxy) Stop(ctx context.Context) error
- func (p *MediaProjectionProxy) UnregisterCallback(ctx context.Context, callback IMediaProjectionCallback) error
- type MediaProjectionStub
- type MediaProjectionWatcherCallbackProxy
- func (p *MediaProjectionWatcherCallbackProxy) AsBinder() binder.IBinder
- func (p *MediaProjectionWatcherCallbackProxy) OnRecordingSessionSet(ctx context.Context, info MediaProjectionInfo, ...) error
- func (p *MediaProjectionWatcherCallbackProxy) OnStart(ctx context.Context, info MediaProjectionInfo) error
- func (p *MediaProjectionWatcherCallbackProxy) OnStop(ctx context.Context, info MediaProjectionInfo) error
- type MediaProjectionWatcherCallbackStub
- type ReviewGrantedConsentResult
Constants ¶
const ( TransactionIMediaProjectionStart = binder.FirstCallTransaction + 0 TransactionIMediaProjectionStop = binder.FirstCallTransaction + 1 TransactionIMediaProjectionCanProjectAudio = binder.FirstCallTransaction + 2 TransactionIMediaProjectionCanProjectVideo = binder.FirstCallTransaction + 3 TransactionIMediaProjectionCanProjectSecureVideo = binder.FirstCallTransaction + 4 TransactionIMediaProjectionApplyVirtualDisplayFlags = binder.FirstCallTransaction + 5 TransactionIMediaProjectionRegisterCallback = binder.FirstCallTransaction + 6 TransactionIMediaProjectionUnregisterCallback = binder.FirstCallTransaction + 7 TransactionIMediaProjectionGetLaunchCookie = binder.FirstCallTransaction + 8 TransactionIMediaProjectionSetLaunchCookie = binder.FirstCallTransaction + 9 TransactionIMediaProjectionIsValid = binder.FirstCallTransaction + 10 TransactionIMediaProjectionNotifyVirtualDisplayCreated = binder.FirstCallTransaction + 11 )
const ( MethodIMediaProjectionStart = "start" MethodIMediaProjectionStop = "stop" MethodIMediaProjectionCanProjectAudio = "canProjectAudio" MethodIMediaProjectionCanProjectVideo = "canProjectVideo" MethodIMediaProjectionCanProjectSecureVideo = "canProjectSecureVideo" MethodIMediaProjectionApplyVirtualDisplayFlags = "applyVirtualDisplayFlags" MethodIMediaProjectionRegisterCallback = "registerCallback" MethodIMediaProjectionUnregisterCallback = "unregisterCallback" MethodIMediaProjectionGetLaunchCookie = "getLaunchCookie" MethodIMediaProjectionSetLaunchCookie = "setLaunchCookie" MethodIMediaProjectionIsValid = "isValid" MethodIMediaProjectionNotifyVirtualDisplayCreated = "notifyVirtualDisplayCreated" )
const ( TransactionIMediaProjectionCallbackOnStop = binder.FirstCallTransaction + 0 TransactionIMediaProjectionCallbackOnCapturedContentResize = binder.FirstCallTransaction + 1 TransactionIMediaProjectionCallbackOnCapturedContentVisibilityChanged = binder.FirstCallTransaction + 2 )
const ( MethodIMediaProjectionCallbackOnStop = "onStop" MethodIMediaProjectionCallbackOnCapturedContentResize = "onCapturedContentResize" MethodIMediaProjectionCallbackOnCapturedContentVisibilityChanged = "onCapturedContentVisibilityChanged" )
const ( TransactionIMediaProjectionManagerHasProjectionPermission = binder.FirstCallTransaction + 0 TransactionIMediaProjectionManagerCreateProjection = binder.FirstCallTransaction + 1 TransactionIMediaProjectionManagerGetProjection = binder.FirstCallTransaction + 2 TransactionIMediaProjectionManagerIsCurrentProjection = binder.FirstCallTransaction + 3 TransactionIMediaProjectionManagerRequestConsentForInvalidProjection = binder.FirstCallTransaction + 4 TransactionIMediaProjectionManagerGetActiveProjectionInfo = binder.FirstCallTransaction + 5 TransactionIMediaProjectionManagerStopActiveProjection = binder.FirstCallTransaction + 6 TransactionIMediaProjectionManagerNotifyActiveProjectionCapturedContentResized = binder.FirstCallTransaction + 7 TransactionIMediaProjectionManagerNotifyActiveProjectionCapturedContentVisibilityChanged = binder.FirstCallTransaction + 8 TransactionIMediaProjectionManagerAddCallback = binder.FirstCallTransaction + 9 TransactionIMediaProjectionManagerRemoveCallback = binder.FirstCallTransaction + 10 TransactionIMediaProjectionManagerSetContentRecordingSession = binder.FirstCallTransaction + 11 TransactionIMediaProjectionManagerSetUserReviewGrantedConsentResult = binder.FirstCallTransaction + 12 TransactionIMediaProjectionManagerNotifyPermissionRequestInitiated = binder.FirstCallTransaction + 13 TransactionIMediaProjectionManagerNotifyPermissionRequestDisplayed = binder.FirstCallTransaction + 14 TransactionIMediaProjectionManagerNotifyPermissionRequestCancelled = binder.FirstCallTransaction + 15 TransactionIMediaProjectionManagerNotifyAppSelectorDisplayed = binder.FirstCallTransaction + 16 TransactionIMediaProjectionManagerNotifyWindowingModeChanged = binder.FirstCallTransaction + 17 )
const ( MethodIMediaProjectionManagerHasProjectionPermission = "hasProjectionPermission" MethodIMediaProjectionManagerCreateProjection = "createProjection" MethodIMediaProjectionManagerGetProjection = "getProjection" MethodIMediaProjectionManagerIsCurrentProjection = "isCurrentProjection" MethodIMediaProjectionManagerRequestConsentForInvalidProjection = "requestConsentForInvalidProjection" MethodIMediaProjectionManagerGetActiveProjectionInfo = "getActiveProjectionInfo" MethodIMediaProjectionManagerStopActiveProjection = "stopActiveProjection" MethodIMediaProjectionManagerNotifyActiveProjectionCapturedContentResized = "notifyActiveProjectionCapturedContentResized" MethodIMediaProjectionManagerNotifyActiveProjectionCapturedContentVisibilityChanged = "notifyActiveProjectionCapturedContentVisibilityChanged" MethodIMediaProjectionManagerAddCallback = "addCallback" MethodIMediaProjectionManagerRemoveCallback = "removeCallback" MethodIMediaProjectionManagerSetContentRecordingSession = "setContentRecordingSession" MethodIMediaProjectionManagerSetUserReviewGrantedConsentResult = "setUserReviewGrantedConsentResult" MethodIMediaProjectionManagerNotifyPermissionRequestInitiated = "notifyPermissionRequestInitiated" MethodIMediaProjectionManagerNotifyPermissionRequestDisplayed = "notifyPermissionRequestDisplayed" MethodIMediaProjectionManagerNotifyPermissionRequestCancelled = "notifyPermissionRequestCancelled" MethodIMediaProjectionManagerNotifyAppSelectorDisplayed = "notifyAppSelectorDisplayed" MethodIMediaProjectionManagerNotifyWindowingModeChanged = "notifyWindowingModeChanged" )
const ( IMediaProjectionManagerExtraUserReviewGrantedConsent string = "extra_media_projection_user_consent_required" IMediaProjectionManagerExtraPackageReusingGrantedConsent string = "extra_media_projection_package_reusing_consent" )
const ( TransactionIMediaProjectionWatcherCallbackOnStart = binder.FirstCallTransaction + 0 TransactionIMediaProjectionWatcherCallbackOnStop = binder.FirstCallTransaction + 1 TransactionIMediaProjectionWatcherCallbackOnRecordingSessionSet = binder.FirstCallTransaction + 2 )
const ( MethodIMediaProjectionWatcherCallbackOnStart = "onStart" MethodIMediaProjectionWatcherCallbackOnStop = "onStop" MethodIMediaProjectionWatcherCallbackOnRecordingSessionSet = "onRecordingSessionSet" )
const DescriptorIMediaProjection = "android.media.projection.IMediaProjection"
const DescriptorIMediaProjectionCallback = "android.media.projection.IMediaProjectionCallback"
const DescriptorIMediaProjectionManager = "android.media.projection.IMediaProjectionManager"
const DescriptorIMediaProjectionWatcherCallback = "android.media.projection.IMediaProjectionWatcherCallback"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IMediaProjection ¶
type IMediaProjection interface {
AsBinder() binder.IBinder
Start(ctx context.Context, callback IMediaProjectionCallback) error
Stop(ctx context.Context) error
CanProjectAudio(ctx context.Context) (bool, error)
CanProjectVideo(ctx context.Context) (bool, error)
CanProjectSecureVideo(ctx context.Context) (bool, error)
ApplyVirtualDisplayFlags(ctx context.Context, flags int32) (int32, error)
RegisterCallback(ctx context.Context, callback IMediaProjectionCallback) error
UnregisterCallback(ctx context.Context, callback IMediaProjectionCallback) error
GetLaunchCookie(ctx context.Context) (types.ActivityOptionsLaunchCookie, error)
SetLaunchCookie(ctx context.Context, launchCookie types.ActivityOptionsLaunchCookie) error
IsValid(ctx context.Context) (bool, error)
NotifyVirtualDisplayCreated(ctx context.Context, displayId int32) error
}
func NewMediaProjectionStub ¶
func NewMediaProjectionStub( impl IMediaProjectionServer, ) IMediaProjection
NewMediaProjectionStub creates a server-side IMediaProjection wrapping the given server implementation. The returned value satisfies IMediaProjection and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IMediaProjectionCallback ¶
type IMediaProjectionCallback interface {
AsBinder() binder.IBinder
OnStop(ctx context.Context) error
OnCapturedContentResize(ctx context.Context, width int32, height int32) error
OnCapturedContentVisibilityChanged(ctx context.Context, isVisible bool) error
}
func NewMediaProjectionCallbackStub ¶
func NewMediaProjectionCallbackStub( impl IMediaProjectionCallbackServer, ) IMediaProjectionCallback
NewMediaProjectionCallbackStub creates a server-side IMediaProjectionCallback wrapping the given server implementation. The returned value satisfies IMediaProjectionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IMediaProjectionCallbackServer ¶
type IMediaProjectionCallbackServer interface {
OnStop(ctx context.Context) error
OnCapturedContentResize(ctx context.Context, width int32, height int32) error
OnCapturedContentVisibilityChanged(ctx context.Context, isVisible bool) error
}
IMediaProjectionCallbackServer is the server-side interface that user implementations provide to NewMediaProjectionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IMediaProjectionManager ¶
type IMediaProjectionManager interface {
AsBinder() binder.IBinder
HasProjectionPermission(ctx context.Context, processUid int32, packageName string) (bool, error)
CreateProjection(ctx context.Context, processUid int32, packageName string, type_ int32, permanentGrant bool) (IMediaProjection, error)
GetProjection(ctx context.Context, processUid int32, packageName string) (IMediaProjection, error)
IsCurrentProjection(ctx context.Context, projection IMediaProjection) (bool, error)
RequestConsentForInvalidProjection(ctx context.Context, projection IMediaProjection) error
GetActiveProjectionInfo(ctx context.Context) (MediaProjectionInfo, error)
StopActiveProjection(ctx context.Context) error
NotifyActiveProjectionCapturedContentResized(ctx context.Context, width int32, height int32) error
NotifyActiveProjectionCapturedContentVisibilityChanged(ctx context.Context, isVisible bool) error
AddCallback(ctx context.Context, callback IMediaProjectionWatcherCallback) (MediaProjectionInfo, error)
RemoveCallback(ctx context.Context, callback IMediaProjectionWatcherCallback) error
SetContentRecordingSession(ctx context.Context, incomingSession view.ContentRecordingSession, projection IMediaProjection) (bool, error)
SetUserReviewGrantedConsentResult(ctx context.Context, consentResult ReviewGrantedConsentResult, projection IMediaProjection) error
NotifyPermissionRequestInitiated(ctx context.Context, hostProcessUid int32, sessionCreationSource int32) error
NotifyPermissionRequestDisplayed(ctx context.Context, hostProcessUid int32) error
NotifyPermissionRequestCancelled(ctx context.Context, hostProcessUid int32) error
NotifyAppSelectorDisplayed(ctx context.Context, hostProcessUid int32) error
NotifyWindowingModeChanged(ctx context.Context, contentToRecord int32, targetProcessUid int32, windowingMode int32) error
}
func NewMediaProjectionManagerStub ¶
func NewMediaProjectionManagerStub( impl IMediaProjectionManagerServer, ) IMediaProjectionManager
NewMediaProjectionManagerStub creates a server-side IMediaProjectionManager wrapping the given server implementation. The returned value satisfies IMediaProjectionManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IMediaProjectionManagerServer ¶
type IMediaProjectionManagerServer interface {
HasProjectionPermission(ctx context.Context, processUid int32, packageName string) (bool, error)
CreateProjection(ctx context.Context, processUid int32, packageName string, type_ int32, permanentGrant bool) (IMediaProjection, error)
GetProjection(ctx context.Context, processUid int32, packageName string) (IMediaProjection, error)
IsCurrentProjection(ctx context.Context, projection IMediaProjection) (bool, error)
RequestConsentForInvalidProjection(ctx context.Context, projection IMediaProjection) error
GetActiveProjectionInfo(ctx context.Context) (MediaProjectionInfo, error)
StopActiveProjection(ctx context.Context) error
NotifyActiveProjectionCapturedContentResized(ctx context.Context, width int32, height int32) error
NotifyActiveProjectionCapturedContentVisibilityChanged(ctx context.Context, isVisible bool) error
AddCallback(ctx context.Context, callback IMediaProjectionWatcherCallback) (MediaProjectionInfo, error)
RemoveCallback(ctx context.Context, callback IMediaProjectionWatcherCallback) error
SetContentRecordingSession(ctx context.Context, incomingSession view.ContentRecordingSession, projection IMediaProjection) (bool, error)
SetUserReviewGrantedConsentResult(ctx context.Context, consentResult ReviewGrantedConsentResult, projection IMediaProjection) error
NotifyPermissionRequestInitiated(ctx context.Context, hostProcessUid int32, sessionCreationSource int32) error
NotifyPermissionRequestDisplayed(ctx context.Context, hostProcessUid int32) error
NotifyPermissionRequestCancelled(ctx context.Context, hostProcessUid int32) error
NotifyAppSelectorDisplayed(ctx context.Context, hostProcessUid int32) error
NotifyWindowingModeChanged(ctx context.Context, contentToRecord int32, targetProcessUid int32, windowingMode int32) error
}
IMediaProjectionManagerServer is the server-side interface that user implementations provide to NewMediaProjectionManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IMediaProjectionServer ¶
type IMediaProjectionServer interface {
Start(ctx context.Context, callback IMediaProjectionCallback) error
Stop(ctx context.Context) error
CanProjectAudio(ctx context.Context) (bool, error)
CanProjectVideo(ctx context.Context) (bool, error)
CanProjectSecureVideo(ctx context.Context) (bool, error)
ApplyVirtualDisplayFlags(ctx context.Context, flags int32) (int32, error)
RegisterCallback(ctx context.Context, callback IMediaProjectionCallback) error
UnregisterCallback(ctx context.Context, callback IMediaProjectionCallback) error
GetLaunchCookie(ctx context.Context) (types.ActivityOptionsLaunchCookie, error)
SetLaunchCookie(ctx context.Context, launchCookie types.ActivityOptionsLaunchCookie) error
IsValid(ctx context.Context) (bool, error)
NotifyVirtualDisplayCreated(ctx context.Context, displayId int32) error
}
IMediaProjectionServer is the server-side interface that user implementations provide to NewMediaProjectionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IMediaProjectionWatcherCallback ¶
type IMediaProjectionWatcherCallback interface {
AsBinder() binder.IBinder
OnStart(ctx context.Context, info MediaProjectionInfo) error
OnStop(ctx context.Context, info MediaProjectionInfo) error
OnRecordingSessionSet(ctx context.Context, info MediaProjectionInfo, session *view.ContentRecordingSession) error
}
func NewMediaProjectionWatcherCallbackStub ¶
func NewMediaProjectionWatcherCallbackStub( impl IMediaProjectionWatcherCallbackServer, ) IMediaProjectionWatcherCallback
NewMediaProjectionWatcherCallbackStub creates a server-side IMediaProjectionWatcherCallback wrapping the given server implementation. The returned value satisfies IMediaProjectionWatcherCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IMediaProjectionWatcherCallbackServer ¶
type IMediaProjectionWatcherCallbackServer interface {
OnStart(ctx context.Context, info MediaProjectionInfo) error
OnStop(ctx context.Context, info MediaProjectionInfo) error
OnRecordingSessionSet(ctx context.Context, info MediaProjectionInfo, session *view.ContentRecordingSession) error
}
IMediaProjectionWatcherCallbackServer is the server-side interface that user implementations provide to NewMediaProjectionWatcherCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type MediaProjectionCallbackProxy ¶
func NewMediaProjectionCallbackProxy ¶
func NewMediaProjectionCallbackProxy( remote binder.IBinder, ) *MediaProjectionCallbackProxy
func (*MediaProjectionCallbackProxy) AsBinder ¶
func (p *MediaProjectionCallbackProxy) AsBinder() binder.IBinder
func (*MediaProjectionCallbackProxy) OnCapturedContentResize ¶
func (*MediaProjectionCallbackProxy) OnCapturedContentVisibilityChanged ¶
func (p *MediaProjectionCallbackProxy) OnCapturedContentVisibilityChanged( ctx context.Context, isVisible bool, ) error
type MediaProjectionCallbackStub ¶
type MediaProjectionCallbackStub struct {
Impl IMediaProjectionCallback
Transport binder.VersionAwareTransport
}
MediaProjectionCallbackStub dispatches incoming binder transactions to a typed IMediaProjectionCallback implementation.
func (*MediaProjectionCallbackStub) Descriptor ¶
func (s *MediaProjectionCallbackStub) Descriptor() string
func (*MediaProjectionCallbackStub) OnTransaction ¶
func (s *MediaProjectionCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type MediaProjectionConfig ¶
func (*MediaProjectionConfig) MarshalParcel ¶
func (s *MediaProjectionConfig) MarshalParcel( p *parcel.Parcel, ) error
func (*MediaProjectionConfig) UnmarshalParcel ¶
func (s *MediaProjectionConfig) UnmarshalParcel( p *parcel.Parcel, ) error
type MediaProjectionInfo ¶
type MediaProjectionInfo struct {
PackageName string
}
func (*MediaProjectionInfo) MarshalParcel ¶
func (s *MediaProjectionInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*MediaProjectionInfo) UnmarshalParcel ¶
func (s *MediaProjectionInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type MediaProjectionManagerProxy ¶
func NewMediaProjectionManagerProxy ¶
func NewMediaProjectionManagerProxy( remote binder.IBinder, ) *MediaProjectionManagerProxy
func (*MediaProjectionManagerProxy) AddCallback ¶
func (p *MediaProjectionManagerProxy) AddCallback( ctx context.Context, callback IMediaProjectionWatcherCallback, ) (MediaProjectionInfo, error)
func (*MediaProjectionManagerProxy) AsBinder ¶
func (p *MediaProjectionManagerProxy) AsBinder() binder.IBinder
func (*MediaProjectionManagerProxy) CreateProjection ¶
func (p *MediaProjectionManagerProxy) CreateProjection( ctx context.Context, processUid int32, packageName string, type_ int32, permanentGrant bool, ) (IMediaProjection, error)
func (*MediaProjectionManagerProxy) GetActiveProjectionInfo ¶
func (p *MediaProjectionManagerProxy) GetActiveProjectionInfo( ctx context.Context, ) (MediaProjectionInfo, error)
func (*MediaProjectionManagerProxy) GetProjection ¶
func (p *MediaProjectionManagerProxy) GetProjection( ctx context.Context, processUid int32, packageName string, ) (IMediaProjection, error)
func (*MediaProjectionManagerProxy) HasProjectionPermission ¶
func (*MediaProjectionManagerProxy) IsCurrentProjection ¶
func (p *MediaProjectionManagerProxy) IsCurrentProjection( ctx context.Context, projection IMediaProjection, ) (bool, error)
func (*MediaProjectionManagerProxy) NotifyActiveProjectionCapturedContentResized ¶
func (*MediaProjectionManagerProxy) NotifyActiveProjectionCapturedContentVisibilityChanged ¶
func (p *MediaProjectionManagerProxy) NotifyActiveProjectionCapturedContentVisibilityChanged( ctx context.Context, isVisible bool, ) error
func (*MediaProjectionManagerProxy) NotifyAppSelectorDisplayed ¶
func (p *MediaProjectionManagerProxy) NotifyAppSelectorDisplayed( ctx context.Context, hostProcessUid int32, ) error
func (*MediaProjectionManagerProxy) NotifyPermissionRequestCancelled ¶
func (p *MediaProjectionManagerProxy) NotifyPermissionRequestCancelled( ctx context.Context, hostProcessUid int32, ) error
func (*MediaProjectionManagerProxy) NotifyPermissionRequestDisplayed ¶
func (p *MediaProjectionManagerProxy) NotifyPermissionRequestDisplayed( ctx context.Context, hostProcessUid int32, ) error
func (*MediaProjectionManagerProxy) NotifyPermissionRequestInitiated ¶
func (*MediaProjectionManagerProxy) NotifyWindowingModeChanged ¶
func (*MediaProjectionManagerProxy) RemoveCallback ¶
func (p *MediaProjectionManagerProxy) RemoveCallback( ctx context.Context, callback IMediaProjectionWatcherCallback, ) error
func (*MediaProjectionManagerProxy) RequestConsentForInvalidProjection ¶
func (p *MediaProjectionManagerProxy) RequestConsentForInvalidProjection( ctx context.Context, projection IMediaProjection, ) error
func (*MediaProjectionManagerProxy) SetContentRecordingSession ¶
func (p *MediaProjectionManagerProxy) SetContentRecordingSession( ctx context.Context, incomingSession view.ContentRecordingSession, projection IMediaProjection, ) (bool, error)
func (*MediaProjectionManagerProxy) SetUserReviewGrantedConsentResult ¶
func (p *MediaProjectionManagerProxy) SetUserReviewGrantedConsentResult( ctx context.Context, consentResult ReviewGrantedConsentResult, projection IMediaProjection, ) error
func (*MediaProjectionManagerProxy) StopActiveProjection ¶
func (p *MediaProjectionManagerProxy) StopActiveProjection( ctx context.Context, ) error
type MediaProjectionManagerStub ¶
type MediaProjectionManagerStub struct {
Impl IMediaProjectionManager
Transport binder.VersionAwareTransport
}
MediaProjectionManagerStub dispatches incoming binder transactions to a typed IMediaProjectionManager implementation.
func (*MediaProjectionManagerStub) Descriptor ¶
func (s *MediaProjectionManagerStub) Descriptor() string
func (*MediaProjectionManagerStub) OnTransaction ¶
func (s *MediaProjectionManagerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type MediaProjectionProxy ¶
func NewMediaProjectionProxy ¶
func NewMediaProjectionProxy( remote binder.IBinder, ) *MediaProjectionProxy
func (*MediaProjectionProxy) ApplyVirtualDisplayFlags ¶
func (*MediaProjectionProxy) AsBinder ¶
func (p *MediaProjectionProxy) AsBinder() binder.IBinder
func (*MediaProjectionProxy) CanProjectAudio ¶
func (p *MediaProjectionProxy) CanProjectAudio( ctx context.Context, ) (bool, error)
func (*MediaProjectionProxy) CanProjectSecureVideo ¶
func (p *MediaProjectionProxy) CanProjectSecureVideo( ctx context.Context, ) (bool, error)
func (*MediaProjectionProxy) CanProjectVideo ¶
func (p *MediaProjectionProxy) CanProjectVideo( ctx context.Context, ) (bool, error)
func (*MediaProjectionProxy) GetLaunchCookie ¶
func (p *MediaProjectionProxy) GetLaunchCookie( ctx context.Context, ) (types.ActivityOptionsLaunchCookie, error)
func (*MediaProjectionProxy) IsValid ¶
func (p *MediaProjectionProxy) IsValid( ctx context.Context, ) (bool, error)
func (*MediaProjectionProxy) NotifyVirtualDisplayCreated ¶
func (p *MediaProjectionProxy) NotifyVirtualDisplayCreated( ctx context.Context, displayId int32, ) error
func (*MediaProjectionProxy) RegisterCallback ¶
func (p *MediaProjectionProxy) RegisterCallback( ctx context.Context, callback IMediaProjectionCallback, ) error
func (*MediaProjectionProxy) SetLaunchCookie ¶
func (p *MediaProjectionProxy) SetLaunchCookie( ctx context.Context, launchCookie types.ActivityOptionsLaunchCookie, ) error
func (*MediaProjectionProxy) Start ¶
func (p *MediaProjectionProxy) Start( ctx context.Context, callback IMediaProjectionCallback, ) error
func (*MediaProjectionProxy) Stop ¶
func (p *MediaProjectionProxy) Stop( ctx context.Context, ) error
func (*MediaProjectionProxy) UnregisterCallback ¶
func (p *MediaProjectionProxy) UnregisterCallback( ctx context.Context, callback IMediaProjectionCallback, ) error
type MediaProjectionStub ¶
type MediaProjectionStub struct {
Impl IMediaProjection
Transport binder.VersionAwareTransport
}
MediaProjectionStub dispatches incoming binder transactions to a typed IMediaProjection implementation.
func (*MediaProjectionStub) Descriptor ¶
func (s *MediaProjectionStub) Descriptor() string
func (*MediaProjectionStub) OnTransaction ¶
func (s *MediaProjectionStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type MediaProjectionWatcherCallbackProxy ¶
func NewMediaProjectionWatcherCallbackProxy ¶
func NewMediaProjectionWatcherCallbackProxy( remote binder.IBinder, ) *MediaProjectionWatcherCallbackProxy
func (*MediaProjectionWatcherCallbackProxy) AsBinder ¶
func (p *MediaProjectionWatcherCallbackProxy) AsBinder() binder.IBinder
func (*MediaProjectionWatcherCallbackProxy) OnRecordingSessionSet ¶
func (p *MediaProjectionWatcherCallbackProxy) OnRecordingSessionSet( ctx context.Context, info MediaProjectionInfo, session *view.ContentRecordingSession, ) error
func (*MediaProjectionWatcherCallbackProxy) OnStart ¶
func (p *MediaProjectionWatcherCallbackProxy) OnStart( ctx context.Context, info MediaProjectionInfo, ) error
func (*MediaProjectionWatcherCallbackProxy) OnStop ¶
func (p *MediaProjectionWatcherCallbackProxy) OnStop( ctx context.Context, info MediaProjectionInfo, ) error
type MediaProjectionWatcherCallbackStub ¶
type MediaProjectionWatcherCallbackStub struct {
Impl IMediaProjectionWatcherCallback
Transport binder.VersionAwareTransport
}
MediaProjectionWatcherCallbackStub dispatches incoming binder transactions to a typed IMediaProjectionWatcherCallback implementation.
func (*MediaProjectionWatcherCallbackStub) Descriptor ¶
func (s *MediaProjectionWatcherCallbackStub) Descriptor() string
func (*MediaProjectionWatcherCallbackStub) OnTransaction ¶
func (s *MediaProjectionWatcherCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ReviewGrantedConsentResult ¶
type ReviewGrantedConsentResult int32
const ( ReviewGrantedConsentResultUNKNOWN ReviewGrantedConsentResult = -1 ReviewGrantedConsentResultRecordCancel ReviewGrantedConsentResult = 0 ReviewGrantedConsentResultRecordContentDisplay ReviewGrantedConsentResult = 1 ReviewGrantedConsentResultRecordContentTask ReviewGrantedConsentResult = 2 )