Documentation
¶
Index ¶
- Constants
- type ITvAdClient
- type ITvAdClientServer
- type ITvAdManager
- type ITvAdManagerCallback
- type ITvAdManagerCallbackServer
- type ITvAdManagerServer
- type ITvAdService
- type ITvAdServiceCallback
- type ITvAdServiceCallbackServer
- type ITvAdServiceServer
- type ITvAdSession
- type ITvAdSessionCallback
- type ITvAdSessionCallbackServer
- type ITvAdSessionServer
- type TvAdClientProxy
- func (p *TvAdClientProxy) AsBinder() binder.IBinder
- func (p *TvAdClientProxy) OnLayoutSurface(ctx context.Context, left int32, top int32, right int32, bottom int32, ...) error
- func (p *TvAdClientProxy) OnRequestCurrentChannelUri(ctx context.Context, seq int32) error
- func (p *TvAdClientProxy) OnRequestCurrentTvInputId(ctx context.Context, seq int32) error
- func (p *TvAdClientProxy) OnRequestCurrentVideoBounds(ctx context.Context, seq int32) error
- func (p *TvAdClientProxy) OnRequestSigning(ctx context.Context, id string, algorithm string, alias string, data []byte, ...) error
- func (p *TvAdClientProxy) OnRequestTrackInfoList(ctx context.Context, seq int32) error
- func (p *TvAdClientProxy) OnSessionCreated(ctx context.Context, serviceId string, token binder.IBinder, ...) error
- func (p *TvAdClientProxy) OnSessionReleased(ctx context.Context, seq int32) error
- func (p *TvAdClientProxy) OnTvAdSessionData(ctx context.Context, type_ string, data os.Bundle, seq int32) error
- type TvAdClientStub
- type TvAdManagerCallbackProxy
- func (p *TvAdManagerCallbackProxy) AsBinder() binder.IBinder
- func (p *TvAdManagerCallbackProxy) OnAdServiceAdded(ctx context.Context, serviceId string) error
- func (p *TvAdManagerCallbackProxy) OnAdServiceRemoved(ctx context.Context, serviceId string) error
- func (p *TvAdManagerCallbackProxy) OnAdServiceUpdated(ctx context.Context, serviceId string) error
- type TvAdManagerCallbackStub
- type TvAdManagerProxy
- func (p *TvAdManagerProxy) AsBinder() binder.IBinder
- func (p *TvAdManagerProxy) CreateMediaView(ctx context.Context, sessionToken binder.IBinder, windowToken binder.IBinder, ...) error
- func (p *TvAdManagerProxy) CreateSession(ctx context.Context, client ITvAdClient, serviceId string, type_ string, ...) error
- func (p *TvAdManagerProxy) DispatchSurfaceChanged(ctx context.Context, sessionToken binder.IBinder, format int32, width int32, ...) error
- func (p *TvAdManagerProxy) GetTvAdServiceList(ctx context.Context) ([]TvAdServiceInfo, error)
- func (p *TvAdManagerProxy) NotifyError(ctx context.Context, sessionToken binder.IBinder, errMsg string, ...) error
- func (p *TvAdManagerProxy) NotifyTvInputSessionData(ctx context.Context, sessionToken binder.IBinder, type_ string, data os.Bundle) error
- func (p *TvAdManagerProxy) NotifyTvMessage(ctx context.Context, sessionToken binder.IBinder, type_ int32, data os.Bundle) error
- func (p *TvAdManagerProxy) RegisterCallback(ctx context.Context, callback ITvAdManagerCallback) error
- func (p *TvAdManagerProxy) RelayoutMediaView(ctx context.Context, sessionToken binder.IBinder, frame graphics.Rect) error
- func (p *TvAdManagerProxy) ReleaseSession(ctx context.Context, sessionToken binder.IBinder) error
- func (p *TvAdManagerProxy) RemoveMediaView(ctx context.Context, sessionToken binder.IBinder) error
- func (p *TvAdManagerProxy) ResetAdService(ctx context.Context, sessionToken binder.IBinder) error
- func (p *TvAdManagerProxy) SendAppLinkCommand(ctx context.Context, serviceId string, command os.Bundle) error
- func (p *TvAdManagerProxy) SendCurrentChannelUri(ctx context.Context, sessionToken binder.IBinder, channelUri net.Uri) error
- func (p *TvAdManagerProxy) SendCurrentTvInputId(ctx context.Context, sessionToken binder.IBinder, inputId string) error
- func (p *TvAdManagerProxy) SendCurrentVideoBounds(ctx context.Context, sessionToken binder.IBinder, bounds graphics.Rect) error
- func (p *TvAdManagerProxy) SendSigningResult(ctx context.Context, sessionToken binder.IBinder, signingId string, ...) error
- func (p *TvAdManagerProxy) SendTrackInfoList(ctx context.Context, sessionToken binder.IBinder, tracks []tv.TvTrackInfo) error
- func (p *TvAdManagerProxy) SetSurface(ctx context.Context, sessionToken binder.IBinder, surface view.Surface) error
- func (p *TvAdManagerProxy) StartAdService(ctx context.Context, sessionToken binder.IBinder) error
- func (p *TvAdManagerProxy) StopAdService(ctx context.Context, sessionToken binder.IBinder) error
- func (p *TvAdManagerProxy) UnregisterCallback(ctx context.Context, callback ITvAdManagerCallback) error
- type TvAdManagerStub
- type TvAdServiceCallbackProxy
- type TvAdServiceCallbackStub
- type TvAdServiceInfo
- type TvAdServiceProxy
- func (p *TvAdServiceProxy) AsBinder() binder.IBinder
- func (p *TvAdServiceProxy) CreateSession(ctx context.Context, channel view.InputChannel, callback ITvAdSessionCallback, ...) error
- func (p *TvAdServiceProxy) RegisterCallback(ctx context.Context, callback ITvAdServiceCallback) error
- func (p *TvAdServiceProxy) SendAppLinkCommand(ctx context.Context, command os.Bundle) error
- func (p *TvAdServiceProxy) UnregisterCallback(ctx context.Context, callback ITvAdServiceCallback) error
- type TvAdServiceStub
- type TvAdSessionCallbackProxy
- func (p *TvAdSessionCallbackProxy) AsBinder() binder.IBinder
- func (p *TvAdSessionCallbackProxy) OnLayoutSurface(ctx context.Context, left int32, top int32, right int32, bottom int32) error
- func (p *TvAdSessionCallbackProxy) OnRequestCurrentChannelUri(ctx context.Context) error
- func (p *TvAdSessionCallbackProxy) OnRequestCurrentTvInputId(ctx context.Context) error
- func (p *TvAdSessionCallbackProxy) OnRequestCurrentVideoBounds(ctx context.Context) error
- func (p *TvAdSessionCallbackProxy) OnRequestSigning(ctx context.Context, id string, algorithm string, alias string, data []byte) error
- func (p *TvAdSessionCallbackProxy) OnRequestTrackInfoList(ctx context.Context) error
- func (p *TvAdSessionCallbackProxy) OnSessionCreated(ctx context.Context, session ITvAdSession) error
- func (p *TvAdSessionCallbackProxy) OnTvAdSessionData(ctx context.Context, type_ string, data os.Bundle) error
- type TvAdSessionCallbackStub
- type TvAdSessionProxy
- func (p *TvAdSessionProxy) AsBinder() binder.IBinder
- func (p *TvAdSessionProxy) CreateMediaView(ctx context.Context, windowToken binder.IBinder, frame graphics.Rect) error
- func (p *TvAdSessionProxy) DispatchSurfaceChanged(ctx context.Context, format int32, width int32, height int32) error
- func (p *TvAdSessionProxy) NotifyError(ctx context.Context, errMsg string, params os.Bundle) error
- func (p *TvAdSessionProxy) NotifyTvInputSessionData(ctx context.Context, type_ string, data os.Bundle) error
- func (p *TvAdSessionProxy) NotifyTvMessage(ctx context.Context, type_ int32, data os.Bundle) error
- func (p *TvAdSessionProxy) RelayoutMediaView(ctx context.Context, frame graphics.Rect) error
- func (p *TvAdSessionProxy) Release(ctx context.Context) error
- func (p *TvAdSessionProxy) RemoveMediaView(ctx context.Context) error
- func (p *TvAdSessionProxy) ResetAdService(ctx context.Context) error
- func (p *TvAdSessionProxy) SendCurrentChannelUri(ctx context.Context, channelUri net.Uri) error
- func (p *TvAdSessionProxy) SendCurrentTvInputId(ctx context.Context, inputId string) error
- func (p *TvAdSessionProxy) SendCurrentVideoBounds(ctx context.Context, bounds graphics.Rect) error
- func (p *TvAdSessionProxy) SendSigningResult(ctx context.Context, signingId string, result []byte) error
- func (p *TvAdSessionProxy) SendTrackInfoList(ctx context.Context, tracks []tv.TvTrackInfo) error
- func (p *TvAdSessionProxy) SetSurface(ctx context.Context, surface view.Surface) error
- func (p *TvAdSessionProxy) StartAdService(ctx context.Context) error
- func (p *TvAdSessionProxy) StopAdService(ctx context.Context) error
- type TvAdSessionStub
Constants ¶
const ( TransactionITvAdClientOnSessionCreated = binder.FirstCallTransaction + 0 TransactionITvAdClientOnSessionReleased = binder.FirstCallTransaction + 1 TransactionITvAdClientOnLayoutSurface = binder.FirstCallTransaction + 2 TransactionITvAdClientOnRequestCurrentVideoBounds = binder.FirstCallTransaction + 3 TransactionITvAdClientOnRequestCurrentChannelUri = binder.FirstCallTransaction + 4 TransactionITvAdClientOnRequestTrackInfoList = binder.FirstCallTransaction + 5 TransactionITvAdClientOnRequestCurrentTvInputId = binder.FirstCallTransaction + 6 TransactionITvAdClientOnRequestSigning = binder.FirstCallTransaction + 7 TransactionITvAdClientOnTvAdSessionData = binder.FirstCallTransaction + 8 )
const ( MethodITvAdClientOnSessionCreated = "onSessionCreated" MethodITvAdClientOnSessionReleased = "onSessionReleased" MethodITvAdClientOnLayoutSurface = "onLayoutSurface" MethodITvAdClientOnRequestCurrentVideoBounds = "onRequestCurrentVideoBounds" MethodITvAdClientOnRequestCurrentChannelUri = "onRequestCurrentChannelUri" MethodITvAdClientOnRequestTrackInfoList = "onRequestTrackInfoList" MethodITvAdClientOnRequestCurrentTvInputId = "onRequestCurrentTvInputId" MethodITvAdClientOnRequestSigning = "onRequestSigning" MethodITvAdClientOnTvAdSessionData = "onTvAdSessionData" )
const ( TransactionITvAdManagerGetTvAdServiceList = binder.FirstCallTransaction + 0 TransactionITvAdManagerSendAppLinkCommand = binder.FirstCallTransaction + 1 TransactionITvAdManagerCreateSession = binder.FirstCallTransaction + 2 TransactionITvAdManagerReleaseSession = binder.FirstCallTransaction + 3 TransactionITvAdManagerStartAdService = binder.FirstCallTransaction + 4 TransactionITvAdManagerStopAdService = binder.FirstCallTransaction + 5 TransactionITvAdManagerResetAdService = binder.FirstCallTransaction + 6 TransactionITvAdManagerSetSurface = binder.FirstCallTransaction + 7 TransactionITvAdManagerDispatchSurfaceChanged = binder.FirstCallTransaction + 8 TransactionITvAdManagerSendCurrentVideoBounds = binder.FirstCallTransaction + 9 TransactionITvAdManagerSendCurrentChannelUri = binder.FirstCallTransaction + 10 TransactionITvAdManagerSendTrackInfoList = binder.FirstCallTransaction + 11 TransactionITvAdManagerSendCurrentTvInputId = binder.FirstCallTransaction + 12 TransactionITvAdManagerSendSigningResult = binder.FirstCallTransaction + 13 TransactionITvAdManagerNotifyError = binder.FirstCallTransaction + 14 TransactionITvAdManagerNotifyTvMessage = binder.FirstCallTransaction + 15 TransactionITvAdManagerRegisterCallback = binder.FirstCallTransaction + 16 TransactionITvAdManagerUnregisterCallback = binder.FirstCallTransaction + 17 TransactionITvAdManagerCreateMediaView = binder.FirstCallTransaction + 18 TransactionITvAdManagerRelayoutMediaView = binder.FirstCallTransaction + 19 TransactionITvAdManagerRemoveMediaView = binder.FirstCallTransaction + 20 TransactionITvAdManagerNotifyTvInputSessionData = binder.FirstCallTransaction + 21 )
const ( MethodITvAdManagerGetTvAdServiceList = "getTvAdServiceList" MethodITvAdManagerSendAppLinkCommand = "sendAppLinkCommand" MethodITvAdManagerCreateSession = "createSession" MethodITvAdManagerReleaseSession = "releaseSession" MethodITvAdManagerStartAdService = "startAdService" MethodITvAdManagerStopAdService = "stopAdService" MethodITvAdManagerResetAdService = "resetAdService" MethodITvAdManagerSetSurface = "setSurface" MethodITvAdManagerDispatchSurfaceChanged = "dispatchSurfaceChanged" MethodITvAdManagerSendCurrentVideoBounds = "sendCurrentVideoBounds" MethodITvAdManagerSendCurrentChannelUri = "sendCurrentChannelUri" MethodITvAdManagerSendTrackInfoList = "sendTrackInfoList" MethodITvAdManagerSendCurrentTvInputId = "sendCurrentTvInputId" MethodITvAdManagerSendSigningResult = "sendSigningResult" MethodITvAdManagerNotifyError = "notifyError" MethodITvAdManagerNotifyTvMessage = "notifyTvMessage" MethodITvAdManagerRegisterCallback = "registerCallback" MethodITvAdManagerUnregisterCallback = "unregisterCallback" MethodITvAdManagerCreateMediaView = "createMediaView" MethodITvAdManagerRelayoutMediaView = "relayoutMediaView" MethodITvAdManagerRemoveMediaView = "removeMediaView" MethodITvAdManagerNotifyTvInputSessionData = "notifyTvInputSessionData" )
const ( TransactionITvAdManagerCallbackOnAdServiceAdded = binder.FirstCallTransaction + 0 TransactionITvAdManagerCallbackOnAdServiceRemoved = binder.FirstCallTransaction + 1 TransactionITvAdManagerCallbackOnAdServiceUpdated = binder.FirstCallTransaction + 2 )
const ( MethodITvAdManagerCallbackOnAdServiceAdded = "onAdServiceAdded" MethodITvAdManagerCallbackOnAdServiceRemoved = "onAdServiceRemoved" MethodITvAdManagerCallbackOnAdServiceUpdated = "onAdServiceUpdated" )
const ( TransactionITvAdServiceRegisterCallback = binder.FirstCallTransaction + 0 TransactionITvAdServiceUnregisterCallback = binder.FirstCallTransaction + 1 TransactionITvAdServiceCreateSession = binder.FirstCallTransaction + 2 TransactionITvAdServiceSendAppLinkCommand = binder.FirstCallTransaction + 3 )
const ( MethodITvAdServiceRegisterCallback = "registerCallback" MethodITvAdServiceUnregisterCallback = "unregisterCallback" MethodITvAdServiceCreateSession = "createSession" MethodITvAdServiceSendAppLinkCommand = "sendAppLinkCommand" )
const ( TransactionITvAdSessionRelease = binder.FirstCallTransaction + 0 TransactionITvAdSessionStartAdService = binder.FirstCallTransaction + 1 TransactionITvAdSessionStopAdService = binder.FirstCallTransaction + 2 TransactionITvAdSessionResetAdService = binder.FirstCallTransaction + 3 TransactionITvAdSessionSetSurface = binder.FirstCallTransaction + 4 TransactionITvAdSessionDispatchSurfaceChanged = binder.FirstCallTransaction + 5 TransactionITvAdSessionSendCurrentVideoBounds = binder.FirstCallTransaction + 6 TransactionITvAdSessionSendCurrentChannelUri = binder.FirstCallTransaction + 7 TransactionITvAdSessionSendTrackInfoList = binder.FirstCallTransaction + 8 TransactionITvAdSessionSendCurrentTvInputId = binder.FirstCallTransaction + 9 TransactionITvAdSessionSendSigningResult = binder.FirstCallTransaction + 10 TransactionITvAdSessionNotifyError = binder.FirstCallTransaction + 11 TransactionITvAdSessionNotifyTvMessage = binder.FirstCallTransaction + 12 TransactionITvAdSessionCreateMediaView = binder.FirstCallTransaction + 13 TransactionITvAdSessionRelayoutMediaView = binder.FirstCallTransaction + 14 TransactionITvAdSessionRemoveMediaView = binder.FirstCallTransaction + 15 TransactionITvAdSessionNotifyTvInputSessionData = binder.FirstCallTransaction + 16 )
const ( MethodITvAdSessionRelease = "release" MethodITvAdSessionStartAdService = "startAdService" MethodITvAdSessionStopAdService = "stopAdService" MethodITvAdSessionResetAdService = "resetAdService" MethodITvAdSessionSetSurface = "setSurface" MethodITvAdSessionDispatchSurfaceChanged = "dispatchSurfaceChanged" MethodITvAdSessionSendCurrentVideoBounds = "sendCurrentVideoBounds" MethodITvAdSessionSendCurrentChannelUri = "sendCurrentChannelUri" MethodITvAdSessionSendTrackInfoList = "sendTrackInfoList" MethodITvAdSessionSendCurrentTvInputId = "sendCurrentTvInputId" MethodITvAdSessionSendSigningResult = "sendSigningResult" MethodITvAdSessionNotifyError = "notifyError" MethodITvAdSessionNotifyTvMessage = "notifyTvMessage" MethodITvAdSessionCreateMediaView = "createMediaView" MethodITvAdSessionRelayoutMediaView = "relayoutMediaView" MethodITvAdSessionRemoveMediaView = "removeMediaView" MethodITvAdSessionNotifyTvInputSessionData = "notifyTvInputSessionData" )
const ( TransactionITvAdSessionCallbackOnSessionCreated = binder.FirstCallTransaction + 0 TransactionITvAdSessionCallbackOnLayoutSurface = binder.FirstCallTransaction + 1 TransactionITvAdSessionCallbackOnRequestCurrentVideoBounds = binder.FirstCallTransaction + 2 TransactionITvAdSessionCallbackOnRequestCurrentChannelUri = binder.FirstCallTransaction + 3 TransactionITvAdSessionCallbackOnRequestTrackInfoList = binder.FirstCallTransaction + 4 TransactionITvAdSessionCallbackOnRequestCurrentTvInputId = binder.FirstCallTransaction + 5 TransactionITvAdSessionCallbackOnRequestSigning = binder.FirstCallTransaction + 6 TransactionITvAdSessionCallbackOnTvAdSessionData = binder.FirstCallTransaction + 7 )
const ( MethodITvAdSessionCallbackOnSessionCreated = "onSessionCreated" MethodITvAdSessionCallbackOnLayoutSurface = "onLayoutSurface" MethodITvAdSessionCallbackOnRequestCurrentVideoBounds = "onRequestCurrentVideoBounds" MethodITvAdSessionCallbackOnRequestCurrentChannelUri = "onRequestCurrentChannelUri" MethodITvAdSessionCallbackOnRequestTrackInfoList = "onRequestTrackInfoList" MethodITvAdSessionCallbackOnRequestCurrentTvInputId = "onRequestCurrentTvInputId" MethodITvAdSessionCallbackOnRequestSigning = "onRequestSigning" MethodITvAdSessionCallbackOnTvAdSessionData = "onTvAdSessionData" )
const DescriptorITvAdClient = "android.media.tv.ad.ITvAdClient"
const DescriptorITvAdManager = "android.media.tv.ad.ITvAdManager"
const DescriptorITvAdManagerCallback = "android.media.tv.ad.ITvAdManagerCallback"
const DescriptorITvAdService = "android.media.tv.ad.ITvAdService"
const DescriptorITvAdServiceCallback = "android.media.tv.ad.ITvAdServiceCallback"
const DescriptorITvAdSession = "android.media.tv.ad.ITvAdSession"
const DescriptorITvAdSessionCallback = "android.media.tv.ad.ITvAdSessionCallback"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ITvAdClient ¶
type ITvAdClient interface {
AsBinder() binder.IBinder
OnSessionCreated(ctx context.Context, serviceId string, token binder.IBinder, channel view.InputChannel, seq int32) error
OnSessionReleased(ctx context.Context, seq int32) error
OnLayoutSurface(ctx context.Context, left int32, top int32, right int32, bottom int32, seq int32) error
OnRequestCurrentVideoBounds(ctx context.Context, seq int32) error
OnRequestCurrentChannelUri(ctx context.Context, seq int32) error
OnRequestTrackInfoList(ctx context.Context, seq int32) error
OnRequestCurrentTvInputId(ctx context.Context, seq int32) error
OnRequestSigning(ctx context.Context, id string, algorithm string, alias string, data []byte, seq int32) error
OnTvAdSessionData(ctx context.Context, type_ string, data os.Bundle, seq int32) error
}
func NewTvAdClientStub ¶
func NewTvAdClientStub( impl ITvAdClientServer, ) ITvAdClient
NewTvAdClientStub creates a server-side ITvAdClient wrapping the given server implementation. The returned value satisfies ITvAdClient and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITvAdClientServer ¶
type ITvAdClientServer interface {
OnSessionCreated(ctx context.Context, serviceId string, token binder.IBinder, channel view.InputChannel, seq int32) error
OnSessionReleased(ctx context.Context, seq int32) error
OnLayoutSurface(ctx context.Context, left int32, top int32, right int32, bottom int32, seq int32) error
OnRequestCurrentVideoBounds(ctx context.Context, seq int32) error
OnRequestCurrentChannelUri(ctx context.Context, seq int32) error
OnRequestTrackInfoList(ctx context.Context, seq int32) error
OnRequestCurrentTvInputId(ctx context.Context, seq int32) error
OnRequestSigning(ctx context.Context, id string, algorithm string, alias string, data []byte, seq int32) error
OnTvAdSessionData(ctx context.Context, type_ string, data os.Bundle, seq int32) error
}
ITvAdClientServer is the server-side interface that user implementations provide to NewTvAdClientStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ITvAdManager ¶
type ITvAdManager interface {
AsBinder() binder.IBinder
GetTvAdServiceList(ctx context.Context) ([]TvAdServiceInfo, error)
SendAppLinkCommand(ctx context.Context, serviceId string, command os.Bundle) error
CreateSession(ctx context.Context, client ITvAdClient, serviceId string, type_ string, seq int32) error
ReleaseSession(ctx context.Context, sessionToken binder.IBinder) error
StartAdService(ctx context.Context, sessionToken binder.IBinder) error
StopAdService(ctx context.Context, sessionToken binder.IBinder) error
ResetAdService(ctx context.Context, sessionToken binder.IBinder) error
SetSurface(ctx context.Context, sessionToken binder.IBinder, surface view.Surface) error
DispatchSurfaceChanged(ctx context.Context, sessionToken binder.IBinder, format int32, width int32, height int32) error
SendCurrentVideoBounds(ctx context.Context, sessionToken binder.IBinder, bounds graphics.Rect) error
SendCurrentChannelUri(ctx context.Context, sessionToken binder.IBinder, channelUri net.Uri) error
SendTrackInfoList(ctx context.Context, sessionToken binder.IBinder, tracks []tv.TvTrackInfo) error
SendCurrentTvInputId(ctx context.Context, sessionToken binder.IBinder, inputId string) error
SendSigningResult(ctx context.Context, sessionToken binder.IBinder, signingId string, result []byte) error
NotifyError(ctx context.Context, sessionToken binder.IBinder, errMsg string, params os.Bundle) error
NotifyTvMessage(ctx context.Context, sessionToken binder.IBinder, type_ int32, data os.Bundle) error
RegisterCallback(ctx context.Context, callback ITvAdManagerCallback) error
UnregisterCallback(ctx context.Context, callback ITvAdManagerCallback) error
CreateMediaView(ctx context.Context, sessionToken binder.IBinder, windowToken binder.IBinder, frame graphics.Rect) error
RelayoutMediaView(ctx context.Context, sessionToken binder.IBinder, frame graphics.Rect) error
RemoveMediaView(ctx context.Context, sessionToken binder.IBinder) error
NotifyTvInputSessionData(ctx context.Context, sessionToken binder.IBinder, type_ string, data os.Bundle) error
}
func NewTvAdManagerStub ¶
func NewTvAdManagerStub( impl ITvAdManagerServer, ) ITvAdManager
NewTvAdManagerStub creates a server-side ITvAdManager wrapping the given server implementation. The returned value satisfies ITvAdManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITvAdManagerCallback ¶
type ITvAdManagerCallback interface {
AsBinder() binder.IBinder
OnAdServiceAdded(ctx context.Context, serviceId string) error
OnAdServiceRemoved(ctx context.Context, serviceId string) error
OnAdServiceUpdated(ctx context.Context, serviceId string) error
}
func NewTvAdManagerCallbackStub ¶
func NewTvAdManagerCallbackStub( impl ITvAdManagerCallbackServer, ) ITvAdManagerCallback
NewTvAdManagerCallbackStub creates a server-side ITvAdManagerCallback wrapping the given server implementation. The returned value satisfies ITvAdManagerCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITvAdManagerCallbackServer ¶
type ITvAdManagerCallbackServer interface {
OnAdServiceAdded(ctx context.Context, serviceId string) error
OnAdServiceRemoved(ctx context.Context, serviceId string) error
OnAdServiceUpdated(ctx context.Context, serviceId string) error
}
ITvAdManagerCallbackServer is the server-side interface that user implementations provide to NewTvAdManagerCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ITvAdManagerServer ¶
type ITvAdManagerServer interface {
GetTvAdServiceList(ctx context.Context) ([]TvAdServiceInfo, error)
SendAppLinkCommand(ctx context.Context, serviceId string, command os.Bundle) error
CreateSession(ctx context.Context, client ITvAdClient, serviceId string, type_ string, seq int32) error
ReleaseSession(ctx context.Context, sessionToken binder.IBinder) error
StartAdService(ctx context.Context, sessionToken binder.IBinder) error
StopAdService(ctx context.Context, sessionToken binder.IBinder) error
ResetAdService(ctx context.Context, sessionToken binder.IBinder) error
SetSurface(ctx context.Context, sessionToken binder.IBinder, surface view.Surface) error
DispatchSurfaceChanged(ctx context.Context, sessionToken binder.IBinder, format int32, width int32, height int32) error
SendCurrentVideoBounds(ctx context.Context, sessionToken binder.IBinder, bounds graphics.Rect) error
SendCurrentChannelUri(ctx context.Context, sessionToken binder.IBinder, channelUri net.Uri) error
SendTrackInfoList(ctx context.Context, sessionToken binder.IBinder, tracks []tv.TvTrackInfo) error
SendCurrentTvInputId(ctx context.Context, sessionToken binder.IBinder, inputId string) error
SendSigningResult(ctx context.Context, sessionToken binder.IBinder, signingId string, result []byte) error
NotifyError(ctx context.Context, sessionToken binder.IBinder, errMsg string, params os.Bundle) error
NotifyTvMessage(ctx context.Context, sessionToken binder.IBinder, type_ int32, data os.Bundle) error
RegisterCallback(ctx context.Context, callback ITvAdManagerCallback) error
UnregisterCallback(ctx context.Context, callback ITvAdManagerCallback) error
CreateMediaView(ctx context.Context, sessionToken binder.IBinder, windowToken binder.IBinder, frame graphics.Rect) error
RelayoutMediaView(ctx context.Context, sessionToken binder.IBinder, frame graphics.Rect) error
RemoveMediaView(ctx context.Context, sessionToken binder.IBinder) error
NotifyTvInputSessionData(ctx context.Context, sessionToken binder.IBinder, type_ string, data os.Bundle) error
}
ITvAdManagerServer is the server-side interface that user implementations provide to NewTvAdManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ITvAdService ¶
type ITvAdService interface {
AsBinder() binder.IBinder
RegisterCallback(ctx context.Context, callback ITvAdServiceCallback) error
UnregisterCallback(ctx context.Context, callback ITvAdServiceCallback) error
CreateSession(ctx context.Context, channel view.InputChannel, callback ITvAdSessionCallback, serviceId string, type_ string) error
SendAppLinkCommand(ctx context.Context, command os.Bundle) error
}
func NewTvAdServiceStub ¶
func NewTvAdServiceStub( impl ITvAdServiceServer, ) ITvAdService
NewTvAdServiceStub creates a server-side ITvAdService wrapping the given server implementation. The returned value satisfies ITvAdService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITvAdServiceCallback ¶
func NewTvAdServiceCallbackStub ¶
func NewTvAdServiceCallbackStub( impl ITvAdServiceCallbackServer, ) ITvAdServiceCallback
NewTvAdServiceCallbackStub creates a server-side ITvAdServiceCallback wrapping the given server implementation. The returned value satisfies ITvAdServiceCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITvAdServiceCallbackServer ¶
type ITvAdServiceCallbackServer interface {
}
ITvAdServiceCallbackServer is the server-side interface that user implementations provide to NewTvAdServiceCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ITvAdServiceServer ¶
type ITvAdServiceServer interface {
RegisterCallback(ctx context.Context, callback ITvAdServiceCallback) error
UnregisterCallback(ctx context.Context, callback ITvAdServiceCallback) error
CreateSession(ctx context.Context, channel view.InputChannel, callback ITvAdSessionCallback, serviceId string, type_ string) error
SendAppLinkCommand(ctx context.Context, command os.Bundle) error
}
ITvAdServiceServer is the server-side interface that user implementations provide to NewTvAdServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ITvAdSession ¶
type ITvAdSession interface {
AsBinder() binder.IBinder
Release(ctx context.Context) error
StartAdService(ctx context.Context) error
StopAdService(ctx context.Context) error
ResetAdService(ctx context.Context) error
SetSurface(ctx context.Context, surface view.Surface) error
DispatchSurfaceChanged(ctx context.Context, format int32, width int32, height int32) error
SendCurrentVideoBounds(ctx context.Context, bounds graphics.Rect) error
SendCurrentChannelUri(ctx context.Context, channelUri net.Uri) error
SendTrackInfoList(ctx context.Context, tracks []tv.TvTrackInfo) error
SendCurrentTvInputId(ctx context.Context, inputId string) error
SendSigningResult(ctx context.Context, signingId string, result []byte) error
NotifyError(ctx context.Context, errMsg string, params os.Bundle) error
NotifyTvMessage(ctx context.Context, type_ int32, data os.Bundle) error
CreateMediaView(ctx context.Context, windowToken binder.IBinder, frame graphics.Rect) error
RelayoutMediaView(ctx context.Context, frame graphics.Rect) error
RemoveMediaView(ctx context.Context) error
NotifyTvInputSessionData(ctx context.Context, type_ string, data os.Bundle) error
}
func NewTvAdSessionStub ¶
func NewTvAdSessionStub( impl ITvAdSessionServer, ) ITvAdSession
NewTvAdSessionStub creates a server-side ITvAdSession wrapping the given server implementation. The returned value satisfies ITvAdSession and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITvAdSessionCallback ¶
type ITvAdSessionCallback interface {
AsBinder() binder.IBinder
OnSessionCreated(ctx context.Context, session ITvAdSession) error
OnLayoutSurface(ctx context.Context, left int32, top int32, right int32, bottom int32) error
OnRequestCurrentVideoBounds(ctx context.Context) error
OnRequestCurrentChannelUri(ctx context.Context) error
OnRequestTrackInfoList(ctx context.Context) error
OnRequestCurrentTvInputId(ctx context.Context) error
OnRequestSigning(ctx context.Context, id string, algorithm string, alias string, data []byte) error
OnTvAdSessionData(ctx context.Context, type_ string, data os.Bundle) error
}
func NewTvAdSessionCallbackStub ¶
func NewTvAdSessionCallbackStub( impl ITvAdSessionCallbackServer, ) ITvAdSessionCallback
NewTvAdSessionCallbackStub creates a server-side ITvAdSessionCallback wrapping the given server implementation. The returned value satisfies ITvAdSessionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITvAdSessionCallbackServer ¶
type ITvAdSessionCallbackServer interface {
OnSessionCreated(ctx context.Context, session ITvAdSession) error
OnLayoutSurface(ctx context.Context, left int32, top int32, right int32, bottom int32) error
OnRequestCurrentVideoBounds(ctx context.Context) error
OnRequestCurrentChannelUri(ctx context.Context) error
OnRequestTrackInfoList(ctx context.Context) error
OnRequestCurrentTvInputId(ctx context.Context) error
OnRequestSigning(ctx context.Context, id string, algorithm string, alias string, data []byte) error
OnTvAdSessionData(ctx context.Context, type_ string, data os.Bundle) error
}
ITvAdSessionCallbackServer is the server-side interface that user implementations provide to NewTvAdSessionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ITvAdSessionServer ¶
type ITvAdSessionServer interface {
Release(ctx context.Context) error
StartAdService(ctx context.Context) error
StopAdService(ctx context.Context) error
ResetAdService(ctx context.Context) error
SetSurface(ctx context.Context, surface view.Surface) error
DispatchSurfaceChanged(ctx context.Context, format int32, width int32, height int32) error
SendCurrentVideoBounds(ctx context.Context, bounds graphics.Rect) error
SendCurrentChannelUri(ctx context.Context, channelUri net.Uri) error
SendTrackInfoList(ctx context.Context, tracks []tv.TvTrackInfo) error
SendCurrentTvInputId(ctx context.Context, inputId string) error
SendSigningResult(ctx context.Context, signingId string, result []byte) error
NotifyError(ctx context.Context, errMsg string, params os.Bundle) error
NotifyTvMessage(ctx context.Context, type_ int32, data os.Bundle) error
CreateMediaView(ctx context.Context, windowToken binder.IBinder, frame graphics.Rect) error
RelayoutMediaView(ctx context.Context, frame graphics.Rect) error
RemoveMediaView(ctx context.Context) error
NotifyTvInputSessionData(ctx context.Context, type_ string, data os.Bundle) error
}
ITvAdSessionServer is the server-side interface that user implementations provide to NewTvAdSessionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type TvAdClientProxy ¶
func NewTvAdClientProxy ¶
func NewTvAdClientProxy( remote binder.IBinder, ) *TvAdClientProxy
func (*TvAdClientProxy) AsBinder ¶
func (p *TvAdClientProxy) AsBinder() binder.IBinder
func (*TvAdClientProxy) OnLayoutSurface ¶
func (*TvAdClientProxy) OnRequestCurrentChannelUri ¶
func (p *TvAdClientProxy) OnRequestCurrentChannelUri( ctx context.Context, seq int32, ) error
func (*TvAdClientProxy) OnRequestCurrentTvInputId ¶
func (p *TvAdClientProxy) OnRequestCurrentTvInputId( ctx context.Context, seq int32, ) error
func (*TvAdClientProxy) OnRequestCurrentVideoBounds ¶
func (p *TvAdClientProxy) OnRequestCurrentVideoBounds( ctx context.Context, seq int32, ) error
func (*TvAdClientProxy) OnRequestSigning ¶
func (*TvAdClientProxy) OnRequestTrackInfoList ¶
func (p *TvAdClientProxy) OnRequestTrackInfoList( ctx context.Context, seq int32, ) error
func (*TvAdClientProxy) OnSessionCreated ¶
func (p *TvAdClientProxy) OnSessionCreated( ctx context.Context, serviceId string, token binder.IBinder, channel view.InputChannel, seq int32, ) error
func (*TvAdClientProxy) OnSessionReleased ¶
func (p *TvAdClientProxy) OnSessionReleased( ctx context.Context, seq int32, ) error
func (*TvAdClientProxy) OnTvAdSessionData ¶
type TvAdClientStub ¶
type TvAdClientStub struct {
Impl ITvAdClient
Transport binder.VersionAwareTransport
}
TvAdClientStub dispatches incoming binder transactions to a typed ITvAdClient implementation.
func (*TvAdClientStub) Descriptor ¶
func (s *TvAdClientStub) Descriptor() string
func (*TvAdClientStub) OnTransaction ¶
func (s *TvAdClientStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type TvAdManagerCallbackProxy ¶
func NewTvAdManagerCallbackProxy ¶
func NewTvAdManagerCallbackProxy( remote binder.IBinder, ) *TvAdManagerCallbackProxy
func (*TvAdManagerCallbackProxy) AsBinder ¶
func (p *TvAdManagerCallbackProxy) AsBinder() binder.IBinder
func (*TvAdManagerCallbackProxy) OnAdServiceAdded ¶
func (p *TvAdManagerCallbackProxy) OnAdServiceAdded( ctx context.Context, serviceId string, ) error
func (*TvAdManagerCallbackProxy) OnAdServiceRemoved ¶
func (p *TvAdManagerCallbackProxy) OnAdServiceRemoved( ctx context.Context, serviceId string, ) error
func (*TvAdManagerCallbackProxy) OnAdServiceUpdated ¶
func (p *TvAdManagerCallbackProxy) OnAdServiceUpdated( ctx context.Context, serviceId string, ) error
type TvAdManagerCallbackStub ¶
type TvAdManagerCallbackStub struct {
Impl ITvAdManagerCallback
Transport binder.VersionAwareTransport
}
TvAdManagerCallbackStub dispatches incoming binder transactions to a typed ITvAdManagerCallback implementation.
func (*TvAdManagerCallbackStub) Descriptor ¶
func (s *TvAdManagerCallbackStub) Descriptor() string
func (*TvAdManagerCallbackStub) OnTransaction ¶
func (s *TvAdManagerCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type TvAdManagerProxy ¶
func GetTvAdManager ¶
func GetTvAdManager( ctx context.Context, sm *servicemanager.ServiceManager, ) (*TvAdManagerProxy, error)
GetTvAdManager retrieves the TvAdService service and returns a typed proxy.
func NewTvAdManagerProxy ¶
func NewTvAdManagerProxy( remote binder.IBinder, ) *TvAdManagerProxy
func (*TvAdManagerProxy) AsBinder ¶
func (p *TvAdManagerProxy) AsBinder() binder.IBinder
func (*TvAdManagerProxy) CreateMediaView ¶
func (*TvAdManagerProxy) CreateSession ¶
func (p *TvAdManagerProxy) CreateSession( ctx context.Context, client ITvAdClient, serviceId string, type_ string, seq int32, ) error
func (*TvAdManagerProxy) DispatchSurfaceChanged ¶
func (*TvAdManagerProxy) GetTvAdServiceList ¶
func (p *TvAdManagerProxy) GetTvAdServiceList( ctx context.Context, ) ([]TvAdServiceInfo, error)
func (*TvAdManagerProxy) NotifyError ¶
func (*TvAdManagerProxy) NotifyTvInputSessionData ¶
func (*TvAdManagerProxy) NotifyTvMessage ¶
func (*TvAdManagerProxy) RegisterCallback ¶
func (p *TvAdManagerProxy) RegisterCallback( ctx context.Context, callback ITvAdManagerCallback, ) error
func (*TvAdManagerProxy) RelayoutMediaView ¶
func (*TvAdManagerProxy) ReleaseSession ¶
func (*TvAdManagerProxy) RemoveMediaView ¶
func (*TvAdManagerProxy) ResetAdService ¶
func (*TvAdManagerProxy) SendAppLinkCommand ¶
func (*TvAdManagerProxy) SendCurrentChannelUri ¶
func (*TvAdManagerProxy) SendCurrentTvInputId ¶
func (*TvAdManagerProxy) SendCurrentVideoBounds ¶
func (*TvAdManagerProxy) SendSigningResult ¶
func (*TvAdManagerProxy) SendTrackInfoList ¶
func (p *TvAdManagerProxy) SendTrackInfoList( ctx context.Context, sessionToken binder.IBinder, tracks []tv.TvTrackInfo, ) error
func (*TvAdManagerProxy) SetSurface ¶
func (*TvAdManagerProxy) StartAdService ¶
func (*TvAdManagerProxy) StopAdService ¶
func (*TvAdManagerProxy) UnregisterCallback ¶
func (p *TvAdManagerProxy) UnregisterCallback( ctx context.Context, callback ITvAdManagerCallback, ) error
type TvAdManagerStub ¶
type TvAdManagerStub struct {
Impl ITvAdManager
Transport binder.VersionAwareTransport
}
TvAdManagerStub dispatches incoming binder transactions to a typed ITvAdManager implementation.
func (*TvAdManagerStub) Descriptor ¶
func (s *TvAdManagerStub) Descriptor() string
func (*TvAdManagerStub) OnTransaction ¶
func (s *TvAdManagerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type TvAdServiceCallbackProxy ¶
func NewTvAdServiceCallbackProxy ¶
func NewTvAdServiceCallbackProxy( remote binder.IBinder, ) *TvAdServiceCallbackProxy
func (*TvAdServiceCallbackProxy) AsBinder ¶
func (p *TvAdServiceCallbackProxy) AsBinder() binder.IBinder
type TvAdServiceCallbackStub ¶
type TvAdServiceCallbackStub struct {
Impl ITvAdServiceCallback
Transport binder.VersionAwareTransport
}
TvAdServiceCallbackStub dispatches incoming binder transactions to a typed ITvAdServiceCallback implementation.
func (*TvAdServiceCallbackStub) Descriptor ¶
func (s *TvAdServiceCallbackStub) Descriptor() string
func (*TvAdServiceCallbackStub) OnTransaction ¶
func (s *TvAdServiceCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type TvAdServiceInfo ¶
type TvAdServiceInfo struct {
Id string
}
func (*TvAdServiceInfo) MarshalParcel ¶
func (s *TvAdServiceInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*TvAdServiceInfo) UnmarshalParcel ¶
func (s *TvAdServiceInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type TvAdServiceProxy ¶
func NewTvAdServiceProxy ¶
func NewTvAdServiceProxy( remote binder.IBinder, ) *TvAdServiceProxy
func (*TvAdServiceProxy) AsBinder ¶
func (p *TvAdServiceProxy) AsBinder() binder.IBinder
func (*TvAdServiceProxy) CreateSession ¶
func (p *TvAdServiceProxy) CreateSession( ctx context.Context, channel view.InputChannel, callback ITvAdSessionCallback, serviceId string, type_ string, ) error
func (*TvAdServiceProxy) RegisterCallback ¶
func (p *TvAdServiceProxy) RegisterCallback( ctx context.Context, callback ITvAdServiceCallback, ) error
func (*TvAdServiceProxy) SendAppLinkCommand ¶
func (*TvAdServiceProxy) UnregisterCallback ¶
func (p *TvAdServiceProxy) UnregisterCallback( ctx context.Context, callback ITvAdServiceCallback, ) error
type TvAdServiceStub ¶
type TvAdServiceStub struct {
Impl ITvAdService
Transport binder.VersionAwareTransport
}
TvAdServiceStub dispatches incoming binder transactions to a typed ITvAdService implementation.
func (*TvAdServiceStub) Descriptor ¶
func (s *TvAdServiceStub) Descriptor() string
func (*TvAdServiceStub) OnTransaction ¶
func (s *TvAdServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type TvAdSessionCallbackProxy ¶
func NewTvAdSessionCallbackProxy ¶
func NewTvAdSessionCallbackProxy( remote binder.IBinder, ) *TvAdSessionCallbackProxy
func (*TvAdSessionCallbackProxy) AsBinder ¶
func (p *TvAdSessionCallbackProxy) AsBinder() binder.IBinder
func (*TvAdSessionCallbackProxy) OnLayoutSurface ¶
func (*TvAdSessionCallbackProxy) OnRequestCurrentChannelUri ¶
func (p *TvAdSessionCallbackProxy) OnRequestCurrentChannelUri( ctx context.Context, ) error
func (*TvAdSessionCallbackProxy) OnRequestCurrentTvInputId ¶
func (p *TvAdSessionCallbackProxy) OnRequestCurrentTvInputId( ctx context.Context, ) error
func (*TvAdSessionCallbackProxy) OnRequestCurrentVideoBounds ¶
func (p *TvAdSessionCallbackProxy) OnRequestCurrentVideoBounds( ctx context.Context, ) error
func (*TvAdSessionCallbackProxy) OnRequestSigning ¶
func (*TvAdSessionCallbackProxy) OnRequestTrackInfoList ¶
func (p *TvAdSessionCallbackProxy) OnRequestTrackInfoList( ctx context.Context, ) error
func (*TvAdSessionCallbackProxy) OnSessionCreated ¶
func (p *TvAdSessionCallbackProxy) OnSessionCreated( ctx context.Context, session ITvAdSession, ) error
func (*TvAdSessionCallbackProxy) OnTvAdSessionData ¶
type TvAdSessionCallbackStub ¶
type TvAdSessionCallbackStub struct {
Impl ITvAdSessionCallback
Transport binder.VersionAwareTransport
}
TvAdSessionCallbackStub dispatches incoming binder transactions to a typed ITvAdSessionCallback implementation.
func (*TvAdSessionCallbackStub) Descriptor ¶
func (s *TvAdSessionCallbackStub) Descriptor() string
func (*TvAdSessionCallbackStub) OnTransaction ¶
func (s *TvAdSessionCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type TvAdSessionProxy ¶
func NewTvAdSessionProxy ¶
func NewTvAdSessionProxy( remote binder.IBinder, ) *TvAdSessionProxy
func (*TvAdSessionProxy) AsBinder ¶
func (p *TvAdSessionProxy) AsBinder() binder.IBinder
func (*TvAdSessionProxy) CreateMediaView ¶
func (*TvAdSessionProxy) DispatchSurfaceChanged ¶
func (*TvAdSessionProxy) NotifyError ¶
func (*TvAdSessionProxy) NotifyTvInputSessionData ¶
func (*TvAdSessionProxy) NotifyTvMessage ¶
func (*TvAdSessionProxy) RelayoutMediaView ¶
func (*TvAdSessionProxy) RemoveMediaView ¶
func (p *TvAdSessionProxy) RemoveMediaView( ctx context.Context, ) error
func (*TvAdSessionProxy) ResetAdService ¶
func (p *TvAdSessionProxy) ResetAdService( ctx context.Context, ) error
func (*TvAdSessionProxy) SendCurrentChannelUri ¶
func (*TvAdSessionProxy) SendCurrentTvInputId ¶
func (p *TvAdSessionProxy) SendCurrentTvInputId( ctx context.Context, inputId string, ) error
func (*TvAdSessionProxy) SendCurrentVideoBounds ¶
func (*TvAdSessionProxy) SendSigningResult ¶
func (*TvAdSessionProxy) SendTrackInfoList ¶
func (p *TvAdSessionProxy) SendTrackInfoList( ctx context.Context, tracks []tv.TvTrackInfo, ) error
func (*TvAdSessionProxy) SetSurface ¶
func (*TvAdSessionProxy) StartAdService ¶
func (p *TvAdSessionProxy) StartAdService( ctx context.Context, ) error
func (*TvAdSessionProxy) StopAdService ¶
func (p *TvAdSessionProxy) StopAdService( ctx context.Context, ) error
type TvAdSessionStub ¶
type TvAdSessionStub struct {
Impl ITvAdSession
Transport binder.VersionAwareTransport
}
TvAdSessionStub dispatches incoming binder transactions to a typed ITvAdSession implementation.
func (*TvAdSessionStub) Descriptor ¶
func (s *TvAdSessionStub) Descriptor() string
func (*TvAdSessionStub) OnTransaction ¶
func (s *TvAdSessionStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)