Documentation
¶
Index ¶
- Constants
- type AutoFillServiceProxy
- func (p *AutoFillServiceProxy) AsBinder() binder.IBinder
- func (p *AutoFillServiceProxy) OnConnectedStateChanged(ctx context.Context, connected bool) error
- func (p *AutoFillServiceProxy) OnConvertCredentialRequest(ctx context.Context, convertCredentialRequest ConvertCredentialRequest, ...) error
- func (p *AutoFillServiceProxy) OnFillCredentialRequest(ctx context.Context, request FillRequest, callback IFillCallback, ...) error
- func (p *AutoFillServiceProxy) OnFillRequest(ctx context.Context, request FillRequest, callback IFillCallback) error
- func (p *AutoFillServiceProxy) OnSaveRequest(ctx context.Context, request SaveRequest, callback ISaveCallback) error
- func (p *AutoFillServiceProxy) OnSavedPasswordCountRequest(ctx context.Context, receiver os.IResultReceiver) error
- type AutoFillServiceStub
- type AutofillFieldClassificationServiceProxy
- type AutofillFieldClassificationServiceStub
- type ConvertCredentialCallbackProxy
- type ConvertCredentialCallbackStub
- type ConvertCredentialRequest
- type ConvertCredentialResponse
- type Dataset
- type FieldClassificationAlgorithmInfo
- type FillCallbackProxy
- func (p *FillCallbackProxy) AsBinder() binder.IBinder
- func (p *FillCallbackProxy) OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
- func (p *FillCallbackProxy) OnFailure(ctx context.Context, requestId int32, message string) error
- func (p *FillCallbackProxy) OnSuccess(ctx context.Context, response FillResponse) error
- type FillCallbackStub
- type FillEventHistory
- type FillRequest
- type FillResponse
- type IAutoFillService
- type IAutoFillServiceServer
- type IAutofillFieldClassificationService
- type IAutofillFieldClassificationServiceServer
- type IConvertCredentialCallback
- type IConvertCredentialCallbackServer
- type IFillCallback
- type IFillCallbackServer
- type IInlineSuggestionRenderService
- type IInlineSuggestionRenderServiceServer
- type IInlineSuggestionUi
- type IInlineSuggestionUiCallback
- type IInlineSuggestionUiCallbackServer
- type IInlineSuggestionUiServer
- type ISaveCallback
- type ISaveCallbackServer
- type ISurfacePackageResultCallback
- type ISurfacePackageResultCallbackServer
- type InlinePresentation
- type InlineSuggestionRenderServiceProxy
- func (p *InlineSuggestionRenderServiceProxy) AsBinder() binder.IBinder
- func (p *InlineSuggestionRenderServiceProxy) DestroySuggestionViews(ctx context.Context, sessionId int32) error
- func (p *InlineSuggestionRenderServiceProxy) GetInlineSuggestionsRendererInfo(ctx context.Context, callback os.RemoteCallback) error
- func (p *InlineSuggestionRenderServiceProxy) RenderSuggestion(ctx context.Context, callback IInlineSuggestionUiCallback, ...) error
- type InlineSuggestionRenderServiceStub
- type InlineSuggestionUiCallbackProxy
- func (p *InlineSuggestionUiCallbackProxy) AsBinder() binder.IBinder
- func (p *InlineSuggestionUiCallbackProxy) OnClick(ctx context.Context) error
- func (p *InlineSuggestionUiCallbackProxy) OnContent(ctx context.Context, content IInlineSuggestionUi, ...) error
- func (p *InlineSuggestionUiCallbackProxy) OnError(ctx context.Context) error
- func (p *InlineSuggestionUiCallbackProxy) OnLongClick(ctx context.Context) error
- func (p *InlineSuggestionUiCallbackProxy) OnStartIntentSender(ctx context.Context, intentSender androidContent.IntentSender) error
- func (p *InlineSuggestionUiCallbackProxy) OnTransferTouchFocusToImeWindow(ctx context.Context, sourceInputToken binder.IBinder, displayId int32) error
- type InlineSuggestionUiCallbackStub
- type InlineSuggestionUiProxy
- type InlineSuggestionUiStub
- type SaveCallbackProxy
- type SaveCallbackStub
- type SaveRequest
- type SurfacePackageResultCallbackProxy
- type SurfacePackageResultCallbackStub
- type UserData
Constants ¶
const ( TransactionIAutoFillServiceOnConnectedStateChanged = binder.FirstCallTransaction + 0 TransactionIAutoFillServiceOnFillRequest = binder.FirstCallTransaction + 1 TransactionIAutoFillServiceOnFillCredentialRequest = binder.FirstCallTransaction + 2 TransactionIAutoFillServiceOnSaveRequest = binder.FirstCallTransaction + 3 TransactionIAutoFillServiceOnSavedPasswordCountRequest = binder.FirstCallTransaction + 4 TransactionIAutoFillServiceOnConvertCredentialRequest = binder.FirstCallTransaction + 5 )
const ( MethodIAutoFillServiceOnConnectedStateChanged = "onConnectedStateChanged" MethodIAutoFillServiceOnFillRequest = "onFillRequest" MethodIAutoFillServiceOnFillCredentialRequest = "onFillCredentialRequest" MethodIAutoFillServiceOnSaveRequest = "onSaveRequest" MethodIAutoFillServiceOnSavedPasswordCountRequest = "onSavedPasswordCountRequest" MethodIAutoFillServiceOnConvertCredentialRequest = "onConvertCredentialRequest" )
const ( TransactionIConvertCredentialCallbackOnSuccess = binder.FirstCallTransaction + 0 TransactionIConvertCredentialCallbackOnFailure = binder.FirstCallTransaction + 1 )
const ( MethodIConvertCredentialCallbackOnSuccess = "onSuccess" MethodIConvertCredentialCallbackOnFailure = "onFailure" )
const ( TransactionIFillCallbackOnCancellable = binder.FirstCallTransaction + 0 TransactionIFillCallbackOnSuccess = binder.FirstCallTransaction + 1 TransactionIFillCallbackOnFailure = binder.FirstCallTransaction + 2 )
const ( MethodIFillCallbackOnCancellable = "onCancellable" MethodIFillCallbackOnSuccess = "onSuccess" MethodIFillCallbackOnFailure = "onFailure" )
const ( TransactionIInlineSuggestionRenderServiceRenderSuggestion = binder.FirstCallTransaction + 0 TransactionIInlineSuggestionRenderServiceGetInlineSuggestionsRendererInfo = binder.FirstCallTransaction + 1 TransactionIInlineSuggestionRenderServiceDestroySuggestionViews = binder.FirstCallTransaction + 2 )
const ( MethodIInlineSuggestionRenderServiceRenderSuggestion = "renderSuggestion" MethodIInlineSuggestionRenderServiceGetInlineSuggestionsRendererInfo = "getInlineSuggestionsRendererInfo" MethodIInlineSuggestionRenderServiceDestroySuggestionViews = "destroySuggestionViews" )
const ( TransactionIInlineSuggestionUiGetSurfacePackage = binder.FirstCallTransaction + 0 TransactionIInlineSuggestionUiReleaseSurfaceControlViewHost = binder.FirstCallTransaction + 1 )
const ( MethodIInlineSuggestionUiGetSurfacePackage = "getSurfacePackage" MethodIInlineSuggestionUiReleaseSurfaceControlViewHost = "releaseSurfaceControlViewHost" )
const ( TransactionIInlineSuggestionUiCallbackOnClick = binder.FirstCallTransaction + 0 TransactionIInlineSuggestionUiCallbackOnLongClick = binder.FirstCallTransaction + 1 TransactionIInlineSuggestionUiCallbackOnContent = binder.FirstCallTransaction + 2 TransactionIInlineSuggestionUiCallbackOnError = binder.FirstCallTransaction + 3 TransactionIInlineSuggestionUiCallbackOnTransferTouchFocusToImeWindow = binder.FirstCallTransaction + 4 TransactionIInlineSuggestionUiCallbackOnStartIntentSender = binder.FirstCallTransaction + 5 )
const ( MethodIInlineSuggestionUiCallbackOnClick = "onClick" MethodIInlineSuggestionUiCallbackOnLongClick = "onLongClick" MethodIInlineSuggestionUiCallbackOnContent = "onContent" MethodIInlineSuggestionUiCallbackOnError = "onError" MethodIInlineSuggestionUiCallbackOnTransferTouchFocusToImeWindow = "onTransferTouchFocusToImeWindow" MethodIInlineSuggestionUiCallbackOnStartIntentSender = "onStartIntentSender" )
const ( TransactionISaveCallbackOnSuccess = binder.FirstCallTransaction + 0 TransactionISaveCallbackOnFailure = binder.FirstCallTransaction + 1 )
const ( MethodISaveCallbackOnSuccess = "onSuccess" MethodISaveCallbackOnFailure = "onFailure" )
const DescriptorIAutoFillService = "android.service.autofill.IAutoFillService"
const DescriptorIAutofillFieldClassificationService = "android.service.autofill.IAutofillFieldClassificationService"
const DescriptorIConvertCredentialCallback = "android.service.autofill.IConvertCredentialCallback"
const DescriptorIFillCallback = "android.service.autofill.IFillCallback"
const DescriptorIInlineSuggestionRenderService = "android.service.autofill.IInlineSuggestionRenderService"
const DescriptorIInlineSuggestionUi = "android.service.autofill.IInlineSuggestionUi"
const DescriptorIInlineSuggestionUiCallback = "android.service.autofill.IInlineSuggestionUiCallback"
const DescriptorISaveCallback = "android.service.autofill.ISaveCallback"
const DescriptorISurfacePackageResultCallback = "android.service.autofill.ISurfacePackageResultCallback"
const (
MethodIAutofillFieldClassificationServiceCalculateScores = "calculateScores"
)
const (
MethodISurfacePackageResultCallbackOnResult = "onResult"
)
const (
TransactionIAutofillFieldClassificationServiceCalculateScores = binder.FirstCallTransaction + 0
)
const (
TransactionISurfacePackageResultCallbackOnResult = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AutoFillServiceProxy ¶
func NewAutoFillServiceProxy ¶
func NewAutoFillServiceProxy( remote binder.IBinder, ) *AutoFillServiceProxy
func (*AutoFillServiceProxy) AsBinder ¶
func (p *AutoFillServiceProxy) AsBinder() binder.IBinder
func (*AutoFillServiceProxy) OnConnectedStateChanged ¶
func (p *AutoFillServiceProxy) OnConnectedStateChanged( ctx context.Context, connected bool, ) error
func (*AutoFillServiceProxy) OnConvertCredentialRequest ¶
func (p *AutoFillServiceProxy) OnConvertCredentialRequest( ctx context.Context, convertCredentialRequest ConvertCredentialRequest, convertCredentialCallback IConvertCredentialCallback, ) error
func (*AutoFillServiceProxy) OnFillCredentialRequest ¶
func (p *AutoFillServiceProxy) OnFillCredentialRequest( ctx context.Context, request FillRequest, callback IFillCallback, client types.IAutoFillManagerClient, ) error
func (*AutoFillServiceProxy) OnFillRequest ¶
func (p *AutoFillServiceProxy) OnFillRequest( ctx context.Context, request FillRequest, callback IFillCallback, ) error
func (*AutoFillServiceProxy) OnSaveRequest ¶
func (p *AutoFillServiceProxy) OnSaveRequest( ctx context.Context, request SaveRequest, callback ISaveCallback, ) error
func (*AutoFillServiceProxy) OnSavedPasswordCountRequest ¶
func (p *AutoFillServiceProxy) OnSavedPasswordCountRequest( ctx context.Context, receiver os.IResultReceiver, ) error
type AutoFillServiceStub ¶
type AutoFillServiceStub struct {
Impl IAutoFillService
Transport binder.VersionAwareTransport
}
AutoFillServiceStub dispatches incoming binder transactions to a typed IAutoFillService implementation.
func (*AutoFillServiceStub) Descriptor ¶
func (s *AutoFillServiceStub) Descriptor() string
func (*AutoFillServiceStub) OnTransaction ¶
func (s *AutoFillServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type AutofillFieldClassificationServiceProxy ¶
func NewAutofillFieldClassificationServiceProxy ¶
func NewAutofillFieldClassificationServiceProxy( remote binder.IBinder, ) *AutofillFieldClassificationServiceProxy
func (*AutofillFieldClassificationServiceProxy) AsBinder ¶
func (p *AutofillFieldClassificationServiceProxy) AsBinder() binder.IBinder
func (*AutofillFieldClassificationServiceProxy) CalculateScores ¶
type AutofillFieldClassificationServiceStub ¶
type AutofillFieldClassificationServiceStub struct {
Impl IAutofillFieldClassificationService
Transport binder.VersionAwareTransport
}
AutofillFieldClassificationServiceStub dispatches incoming binder transactions to a typed IAutofillFieldClassificationService implementation.
func (*AutofillFieldClassificationServiceStub) Descriptor ¶
func (s *AutofillFieldClassificationServiceStub) Descriptor() string
func (*AutofillFieldClassificationServiceStub) OnTransaction ¶
func (s *AutofillFieldClassificationServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ConvertCredentialCallbackProxy ¶
func NewConvertCredentialCallbackProxy ¶
func NewConvertCredentialCallbackProxy( remote binder.IBinder, ) *ConvertCredentialCallbackProxy
func (*ConvertCredentialCallbackProxy) AsBinder ¶
func (p *ConvertCredentialCallbackProxy) AsBinder() binder.IBinder
func (*ConvertCredentialCallbackProxy) OnFailure ¶
func (p *ConvertCredentialCallbackProxy) OnFailure( ctx context.Context, message string, ) error
func (*ConvertCredentialCallbackProxy) OnSuccess ¶
func (p *ConvertCredentialCallbackProxy) OnSuccess( ctx context.Context, convertCredentialResponse ConvertCredentialResponse, ) error
type ConvertCredentialCallbackStub ¶
type ConvertCredentialCallbackStub struct {
Impl IConvertCredentialCallback
Transport binder.VersionAwareTransport
}
ConvertCredentialCallbackStub dispatches incoming binder transactions to a typed IConvertCredentialCallback implementation.
func (*ConvertCredentialCallbackStub) Descriptor ¶
func (s *ConvertCredentialCallbackStub) Descriptor() string
func (*ConvertCredentialCallbackStub) OnTransaction ¶
func (s *ConvertCredentialCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ConvertCredentialRequest ¶
type ConvertCredentialRequest struct {
GetCredentialResponse *types.GetCredentialResponse
}
func (*ConvertCredentialRequest) MarshalParcel ¶
func (s *ConvertCredentialRequest) MarshalParcel( p *parcel.Parcel, ) error
func (*ConvertCredentialRequest) UnmarshalParcel ¶
func (s *ConvertCredentialRequest) UnmarshalParcel( p *parcel.Parcel, ) error
type ConvertCredentialResponse ¶
func (*ConvertCredentialResponse) MarshalParcel ¶
func (s *ConvertCredentialResponse) MarshalParcel( p *parcel.Parcel, ) error
func (*ConvertCredentialResponse) UnmarshalParcel ¶
func (s *ConvertCredentialResponse) UnmarshalParcel( p *parcel.Parcel, ) error
type Dataset ¶
type Dataset struct {
Id string
EligibleReason int32
InlinePresentation *InlinePresentation
}
type FieldClassificationAlgorithmInfo ¶
type FieldClassificationAlgorithmInfo struct {
}
func (*FieldClassificationAlgorithmInfo) MarshalParcel ¶
func (s *FieldClassificationAlgorithmInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*FieldClassificationAlgorithmInfo) UnmarshalParcel ¶
func (s *FieldClassificationAlgorithmInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type FillCallbackProxy ¶
func NewFillCallbackProxy ¶
func NewFillCallbackProxy( remote binder.IBinder, ) *FillCallbackProxy
func (*FillCallbackProxy) AsBinder ¶
func (p *FillCallbackProxy) AsBinder() binder.IBinder
func (*FillCallbackProxy) OnCancellable ¶
func (p *FillCallbackProxy) OnCancellable( ctx context.Context, cancellation os.ICancellationSignal, ) error
func (*FillCallbackProxy) OnSuccess ¶
func (p *FillCallbackProxy) OnSuccess( ctx context.Context, response FillResponse, ) error
type FillCallbackStub ¶
type FillCallbackStub struct {
Impl IFillCallback
Transport binder.VersionAwareTransport
}
FillCallbackStub dispatches incoming binder transactions to a typed IFillCallback implementation.
func (*FillCallbackStub) Descriptor ¶
func (s *FillCallbackStub) Descriptor() string
func (*FillCallbackStub) OnTransaction ¶
func (s *FillCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type FillEventHistory ¶
type FillEventHistory struct {
}
func (*FillEventHistory) MarshalParcel ¶
func (s *FillEventHistory) MarshalParcel( p *parcel.Parcel, ) error
func (*FillEventHistory) UnmarshalParcel ¶
func (s *FillEventHistory) UnmarshalParcel( p *parcel.Parcel, ) error
type FillRequest ¶
type FillRequest struct {
Flg int32
Id int32
Flags int32
InlineSuggestionsRequest *types.InlineSuggestionsRequest
}
func (*FillRequest) MarshalParcel ¶
func (s *FillRequest) MarshalParcel( p *parcel.Parcel, ) error
func (*FillRequest) UnmarshalParcel ¶
func (s *FillRequest) UnmarshalParcel( p *parcel.Parcel, ) error
type FillResponse ¶
type FillResponse struct {
DisableDuration int64
IconResourceId int32
ServiceDisplayNameResourceId int32
ShowFillDialogIcon bool
ShowSaveDialogIcon bool
Flags int32
RequestId int32
InlinePresentation *InlinePresentation
UserData *UserData
}
func (*FillResponse) MarshalParcel ¶
func (s *FillResponse) MarshalParcel( p *parcel.Parcel, ) error
func (*FillResponse) UnmarshalParcel ¶
func (s *FillResponse) UnmarshalParcel( p *parcel.Parcel, ) error
type IAutoFillService ¶
type IAutoFillService interface {
AsBinder() binder.IBinder
OnConnectedStateChanged(ctx context.Context, connected bool) error
OnFillRequest(ctx context.Context, request FillRequest, callback IFillCallback) error
OnFillCredentialRequest(ctx context.Context, request FillRequest, callback IFillCallback, client types.IAutoFillManagerClient) error
OnSaveRequest(ctx context.Context, request SaveRequest, callback ISaveCallback) error
OnSavedPasswordCountRequest(ctx context.Context, receiver os.IResultReceiver) error
OnConvertCredentialRequest(ctx context.Context, convertCredentialRequest ConvertCredentialRequest, convertCredentialCallback IConvertCredentialCallback) error
}
func NewAutoFillServiceStub ¶
func NewAutoFillServiceStub( impl IAutoFillServiceServer, ) IAutoFillService
NewAutoFillServiceStub creates a server-side IAutoFillService wrapping the given server implementation. The returned value satisfies IAutoFillService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IAutoFillServiceServer ¶
type IAutoFillServiceServer interface {
OnConnectedStateChanged(ctx context.Context, connected bool) error
OnFillRequest(ctx context.Context, request FillRequest, callback IFillCallback) error
OnFillCredentialRequest(ctx context.Context, request FillRequest, callback IFillCallback, client types.IAutoFillManagerClient) error
OnSaveRequest(ctx context.Context, request SaveRequest, callback ISaveCallback) error
OnSavedPasswordCountRequest(ctx context.Context, receiver os.IResultReceiver) error
OnConvertCredentialRequest(ctx context.Context, convertCredentialRequest ConvertCredentialRequest, convertCredentialCallback IConvertCredentialCallback) error
}
IAutoFillServiceServer is the server-side interface that user implementations provide to NewAutoFillServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IAutofillFieldClassificationService ¶
type IAutofillFieldClassificationService interface {
AsBinder() binder.IBinder
CalculateScores(ctx context.Context, callback os.RemoteCallback, actualValues []types.AutofillValue, userDataValues []string, categoryIds []string, defaultAlgorithm string, defaultArgs os.Bundle, algorithms map[any]any, args map[any]any) error
}
func NewAutofillFieldClassificationServiceStub ¶
func NewAutofillFieldClassificationServiceStub( impl IAutofillFieldClassificationServiceServer, ) IAutofillFieldClassificationService
NewAutofillFieldClassificationServiceStub creates a server-side IAutofillFieldClassificationService wrapping the given server implementation. The returned value satisfies IAutofillFieldClassificationService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IAutofillFieldClassificationServiceServer ¶
type IAutofillFieldClassificationServiceServer interface {
CalculateScores(ctx context.Context, callback os.RemoteCallback, actualValues []types.AutofillValue, userDataValues []string, categoryIds []string, defaultAlgorithm string, defaultArgs os.Bundle, algorithms map[any]any, args map[any]any) error
}
IAutofillFieldClassificationServiceServer is the server-side interface that user implementations provide to NewAutofillFieldClassificationServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IConvertCredentialCallback ¶
type IConvertCredentialCallback interface {
AsBinder() binder.IBinder
OnSuccess(ctx context.Context, convertCredentialResponse ConvertCredentialResponse) error
OnFailure(ctx context.Context, message string) error
}
func NewConvertCredentialCallbackStub ¶
func NewConvertCredentialCallbackStub( impl IConvertCredentialCallbackServer, ) IConvertCredentialCallback
NewConvertCredentialCallbackStub creates a server-side IConvertCredentialCallback wrapping the given server implementation. The returned value satisfies IConvertCredentialCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IConvertCredentialCallbackServer ¶
type IConvertCredentialCallbackServer interface {
OnSuccess(ctx context.Context, convertCredentialResponse ConvertCredentialResponse) error
OnFailure(ctx context.Context, message string) error
}
IConvertCredentialCallbackServer is the server-side interface that user implementations provide to NewConvertCredentialCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IFillCallback ¶
type IFillCallback interface {
AsBinder() binder.IBinder
OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
OnSuccess(ctx context.Context, response FillResponse) error
OnFailure(ctx context.Context, requestId int32, message string) error
}
func NewFillCallbackStub ¶
func NewFillCallbackStub( impl IFillCallbackServer, ) IFillCallback
NewFillCallbackStub creates a server-side IFillCallback wrapping the given server implementation. The returned value satisfies IFillCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IFillCallbackServer ¶
type IFillCallbackServer interface {
OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
OnSuccess(ctx context.Context, response FillResponse) error
OnFailure(ctx context.Context, requestId int32, message string) error
}
IFillCallbackServer is the server-side interface that user implementations provide to NewFillCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IInlineSuggestionRenderService ¶
type IInlineSuggestionRenderService interface {
AsBinder() binder.IBinder
RenderSuggestion(ctx context.Context, callback IInlineSuggestionUiCallback, presentation InlinePresentation, width int32, height int32, hostInputToken binder.IBinder, displayId int32, sessionId int32) error
GetInlineSuggestionsRendererInfo(ctx context.Context, callback os.RemoteCallback) error
DestroySuggestionViews(ctx context.Context, sessionId int32) error
}
func NewInlineSuggestionRenderServiceStub ¶
func NewInlineSuggestionRenderServiceStub( impl IInlineSuggestionRenderServiceServer, ) IInlineSuggestionRenderService
NewInlineSuggestionRenderServiceStub creates a server-side IInlineSuggestionRenderService wrapping the given server implementation. The returned value satisfies IInlineSuggestionRenderService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IInlineSuggestionRenderServiceServer ¶
type IInlineSuggestionRenderServiceServer interface {
RenderSuggestion(ctx context.Context, callback IInlineSuggestionUiCallback, presentation InlinePresentation, width int32, height int32, hostInputToken binder.IBinder, displayId int32, sessionId int32) error
GetInlineSuggestionsRendererInfo(ctx context.Context, callback os.RemoteCallback) error
DestroySuggestionViews(ctx context.Context, sessionId int32) error
}
IInlineSuggestionRenderServiceServer is the server-side interface that user implementations provide to NewInlineSuggestionRenderServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IInlineSuggestionUi ¶
type IInlineSuggestionUi interface {
AsBinder() binder.IBinder
GetSurfacePackage(ctx context.Context, callback ISurfacePackageResultCallback) error
ReleaseSurfaceControlViewHost(ctx context.Context) error
}
func NewInlineSuggestionUiStub ¶
func NewInlineSuggestionUiStub( impl IInlineSuggestionUiServer, ) IInlineSuggestionUi
NewInlineSuggestionUiStub creates a server-side IInlineSuggestionUi wrapping the given server implementation. The returned value satisfies IInlineSuggestionUi and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IInlineSuggestionUiCallback ¶
type IInlineSuggestionUiCallback interface {
AsBinder() binder.IBinder
OnClick(ctx context.Context) error
OnLongClick(ctx context.Context) error
OnContent(ctx context.Context, content IInlineSuggestionUi, surface view.SurfaceControlViewHostSurfacePackage, width int32, height int32) error
OnError(ctx context.Context) error
OnTransferTouchFocusToImeWindow(ctx context.Context, sourceInputToken binder.IBinder, displayId int32) error
OnStartIntentSender(ctx context.Context, intentSender androidContent.IntentSender) error
}
func NewInlineSuggestionUiCallbackStub ¶
func NewInlineSuggestionUiCallbackStub( impl IInlineSuggestionUiCallbackServer, ) IInlineSuggestionUiCallback
NewInlineSuggestionUiCallbackStub creates a server-side IInlineSuggestionUiCallback wrapping the given server implementation. The returned value satisfies IInlineSuggestionUiCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IInlineSuggestionUiCallbackServer ¶
type IInlineSuggestionUiCallbackServer interface {
OnClick(ctx context.Context) error
OnLongClick(ctx context.Context) error
OnContent(ctx context.Context, content IInlineSuggestionUi, surface view.SurfaceControlViewHostSurfacePackage, width int32, height int32) error
OnError(ctx context.Context) error
OnTransferTouchFocusToImeWindow(ctx context.Context, sourceInputToken binder.IBinder, displayId int32) error
OnStartIntentSender(ctx context.Context, intentSender androidContent.IntentSender) error
}
IInlineSuggestionUiCallbackServer is the server-side interface that user implementations provide to NewInlineSuggestionUiCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IInlineSuggestionUiServer ¶
type IInlineSuggestionUiServer interface {
GetSurfacePackage(ctx context.Context, callback ISurfacePackageResultCallback) error
ReleaseSurfaceControlViewHost(ctx context.Context) error
}
IInlineSuggestionUiServer is the server-side interface that user implementations provide to NewInlineSuggestionUiStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ISaveCallback ¶
type ISaveCallback interface {
AsBinder() binder.IBinder
OnSuccess(ctx context.Context, intentSender content.IntentSender) error
OnFailure(ctx context.Context, message string) error
}
func NewSaveCallbackStub ¶
func NewSaveCallbackStub( impl ISaveCallbackServer, ) ISaveCallback
NewSaveCallbackStub creates a server-side ISaveCallback wrapping the given server implementation. The returned value satisfies ISaveCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ISaveCallbackServer ¶
type ISaveCallbackServer interface {
OnSuccess(ctx context.Context, intentSender content.IntentSender) error
OnFailure(ctx context.Context, message string) error
}
ISaveCallbackServer is the server-side interface that user implementations provide to NewSaveCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ISurfacePackageResultCallback ¶
type ISurfacePackageResultCallback interface {
AsBinder() binder.IBinder
OnResult(ctx context.Context, result view.SurfaceControlViewHostSurfacePackage) error
}
func NewSurfacePackageResultCallbackStub ¶
func NewSurfacePackageResultCallbackStub( impl ISurfacePackageResultCallbackServer, ) ISurfacePackageResultCallback
NewSurfacePackageResultCallbackStub creates a server-side ISurfacePackageResultCallback wrapping the given server implementation. The returned value satisfies ISurfacePackageResultCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ISurfacePackageResultCallbackServer ¶
type ISurfacePackageResultCallbackServer interface {
OnResult(ctx context.Context, result view.SurfaceControlViewHostSurfacePackage) error
}
ISurfacePackageResultCallbackServer is the server-side interface that user implementations provide to NewSurfacePackageResultCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type InlinePresentation ¶
type InlinePresentation struct {
Flg int32
Slice *types.Slice
InlinePresentationSpec *inline.InlinePresentationSpec
}
func (*InlinePresentation) MarshalParcel ¶
func (s *InlinePresentation) MarshalParcel( p *parcel.Parcel, ) error
func (*InlinePresentation) UnmarshalParcel ¶
func (s *InlinePresentation) UnmarshalParcel( p *parcel.Parcel, ) error
type InlineSuggestionRenderServiceProxy ¶
func NewInlineSuggestionRenderServiceProxy ¶
func NewInlineSuggestionRenderServiceProxy( remote binder.IBinder, ) *InlineSuggestionRenderServiceProxy
func (*InlineSuggestionRenderServiceProxy) AsBinder ¶
func (p *InlineSuggestionRenderServiceProxy) AsBinder() binder.IBinder
func (*InlineSuggestionRenderServiceProxy) DestroySuggestionViews ¶
func (p *InlineSuggestionRenderServiceProxy) DestroySuggestionViews( ctx context.Context, sessionId int32, ) error
func (*InlineSuggestionRenderServiceProxy) GetInlineSuggestionsRendererInfo ¶
func (p *InlineSuggestionRenderServiceProxy) GetInlineSuggestionsRendererInfo( ctx context.Context, callback os.RemoteCallback, ) error
func (*InlineSuggestionRenderServiceProxy) RenderSuggestion ¶
func (p *InlineSuggestionRenderServiceProxy) RenderSuggestion( ctx context.Context, callback IInlineSuggestionUiCallback, presentation InlinePresentation, width int32, height int32, hostInputToken binder.IBinder, displayId int32, sessionId int32, ) error
type InlineSuggestionRenderServiceStub ¶
type InlineSuggestionRenderServiceStub struct {
Impl IInlineSuggestionRenderService
Transport binder.VersionAwareTransport
}
InlineSuggestionRenderServiceStub dispatches incoming binder transactions to a typed IInlineSuggestionRenderService implementation.
func (*InlineSuggestionRenderServiceStub) Descriptor ¶
func (s *InlineSuggestionRenderServiceStub) Descriptor() string
func (*InlineSuggestionRenderServiceStub) OnTransaction ¶
func (s *InlineSuggestionRenderServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type InlineSuggestionUiCallbackProxy ¶
func NewInlineSuggestionUiCallbackProxy ¶
func NewInlineSuggestionUiCallbackProxy( remote binder.IBinder, ) *InlineSuggestionUiCallbackProxy
func (*InlineSuggestionUiCallbackProxy) AsBinder ¶
func (p *InlineSuggestionUiCallbackProxy) AsBinder() binder.IBinder
func (*InlineSuggestionUiCallbackProxy) OnClick ¶
func (p *InlineSuggestionUiCallbackProxy) OnClick( ctx context.Context, ) error
func (*InlineSuggestionUiCallbackProxy) OnContent ¶
func (p *InlineSuggestionUiCallbackProxy) OnContent( ctx context.Context, content IInlineSuggestionUi, surface view.SurfaceControlViewHostSurfacePackage, width int32, height int32, ) error
func (*InlineSuggestionUiCallbackProxy) OnError ¶
func (p *InlineSuggestionUiCallbackProxy) OnError( ctx context.Context, ) error
func (*InlineSuggestionUiCallbackProxy) OnLongClick ¶
func (p *InlineSuggestionUiCallbackProxy) OnLongClick( ctx context.Context, ) error
func (*InlineSuggestionUiCallbackProxy) OnStartIntentSender ¶
func (p *InlineSuggestionUiCallbackProxy) OnStartIntentSender( ctx context.Context, intentSender androidContent.IntentSender, ) error
func (*InlineSuggestionUiCallbackProxy) OnTransferTouchFocusToImeWindow ¶
type InlineSuggestionUiCallbackStub ¶
type InlineSuggestionUiCallbackStub struct {
Impl IInlineSuggestionUiCallback
Transport binder.VersionAwareTransport
}
InlineSuggestionUiCallbackStub dispatches incoming binder transactions to a typed IInlineSuggestionUiCallback implementation.
func (*InlineSuggestionUiCallbackStub) Descriptor ¶
func (s *InlineSuggestionUiCallbackStub) Descriptor() string
func (*InlineSuggestionUiCallbackStub) OnTransaction ¶
func (s *InlineSuggestionUiCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type InlineSuggestionUiProxy ¶
func NewInlineSuggestionUiProxy ¶
func NewInlineSuggestionUiProxy( remote binder.IBinder, ) *InlineSuggestionUiProxy
func (*InlineSuggestionUiProxy) AsBinder ¶
func (p *InlineSuggestionUiProxy) AsBinder() binder.IBinder
func (*InlineSuggestionUiProxy) GetSurfacePackage ¶
func (p *InlineSuggestionUiProxy) GetSurfacePackage( ctx context.Context, callback ISurfacePackageResultCallback, ) error
func (*InlineSuggestionUiProxy) ReleaseSurfaceControlViewHost ¶
func (p *InlineSuggestionUiProxy) ReleaseSurfaceControlViewHost( ctx context.Context, ) error
type InlineSuggestionUiStub ¶
type InlineSuggestionUiStub struct {
Impl IInlineSuggestionUi
Transport binder.VersionAwareTransport
}
InlineSuggestionUiStub dispatches incoming binder transactions to a typed IInlineSuggestionUi implementation.
func (*InlineSuggestionUiStub) Descriptor ¶
func (s *InlineSuggestionUiStub) Descriptor() string
func (*InlineSuggestionUiStub) OnTransaction ¶
func (s *InlineSuggestionUiStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type SaveCallbackProxy ¶
func NewSaveCallbackProxy ¶
func NewSaveCallbackProxy( remote binder.IBinder, ) *SaveCallbackProxy
func (*SaveCallbackProxy) AsBinder ¶
func (p *SaveCallbackProxy) AsBinder() binder.IBinder
func (*SaveCallbackProxy) OnFailure ¶
func (p *SaveCallbackProxy) OnFailure( ctx context.Context, message string, ) error
func (*SaveCallbackProxy) OnSuccess ¶
func (p *SaveCallbackProxy) OnSuccess( ctx context.Context, intentSender content.IntentSender, ) error
type SaveCallbackStub ¶
type SaveCallbackStub struct {
Impl ISaveCallback
Transport binder.VersionAwareTransport
}
SaveCallbackStub dispatches incoming binder transactions to a typed ISaveCallback implementation.
func (*SaveCallbackStub) Descriptor ¶
func (s *SaveCallbackStub) Descriptor() string
func (*SaveCallbackStub) OnTransaction ¶
func (s *SaveCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type SaveRequest ¶
type SaveRequest struct {
}
func (*SaveRequest) MarshalParcel ¶
func (s *SaveRequest) MarshalParcel( p *parcel.Parcel, ) error
func (*SaveRequest) UnmarshalParcel ¶
func (s *SaveRequest) UnmarshalParcel( p *parcel.Parcel, ) error
type SurfacePackageResultCallbackProxy ¶
func NewSurfacePackageResultCallbackProxy ¶
func NewSurfacePackageResultCallbackProxy( remote binder.IBinder, ) *SurfacePackageResultCallbackProxy
func (*SurfacePackageResultCallbackProxy) AsBinder ¶
func (p *SurfacePackageResultCallbackProxy) AsBinder() binder.IBinder
func (*SurfacePackageResultCallbackProxy) OnResult ¶
func (p *SurfacePackageResultCallbackProxy) OnResult( ctx context.Context, result view.SurfaceControlViewHostSurfacePackage, ) error
type SurfacePackageResultCallbackStub ¶
type SurfacePackageResultCallbackStub struct {
Impl ISurfacePackageResultCallback
Transport binder.VersionAwareTransport
}
SurfacePackageResultCallbackStub dispatches incoming binder transactions to a typed ISurfacePackageResultCallback implementation.
func (*SurfacePackageResultCallbackStub) Descriptor ¶
func (s *SurfacePackageResultCallbackStub) Descriptor() string
func (*SurfacePackageResultCallbackStub) OnTransaction ¶
func (s *SurfacePackageResultCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
Source Files
¶
- convertcredentialrequest.go
- convertcredentialresponse.go
- dataset.go
- fieldclassification.algorithminfo.go
- filleventhistory.go
- fillrequest.go
- fillresponse.go
- iautofillfieldclassificationservice.go
- iautofillservice.go
- iconvertcredentialcallback.go
- ifillcallback.go
- iinlinesuggestionrenderservice.go
- iinlinesuggestionui.go
- iinlinesuggestionuicallback.go
- inlinepresentation.go
- isavecallback.go
- isurfacepackageresultcallback.go
- saverequest.go
- userdata.go