Documentation
¶
Index ¶
- Constants
- type AugmentedAutofillServiceProxy
- func (p *AugmentedAutofillServiceProxy) AsBinder() binder.IBinder
- func (p *AugmentedAutofillServiceProxy) OnConnected(ctx context.Context, debug bool, verbose bool) error
- func (p *AugmentedAutofillServiceProxy) OnDestroyAllFillWindowsRequest(ctx context.Context) error
- func (p *AugmentedAutofillServiceProxy) OnDisconnected(ctx context.Context) error
- func (p *AugmentedAutofillServiceProxy) OnFillRequest(ctx context.Context, sessionId int32, autofillManagerClient binder.IBinder, ...) error
- type AugmentedAutofillServiceStub
- type FillCallbackProxy
- func (p *FillCallbackProxy) AsBinder() binder.IBinder
- func (p *FillCallbackProxy) Cancel(ctx context.Context) error
- func (p *FillCallbackProxy) IsCompleted(ctx context.Context) (bool, error)
- func (p *FillCallbackProxy) OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
- func (p *FillCallbackProxy) OnSuccess(ctx context.Context, inlineSuggestionsData []autofill.Dataset, ...) error
- type FillCallbackStub
- type IAugmentedAutofillService
- type IAugmentedAutofillServiceServer
- type IFillCallback
- type IFillCallbackServer
Constants ¶
const ( TransactionIAugmentedAutofillServiceOnConnected = binder.FirstCallTransaction + 0 TransactionIAugmentedAutofillServiceOnDisconnected = binder.FirstCallTransaction + 1 TransactionIAugmentedAutofillServiceOnFillRequest = binder.FirstCallTransaction + 2 TransactionIAugmentedAutofillServiceOnDestroyAllFillWindowsRequest = binder.FirstCallTransaction + 3 )
const ( MethodIAugmentedAutofillServiceOnConnected = "onConnected" MethodIAugmentedAutofillServiceOnDisconnected = "onDisconnected" MethodIAugmentedAutofillServiceOnFillRequest = "onFillRequest" MethodIAugmentedAutofillServiceOnDestroyAllFillWindowsRequest = "onDestroyAllFillWindowsRequest" )
const ( TransactionIFillCallbackOnCancellable = binder.FirstCallTransaction + 0 TransactionIFillCallbackOnSuccess = binder.FirstCallTransaction + 1 TransactionIFillCallbackIsCompleted = binder.FirstCallTransaction + 2 TransactionIFillCallbackCancel = binder.FirstCallTransaction + 3 )
const ( MethodIFillCallbackOnCancellable = "onCancellable" MethodIFillCallbackOnSuccess = "onSuccess" MethodIFillCallbackIsCompleted = "isCompleted" MethodIFillCallbackCancel = "cancel" )
const DescriptorIAugmentedAutofillService = "android.service.autofill.augmented.IAugmentedAutofillService"
const DescriptorIFillCallback = "android.service.autofill.augmented.IFillCallback"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AugmentedAutofillServiceProxy ¶
func NewAugmentedAutofillServiceProxy ¶
func NewAugmentedAutofillServiceProxy( remote binder.IBinder, ) *AugmentedAutofillServiceProxy
func (*AugmentedAutofillServiceProxy) AsBinder ¶
func (p *AugmentedAutofillServiceProxy) AsBinder() binder.IBinder
func (*AugmentedAutofillServiceProxy) OnConnected ¶
func (*AugmentedAutofillServiceProxy) OnDestroyAllFillWindowsRequest ¶
func (p *AugmentedAutofillServiceProxy) OnDestroyAllFillWindowsRequest( ctx context.Context, ) error
func (*AugmentedAutofillServiceProxy) OnDisconnected ¶
func (p *AugmentedAutofillServiceProxy) OnDisconnected( ctx context.Context, ) error
func (*AugmentedAutofillServiceProxy) OnFillRequest ¶
func (p *AugmentedAutofillServiceProxy) OnFillRequest( ctx context.Context, sessionId int32, autofillManagerClient binder.IBinder, taskId int32, activityComponent content.ComponentName, focusedId autofill.AutofillId, focusedValue autofill.AutofillValue, requestTime int64, inlineSuggestionsRequest inputmethod.InlineSuggestionsRequest, callback IFillCallback, ) error
type AugmentedAutofillServiceStub ¶
type AugmentedAutofillServiceStub struct {
Impl IAugmentedAutofillService
Transport binder.VersionAwareTransport
}
AugmentedAutofillServiceStub dispatches incoming binder transactions to a typed IAugmentedAutofillService implementation.
func (*AugmentedAutofillServiceStub) Descriptor ¶
func (s *AugmentedAutofillServiceStub) Descriptor() string
func (*AugmentedAutofillServiceStub) OnTransaction ¶
func (s *AugmentedAutofillServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type FillCallbackProxy ¶
func NewFillCallbackProxy ¶
func NewFillCallbackProxy( remote binder.IBinder, ) *FillCallbackProxy
func (*FillCallbackProxy) AsBinder ¶
func (p *FillCallbackProxy) AsBinder() binder.IBinder
func (*FillCallbackProxy) IsCompleted ¶
func (p *FillCallbackProxy) IsCompleted( ctx context.Context, ) (bool, error)
func (*FillCallbackProxy) OnCancellable ¶
func (p *FillCallbackProxy) OnCancellable( ctx context.Context, cancellation os.ICancellationSignal, ) error
type FillCallbackStub ¶
type FillCallbackStub struct {
Impl IFillCallback
Transport binder.VersionAwareTransport
}
FillCallbackStub dispatches incoming binder transactions to a typed IFillCallback implementation.
func (*FillCallbackStub) Descriptor ¶
func (s *FillCallbackStub) Descriptor() string
func (*FillCallbackStub) OnTransaction ¶
func (s *FillCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type IAugmentedAutofillService ¶
type IAugmentedAutofillService interface {
AsBinder() binder.IBinder
OnConnected(ctx context.Context, debug bool, verbose bool) error
OnDisconnected(ctx context.Context) error
OnFillRequest(ctx context.Context, sessionId int32, autofillManagerClient binder.IBinder, taskId int32, activityComponent content.ComponentName, focusedId autofill.AutofillId, focusedValue autofill.AutofillValue, requestTime int64, inlineSuggestionsRequest inputmethod.InlineSuggestionsRequest, callback IFillCallback) error
OnDestroyAllFillWindowsRequest(ctx context.Context) error
}
func NewAugmentedAutofillServiceStub ¶
func NewAugmentedAutofillServiceStub( impl IAugmentedAutofillServiceServer, ) IAugmentedAutofillService
NewAugmentedAutofillServiceStub creates a server-side IAugmentedAutofillService wrapping the given server implementation. The returned value satisfies IAugmentedAutofillService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IAugmentedAutofillServiceServer ¶
type IAugmentedAutofillServiceServer interface {
OnConnected(ctx context.Context, debug bool, verbose bool) error
OnDisconnected(ctx context.Context) error
OnFillRequest(ctx context.Context, sessionId int32, autofillManagerClient binder.IBinder, taskId int32, activityComponent content.ComponentName, focusedId autofill.AutofillId, focusedValue autofill.AutofillValue, requestTime int64, inlineSuggestionsRequest inputmethod.InlineSuggestionsRequest, callback IFillCallback) error
OnDestroyAllFillWindowsRequest(ctx context.Context) error
}
IAugmentedAutofillServiceServer is the server-side interface that user implementations provide to NewAugmentedAutofillServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IFillCallback ¶
type IFillCallback interface {
AsBinder() binder.IBinder
OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
OnSuccess(ctx context.Context, inlineSuggestionsData []autofill.Dataset, clientState *os.Bundle, showingFillWindow bool) error
IsCompleted(ctx context.Context) (bool, error)
Cancel(ctx context.Context) error
}
func NewFillCallbackStub ¶
func NewFillCallbackStub( impl IFillCallbackServer, ) IFillCallback
NewFillCallbackStub creates a server-side IFillCallback wrapping the given server implementation. The returned value satisfies IFillCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IFillCallbackServer ¶
type IFillCallbackServer interface {
OnCancellable(ctx context.Context, cancellation os.ICancellationSignal) error
OnSuccess(ctx context.Context, inlineSuggestionsData []autofill.Dataset, clientState *os.Bundle, showingFillWindow bool) error
IsCompleted(ctx context.Context) (bool, error)
Cancel(ctx context.Context) error
}
IFillCallbackServer is the server-side interface that user implementations provide to NewFillCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).