Documentation
¶
Index ¶
Constants ¶
const DescriptorIChooserTargetResult = "android.service.chooser.IChooserTargetResult"
const DescriptorIChooserTargetService = "android.service.chooser.IChooserTargetService"
const (
MethodIChooserTargetResultSendResult = "sendResult"
)
const (
MethodIChooserTargetServiceGetChooserTargets = "getChooserTargets"
)
const (
TransactionIChooserTargetResultSendResult = binder.FirstCallTransaction + 0
)
const (
TransactionIChooserTargetServiceGetChooserTargets = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ChooserTarget ¶
type ChooserTarget struct {
Score float32
}
func (*ChooserTarget) MarshalParcel ¶
func (s *ChooserTarget) MarshalParcel( p *parcel.Parcel, ) error
func (*ChooserTarget) UnmarshalParcel ¶
func (s *ChooserTarget) UnmarshalParcel( p *parcel.Parcel, ) error
type ChooserTargetResultProxy ¶
func NewChooserTargetResultProxy ¶
func NewChooserTargetResultProxy( remote binder.IBinder, ) *ChooserTargetResultProxy
func (*ChooserTargetResultProxy) AsBinder ¶
func (p *ChooserTargetResultProxy) AsBinder() binder.IBinder
func (*ChooserTargetResultProxy) SendResult ¶
func (p *ChooserTargetResultProxy) SendResult( ctx context.Context, targets []ChooserTarget, ) error
type ChooserTargetResultStub ¶
type ChooserTargetResultStub struct {
Impl IChooserTargetResult
Transport binder.VersionAwareTransport
}
ChooserTargetResultStub dispatches incoming binder transactions to a typed IChooserTargetResult implementation.
func (*ChooserTargetResultStub) Descriptor ¶
func (s *ChooserTargetResultStub) Descriptor() string
func (*ChooserTargetResultStub) OnTransaction ¶
func (s *ChooserTargetResultStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ChooserTargetServiceProxy ¶
func NewChooserTargetServiceProxy ¶
func NewChooserTargetServiceProxy( remote binder.IBinder, ) *ChooserTargetServiceProxy
func (*ChooserTargetServiceProxy) AsBinder ¶
func (p *ChooserTargetServiceProxy) AsBinder() binder.IBinder
func (*ChooserTargetServiceProxy) GetChooserTargets ¶
func (p *ChooserTargetServiceProxy) GetChooserTargets( ctx context.Context, targetComponentName content.ComponentName, matchedFilter content.IntentFilter, result IChooserTargetResult, ) error
type ChooserTargetServiceStub ¶
type ChooserTargetServiceStub struct {
Impl IChooserTargetService
Transport binder.VersionAwareTransport
}
ChooserTargetServiceStub dispatches incoming binder transactions to a typed IChooserTargetService implementation.
func (*ChooserTargetServiceStub) Descriptor ¶
func (s *ChooserTargetServiceStub) Descriptor() string
func (*ChooserTargetServiceStub) OnTransaction ¶
func (s *ChooserTargetServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type IChooserTargetResult ¶
type IChooserTargetResult interface {
AsBinder() binder.IBinder
SendResult(ctx context.Context, targets []ChooserTarget) error
}
func NewChooserTargetResultStub ¶
func NewChooserTargetResultStub( impl IChooserTargetResultServer, ) IChooserTargetResult
NewChooserTargetResultStub creates a server-side IChooserTargetResult wrapping the given server implementation. The returned value satisfies IChooserTargetResult and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IChooserTargetResultServer ¶
type IChooserTargetResultServer interface {
SendResult(ctx context.Context, targets []ChooserTarget) error
}
IChooserTargetResultServer is the server-side interface that user implementations provide to NewChooserTargetResultStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IChooserTargetService ¶
type IChooserTargetService interface {
AsBinder() binder.IBinder
GetChooserTargets(ctx context.Context, targetComponentName content.ComponentName, matchedFilter content.IntentFilter, result IChooserTargetResult) error
}
func NewChooserTargetServiceStub ¶
func NewChooserTargetServiceStub( impl IChooserTargetServiceServer, ) IChooserTargetService
NewChooserTargetServiceStub creates a server-side IChooserTargetService wrapping the given server implementation. The returned value satisfies IChooserTargetService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IChooserTargetServiceServer ¶
type IChooserTargetServiceServer interface {
GetChooserTargets(ctx context.Context, targetComponentName content.ComponentName, matchedFilter content.IntentFilter, result IChooserTargetResult) error
}
IChooserTargetServiceServer is the server-side interface that user implementations provide to NewChooserTargetServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).