Documentation
¶
Index ¶
- Constants
- type ActivityEvent
- type ContentCaptureServiceCallbackProxy
- func (p *ContentCaptureServiceCallbackProxy) AsBinder() binder.IBinder
- func (p *ContentCaptureServiceCallbackProxy) DisableSelf(ctx context.Context) error
- func (p *ContentCaptureServiceCallbackProxy) SetContentCaptureConditions(ctx context.Context, packageName string, ...) error
- func (p *ContentCaptureServiceCallbackProxy) SetContentCaptureWhitelist(ctx context.Context, packages []string, activities []content.ComponentName) error
- func (p *ContentCaptureServiceCallbackProxy) WriteSessionFlush(ctx context.Context, sessionId int32, app content.ComponentName, ...) error
- type ContentCaptureServiceCallbackStub
- type ContentCaptureServiceProxy
- func (p *ContentCaptureServiceProxy) AsBinder() binder.IBinder
- func (p *ContentCaptureServiceProxy) OnActivityEvent(ctx context.Context, event ActivityEvent) error
- func (p *ContentCaptureServiceProxy) OnActivitySnapshot(ctx context.Context, sessionId int32, snapshotData SnapshotData) error
- func (p *ContentCaptureServiceProxy) OnConnected(ctx context.Context, callback binder.IBinder, verbose bool, debug bool) error
- func (p *ContentCaptureServiceProxy) OnDataRemovalRequest(ctx context.Context, request viewContentcapture.DataRemovalRequest) error
- func (p *ContentCaptureServiceProxy) OnDataShared(ctx context.Context, request viewContentcapture.DataShareRequest, ...) error
- func (p *ContentCaptureServiceProxy) OnDisconnected(ctx context.Context) error
- func (p *ContentCaptureServiceProxy) OnSessionFinished(ctx context.Context, sessionId int32) error
- func (p *ContentCaptureServiceProxy) OnSessionStarted(ctx context.Context, context_ viewContentcapture.ContentCaptureContext, ...) error
- type ContentCaptureServiceStub
- type ContentProtectionAllowlistCallbackProxy
- type ContentProtectionAllowlistCallbackStub
- type ContentProtectionServiceProxy
- type ContentProtectionServiceStub
- type DataShareCallbackProxy
- type DataShareCallbackStub
- type DataShareReadAdapterProxy
- type DataShareReadAdapterStub
- type FlushMetrics
- type IContentCaptureService
- type IContentCaptureServiceCallback
- type IContentCaptureServiceCallbackServer
- type IContentCaptureServiceServer
- type IContentProtectionAllowlistCallback
- type IContentProtectionAllowlistCallbackServer
- type IContentProtectionService
- type IContentProtectionServiceServer
- type IDataShareCallback
- type IDataShareCallbackServer
- type IDataShareReadAdapter
- type IDataShareReadAdapterServer
- type SnapshotData
Constants ¶
const ( TransactionIContentCaptureServiceOnConnected = binder.FirstCallTransaction + 0 TransactionIContentCaptureServiceOnDisconnected = binder.FirstCallTransaction + 1 TransactionIContentCaptureServiceOnSessionStarted = binder.FirstCallTransaction + 2 TransactionIContentCaptureServiceOnSessionFinished = binder.FirstCallTransaction + 3 TransactionIContentCaptureServiceOnActivitySnapshot = binder.FirstCallTransaction + 4 TransactionIContentCaptureServiceOnDataRemovalRequest = binder.FirstCallTransaction + 5 TransactionIContentCaptureServiceOnActivityEvent = binder.FirstCallTransaction + 7 )
const ( MethodIContentCaptureServiceOnConnected = "onConnected" MethodIContentCaptureServiceOnDisconnected = "onDisconnected" MethodIContentCaptureServiceOnSessionStarted = "onSessionStarted" MethodIContentCaptureServiceOnSessionFinished = "onSessionFinished" MethodIContentCaptureServiceOnActivitySnapshot = "onActivitySnapshot" MethodIContentCaptureServiceOnDataRemovalRequest = "onDataRemovalRequest" MethodIContentCaptureServiceOnActivityEvent = "onActivityEvent" )
const ( TransactionIContentCaptureServiceCallbackSetContentCaptureWhitelist = binder.FirstCallTransaction + 0 TransactionIContentCaptureServiceCallbackSetContentCaptureConditions = binder.FirstCallTransaction + 1 TransactionIContentCaptureServiceCallbackDisableSelf = binder.FirstCallTransaction + 2 TransactionIContentCaptureServiceCallbackWriteSessionFlush = binder.FirstCallTransaction + 3 )
const ( MethodIContentCaptureServiceCallbackSetContentCaptureWhitelist = "setContentCaptureWhitelist" MethodIContentCaptureServiceCallbackSetContentCaptureConditions = "setContentCaptureConditions" MethodIContentCaptureServiceCallbackDisableSelf = "disableSelf" MethodIContentCaptureServiceCallbackWriteSessionFlush = "writeSessionFlush" )
const ( TransactionIContentProtectionServiceOnLoginDetected = binder.FirstCallTransaction + 0 TransactionIContentProtectionServiceOnUpdateAllowlistRequest = binder.FirstCallTransaction + 1 )
const ( MethodIContentProtectionServiceOnLoginDetected = "onLoginDetected" MethodIContentProtectionServiceOnUpdateAllowlistRequest = "onUpdateAllowlistRequest" )
const ( )
const ( )
const ( )
const ( )
const DescriptorIContentCaptureService = "android.service.contentcapture.IContentCaptureService"
const DescriptorIContentCaptureServiceCallback = "android.service.contentcapture.IContentCaptureServiceCallback"
const DescriptorIContentProtectionAllowlistCallback = "android.service.contentcapture.IContentProtectionAllowlistCallback"
const DescriptorIContentProtectionService = "android.service.contentcapture.IContentProtectionService"
const (
MethodIContentProtectionAllowlistCallbackSetAllowlist = "setAllowlist"
)
const (
TransactionIContentProtectionAllowlistCallbackSetAllowlist = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ActivityEvent ¶
type ActivityEvent struct {
Type int32
ComponentName *content.ComponentName
}
func (*ActivityEvent) MarshalParcel ¶
func (s *ActivityEvent) MarshalParcel( p *parcel.Parcel, ) error
func (*ActivityEvent) UnmarshalParcel ¶
func (s *ActivityEvent) UnmarshalParcel( p *parcel.Parcel, ) error
type ContentCaptureServiceCallbackProxy ¶
func NewContentCaptureServiceCallbackProxy ¶
func NewContentCaptureServiceCallbackProxy( remote binder.IBinder, ) *ContentCaptureServiceCallbackProxy
func (*ContentCaptureServiceCallbackProxy) AsBinder ¶
func (p *ContentCaptureServiceCallbackProxy) AsBinder() binder.IBinder
func (*ContentCaptureServiceCallbackProxy) DisableSelf ¶
func (p *ContentCaptureServiceCallbackProxy) DisableSelf( ctx context.Context, ) error
func (*ContentCaptureServiceCallbackProxy) SetContentCaptureConditions ¶
func (p *ContentCaptureServiceCallbackProxy) SetContentCaptureConditions( ctx context.Context, packageName string, conditions []viewContentcapture.ContentCaptureCondition, ) error
func (*ContentCaptureServiceCallbackProxy) SetContentCaptureWhitelist ¶
func (p *ContentCaptureServiceCallbackProxy) SetContentCaptureWhitelist( ctx context.Context, packages []string, activities []content.ComponentName, ) error
func (*ContentCaptureServiceCallbackProxy) WriteSessionFlush ¶
func (p *ContentCaptureServiceCallbackProxy) WriteSessionFlush( ctx context.Context, sessionId int32, app content.ComponentName, flushMetrics FlushMetrics, options content.ContentCaptureOptions, flushReason int32, ) error
type ContentCaptureServiceCallbackStub ¶
type ContentCaptureServiceCallbackStub struct {
Impl IContentCaptureServiceCallback
Transport binder.VersionAwareTransport
}
ContentCaptureServiceCallbackStub dispatches incoming binder transactions to a typed IContentCaptureServiceCallback implementation.
func (*ContentCaptureServiceCallbackStub) Descriptor ¶
func (s *ContentCaptureServiceCallbackStub) Descriptor() string
func (*ContentCaptureServiceCallbackStub) OnTransaction ¶
func (s *ContentCaptureServiceCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ContentCaptureServiceProxy ¶
func NewContentCaptureServiceProxy ¶
func NewContentCaptureServiceProxy( remote binder.IBinder, ) *ContentCaptureServiceProxy
func (*ContentCaptureServiceProxy) AsBinder ¶
func (p *ContentCaptureServiceProxy) AsBinder() binder.IBinder
func (*ContentCaptureServiceProxy) OnActivityEvent ¶
func (p *ContentCaptureServiceProxy) OnActivityEvent( ctx context.Context, event ActivityEvent, ) error
func (*ContentCaptureServiceProxy) OnActivitySnapshot ¶
func (p *ContentCaptureServiceProxy) OnActivitySnapshot( ctx context.Context, sessionId int32, snapshotData SnapshotData, ) error
func (*ContentCaptureServiceProxy) OnConnected ¶
func (*ContentCaptureServiceProxy) OnDataRemovalRequest ¶
func (p *ContentCaptureServiceProxy) OnDataRemovalRequest( ctx context.Context, request viewContentcapture.DataRemovalRequest, ) error
func (*ContentCaptureServiceProxy) OnDataShared ¶
func (p *ContentCaptureServiceProxy) OnDataShared( ctx context.Context, request viewContentcapture.DataShareRequest, callback IDataShareCallback, ) error
func (*ContentCaptureServiceProxy) OnDisconnected ¶
func (p *ContentCaptureServiceProxy) OnDisconnected( ctx context.Context, ) error
func (*ContentCaptureServiceProxy) OnSessionFinished ¶
func (p *ContentCaptureServiceProxy) OnSessionFinished( ctx context.Context, sessionId int32, ) error
func (*ContentCaptureServiceProxy) OnSessionStarted ¶
func (p *ContentCaptureServiceProxy) OnSessionStarted( ctx context.Context, context_ viewContentcapture.ContentCaptureContext, sessionId int32, uid int32, clientReceiver os.IResultReceiver, initialState int32, ) error
type ContentCaptureServiceStub ¶
type ContentCaptureServiceStub struct {
Impl IContentCaptureService
Transport binder.VersionAwareTransport
}
ContentCaptureServiceStub dispatches incoming binder transactions to a typed IContentCaptureService implementation.
func (*ContentCaptureServiceStub) Descriptor ¶
func (s *ContentCaptureServiceStub) Descriptor() string
func (*ContentCaptureServiceStub) OnTransaction ¶
func (s *ContentCaptureServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ContentProtectionAllowlistCallbackProxy ¶
func NewContentProtectionAllowlistCallbackProxy ¶
func NewContentProtectionAllowlistCallbackProxy( remote binder.IBinder, ) *ContentProtectionAllowlistCallbackProxy
func (*ContentProtectionAllowlistCallbackProxy) AsBinder ¶
func (p *ContentProtectionAllowlistCallbackProxy) AsBinder() binder.IBinder
func (*ContentProtectionAllowlistCallbackProxy) SetAllowlist ¶
func (p *ContentProtectionAllowlistCallbackProxy) SetAllowlist( ctx context.Context, packages []string, ) error
type ContentProtectionAllowlistCallbackStub ¶
type ContentProtectionAllowlistCallbackStub struct {
Impl IContentProtectionAllowlistCallback
Transport binder.VersionAwareTransport
}
ContentProtectionAllowlistCallbackStub dispatches incoming binder transactions to a typed IContentProtectionAllowlistCallback implementation.
func (*ContentProtectionAllowlistCallbackStub) Descriptor ¶
func (s *ContentProtectionAllowlistCallbackStub) Descriptor() string
func (*ContentProtectionAllowlistCallbackStub) OnTransaction ¶
func (s *ContentProtectionAllowlistCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ContentProtectionServiceProxy ¶
func NewContentProtectionServiceProxy ¶
func NewContentProtectionServiceProxy( remote binder.IBinder, ) *ContentProtectionServiceProxy
func (*ContentProtectionServiceProxy) AsBinder ¶
func (p *ContentProtectionServiceProxy) AsBinder() binder.IBinder
func (*ContentProtectionServiceProxy) OnLoginDetected ¶
func (p *ContentProtectionServiceProxy) OnLoginDetected( ctx context.Context, events pm.ParceledListSlice, ) error
func (*ContentProtectionServiceProxy) OnUpdateAllowlistRequest ¶
type ContentProtectionServiceStub ¶
type ContentProtectionServiceStub struct {
Impl IContentProtectionService
Transport binder.VersionAwareTransport
}
ContentProtectionServiceStub dispatches incoming binder transactions to a typed IContentProtectionService implementation.
func (*ContentProtectionServiceStub) Descriptor ¶
func (s *ContentProtectionServiceStub) Descriptor() string
func (*ContentProtectionServiceStub) OnTransaction ¶
func (s *ContentProtectionServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type DataShareCallbackProxy ¶
type DataShareCallbackProxy struct {
}
func NewDataShareCallbackProxy ¶
func NewDataShareCallbackProxy( remote binder.IBinder, ) *DataShareCallbackProxy
func (*DataShareCallbackProxy) Accept ¶
func (p *DataShareCallbackProxy) Accept( ctx context.Context, adapter IDataShareReadAdapter, ) error
func (*DataShareCallbackProxy) AsBinder ¶
func (p *DataShareCallbackProxy) AsBinder() binder.IBinder
type DataShareCallbackStub ¶
type DataShareCallbackStub struct {
}
DataShareCallbackStub dispatches incoming binder transactions to a typed IDataShareCallback implementation.
func (*DataShareCallbackStub) Descriptor ¶
func (s *DataShareCallbackStub) Descriptor() string
func (*DataShareCallbackStub) OnTransaction ¶
func (s *DataShareCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type DataShareReadAdapterProxy ¶
type DataShareReadAdapterProxy struct {
}
func NewDataShareReadAdapterProxy ¶
func NewDataShareReadAdapterProxy( remote binder.IBinder, ) *DataShareReadAdapterProxy
func (*DataShareReadAdapterProxy) AsBinder ¶
func (p *DataShareReadAdapterProxy) AsBinder() binder.IBinder
func (*DataShareReadAdapterProxy) Error ¶
func (p *DataShareReadAdapterProxy) Error( ctx context.Context, errorCode int32, ) error
type DataShareReadAdapterStub ¶
type DataShareReadAdapterStub struct {
}
DataShareReadAdapterStub dispatches incoming binder transactions to a typed IDataShareReadAdapter implementation.
func (*DataShareReadAdapterStub) Descriptor ¶
func (s *DataShareReadAdapterStub) Descriptor() string
func (*DataShareReadAdapterStub) OnTransaction ¶
func (s *DataShareReadAdapterStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type FlushMetrics ¶
type FlushMetrics struct {
SessionStarted int32
SessionFinished int32
ViewAppearedCount int32
ViewDisappearedCount int32
ViewTextChangedCount int32
}
func (*FlushMetrics) MarshalParcel ¶
func (s *FlushMetrics) MarshalParcel( p *parcel.Parcel, ) error
func (*FlushMetrics) UnmarshalParcel ¶
func (s *FlushMetrics) UnmarshalParcel( p *parcel.Parcel, ) error
type IContentCaptureService ¶
type IContentCaptureService interface {
AsBinder() binder.IBinder
OnConnected(ctx context.Context, callback binder.IBinder, verbose bool, debug bool) error
OnDisconnected(ctx context.Context) error
OnSessionStarted(ctx context.Context, context_ viewContentcapture.ContentCaptureContext, sessionId int32, uid int32, clientReceiver os.IResultReceiver, initialState int32) error
OnSessionFinished(ctx context.Context, sessionId int32) error
OnActivitySnapshot(ctx context.Context, sessionId int32, snapshotData SnapshotData) error
OnDataRemovalRequest(ctx context.Context, request viewContentcapture.DataRemovalRequest) error
OnActivityEvent(ctx context.Context, event ActivityEvent) error
}
func NewContentCaptureServiceStub ¶
func NewContentCaptureServiceStub( impl IContentCaptureServiceServer, ) IContentCaptureService
NewContentCaptureServiceStub creates a server-side IContentCaptureService wrapping the given server implementation. The returned value satisfies IContentCaptureService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IContentCaptureServiceCallback ¶
type IContentCaptureServiceCallback interface {
AsBinder() binder.IBinder
SetContentCaptureWhitelist(ctx context.Context, packages []string, activities []content.ComponentName) error
SetContentCaptureConditions(ctx context.Context, packageName string, conditions []viewContentcapture.ContentCaptureCondition) error
DisableSelf(ctx context.Context) error
WriteSessionFlush(ctx context.Context, sessionId int32, app content.ComponentName, flushMetrics FlushMetrics, options content.ContentCaptureOptions, flushReason int32) error
}
func NewContentCaptureServiceCallbackStub ¶
func NewContentCaptureServiceCallbackStub( impl IContentCaptureServiceCallbackServer, ) IContentCaptureServiceCallback
NewContentCaptureServiceCallbackStub creates a server-side IContentCaptureServiceCallback wrapping the given server implementation. The returned value satisfies IContentCaptureServiceCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IContentCaptureServiceCallbackServer ¶
type IContentCaptureServiceCallbackServer interface {
SetContentCaptureWhitelist(ctx context.Context, packages []string, activities []content.ComponentName) error
SetContentCaptureConditions(ctx context.Context, packageName string, conditions []viewContentcapture.ContentCaptureCondition) error
DisableSelf(ctx context.Context) error
WriteSessionFlush(ctx context.Context, sessionId int32, app content.ComponentName, flushMetrics FlushMetrics, options content.ContentCaptureOptions, flushReason int32) error
}
IContentCaptureServiceCallbackServer is the server-side interface that user implementations provide to NewContentCaptureServiceCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IContentCaptureServiceServer ¶
type IContentCaptureServiceServer interface {
OnConnected(ctx context.Context, callback binder.IBinder, verbose bool, debug bool) error
OnDisconnected(ctx context.Context) error
OnSessionStarted(ctx context.Context, context_ viewContentcapture.ContentCaptureContext, sessionId int32, uid int32, clientReceiver os.IResultReceiver, initialState int32) error
OnSessionFinished(ctx context.Context, sessionId int32) error
OnActivitySnapshot(ctx context.Context, sessionId int32, snapshotData SnapshotData) error
OnDataRemovalRequest(ctx context.Context, request viewContentcapture.DataRemovalRequest) error
OnActivityEvent(ctx context.Context, event ActivityEvent) error
}
IContentCaptureServiceServer is the server-side interface that user implementations provide to NewContentCaptureServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IContentProtectionAllowlistCallback ¶
type IContentProtectionAllowlistCallback interface {
AsBinder() binder.IBinder
SetAllowlist(ctx context.Context, packages []string) error
}
func NewContentProtectionAllowlistCallbackStub ¶
func NewContentProtectionAllowlistCallbackStub( impl IContentProtectionAllowlistCallbackServer, ) IContentProtectionAllowlistCallback
NewContentProtectionAllowlistCallbackStub creates a server-side IContentProtectionAllowlistCallback wrapping the given server implementation. The returned value satisfies IContentProtectionAllowlistCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IContentProtectionAllowlistCallbackServer ¶
type IContentProtectionAllowlistCallbackServer interface {
SetAllowlist(ctx context.Context, packages []string) error
}
IContentProtectionAllowlistCallbackServer is the server-side interface that user implementations provide to NewContentProtectionAllowlistCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IContentProtectionService ¶
type IContentProtectionService interface {
AsBinder() binder.IBinder
OnLoginDetected(ctx context.Context, events pm.ParceledListSlice) error
OnUpdateAllowlistRequest(ctx context.Context, callback binder.IBinder) error
}
func NewContentProtectionServiceStub ¶
func NewContentProtectionServiceStub( impl IContentProtectionServiceServer, ) IContentProtectionService
NewContentProtectionServiceStub creates a server-side IContentProtectionService wrapping the given server implementation. The returned value satisfies IContentProtectionService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IContentProtectionServiceServer ¶
type IContentProtectionServiceServer interface {
OnLoginDetected(ctx context.Context, events pm.ParceledListSlice) error
OnUpdateAllowlistRequest(ctx context.Context, callback binder.IBinder) error
}
IContentProtectionServiceServer is the server-side interface that user implementations provide to NewContentProtectionServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IDataShareCallback ¶
type IDataShareCallback interface {
}
func NewDataShareCallbackStub ¶
func NewDataShareCallbackStub( impl IDataShareCallbackServer, ) IDataShareCallback
NewDataShareCallbackStub creates a server-side IDataShareCallback wrapping the given server implementation. The returned value satisfies IDataShareCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IDataShareCallbackServer ¶
type IDataShareCallbackServer interface {
}
IDataShareCallbackServer is the server-side interface that user implementations provide to NewDataShareCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IDataShareReadAdapter ¶
type IDataShareReadAdapter interface {
}
func NewDataShareReadAdapterStub ¶
func NewDataShareReadAdapterStub( impl IDataShareReadAdapterServer, ) IDataShareReadAdapter
NewDataShareReadAdapterStub creates a server-side IDataShareReadAdapter wrapping the given server implementation. The returned value satisfies IDataShareReadAdapter and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IDataShareReadAdapterServer ¶
type IDataShareReadAdapterServer interface {
}
IDataShareReadAdapterServer is the server-side interface that user implementations provide to NewDataShareReadAdapterStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type SnapshotData ¶
type SnapshotData struct {
AssistStructure *assist.AssistStructure
AssistContent *assist.AssistContent
}
func (*SnapshotData) MarshalParcel ¶
func (s *SnapshotData) MarshalParcel( p *parcel.Parcel, ) error
func (*SnapshotData) UnmarshalParcel ¶
func (s *SnapshotData) UnmarshalParcel( p *parcel.Parcel, ) error