Documentation
¶
Index ¶
- Constants
- type Control
- type ControlsActionCallbackProxy
- type ControlsActionCallbackStub
- type ControlsProviderProxy
- func (p *ControlsProviderProxy) Action(ctx context.Context, controlId string, action actions.ControlActionWrapper, ...) error
- func (p *ControlsProviderProxy) AsBinder() binder.IBinder
- func (p *ControlsProviderProxy) Load(ctx context.Context, subscriber IControlsSubscriber) error
- func (p *ControlsProviderProxy) LoadSuggested(ctx context.Context, subscriber IControlsSubscriber) error
- func (p *ControlsProviderProxy) Subscribe(ctx context.Context, controlIds []string, subscriber IControlsSubscriber) error
- type ControlsProviderStub
- type ControlsSubscriberProxy
- func (p *ControlsSubscriberProxy) AsBinder() binder.IBinder
- func (p *ControlsSubscriberProxy) OnComplete(ctx context.Context, token binder.IBinder) error
- func (p *ControlsSubscriberProxy) OnError(ctx context.Context, token binder.IBinder, s_ string) error
- func (p *ControlsSubscriberProxy) OnNext(ctx context.Context, token binder.IBinder, c Control) error
- func (p *ControlsSubscriberProxy) OnSubscribe(ctx context.Context, token binder.IBinder, cs IControlsSubscription) error
- type ControlsSubscriberStub
- type ControlsSubscriptionProxy
- type ControlsSubscriptionStub
- type IControlsActionCallback
- type IControlsActionCallbackServer
- type IControlsProvider
- type IControlsProviderServer
- type IControlsSubscriber
- type IControlsSubscriberServer
- type IControlsSubscription
- type IControlsSubscriptionServer
Constants ¶
const ( TransactionIControlsProviderLoad = binder.FirstCallTransaction + 0 TransactionIControlsProviderLoadSuggested = binder.FirstCallTransaction + 1 TransactionIControlsProviderSubscribe = binder.FirstCallTransaction + 2 TransactionIControlsProviderAction = binder.FirstCallTransaction + 3 )
const ( MethodIControlsProviderLoad = "load" MethodIControlsProviderLoadSuggested = "loadSuggested" MethodIControlsProviderSubscribe = "subscribe" MethodIControlsProviderAction = "action" )
const ( TransactionIControlsSubscriberOnSubscribe = binder.FirstCallTransaction + 0 TransactionIControlsSubscriberOnNext = binder.FirstCallTransaction + 1 TransactionIControlsSubscriberOnError = binder.FirstCallTransaction + 2 TransactionIControlsSubscriberOnComplete = binder.FirstCallTransaction + 3 )
const ( MethodIControlsSubscriberOnSubscribe = "onSubscribe" MethodIControlsSubscriberOnNext = "onNext" MethodIControlsSubscriberOnError = "onError" MethodIControlsSubscriberOnComplete = "onComplete" )
const ( TransactionIControlsSubscriptionRequest = binder.FirstCallTransaction + 0 TransactionIControlsSubscriptionCancel = binder.FirstCallTransaction + 1 )
const ( MethodIControlsSubscriptionRequest = "request" MethodIControlsSubscriptionCancel = "cancel" )
const DescriptorIControlsActionCallback = "android.service.controls.IControlsActionCallback"
const DescriptorIControlsProvider = "android.service.controls.IControlsProvider"
const DescriptorIControlsSubscriber = "android.service.controls.IControlsSubscriber"
const DescriptorIControlsSubscription = "android.service.controls.IControlsSubscription"
const (
MethodIControlsActionCallbackAccept = "accept"
)
const (
TransactionIControlsActionCallbackAccept = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ControlsActionCallbackProxy ¶
func NewControlsActionCallbackProxy ¶
func NewControlsActionCallbackProxy( remote binder.IBinder, ) *ControlsActionCallbackProxy
func (*ControlsActionCallbackProxy) AsBinder ¶
func (p *ControlsActionCallbackProxy) AsBinder() binder.IBinder
type ControlsActionCallbackStub ¶
type ControlsActionCallbackStub struct {
Impl IControlsActionCallback
Transport binder.VersionAwareTransport
}
ControlsActionCallbackStub dispatches incoming binder transactions to a typed IControlsActionCallback implementation.
func (*ControlsActionCallbackStub) Descriptor ¶
func (s *ControlsActionCallbackStub) Descriptor() string
func (*ControlsActionCallbackStub) OnTransaction ¶
func (s *ControlsActionCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ControlsProviderProxy ¶
func NewControlsProviderProxy ¶
func NewControlsProviderProxy( remote binder.IBinder, ) *ControlsProviderProxy
func (*ControlsProviderProxy) Action ¶
func (p *ControlsProviderProxy) Action( ctx context.Context, controlId string, action actions.ControlActionWrapper, cb IControlsActionCallback, ) error
func (*ControlsProviderProxy) AsBinder ¶
func (p *ControlsProviderProxy) AsBinder() binder.IBinder
func (*ControlsProviderProxy) Load ¶
func (p *ControlsProviderProxy) Load( ctx context.Context, subscriber IControlsSubscriber, ) error
func (*ControlsProviderProxy) LoadSuggested ¶
func (p *ControlsProviderProxy) LoadSuggested( ctx context.Context, subscriber IControlsSubscriber, ) error
func (*ControlsProviderProxy) Subscribe ¶
func (p *ControlsProviderProxy) Subscribe( ctx context.Context, controlIds []string, subscriber IControlsSubscriber, ) error
type ControlsProviderStub ¶
type ControlsProviderStub struct {
Impl IControlsProvider
Transport binder.VersionAwareTransport
}
ControlsProviderStub dispatches incoming binder transactions to a typed IControlsProvider implementation.
func (*ControlsProviderStub) Descriptor ¶
func (s *ControlsProviderStub) Descriptor() string
func (*ControlsProviderStub) OnTransaction ¶
func (s *ControlsProviderStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ControlsSubscriberProxy ¶
func NewControlsSubscriberProxy ¶
func NewControlsSubscriberProxy( remote binder.IBinder, ) *ControlsSubscriberProxy
func (*ControlsSubscriberProxy) AsBinder ¶
func (p *ControlsSubscriberProxy) AsBinder() binder.IBinder
func (*ControlsSubscriberProxy) OnComplete ¶
func (*ControlsSubscriberProxy) OnSubscribe ¶
func (p *ControlsSubscriberProxy) OnSubscribe( ctx context.Context, token binder.IBinder, cs IControlsSubscription, ) error
type ControlsSubscriberStub ¶
type ControlsSubscriberStub struct {
Impl IControlsSubscriber
Transport binder.VersionAwareTransport
}
ControlsSubscriberStub dispatches incoming binder transactions to a typed IControlsSubscriber implementation.
func (*ControlsSubscriberStub) Descriptor ¶
func (s *ControlsSubscriberStub) Descriptor() string
func (*ControlsSubscriberStub) OnTransaction ¶
func (s *ControlsSubscriberStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ControlsSubscriptionProxy ¶
func NewControlsSubscriptionProxy ¶
func NewControlsSubscriptionProxy( remote binder.IBinder, ) *ControlsSubscriptionProxy
func (*ControlsSubscriptionProxy) AsBinder ¶
func (p *ControlsSubscriptionProxy) AsBinder() binder.IBinder
type ControlsSubscriptionStub ¶
type ControlsSubscriptionStub struct {
Impl IControlsSubscription
Transport binder.VersionAwareTransport
}
ControlsSubscriptionStub dispatches incoming binder transactions to a typed IControlsSubscription implementation.
func (*ControlsSubscriptionStub) Descriptor ¶
func (s *ControlsSubscriptionStub) Descriptor() string
func (*ControlsSubscriptionStub) OnTransaction ¶
func (s *ControlsSubscriptionStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type IControlsActionCallback ¶
type IControlsActionCallback interface {
AsBinder() binder.IBinder
Accept(ctx context.Context, token binder.IBinder, controlId string, response int32) error
}
func NewControlsActionCallbackStub ¶
func NewControlsActionCallbackStub( impl IControlsActionCallbackServer, ) IControlsActionCallback
NewControlsActionCallbackStub creates a server-side IControlsActionCallback wrapping the given server implementation. The returned value satisfies IControlsActionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IControlsActionCallbackServer ¶
type IControlsActionCallbackServer interface {
Accept(ctx context.Context, token binder.IBinder, controlId string, response int32) error
}
IControlsActionCallbackServer is the server-side interface that user implementations provide to NewControlsActionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IControlsProvider ¶
type IControlsProvider interface {
AsBinder() binder.IBinder
Load(ctx context.Context, subscriber IControlsSubscriber) error
LoadSuggested(ctx context.Context, subscriber IControlsSubscriber) error
Subscribe(ctx context.Context, controlIds []string, subscriber IControlsSubscriber) error
Action(ctx context.Context, controlId string, action actions.ControlActionWrapper, cb IControlsActionCallback) error
}
func NewControlsProviderStub ¶
func NewControlsProviderStub( impl IControlsProviderServer, ) IControlsProvider
NewControlsProviderStub creates a server-side IControlsProvider wrapping the given server implementation. The returned value satisfies IControlsProvider and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IControlsProviderServer ¶
type IControlsProviderServer interface {
Load(ctx context.Context, subscriber IControlsSubscriber) error
LoadSuggested(ctx context.Context, subscriber IControlsSubscriber) error
Subscribe(ctx context.Context, controlIds []string, subscriber IControlsSubscriber) error
Action(ctx context.Context, controlId string, action actions.ControlActionWrapper, cb IControlsActionCallback) error
}
IControlsProviderServer is the server-side interface that user implementations provide to NewControlsProviderStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IControlsSubscriber ¶
type IControlsSubscriber interface {
AsBinder() binder.IBinder
OnSubscribe(ctx context.Context, token binder.IBinder, cs IControlsSubscription) error
OnNext(ctx context.Context, token binder.IBinder, c Control) error
OnError(ctx context.Context, token binder.IBinder, s_ string) error
OnComplete(ctx context.Context, token binder.IBinder) error
}
func NewControlsSubscriberStub ¶
func NewControlsSubscriberStub( impl IControlsSubscriberServer, ) IControlsSubscriber
NewControlsSubscriberStub creates a server-side IControlsSubscriber wrapping the given server implementation. The returned value satisfies IControlsSubscriber and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IControlsSubscriberServer ¶
type IControlsSubscriberServer interface {
OnSubscribe(ctx context.Context, token binder.IBinder, cs IControlsSubscription) error
OnNext(ctx context.Context, token binder.IBinder, c Control) error
OnError(ctx context.Context, token binder.IBinder, s_ string) error
OnComplete(ctx context.Context, token binder.IBinder) error
}
IControlsSubscriberServer is the server-side interface that user implementations provide to NewControlsSubscriberStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IControlsSubscription ¶
type IControlsSubscription interface {
AsBinder() binder.IBinder
Request(ctx context.Context, n int64) error
Cancel(ctx context.Context) error
}
func NewControlsSubscriptionStub ¶
func NewControlsSubscriptionStub( impl IControlsSubscriptionServer, ) IControlsSubscription
NewControlsSubscriptionStub creates a server-side IControlsSubscription wrapping the given server implementation. The returned value satisfies IControlsSubscription and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IControlsSubscriptionServer ¶
type IControlsSubscriptionServer interface {
Request(ctx context.Context, n int64) error
Cancel(ctx context.Context) error
}
IControlsSubscriptionServer is the server-side interface that user implementations provide to NewControlsSubscriptionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).