notification

package
v0.0.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: CC0-1.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	TransactionIConditionProviderOnConnected   = binder.FirstCallTransaction + 0
	TransactionIConditionProviderOnSubscribe   = binder.FirstCallTransaction + 1
	TransactionIConditionProviderOnUnsubscribe = binder.FirstCallTransaction + 2
)
const (
	MethodIConditionProviderOnConnected   = "onConnected"
	MethodIConditionProviderOnSubscribe   = "onSubscribe"
	MethodIConditionProviderOnUnsubscribe = "onUnsubscribe"
)
const (
	TransactionINotificationListenerOnListenerConnected                    = binder.FirstCallTransaction + 0
	TransactionINotificationListenerOnNotificationPosted                   = binder.FirstCallTransaction + 1
	TransactionINotificationListenerOnStatusBarIconsBehaviorChanged        = binder.FirstCallTransaction + 2
	TransactionINotificationListenerOnNotificationRemoved                  = binder.FirstCallTransaction + 3
	TransactionINotificationListenerOnNotificationRankingUpdate            = binder.FirstCallTransaction + 4
	TransactionINotificationListenerOnListenerHintsChanged                 = binder.FirstCallTransaction + 5
	TransactionINotificationListenerOnInterruptionFilterChanged            = binder.FirstCallTransaction + 6
	TransactionINotificationListenerOnNotificationChannelModification      = binder.FirstCallTransaction + 7
	TransactionINotificationListenerOnNotificationChannelGroupModification = binder.FirstCallTransaction + 8
	TransactionINotificationListenerOnNotificationEnqueuedWithChannel      = binder.FirstCallTransaction + 9
	TransactionINotificationListenerOnNotificationSnoozedUntilContext      = binder.FirstCallTransaction + 10
	TransactionINotificationListenerOnNotificationsSeen                    = binder.FirstCallTransaction + 11
	TransactionINotificationListenerOnPanelRevealed                        = binder.FirstCallTransaction + 12
	TransactionINotificationListenerOnPanelHidden                          = binder.FirstCallTransaction + 13
	TransactionINotificationListenerOnNotificationVisibilityChanged        = binder.FirstCallTransaction + 14
	TransactionINotificationListenerOnNotificationExpansionChanged         = binder.FirstCallTransaction + 15
	TransactionINotificationListenerOnNotificationDirectReply              = binder.FirstCallTransaction + 16
	TransactionINotificationListenerOnSuggestedReplySent                   = binder.FirstCallTransaction + 17
	TransactionINotificationListenerOnActionClicked                        = binder.FirstCallTransaction + 18
	TransactionINotificationListenerOnNotificationClicked                  = binder.FirstCallTransaction + 19
	TransactionINotificationListenerOnAllowedAdjustmentsChanged            = binder.FirstCallTransaction + 20
	TransactionINotificationListenerOnNotificationFeedbackReceived         = binder.FirstCallTransaction + 21
)
const (
	MethodINotificationListenerOnListenerConnected                    = "onListenerConnected"
	MethodINotificationListenerOnNotificationPosted                   = "onNotificationPosted"
	MethodINotificationListenerOnStatusBarIconsBehaviorChanged        = "onStatusBarIconsBehaviorChanged"
	MethodINotificationListenerOnNotificationRemoved                  = "onNotificationRemoved"
	MethodINotificationListenerOnNotificationRankingUpdate            = "onNotificationRankingUpdate"
	MethodINotificationListenerOnListenerHintsChanged                 = "onListenerHintsChanged"
	MethodINotificationListenerOnInterruptionFilterChanged            = "onInterruptionFilterChanged"
	MethodINotificationListenerOnNotificationChannelModification      = "onNotificationChannelModification"
	MethodINotificationListenerOnNotificationChannelGroupModification = "onNotificationChannelGroupModification"
	MethodINotificationListenerOnNotificationEnqueuedWithChannel      = "onNotificationEnqueuedWithChannel"
	MethodINotificationListenerOnNotificationSnoozedUntilContext      = "onNotificationSnoozedUntilContext"
	MethodINotificationListenerOnNotificationsSeen                    = "onNotificationsSeen"
	MethodINotificationListenerOnPanelRevealed                        = "onPanelRevealed"
	MethodINotificationListenerOnPanelHidden                          = "onPanelHidden"
	MethodINotificationListenerOnNotificationVisibilityChanged        = "onNotificationVisibilityChanged"
	MethodINotificationListenerOnNotificationExpansionChanged         = "onNotificationExpansionChanged"
	MethodINotificationListenerOnNotificationDirectReply              = "onNotificationDirectReply"
	MethodINotificationListenerOnSuggestedReplySent                   = "onSuggestedReplySent"
	MethodINotificationListenerOnActionClicked                        = "onActionClicked"
	MethodINotificationListenerOnNotificationClicked                  = "onNotificationClicked"
	MethodINotificationListenerOnAllowedAdjustmentsChanged            = "onAllowedAdjustmentsChanged"
	MethodINotificationListenerOnNotificationFeedbackReceived         = "onNotificationFeedbackReceived"
)
const DescriptorIConditionListener = "android.service.notification.IConditionListener"
const DescriptorIConditionProvider = "android.service.notification.IConditionProvider"
const DescriptorINotificationListener = "android.service.notification.INotificationListener"
const DescriptorIStatusBarNotificationHolder = "android.service.notification.IStatusBarNotificationHolder"
const (
	MethodIConditionListenerOnConditionsReceived = "onConditionsReceived"
)
const (
	MethodIStatusBarNotificationHolderGet = "get"
)
const (
	TransactionIConditionListenerOnConditionsReceived = binder.FirstCallTransaction + 0
)
const (
	TransactionIStatusBarNotificationHolderGet = binder.FirstCallTransaction + 0
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Adjustment

type Adjustment struct {
	User   int32
	Issuer string
}

func (*Adjustment) MarshalParcel

func (s *Adjustment) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Adjustment) UnmarshalParcel

func (s *Adjustment) UnmarshalParcel(
	p *parcel.Parcel,
) error

type Condition

type Condition struct {
	Summary string
	Line1   string
	Line2   string
	Icon    int32
	State   int32
}

func (*Condition) MarshalParcel

func (s *Condition) MarshalParcel(
	p *parcel.Parcel,
) error

func (*Condition) UnmarshalParcel

func (s *Condition) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ConditionListenerProxy

type ConditionListenerProxy struct {
	Remote binder.IBinder
}

func NewConditionListenerProxy

func NewConditionListenerProxy(
	remote binder.IBinder,
) *ConditionListenerProxy

func (*ConditionListenerProxy) AsBinder

func (p *ConditionListenerProxy) AsBinder() binder.IBinder

func (*ConditionListenerProxy) OnConditionsReceived

func (p *ConditionListenerProxy) OnConditionsReceived(
	ctx context.Context,
	conditions []Condition,
) error

type ConditionListenerStub

type ConditionListenerStub struct {
	Impl      IConditionListener
	Transport binder.VersionAwareTransport
}

ConditionListenerStub dispatches incoming binder transactions to a typed IConditionListener implementation.

func (*ConditionListenerStub) Descriptor

func (s *ConditionListenerStub) Descriptor() string

func (*ConditionListenerStub) OnTransaction

func (s *ConditionListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ConditionProviderProxy

type ConditionProviderProxy struct {
	Remote binder.IBinder
}

func NewConditionProviderProxy

func NewConditionProviderProxy(
	remote binder.IBinder,
) *ConditionProviderProxy

func (*ConditionProviderProxy) AsBinder

func (p *ConditionProviderProxy) AsBinder() binder.IBinder

func (*ConditionProviderProxy) OnConnected

func (p *ConditionProviderProxy) OnConnected(
	ctx context.Context,
) error

func (*ConditionProviderProxy) OnSubscribe

func (p *ConditionProviderProxy) OnSubscribe(
	ctx context.Context,
	conditionId net.Uri,
) error

func (*ConditionProviderProxy) OnUnsubscribe

func (p *ConditionProviderProxy) OnUnsubscribe(
	ctx context.Context,
	conditionId net.Uri,
) error

type ConditionProviderStub

type ConditionProviderStub struct {
	Impl      IConditionProvider
	Transport binder.VersionAwareTransport
}

ConditionProviderStub dispatches incoming binder transactions to a typed IConditionProvider implementation.

func (*ConditionProviderStub) Descriptor

func (s *ConditionProviderStub) Descriptor() string

func (*ConditionProviderStub) OnTransaction

func (s *ConditionProviderStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type ConversationChannelWrapper

type ConversationChannelWrapper struct {
	Uid                 int32
	NotificationChannel *types.NotificationChannel
	ShortcutInfo        *pmTypes.ShortcutInfo
}

func (*ConversationChannelWrapper) MarshalParcel

func (s *ConversationChannelWrapper) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ConversationChannelWrapper) UnmarshalParcel

func (s *ConversationChannelWrapper) UnmarshalParcel(
	p *parcel.Parcel,
) error

type IConditionListener

type IConditionListener interface {
	AsBinder() binder.IBinder
	OnConditionsReceived(ctx context.Context, conditions []Condition) error
}

func NewConditionListenerStub

func NewConditionListenerStub(
	impl IConditionListenerServer,
) IConditionListener

NewConditionListenerStub creates a server-side IConditionListener wrapping the given server implementation. The returned value satisfies IConditionListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IConditionListenerServer

type IConditionListenerServer interface {
	OnConditionsReceived(ctx context.Context, conditions []Condition) error
}

IConditionListenerServer is the server-side interface that user implementations provide to NewConditionListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IConditionProvider

type IConditionProvider interface {
	AsBinder() binder.IBinder
	OnConnected(ctx context.Context) error
	OnSubscribe(ctx context.Context, conditionId net.Uri) error
	OnUnsubscribe(ctx context.Context, conditionId net.Uri) error
}

func NewConditionProviderStub

func NewConditionProviderStub(
	impl IConditionProviderServer,
) IConditionProvider

NewConditionProviderStub creates a server-side IConditionProvider wrapping the given server implementation. The returned value satisfies IConditionProvider and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IConditionProviderServer

type IConditionProviderServer interface {
	OnConnected(ctx context.Context) error
	OnSubscribe(ctx context.Context, conditionId net.Uri) error
	OnUnsubscribe(ctx context.Context, conditionId net.Uri) error
}

IConditionProviderServer is the server-side interface that user implementations provide to NewConditionProviderStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type INotificationListener

type INotificationListener interface {
	AsBinder() binder.IBinder
	OnListenerConnected(ctx context.Context, update NotificationRankingUpdate) error
	OnNotificationPosted(ctx context.Context, notificationHolder IStatusBarNotificationHolder, update NotificationRankingUpdate) error
	OnStatusBarIconsBehaviorChanged(ctx context.Context, hideSilentStatusIcons bool) error
	OnNotificationRemoved(ctx context.Context, notificationHolder IStatusBarNotificationHolder, update NotificationRankingUpdate, stats NotificationStats, reason int32) error
	OnNotificationRankingUpdate(ctx context.Context, update NotificationRankingUpdate) error
	OnListenerHintsChanged(ctx context.Context, hints int32) error
	OnInterruptionFilterChanged(ctx context.Context, interruptionFilter int32) error
	OnNotificationChannelModification(ctx context.Context, pkgName string, user os.UserHandle, channel types.NotificationChannel, modificationType int32) error
	OnNotificationChannelGroupModification(ctx context.Context, pkgName string, user os.UserHandle, group types.NotificationChannelGroup, modificationType int32) error
	OnNotificationEnqueuedWithChannel(ctx context.Context, notificationHolder IStatusBarNotificationHolder, channel types.NotificationChannel, update NotificationRankingUpdate) error
	OnNotificationSnoozedUntilContext(ctx context.Context, notificationHolder IStatusBarNotificationHolder, snoozeCriterionId string) error
	OnNotificationsSeen(ctx context.Context, keys []string) error
	OnPanelRevealed(ctx context.Context, items int32) error
	OnPanelHidden(ctx context.Context) error
	OnNotificationVisibilityChanged(ctx context.Context, key string, isVisible bool) error
	OnNotificationExpansionChanged(ctx context.Context, key string, userAction bool, expanded bool) error
	OnNotificationDirectReply(ctx context.Context, key string) error
	OnSuggestedReplySent(ctx context.Context, key string, reply string, source int32) error
	OnActionClicked(ctx context.Context, key string, action types.NotificationAction, source int32) error
	OnNotificationClicked(ctx context.Context, key string) error
	OnAllowedAdjustmentsChanged(ctx context.Context) error
	OnNotificationFeedbackReceived(ctx context.Context, key string, update NotificationRankingUpdate, feedback os.Bundle) error
}

func NewNotificationListenerStub

func NewNotificationListenerStub(
	impl INotificationListenerServer,
) INotificationListener

NewNotificationListenerStub creates a server-side INotificationListener wrapping the given server implementation. The returned value satisfies INotificationListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type INotificationListenerServer

type INotificationListenerServer interface {
	OnListenerConnected(ctx context.Context, update NotificationRankingUpdate) error
	OnNotificationPosted(ctx context.Context, notificationHolder IStatusBarNotificationHolder, update NotificationRankingUpdate) error
	OnStatusBarIconsBehaviorChanged(ctx context.Context, hideSilentStatusIcons bool) error
	OnNotificationRemoved(ctx context.Context, notificationHolder IStatusBarNotificationHolder, update NotificationRankingUpdate, stats NotificationStats, reason int32) error
	OnNotificationRankingUpdate(ctx context.Context, update NotificationRankingUpdate) error
	OnListenerHintsChanged(ctx context.Context, hints int32) error
	OnInterruptionFilterChanged(ctx context.Context, interruptionFilter int32) error
	OnNotificationChannelModification(ctx context.Context, pkgName string, user os.UserHandle, channel types.NotificationChannel, modificationType int32) error
	OnNotificationChannelGroupModification(ctx context.Context, pkgName string, user os.UserHandle, group types.NotificationChannelGroup, modificationType int32) error
	OnNotificationEnqueuedWithChannel(ctx context.Context, notificationHolder IStatusBarNotificationHolder, channel types.NotificationChannel, update NotificationRankingUpdate) error
	OnNotificationSnoozedUntilContext(ctx context.Context, notificationHolder IStatusBarNotificationHolder, snoozeCriterionId string) error
	OnNotificationsSeen(ctx context.Context, keys []string) error
	OnPanelRevealed(ctx context.Context, items int32) error
	OnPanelHidden(ctx context.Context) error
	OnNotificationVisibilityChanged(ctx context.Context, key string, isVisible bool) error
	OnNotificationExpansionChanged(ctx context.Context, key string, userAction bool, expanded bool) error
	OnNotificationDirectReply(ctx context.Context, key string) error
	OnSuggestedReplySent(ctx context.Context, key string, reply string, source int32) error
	OnActionClicked(ctx context.Context, key string, action types.NotificationAction, source int32) error
	OnNotificationClicked(ctx context.Context, key string) error
	OnAllowedAdjustmentsChanged(ctx context.Context) error
	OnNotificationFeedbackReceived(ctx context.Context, key string, update NotificationRankingUpdate, feedback os.Bundle) error
}

INotificationListenerServer is the server-side interface that user implementations provide to NewNotificationListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type IStatusBarNotificationHolder

type IStatusBarNotificationHolder interface {
	AsBinder() binder.IBinder
	Get(ctx context.Context) (StatusBarNotification, error)
}

func NewStatusBarNotificationHolderStub

func NewStatusBarNotificationHolderStub(
	impl IStatusBarNotificationHolderServer,
) IStatusBarNotificationHolder

NewStatusBarNotificationHolderStub creates a server-side IStatusBarNotificationHolder wrapping the given server implementation. The returned value satisfies IStatusBarNotificationHolder and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.

type IStatusBarNotificationHolderServer

type IStatusBarNotificationHolderServer interface {
	Get(ctx context.Context) (StatusBarNotification, error)
}

IStatusBarNotificationHolderServer is the server-side interface that user implementations provide to NewStatusBarNotificationHolderStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).

type NotificationListenerFilter

type NotificationListenerFilter struct {
	AllowedNotificationTypes int32
}

func (*NotificationListenerFilter) MarshalParcel

func (s *NotificationListenerFilter) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NotificationListenerFilter) UnmarshalParcel

func (s *NotificationListenerFilter) UnmarshalParcel(
	p *parcel.Parcel,
) error

type NotificationListenerProxy

type NotificationListenerProxy struct {
	Remote binder.IBinder
}

func NewNotificationListenerProxy

func NewNotificationListenerProxy(
	remote binder.IBinder,
) *NotificationListenerProxy

func (*NotificationListenerProxy) AsBinder

func (*NotificationListenerProxy) OnActionClicked

func (p *NotificationListenerProxy) OnActionClicked(
	ctx context.Context,
	key string,
	action types.NotificationAction,
	source int32,
) error

func (*NotificationListenerProxy) OnAllowedAdjustmentsChanged

func (p *NotificationListenerProxy) OnAllowedAdjustmentsChanged(
	ctx context.Context,
) error

func (*NotificationListenerProxy) OnInterruptionFilterChanged

func (p *NotificationListenerProxy) OnInterruptionFilterChanged(
	ctx context.Context,
	interruptionFilter int32,
) error

func (*NotificationListenerProxy) OnListenerConnected

func (p *NotificationListenerProxy) OnListenerConnected(
	ctx context.Context,
	update NotificationRankingUpdate,
) error

func (*NotificationListenerProxy) OnListenerHintsChanged

func (p *NotificationListenerProxy) OnListenerHintsChanged(
	ctx context.Context,
	hints int32,
) error

func (*NotificationListenerProxy) OnNotificationChannelGroupModification

func (p *NotificationListenerProxy) OnNotificationChannelGroupModification(
	ctx context.Context,
	pkgName string,
	user os.UserHandle,
	group types.NotificationChannelGroup,
	modificationType int32,
) error

func (*NotificationListenerProxy) OnNotificationChannelModification

func (p *NotificationListenerProxy) OnNotificationChannelModification(
	ctx context.Context,
	pkgName string,
	user os.UserHandle,
	channel types.NotificationChannel,
	modificationType int32,
) error

func (*NotificationListenerProxy) OnNotificationClicked

func (p *NotificationListenerProxy) OnNotificationClicked(
	ctx context.Context,
	key string,
) error

func (*NotificationListenerProxy) OnNotificationDirectReply

func (p *NotificationListenerProxy) OnNotificationDirectReply(
	ctx context.Context,
	key string,
) error

func (*NotificationListenerProxy) OnNotificationEnqueuedWithChannel

func (p *NotificationListenerProxy) OnNotificationEnqueuedWithChannel(
	ctx context.Context,
	notificationHolder IStatusBarNotificationHolder,
	channel types.NotificationChannel,
	update NotificationRankingUpdate,
) error

func (*NotificationListenerProxy) OnNotificationExpansionChanged

func (p *NotificationListenerProxy) OnNotificationExpansionChanged(
	ctx context.Context,
	key string,
	userAction bool,
	expanded bool,
) error

func (*NotificationListenerProxy) OnNotificationFeedbackReceived

func (p *NotificationListenerProxy) OnNotificationFeedbackReceived(
	ctx context.Context,
	key string,
	update NotificationRankingUpdate,
	feedback os.Bundle,
) error

func (*NotificationListenerProxy) OnNotificationPosted

func (p *NotificationListenerProxy) OnNotificationPosted(
	ctx context.Context,
	notificationHolder IStatusBarNotificationHolder,
	update NotificationRankingUpdate,
) error

func (*NotificationListenerProxy) OnNotificationRankingUpdate

func (p *NotificationListenerProxy) OnNotificationRankingUpdate(
	ctx context.Context,
	update NotificationRankingUpdate,
) error

func (*NotificationListenerProxy) OnNotificationRemoved

func (p *NotificationListenerProxy) OnNotificationRemoved(
	ctx context.Context,
	notificationHolder IStatusBarNotificationHolder,
	update NotificationRankingUpdate,
	stats NotificationStats,
	reason int32,
) error

func (*NotificationListenerProxy) OnNotificationSnoozedUntilContext

func (p *NotificationListenerProxy) OnNotificationSnoozedUntilContext(
	ctx context.Context,
	notificationHolder IStatusBarNotificationHolder,
	snoozeCriterionId string,
) error

func (*NotificationListenerProxy) OnNotificationVisibilityChanged

func (p *NotificationListenerProxy) OnNotificationVisibilityChanged(
	ctx context.Context,
	key string,
	isVisible bool,
) error

func (*NotificationListenerProxy) OnNotificationsSeen

func (p *NotificationListenerProxy) OnNotificationsSeen(
	ctx context.Context,
	keys []string,
) error

func (*NotificationListenerProxy) OnPanelHidden

func (p *NotificationListenerProxy) OnPanelHidden(
	ctx context.Context,
) error

func (*NotificationListenerProxy) OnPanelRevealed

func (p *NotificationListenerProxy) OnPanelRevealed(
	ctx context.Context,
	items int32,
) error

func (*NotificationListenerProxy) OnStatusBarIconsBehaviorChanged

func (p *NotificationListenerProxy) OnStatusBarIconsBehaviorChanged(
	ctx context.Context,
	hideSilentStatusIcons bool,
) error

func (*NotificationListenerProxy) OnSuggestedReplySent

func (p *NotificationListenerProxy) OnSuggestedReplySent(
	ctx context.Context,
	key string,
	reply string,
	source int32,
) error

type NotificationListenerStub

type NotificationListenerStub struct {
	Impl      INotificationListener
	Transport binder.VersionAwareTransport
}

NotificationListenerStub dispatches incoming binder transactions to a typed INotificationListener implementation.

func (*NotificationListenerStub) Descriptor

func (s *NotificationListenerStub) Descriptor() string

func (*NotificationListenerStub) OnTransaction

func (s *NotificationListenerStub) OnTransaction(
	ctx context.Context,
	code binder.TransactionCode,
	_data *parcel.Parcel,
) (*parcel.Parcel, error)

type NotificationRankingUpdate

type NotificationRankingUpdate struct {
}

func (*NotificationRankingUpdate) MarshalParcel

func (s *NotificationRankingUpdate) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NotificationRankingUpdate) UnmarshalParcel

func (s *NotificationRankingUpdate) UnmarshalParcel(
	p *parcel.Parcel,
) error

type NotificationStats

type NotificationStats struct {
	DismissalSurface   int32
	DismissalSentiment int32
}

func (*NotificationStats) MarshalParcel

func (s *NotificationStats) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NotificationStats) UnmarshalParcel

func (s *NotificationStats) UnmarshalParcel(
	p *parcel.Parcel,
) error

type NotifyingApp

type NotifyingApp struct {
	UserId       int32
	Pkg          string
	LastNotified int64
}

func (*NotifyingApp) MarshalParcel

func (s *NotifyingApp) MarshalParcel(
	p *parcel.Parcel,
) error

func (*NotifyingApp) UnmarshalParcel

func (s *NotifyingApp) UnmarshalParcel(
	p *parcel.Parcel,
) error

type SnoozeCriterion

type SnoozeCriterion struct {
}

func (*SnoozeCriterion) MarshalParcel

func (s *SnoozeCriterion) MarshalParcel(
	p *parcel.Parcel,
) error

func (*SnoozeCriterion) UnmarshalParcel

func (s *SnoozeCriterion) UnmarshalParcel(
	p *parcel.Parcel,
) error

type StatusBarNotification

type StatusBarNotification struct {
}

func (*StatusBarNotification) MarshalParcel

func (s *StatusBarNotification) MarshalParcel(
	p *parcel.Parcel,
) error

func (*StatusBarNotification) UnmarshalParcel

func (s *StatusBarNotification) UnmarshalParcel(
	p *parcel.Parcel,
) error

type StatusBarNotificationHolderProxy

type StatusBarNotificationHolderProxy struct {
	Remote binder.IBinder
}

func NewStatusBarNotificationHolderProxy

func NewStatusBarNotificationHolderProxy(
	remote binder.IBinder,
) *StatusBarNotificationHolderProxy

func (*StatusBarNotificationHolderProxy) AsBinder

func (*StatusBarNotificationHolderProxy) Get

type StatusBarNotificationHolderStub

type StatusBarNotificationHolderStub struct {
	Impl      IStatusBarNotificationHolder
	Transport binder.VersionAwareTransport
}

StatusBarNotificationHolderStub dispatches incoming binder transactions to a typed IStatusBarNotificationHolder implementation.

func (*StatusBarNotificationHolderStub) Descriptor

func (s *StatusBarNotificationHolderStub) Descriptor() string

func (*StatusBarNotificationHolderStub) OnTransaction

type ZenModeConfig

type ZenModeConfig struct {
	AllowCallsFrom          int32
	AllowMessagesFrom       int32
	User                    int32
	SuppressedVisualEffects int32
	AllowConversations      bool
	AllowConversationsFrom  int32
}

func (*ZenModeConfig) MarshalParcel

func (s *ZenModeConfig) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ZenModeConfig) UnmarshalParcel

func (s *ZenModeConfig) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ZenModeConfigZenRule

type ZenModeConfigZenRule struct {
}

func (*ZenModeConfigZenRule) MarshalParcel

func (s *ZenModeConfigZenRule) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ZenModeConfigZenRule) UnmarshalParcel

func (s *ZenModeConfigZenRule) UnmarshalParcel(
	p *parcel.Parcel,
) error

type ZenPolicy

type ZenPolicy struct {
	PriorityMessages    int32
	PriorityCalls       int32
	ConversationSenders int32
}

func (*ZenPolicy) MarshalParcel

func (s *ZenPolicy) MarshalParcel(
	p *parcel.Parcel,
) error

func (*ZenPolicy) UnmarshalParcel

func (s *ZenPolicy) UnmarshalParcel(
	p *parcel.Parcel,
) error

Directories

Path Synopsis

Jump to