Documentation
¶
Index ¶
- Constants
- type GetWalletCardsError
- type GetWalletCardsRequest
- type GetWalletCardsResponse
- type IQuickAccessWalletService
- type IQuickAccessWalletServiceCallbacks
- type IQuickAccessWalletServiceCallbacksServer
- type IQuickAccessWalletServiceServer
- type QuickAccessWalletServiceCallbacksProxy
- func (p *QuickAccessWalletServiceCallbacksProxy) AsBinder() binder.IBinder
- func (p *QuickAccessWalletServiceCallbacksProxy) OnGetWalletCardsFailure(ctx context.Context, error_ GetWalletCardsError) error
- func (p *QuickAccessWalletServiceCallbacksProxy) OnGetWalletCardsSuccess(ctx context.Context, response GetWalletCardsResponse) error
- func (p *QuickAccessWalletServiceCallbacksProxy) OnTargetActivityPendingIntentReceived(ctx context.Context, pendingIntent app.PendingIntent) error
- func (p *QuickAccessWalletServiceCallbacksProxy) OnWalletServiceEvent(ctx context.Context, event WalletServiceEvent) error
- type QuickAccessWalletServiceCallbacksStub
- type QuickAccessWalletServiceProxy
- func (p *QuickAccessWalletServiceProxy) AsBinder() binder.IBinder
- func (p *QuickAccessWalletServiceProxy) OnTargetActivityIntentRequested(ctx context.Context, callbacks IQuickAccessWalletServiceCallbacks) error
- func (p *QuickAccessWalletServiceProxy) OnWalletCardSelected(ctx context.Context, request SelectWalletCardRequest) error
- func (p *QuickAccessWalletServiceProxy) OnWalletCardsRequested(ctx context.Context, request GetWalletCardsRequest, ...) error
- func (p *QuickAccessWalletServiceProxy) OnWalletDismissed(ctx context.Context) error
- func (p *QuickAccessWalletServiceProxy) RegisterWalletServiceEventListener(ctx context.Context, request WalletServiceEventListenerRequest, ...) error
- func (p *QuickAccessWalletServiceProxy) UnregisterWalletServiceEventListener(ctx context.Context, request WalletServiceEventListenerRequest) error
- type QuickAccessWalletServiceStub
- type SelectWalletCardRequest
- type WalletCard
- type WalletServiceEvent
- type WalletServiceEventListenerRequest
Constants ¶
const ( TransactionIQuickAccessWalletServiceOnWalletCardsRequested = binder.FirstCallTransaction + 0 TransactionIQuickAccessWalletServiceOnWalletCardSelected = binder.FirstCallTransaction + 1 TransactionIQuickAccessWalletServiceOnWalletDismissed = binder.FirstCallTransaction + 2 TransactionIQuickAccessWalletServiceRegisterWalletServiceEventListener = binder.FirstCallTransaction + 3 TransactionIQuickAccessWalletServiceUnregisterWalletServiceEventListener = binder.FirstCallTransaction + 4 TransactionIQuickAccessWalletServiceOnTargetActivityIntentRequested = binder.FirstCallTransaction + 5 )
const ( MethodIQuickAccessWalletServiceOnWalletCardsRequested = "onWalletCardsRequested" MethodIQuickAccessWalletServiceOnWalletCardSelected = "onWalletCardSelected" MethodIQuickAccessWalletServiceOnWalletDismissed = "onWalletDismissed" MethodIQuickAccessWalletServiceRegisterWalletServiceEventListener = "registerWalletServiceEventListener" MethodIQuickAccessWalletServiceUnregisterWalletServiceEventListener = "unregisterWalletServiceEventListener" MethodIQuickAccessWalletServiceOnTargetActivityIntentRequested = "onTargetActivityIntentRequested" )
const ( TransactionIQuickAccessWalletServiceCallbacksOnGetWalletCardsSuccess = binder.FirstCallTransaction + 0 TransactionIQuickAccessWalletServiceCallbacksOnGetWalletCardsFailure = binder.FirstCallTransaction + 1 TransactionIQuickAccessWalletServiceCallbacksOnWalletServiceEvent = binder.FirstCallTransaction + 2 TransactionIQuickAccessWalletServiceCallbacksOnTargetActivityPendingIntentReceived = binder.FirstCallTransaction + 3 )
const ( MethodIQuickAccessWalletServiceCallbacksOnGetWalletCardsSuccess = "onGetWalletCardsSuccess" MethodIQuickAccessWalletServiceCallbacksOnGetWalletCardsFailure = "onGetWalletCardsFailure" MethodIQuickAccessWalletServiceCallbacksOnWalletServiceEvent = "onWalletServiceEvent" MethodIQuickAccessWalletServiceCallbacksOnTargetActivityPendingIntentReceived = "onTargetActivityPendingIntentReceived" )
const DescriptorIQuickAccessWalletService = "android.service.quickaccesswallet.IQuickAccessWalletService"
const DescriptorIQuickAccessWalletServiceCallbacks = "android.service.quickaccesswallet.IQuickAccessWalletServiceCallbacks"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GetWalletCardsError ¶
type GetWalletCardsError struct {
}
func (*GetWalletCardsError) MarshalParcel ¶
func (s *GetWalletCardsError) MarshalParcel( p *parcel.Parcel, ) error
func (*GetWalletCardsError) UnmarshalParcel ¶
func (s *GetWalletCardsError) UnmarshalParcel( p *parcel.Parcel, ) error
type GetWalletCardsRequest ¶
type GetWalletCardsRequest struct {
CardWidthPx int32
CardHeightPx int32
IconSizePx int32
MaxCards int32
}
func (*GetWalletCardsRequest) MarshalParcel ¶
func (s *GetWalletCardsRequest) MarshalParcel( p *parcel.Parcel, ) error
func (*GetWalletCardsRequest) UnmarshalParcel ¶
func (s *GetWalletCardsRequest) UnmarshalParcel( p *parcel.Parcel, ) error
type GetWalletCardsResponse ¶
type GetWalletCardsResponse struct {
SelectedIndex int32
}
func (*GetWalletCardsResponse) MarshalParcel ¶
func (s *GetWalletCardsResponse) MarshalParcel( p *parcel.Parcel, ) error
func (*GetWalletCardsResponse) UnmarshalParcel ¶
func (s *GetWalletCardsResponse) UnmarshalParcel( p *parcel.Parcel, ) error
type IQuickAccessWalletService ¶
type IQuickAccessWalletService interface {
AsBinder() binder.IBinder
OnWalletCardsRequested(ctx context.Context, request GetWalletCardsRequest, callback IQuickAccessWalletServiceCallbacks) error
OnWalletCardSelected(ctx context.Context, request SelectWalletCardRequest) error
OnWalletDismissed(ctx context.Context) error
RegisterWalletServiceEventListener(ctx context.Context, request WalletServiceEventListenerRequest, callback IQuickAccessWalletServiceCallbacks) error
UnregisterWalletServiceEventListener(ctx context.Context, request WalletServiceEventListenerRequest) error
OnTargetActivityIntentRequested(ctx context.Context, callbacks IQuickAccessWalletServiceCallbacks) error
}
func NewQuickAccessWalletServiceStub ¶
func NewQuickAccessWalletServiceStub( impl IQuickAccessWalletServiceServer, ) IQuickAccessWalletService
NewQuickAccessWalletServiceStub creates a server-side IQuickAccessWalletService wrapping the given server implementation. The returned value satisfies IQuickAccessWalletService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IQuickAccessWalletServiceCallbacks ¶
type IQuickAccessWalletServiceCallbacks interface {
AsBinder() binder.IBinder
OnGetWalletCardsSuccess(ctx context.Context, response GetWalletCardsResponse) error
OnGetWalletCardsFailure(ctx context.Context, error_ GetWalletCardsError) error
OnWalletServiceEvent(ctx context.Context, event WalletServiceEvent) error
OnTargetActivityPendingIntentReceived(ctx context.Context, pendingIntent app.PendingIntent) error
}
func NewQuickAccessWalletServiceCallbacksStub ¶
func NewQuickAccessWalletServiceCallbacksStub( impl IQuickAccessWalletServiceCallbacksServer, ) IQuickAccessWalletServiceCallbacks
NewQuickAccessWalletServiceCallbacksStub creates a server-side IQuickAccessWalletServiceCallbacks wrapping the given server implementation. The returned value satisfies IQuickAccessWalletServiceCallbacks and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IQuickAccessWalletServiceCallbacksServer ¶
type IQuickAccessWalletServiceCallbacksServer interface {
OnGetWalletCardsSuccess(ctx context.Context, response GetWalletCardsResponse) error
OnGetWalletCardsFailure(ctx context.Context, error_ GetWalletCardsError) error
OnWalletServiceEvent(ctx context.Context, event WalletServiceEvent) error
OnTargetActivityPendingIntentReceived(ctx context.Context, pendingIntent app.PendingIntent) error
}
IQuickAccessWalletServiceCallbacksServer is the server-side interface that user implementations provide to NewQuickAccessWalletServiceCallbacksStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IQuickAccessWalletServiceServer ¶
type IQuickAccessWalletServiceServer interface {
OnWalletCardsRequested(ctx context.Context, request GetWalletCardsRequest, callback IQuickAccessWalletServiceCallbacks) error
OnWalletCardSelected(ctx context.Context, request SelectWalletCardRequest) error
OnWalletDismissed(ctx context.Context) error
RegisterWalletServiceEventListener(ctx context.Context, request WalletServiceEventListenerRequest, callback IQuickAccessWalletServiceCallbacks) error
UnregisterWalletServiceEventListener(ctx context.Context, request WalletServiceEventListenerRequest) error
OnTargetActivityIntentRequested(ctx context.Context, callbacks IQuickAccessWalletServiceCallbacks) error
}
IQuickAccessWalletServiceServer is the server-side interface that user implementations provide to NewQuickAccessWalletServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type QuickAccessWalletServiceCallbacksProxy ¶
func NewQuickAccessWalletServiceCallbacksProxy ¶
func NewQuickAccessWalletServiceCallbacksProxy( remote binder.IBinder, ) *QuickAccessWalletServiceCallbacksProxy
func (*QuickAccessWalletServiceCallbacksProxy) AsBinder ¶
func (p *QuickAccessWalletServiceCallbacksProxy) AsBinder() binder.IBinder
func (*QuickAccessWalletServiceCallbacksProxy) OnGetWalletCardsFailure ¶
func (p *QuickAccessWalletServiceCallbacksProxy) OnGetWalletCardsFailure( ctx context.Context, error_ GetWalletCardsError, ) error
func (*QuickAccessWalletServiceCallbacksProxy) OnGetWalletCardsSuccess ¶
func (p *QuickAccessWalletServiceCallbacksProxy) OnGetWalletCardsSuccess( ctx context.Context, response GetWalletCardsResponse, ) error
func (*QuickAccessWalletServiceCallbacksProxy) OnTargetActivityPendingIntentReceived ¶
func (p *QuickAccessWalletServiceCallbacksProxy) OnTargetActivityPendingIntentReceived( ctx context.Context, pendingIntent app.PendingIntent, ) error
func (*QuickAccessWalletServiceCallbacksProxy) OnWalletServiceEvent ¶
func (p *QuickAccessWalletServiceCallbacksProxy) OnWalletServiceEvent( ctx context.Context, event WalletServiceEvent, ) error
type QuickAccessWalletServiceCallbacksStub ¶
type QuickAccessWalletServiceCallbacksStub struct {
Impl IQuickAccessWalletServiceCallbacks
Transport binder.VersionAwareTransport
}
QuickAccessWalletServiceCallbacksStub dispatches incoming binder transactions to a typed IQuickAccessWalletServiceCallbacks implementation.
func (*QuickAccessWalletServiceCallbacksStub) Descriptor ¶
func (s *QuickAccessWalletServiceCallbacksStub) Descriptor() string
func (*QuickAccessWalletServiceCallbacksStub) OnTransaction ¶
func (s *QuickAccessWalletServiceCallbacksStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type QuickAccessWalletServiceProxy ¶
func NewQuickAccessWalletServiceProxy ¶
func NewQuickAccessWalletServiceProxy( remote binder.IBinder, ) *QuickAccessWalletServiceProxy
func (*QuickAccessWalletServiceProxy) AsBinder ¶
func (p *QuickAccessWalletServiceProxy) AsBinder() binder.IBinder
func (*QuickAccessWalletServiceProxy) OnTargetActivityIntentRequested ¶
func (p *QuickAccessWalletServiceProxy) OnTargetActivityIntentRequested( ctx context.Context, callbacks IQuickAccessWalletServiceCallbacks, ) error
func (*QuickAccessWalletServiceProxy) OnWalletCardSelected ¶
func (p *QuickAccessWalletServiceProxy) OnWalletCardSelected( ctx context.Context, request SelectWalletCardRequest, ) error
func (*QuickAccessWalletServiceProxy) OnWalletCardsRequested ¶
func (p *QuickAccessWalletServiceProxy) OnWalletCardsRequested( ctx context.Context, request GetWalletCardsRequest, callback IQuickAccessWalletServiceCallbacks, ) error
func (*QuickAccessWalletServiceProxy) OnWalletDismissed ¶
func (p *QuickAccessWalletServiceProxy) OnWalletDismissed( ctx context.Context, ) error
func (*QuickAccessWalletServiceProxy) RegisterWalletServiceEventListener ¶
func (p *QuickAccessWalletServiceProxy) RegisterWalletServiceEventListener( ctx context.Context, request WalletServiceEventListenerRequest, callback IQuickAccessWalletServiceCallbacks, ) error
func (*QuickAccessWalletServiceProxy) UnregisterWalletServiceEventListener ¶
func (p *QuickAccessWalletServiceProxy) UnregisterWalletServiceEventListener( ctx context.Context, request WalletServiceEventListenerRequest, ) error
type QuickAccessWalletServiceStub ¶
type QuickAccessWalletServiceStub struct {
Impl IQuickAccessWalletService
Transport binder.VersionAwareTransport
}
QuickAccessWalletServiceStub dispatches incoming binder transactions to a typed IQuickAccessWalletService implementation.
func (*QuickAccessWalletServiceStub) Descriptor ¶
func (s *QuickAccessWalletServiceStub) Descriptor() string
func (*QuickAccessWalletServiceStub) OnTransaction ¶
func (s *QuickAccessWalletServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type SelectWalletCardRequest ¶
type SelectWalletCardRequest struct {
CardId string
}
func (*SelectWalletCardRequest) MarshalParcel ¶
func (s *SelectWalletCardRequest) MarshalParcel( p *parcel.Parcel, ) error
func (*SelectWalletCardRequest) UnmarshalParcel ¶
func (s *SelectWalletCardRequest) UnmarshalParcel( p *parcel.Parcel, ) error
type WalletCard ¶
func (*WalletCard) MarshalParcel ¶
func (s *WalletCard) MarshalParcel( p *parcel.Parcel, ) error
func (*WalletCard) UnmarshalParcel ¶
func (s *WalletCard) UnmarshalParcel( p *parcel.Parcel, ) error
type WalletServiceEvent ¶
type WalletServiceEvent struct {
EventType int32
}
func (*WalletServiceEvent) MarshalParcel ¶
func (s *WalletServiceEvent) MarshalParcel( p *parcel.Parcel, ) error
func (*WalletServiceEvent) UnmarshalParcel ¶
func (s *WalletServiceEvent) UnmarshalParcel( p *parcel.Parcel, ) error
type WalletServiceEventListenerRequest ¶
type WalletServiceEventListenerRequest struct {
ListenerId string
}
func (*WalletServiceEventListenerRequest) MarshalParcel ¶
func (s *WalletServiceEventListenerRequest) MarshalParcel( p *parcel.Parcel, ) error
func (*WalletServiceEventListenerRequest) UnmarshalParcel ¶
func (s *WalletServiceEventListenerRequest) UnmarshalParcel( p *parcel.Parcel, ) error