Documentation
¶
Index ¶
- Constants
- type IQSService
- type IQSServiceServer
- type IQSTileService
- type IQSTileServiceServer
- type QSServiceProxy
- func (p *QSServiceProxy) AsBinder() binder.IBinder
- func (p *QSServiceProxy) GetTile(ctx context.Context, tile binder.IBinder) (Tile, error)
- func (p *QSServiceProxy) IsLocked(ctx context.Context) (bool, error)
- func (p *QSServiceProxy) IsSecure(ctx context.Context) (bool, error)
- func (p *QSServiceProxy) OnDialogHidden(ctx context.Context, tile binder.IBinder) error
- func (p *QSServiceProxy) OnShowDialog(ctx context.Context, tile binder.IBinder) error
- func (p *QSServiceProxy) OnStartActivity(ctx context.Context, tile binder.IBinder) error
- func (p *QSServiceProxy) OnStartSuccessful(ctx context.Context, tile binder.IBinder) error
- func (p *QSServiceProxy) StartActivity(ctx context.Context, tile binder.IBinder, pendingIntent app.PendingIntent) error
- func (p *QSServiceProxy) StartUnlockAndRun(ctx context.Context, tile binder.IBinder) error
- func (p *QSServiceProxy) UpdateQsTile(ctx context.Context, tile Tile, service binder.IBinder) error
- func (p *QSServiceProxy) UpdateStatusIcon(ctx context.Context, tile binder.IBinder, icon drawable.Icon, ...) error
- type QSServiceStub
- type QSTileServiceProxy
- func (p *QSTileServiceProxy) AsBinder() binder.IBinder
- func (p *QSTileServiceProxy) OnClick(ctx context.Context, wtoken binder.IBinder) error
- func (p *QSTileServiceProxy) OnStartListening(ctx context.Context) error
- func (p *QSTileServiceProxy) OnStopListening(ctx context.Context) error
- func (p *QSTileServiceProxy) OnTileAdded(ctx context.Context) error
- func (p *QSTileServiceProxy) OnTileRemoved(ctx context.Context) error
- func (p *QSTileServiceProxy) OnUnlockComplete(ctx context.Context) error
- type QSTileServiceStub
- type Tile
Constants ¶
const ( TransactionIQSServiceGetTile = binder.FirstCallTransaction + 0 TransactionIQSServiceUpdateQsTile = binder.FirstCallTransaction + 1 TransactionIQSServiceUpdateStatusIcon = binder.FirstCallTransaction + 2 TransactionIQSServiceOnShowDialog = binder.FirstCallTransaction + 3 TransactionIQSServiceOnStartActivity = binder.FirstCallTransaction + 4 TransactionIQSServiceStartActivity = binder.FirstCallTransaction + 5 TransactionIQSServiceIsLocked = binder.FirstCallTransaction + 6 TransactionIQSServiceIsSecure = binder.FirstCallTransaction + 7 TransactionIQSServiceStartUnlockAndRun = binder.FirstCallTransaction + 8 TransactionIQSServiceOnDialogHidden = binder.FirstCallTransaction + 9 TransactionIQSServiceOnStartSuccessful = binder.FirstCallTransaction + 10 )
const ( MethodIQSServiceGetTile = "getTile" MethodIQSServiceUpdateQsTile = "updateQsTile" MethodIQSServiceUpdateStatusIcon = "updateStatusIcon" MethodIQSServiceOnShowDialog = "onShowDialog" MethodIQSServiceOnStartActivity = "onStartActivity" MethodIQSServiceStartActivity = "startActivity" MethodIQSServiceIsLocked = "isLocked" MethodIQSServiceIsSecure = "isSecure" MethodIQSServiceStartUnlockAndRun = "startUnlockAndRun" MethodIQSServiceOnDialogHidden = "onDialogHidden" MethodIQSServiceOnStartSuccessful = "onStartSuccessful" )
const ( TransactionIQSTileServiceOnTileAdded = binder.FirstCallTransaction + 0 TransactionIQSTileServiceOnTileRemoved = binder.FirstCallTransaction + 1 TransactionIQSTileServiceOnStartListening = binder.FirstCallTransaction + 2 TransactionIQSTileServiceOnStopListening = binder.FirstCallTransaction + 3 TransactionIQSTileServiceOnClick = binder.FirstCallTransaction + 4 TransactionIQSTileServiceOnUnlockComplete = binder.FirstCallTransaction + 5 )
const ( MethodIQSTileServiceOnTileAdded = "onTileAdded" MethodIQSTileServiceOnTileRemoved = "onTileRemoved" MethodIQSTileServiceOnStartListening = "onStartListening" MethodIQSTileServiceOnStopListening = "onStopListening" MethodIQSTileServiceOnClick = "onClick" MethodIQSTileServiceOnUnlockComplete = "onUnlockComplete" )
const DescriptorIQSService = "android.service.quicksettings.IQSService"
const DescriptorIQSTileService = "android.service.quicksettings.IQSTileService"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IQSService ¶
type IQSService interface {
AsBinder() binder.IBinder
GetTile(ctx context.Context, tile binder.IBinder) (Tile, error)
UpdateQsTile(ctx context.Context, tile Tile, service binder.IBinder) error
UpdateStatusIcon(ctx context.Context, tile binder.IBinder, icon drawable.Icon, contentDescription string) error
OnShowDialog(ctx context.Context, tile binder.IBinder) error
OnStartActivity(ctx context.Context, tile binder.IBinder) error
StartActivity(ctx context.Context, tile binder.IBinder, pendingIntent app.PendingIntent) error
IsLocked(ctx context.Context) (bool, error)
IsSecure(ctx context.Context) (bool, error)
StartUnlockAndRun(ctx context.Context, tile binder.IBinder) error
OnDialogHidden(ctx context.Context, tile binder.IBinder) error
OnStartSuccessful(ctx context.Context, tile binder.IBinder) error
}
func NewQSServiceStub ¶
func NewQSServiceStub( impl IQSServiceServer, ) IQSService
NewQSServiceStub creates a server-side IQSService wrapping the given server implementation. The returned value satisfies IQSService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IQSServiceServer ¶
type IQSServiceServer interface {
GetTile(ctx context.Context, tile binder.IBinder) (Tile, error)
UpdateQsTile(ctx context.Context, tile Tile, service binder.IBinder) error
UpdateStatusIcon(ctx context.Context, tile binder.IBinder, icon drawable.Icon, contentDescription string) error
OnShowDialog(ctx context.Context, tile binder.IBinder) error
OnStartActivity(ctx context.Context, tile binder.IBinder) error
StartActivity(ctx context.Context, tile binder.IBinder, pendingIntent app.PendingIntent) error
IsLocked(ctx context.Context) (bool, error)
IsSecure(ctx context.Context) (bool, error)
StartUnlockAndRun(ctx context.Context, tile binder.IBinder) error
OnDialogHidden(ctx context.Context, tile binder.IBinder) error
OnStartSuccessful(ctx context.Context, tile binder.IBinder) error
}
IQSServiceServer is the server-side interface that user implementations provide to NewQSServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IQSTileService ¶
type IQSTileService interface {
AsBinder() binder.IBinder
OnTileAdded(ctx context.Context) error
OnTileRemoved(ctx context.Context) error
OnStartListening(ctx context.Context) error
OnStopListening(ctx context.Context) error
OnClick(ctx context.Context, wtoken binder.IBinder) error
OnUnlockComplete(ctx context.Context) error
}
func NewQSTileServiceStub ¶
func NewQSTileServiceStub( impl IQSTileServiceServer, ) IQSTileService
NewQSTileServiceStub creates a server-side IQSTileService wrapping the given server implementation. The returned value satisfies IQSTileService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IQSTileServiceServer ¶
type IQSTileServiceServer interface {
OnTileAdded(ctx context.Context) error
OnTileRemoved(ctx context.Context) error
OnStartListening(ctx context.Context) error
OnStopListening(ctx context.Context) error
OnClick(ctx context.Context, wtoken binder.IBinder) error
OnUnlockComplete(ctx context.Context) error
}
IQSTileServiceServer is the server-side interface that user implementations provide to NewQSTileServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type QSServiceProxy ¶
func NewQSServiceProxy ¶
func NewQSServiceProxy( remote binder.IBinder, ) *QSServiceProxy
func (*QSServiceProxy) AsBinder ¶
func (p *QSServiceProxy) AsBinder() binder.IBinder
func (*QSServiceProxy) IsLocked ¶
func (p *QSServiceProxy) IsLocked( ctx context.Context, ) (bool, error)
func (*QSServiceProxy) IsSecure ¶
func (p *QSServiceProxy) IsSecure( ctx context.Context, ) (bool, error)
func (*QSServiceProxy) OnDialogHidden ¶
func (*QSServiceProxy) OnShowDialog ¶
func (*QSServiceProxy) OnStartActivity ¶
func (*QSServiceProxy) OnStartSuccessful ¶
func (*QSServiceProxy) StartActivity ¶
func (p *QSServiceProxy) StartActivity( ctx context.Context, tile binder.IBinder, pendingIntent app.PendingIntent, ) error
func (*QSServiceProxy) StartUnlockAndRun ¶
func (*QSServiceProxy) UpdateQsTile ¶
type QSServiceStub ¶
type QSServiceStub struct {
Impl IQSService
Transport binder.VersionAwareTransport
}
QSServiceStub dispatches incoming binder transactions to a typed IQSService implementation.
func (*QSServiceStub) Descriptor ¶
func (s *QSServiceStub) Descriptor() string
func (*QSServiceStub) OnTransaction ¶
func (s *QSServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type QSTileServiceProxy ¶
func NewQSTileServiceProxy ¶
func NewQSTileServiceProxy( remote binder.IBinder, ) *QSTileServiceProxy
func (*QSTileServiceProxy) AsBinder ¶
func (p *QSTileServiceProxy) AsBinder() binder.IBinder
func (*QSTileServiceProxy) OnStartListening ¶
func (p *QSTileServiceProxy) OnStartListening( ctx context.Context, ) error
func (*QSTileServiceProxy) OnStopListening ¶
func (p *QSTileServiceProxy) OnStopListening( ctx context.Context, ) error
func (*QSTileServiceProxy) OnTileAdded ¶
func (p *QSTileServiceProxy) OnTileAdded( ctx context.Context, ) error
func (*QSTileServiceProxy) OnTileRemoved ¶
func (p *QSTileServiceProxy) OnTileRemoved( ctx context.Context, ) error
func (*QSTileServiceProxy) OnUnlockComplete ¶
func (p *QSTileServiceProxy) OnUnlockComplete( ctx context.Context, ) error
type QSTileServiceStub ¶
type QSTileServiceStub struct {
Impl IQSTileService
Transport binder.VersionAwareTransport
}
QSTileServiceStub dispatches incoming binder transactions to a typed IQSTileService implementation.
func (*QSTileServiceStub) Descriptor ¶
func (s *QSTileServiceStub) Descriptor() string
func (*QSTileServiceStub) OnTransaction ¶
func (s *QSTileServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)