Documentation
¶
Index ¶
- Constants
- type ITimeZoneProvider
- type ITimeZoneProviderManager
- type ITimeZoneProviderManagerServer
- type ITimeZoneProviderServer
- type TimeZoneProviderEvent
- type TimeZoneProviderManagerProxy
- type TimeZoneProviderManagerStub
- type TimeZoneProviderProxy
- type TimeZoneProviderStatus
- type TimeZoneProviderStub
- type TimeZoneProviderSuggestion
Constants ¶
const ( TransactionITimeZoneProviderStartUpdates = binder.FirstCallTransaction + 0 TransactionITimeZoneProviderStopUpdates = binder.FirstCallTransaction + 1 )
const ( MethodITimeZoneProviderStartUpdates = "startUpdates" MethodITimeZoneProviderStopUpdates = "stopUpdates" )
const DescriptorITimeZoneProvider = "android.service.timezone.ITimeZoneProvider"
const DescriptorITimeZoneProviderManager = "android.service.timezone.ITimeZoneProviderManager"
const (
MethodITimeZoneProviderManagerOnTimeZoneProviderEvent = "onTimeZoneProviderEvent"
)
const (
TransactionITimeZoneProviderManagerOnTimeZoneProviderEvent = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ITimeZoneProvider ¶
type ITimeZoneProvider interface {
AsBinder() binder.IBinder
StartUpdates(ctx context.Context, manager ITimeZoneProviderManager, initializationTimeoutMillis int64, eventFilteringAgeThresholdMillis int64) error
StopUpdates(ctx context.Context) error
}
func NewTimeZoneProviderStub ¶
func NewTimeZoneProviderStub( impl ITimeZoneProviderServer, ) ITimeZoneProvider
NewTimeZoneProviderStub creates a server-side ITimeZoneProvider wrapping the given server implementation. The returned value satisfies ITimeZoneProvider and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITimeZoneProviderManager ¶
type ITimeZoneProviderManager interface {
AsBinder() binder.IBinder
OnTimeZoneProviderEvent(ctx context.Context, timeZoneProviderEvent TimeZoneProviderEvent) error
}
func NewTimeZoneProviderManagerStub ¶
func NewTimeZoneProviderManagerStub( impl ITimeZoneProviderManagerServer, ) ITimeZoneProviderManager
NewTimeZoneProviderManagerStub creates a server-side ITimeZoneProviderManager wrapping the given server implementation. The returned value satisfies ITimeZoneProviderManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ITimeZoneProviderManagerServer ¶
type ITimeZoneProviderManagerServer interface {
OnTimeZoneProviderEvent(ctx context.Context, timeZoneProviderEvent TimeZoneProviderEvent) error
}
ITimeZoneProviderManagerServer is the server-side interface that user implementations provide to NewTimeZoneProviderManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ITimeZoneProviderServer ¶
type ITimeZoneProviderServer interface {
StartUpdates(ctx context.Context, manager ITimeZoneProviderManager, initializationTimeoutMillis int64, eventFilteringAgeThresholdMillis int64) error
StopUpdates(ctx context.Context) error
}
ITimeZoneProviderServer is the server-side interface that user implementations provide to NewTimeZoneProviderStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type TimeZoneProviderEvent ¶
type TimeZoneProviderEvent struct {
Type int32
CreationElapsedMillis int64
FailureCause string
Suggestion *suggestions.Suggestion
TimeZoneProviderStatus *TimeZoneProviderStatus
}
func (*TimeZoneProviderEvent) MarshalParcel ¶
func (s *TimeZoneProviderEvent) MarshalParcel( p *parcel.Parcel, ) error
func (*TimeZoneProviderEvent) UnmarshalParcel ¶
func (s *TimeZoneProviderEvent) UnmarshalParcel( p *parcel.Parcel, ) error
type TimeZoneProviderManagerProxy ¶
func NewTimeZoneProviderManagerProxy ¶
func NewTimeZoneProviderManagerProxy( remote binder.IBinder, ) *TimeZoneProviderManagerProxy
func (*TimeZoneProviderManagerProxy) AsBinder ¶
func (p *TimeZoneProviderManagerProxy) AsBinder() binder.IBinder
func (*TimeZoneProviderManagerProxy) OnTimeZoneProviderEvent ¶
func (p *TimeZoneProviderManagerProxy) OnTimeZoneProviderEvent( ctx context.Context, timeZoneProviderEvent TimeZoneProviderEvent, ) error
type TimeZoneProviderManagerStub ¶
type TimeZoneProviderManagerStub struct {
Impl ITimeZoneProviderManager
Transport binder.VersionAwareTransport
}
TimeZoneProviderManagerStub dispatches incoming binder transactions to a typed ITimeZoneProviderManager implementation.
func (*TimeZoneProviderManagerStub) Descriptor ¶
func (s *TimeZoneProviderManagerStub) Descriptor() string
func (*TimeZoneProviderManagerStub) OnTransaction ¶
func (s *TimeZoneProviderManagerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type TimeZoneProviderProxy ¶
func NewTimeZoneProviderProxy ¶
func NewTimeZoneProviderProxy( remote binder.IBinder, ) *TimeZoneProviderProxy
func (*TimeZoneProviderProxy) AsBinder ¶
func (p *TimeZoneProviderProxy) AsBinder() binder.IBinder
func (*TimeZoneProviderProxy) StartUpdates ¶
func (p *TimeZoneProviderProxy) StartUpdates( ctx context.Context, manager ITimeZoneProviderManager, initializationTimeoutMillis int64, eventFilteringAgeThresholdMillis int64, ) error
func (*TimeZoneProviderProxy) StopUpdates ¶
func (p *TimeZoneProviderProxy) StopUpdates( ctx context.Context, ) error
type TimeZoneProviderStatus ¶
type TimeZoneProviderStatus struct {
LocationDetectionDependencyStatus int32
ConnectivityDependencyStatus int32
TimeZoneResolutionOperationStatus int32
}
func (*TimeZoneProviderStatus) MarshalParcel ¶
func (s *TimeZoneProviderStatus) MarshalParcel( p *parcel.Parcel, ) error
func (*TimeZoneProviderStatus) UnmarshalParcel ¶
func (s *TimeZoneProviderStatus) UnmarshalParcel( p *parcel.Parcel, ) error
type TimeZoneProviderStub ¶
type TimeZoneProviderStub struct {
Impl ITimeZoneProvider
Transport binder.VersionAwareTransport
}
TimeZoneProviderStub dispatches incoming binder transactions to a typed ITimeZoneProvider implementation.
func (*TimeZoneProviderStub) Descriptor ¶
func (s *TimeZoneProviderStub) Descriptor() string
func (*TimeZoneProviderStub) OnTransaction ¶
func (s *TimeZoneProviderStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type TimeZoneProviderSuggestion ¶
type TimeZoneProviderSuggestion struct {
ElapsedRealtimeMillis int64
}
func (*TimeZoneProviderSuggestion) MarshalParcel ¶
func (s *TimeZoneProviderSuggestion) MarshalParcel( p *parcel.Parcel, ) error
func (*TimeZoneProviderSuggestion) UnmarshalParcel ¶
func (s *TimeZoneProviderSuggestion) UnmarshalParcel( p *parcel.Parcel, ) error