Documentation
¶
Index ¶
- Constants
- type DetectorSessionStorageServiceProxy
- type DetectorSessionStorageServiceStub
- type DetectorSessionVisualQueryDetectionCallbackProxy
- func (p *DetectorSessionVisualQueryDetectionCallbackProxy) AsBinder() binder.IBinder
- func (p *DetectorSessionVisualQueryDetectionCallbackProxy) OnAttentionGained(ctx context.Context, attentionResult VisualQueryAttentionResult) error
- func (p *DetectorSessionVisualQueryDetectionCallbackProxy) OnAttentionLost(ctx context.Context, interactionIntention int32) error
- func (p *DetectorSessionVisualQueryDetectionCallbackProxy) OnQueryDetected(ctx context.Context, partialQuery string) error
- func (p *DetectorSessionVisualQueryDetectionCallbackProxy) OnQueryFinished(ctx context.Context) error
- func (p *DetectorSessionVisualQueryDetectionCallbackProxy) OnQueryRejected(ctx context.Context) error
- func (p *DetectorSessionVisualQueryDetectionCallbackProxy) OnResultDetected(ctx context.Context, partialResult VisualQueryDetectedResult) error
- type DetectorSessionVisualQueryDetectionCallbackStub
- type DspHotwordDetectionCallbackProxy
- func (p *DspHotwordDetectionCallbackProxy) AsBinder() binder.IBinder
- func (p *DspHotwordDetectionCallbackProxy) OnDetected(ctx context.Context, hotwordDetectedResult HotwordDetectedResult) error
- func (p *DspHotwordDetectionCallbackProxy) OnRejected(ctx context.Context, result HotwordRejectedResult) error
- type DspHotwordDetectionCallbackStub
- type HotwordAudioStream
- type HotwordDetectedResult
- type HotwordDetectionServiceFailure
- type HotwordRejectedResult
- type IDetectorSessionStorageService
- type IDetectorSessionStorageServiceServer
- type IDetectorSessionVisualQueryDetectionCallback
- type IDetectorSessionVisualQueryDetectionCallbackServer
- type IDspHotwordDetectionCallback
- type IDspHotwordDetectionCallbackServer
- type IMicrophoneHotwordDetectionVoiceInteractionCallback
- type IMicrophoneHotwordDetectionVoiceInteractionCallbackServer
- type ISandboxedDetectionService
- type ISandboxedDetectionServiceServer
- type IVisualQueryDetectionVoiceInteractionCallback
- type IVisualQueryDetectionVoiceInteractionCallbackServer
- type IVoiceInteractionService
- type IVoiceInteractionServiceServer
- type IVoiceInteractionSession
- type IVoiceInteractionSessionServer
- type IVoiceInteractionSessionService
- type IVoiceInteractionSessionServiceServer
- type MicrophoneHotwordDetectionVoiceInteractionCallbackProxy
- func (p *MicrophoneHotwordDetectionVoiceInteractionCallbackProxy) AsBinder() binder.IBinder
- func (p *MicrophoneHotwordDetectionVoiceInteractionCallbackProxy) OnDetected(ctx context.Context, hotwordDetectedResult HotwordDetectedResult, ...) error
- func (p *MicrophoneHotwordDetectionVoiceInteractionCallbackProxy) OnHotwordDetectionServiceFailure(ctx context.Context, ...) error
- func (p *MicrophoneHotwordDetectionVoiceInteractionCallbackProxy) OnRejected(ctx context.Context, hotwordRejectedResult HotwordRejectedResult) error
- type MicrophoneHotwordDetectionVoiceInteractionCallbackStub
- type SandboxedDetectionServiceProxy
- func (p *SandboxedDetectionServiceProxy) AsBinder() binder.IBinder
- func (p *SandboxedDetectionServiceProxy) DetectFromDspSource(ctx context.Context, event soundtrigger.SoundTriggerKeyphraseRecognitionEvent, ...) error
- func (p *SandboxedDetectionServiceProxy) DetectFromMicrophoneSource(ctx context.Context, audioStream int32, audioSource int32, ...) error
- func (p *SandboxedDetectionServiceProxy) DetectWithVisualSignals(ctx context.Context, callback IDetectorSessionVisualQueryDetectionCallback) error
- func (p *SandboxedDetectionServiceProxy) Ping(ctx context.Context, callback os.IRemoteCallback) error
- func (p *SandboxedDetectionServiceProxy) RegisterRemoteStorageService(ctx context.Context, ...) error
- func (p *SandboxedDetectionServiceProxy) StopDetection(ctx context.Context) error
- func (p *SandboxedDetectionServiceProxy) UpdateAudioFlinger(ctx context.Context, audioFlinger binder.IBinder) error
- func (p *SandboxedDetectionServiceProxy) UpdateContentCaptureManager(ctx context.Context, ...) error
- func (p *SandboxedDetectionServiceProxy) UpdateRecognitionServiceManager(ctx context.Context, ...) error
- func (p *SandboxedDetectionServiceProxy) UpdateState(ctx context.Context, options os.PersistableBundle, ...) error
- type SandboxedDetectionServiceStub
- type SoundTriggerFailure
- type VisibleActivityInfo
- type VisualQueryAttentionResult
- type VisualQueryDetectedResult
- type VisualQueryDetectionServiceFailure
- type VisualQueryDetectionVoiceInteractionCallbackProxy
- func (p *VisualQueryDetectionVoiceInteractionCallbackProxy) AsBinder() binder.IBinder
- func (p *VisualQueryDetectionVoiceInteractionCallbackProxy) OnQueryDetected(ctx context.Context, partialQuery string) error
- func (p *VisualQueryDetectionVoiceInteractionCallbackProxy) OnQueryFinished(ctx context.Context) error
- func (p *VisualQueryDetectionVoiceInteractionCallbackProxy) OnQueryRejected(ctx context.Context) error
- func (p *VisualQueryDetectionVoiceInteractionCallbackProxy) OnResultDetected(ctx context.Context, partialResult VisualQueryDetectedResult) error
- func (p *VisualQueryDetectionVoiceInteractionCallbackProxy) OnVisualQueryDetectionServiceFailure(ctx context.Context, ...) error
- type VisualQueryDetectionVoiceInteractionCallbackStub
- type VoiceInteractionServiceProxy
- func (p *VoiceInteractionServiceProxy) AsBinder() binder.IBinder
- func (p *VoiceInteractionServiceProxy) DetectorRemoteExceptionOccurred(ctx context.Context, token binder.IBinder, detectorType int32) error
- func (p *VoiceInteractionServiceProxy) GetActiveServiceSupportedActions(ctx context.Context, voiceActions []string, ...) error
- func (p *VoiceInteractionServiceProxy) LaunchVoiceAssistFromKeyguard(ctx context.Context) error
- func (p *VoiceInteractionServiceProxy) PrepareToShowSession(ctx context.Context, args os.Bundle, flags int32) error
- func (p *VoiceInteractionServiceProxy) Ready(ctx context.Context) error
- func (p *VoiceInteractionServiceProxy) ShowSessionFailed(ctx context.Context, args os.Bundle) error
- func (p *VoiceInteractionServiceProxy) Shutdown(ctx context.Context) error
- func (p *VoiceInteractionServiceProxy) SoundModelsChanged(ctx context.Context) error
- type VoiceInteractionServiceStub
- type VoiceInteractionSessionProxy
- func (p *VoiceInteractionSessionProxy) AsBinder() binder.IBinder
- func (p *VoiceInteractionSessionProxy) CloseSystemDialogs(ctx context.Context) error
- func (p *VoiceInteractionSessionProxy) Destroy(ctx context.Context) error
- func (p *VoiceInteractionSessionProxy) HandleAssist(ctx context.Context, taskId int32, activityId binder.IBinder, ...) error
- func (p *VoiceInteractionSessionProxy) HandleScreenshot(ctx context.Context, screenshot graphics.Bitmap) error
- func (p *VoiceInteractionSessionProxy) Hide(ctx context.Context) error
- func (p *VoiceInteractionSessionProxy) NotifyVisibleActivityInfoChanged(ctx context.Context, visibleActivityInfo VisibleActivityInfo, type_ int32) error
- func (p *VoiceInteractionSessionProxy) OnLockscreenShown(ctx context.Context) error
- func (p *VoiceInteractionSessionProxy) Show(ctx context.Context, sessionArgs os.Bundle, flags int32, ...) error
- func (p *VoiceInteractionSessionProxy) TaskFinished(ctx context.Context, intent androidContent.Intent, taskId int32) error
- func (p *VoiceInteractionSessionProxy) TaskStarted(ctx context.Context, intent androidContent.Intent, taskId int32) error
- type VoiceInteractionSessionServiceProxy
- type VoiceInteractionSessionServiceStub
- type VoiceInteractionSessionStub
Constants ¶
const ( TransactionIDetectorSessionVisualQueryDetectionCallbackOnAttentionGained = binder.FirstCallTransaction + 0 TransactionIDetectorSessionVisualQueryDetectionCallbackOnAttentionLost = binder.FirstCallTransaction + 1 TransactionIDetectorSessionVisualQueryDetectionCallbackOnQueryDetected = binder.FirstCallTransaction + 2 TransactionIDetectorSessionVisualQueryDetectionCallbackOnResultDetected = binder.FirstCallTransaction + 3 TransactionIDetectorSessionVisualQueryDetectionCallbackOnQueryFinished = binder.FirstCallTransaction + 4 TransactionIDetectorSessionVisualQueryDetectionCallbackOnQueryRejected = binder.FirstCallTransaction + 5 )
const ( MethodIDetectorSessionVisualQueryDetectionCallbackOnAttentionGained = "onAttentionGained" MethodIDetectorSessionVisualQueryDetectionCallbackOnAttentionLost = "onAttentionLost" MethodIDetectorSessionVisualQueryDetectionCallbackOnQueryDetected = "onQueryDetected" MethodIDetectorSessionVisualQueryDetectionCallbackOnResultDetected = "onResultDetected" MethodIDetectorSessionVisualQueryDetectionCallbackOnQueryFinished = "onQueryFinished" MethodIDetectorSessionVisualQueryDetectionCallbackOnQueryRejected = "onQueryRejected" )
const ( TransactionIDspHotwordDetectionCallbackOnDetected = binder.FirstCallTransaction + 0 TransactionIDspHotwordDetectionCallbackOnRejected = binder.FirstCallTransaction + 1 )
const ( MethodIDspHotwordDetectionCallbackOnDetected = "onDetected" MethodIDspHotwordDetectionCallbackOnRejected = "onRejected" )
const ( TransactionIMicrophoneHotwordDetectionVoiceInteractionCallbackOnDetected = binder.FirstCallTransaction + 0 TransactionIMicrophoneHotwordDetectionVoiceInteractionCallbackOnHotwordDetectionServiceFailure = binder.FirstCallTransaction + 1 TransactionIMicrophoneHotwordDetectionVoiceInteractionCallbackOnRejected = binder.FirstCallTransaction + 2 )
const ( MethodIMicrophoneHotwordDetectionVoiceInteractionCallbackOnDetected = "onDetected" MethodIMicrophoneHotwordDetectionVoiceInteractionCallbackOnHotwordDetectionServiceFailure = "onHotwordDetectionServiceFailure" MethodIMicrophoneHotwordDetectionVoiceInteractionCallbackOnRejected = "onRejected" )
const ( TransactionISandboxedDetectionServiceDetectFromDspSource = binder.FirstCallTransaction + 0 TransactionISandboxedDetectionServiceDetectFromMicrophoneSource = binder.FirstCallTransaction + 1 TransactionISandboxedDetectionServiceDetectWithVisualSignals = binder.FirstCallTransaction + 2 TransactionISandboxedDetectionServiceUpdateState = binder.FirstCallTransaction + 3 TransactionISandboxedDetectionServiceUpdateAudioFlinger = binder.FirstCallTransaction + 4 TransactionISandboxedDetectionServiceUpdateContentCaptureManager = binder.FirstCallTransaction + 5 TransactionISandboxedDetectionServiceUpdateRecognitionServiceManager = binder.FirstCallTransaction + 6 TransactionISandboxedDetectionServicePing = binder.FirstCallTransaction + 7 TransactionISandboxedDetectionServiceStopDetection = binder.FirstCallTransaction + 8 TransactionISandboxedDetectionServiceRegisterRemoteStorageService = binder.FirstCallTransaction + 9 )
const ( MethodISandboxedDetectionServiceDetectFromDspSource = "detectFromDspSource" MethodISandboxedDetectionServiceDetectFromMicrophoneSource = "detectFromMicrophoneSource" MethodISandboxedDetectionServiceDetectWithVisualSignals = "detectWithVisualSignals" MethodISandboxedDetectionServiceUpdateState = "updateState" MethodISandboxedDetectionServiceUpdateAudioFlinger = "updateAudioFlinger" MethodISandboxedDetectionServiceUpdateContentCaptureManager = "updateContentCaptureManager" MethodISandboxedDetectionServiceUpdateRecognitionServiceManager = "updateRecognitionServiceManager" MethodISandboxedDetectionServicePing = "ping" MethodISandboxedDetectionServiceStopDetection = "stopDetection" MethodISandboxedDetectionServiceRegisterRemoteStorageService = "registerRemoteStorageService" )
const ( TransactionIVisualQueryDetectionVoiceInteractionCallbackOnQueryDetected = binder.FirstCallTransaction + 0 TransactionIVisualQueryDetectionVoiceInteractionCallbackOnResultDetected = binder.FirstCallTransaction + 1 TransactionIVisualQueryDetectionVoiceInteractionCallbackOnQueryFinished = binder.FirstCallTransaction + 2 TransactionIVisualQueryDetectionVoiceInteractionCallbackOnQueryRejected = binder.FirstCallTransaction + 3 TransactionIVisualQueryDetectionVoiceInteractionCallbackOnVisualQueryDetectionServiceFailure = binder.FirstCallTransaction + 4 )
const ( MethodIVisualQueryDetectionVoiceInteractionCallbackOnQueryDetected = "onQueryDetected" MethodIVisualQueryDetectionVoiceInteractionCallbackOnResultDetected = "onResultDetected" MethodIVisualQueryDetectionVoiceInteractionCallbackOnQueryFinished = "onQueryFinished" MethodIVisualQueryDetectionVoiceInteractionCallbackOnQueryRejected = "onQueryRejected" MethodIVisualQueryDetectionVoiceInteractionCallbackOnVisualQueryDetectionServiceFailure = "onVisualQueryDetectionServiceFailure" )
const ( TransactionIVoiceInteractionServiceReady = binder.FirstCallTransaction + 0 TransactionIVoiceInteractionServiceSoundModelsChanged = binder.FirstCallTransaction + 1 TransactionIVoiceInteractionServiceShutdown = binder.FirstCallTransaction + 2 TransactionIVoiceInteractionServiceLaunchVoiceAssistFromKeyguard = binder.FirstCallTransaction + 3 TransactionIVoiceInteractionServiceGetActiveServiceSupportedActions = binder.FirstCallTransaction + 4 TransactionIVoiceInteractionServicePrepareToShowSession = binder.FirstCallTransaction + 5 TransactionIVoiceInteractionServiceShowSessionFailed = binder.FirstCallTransaction + 6 TransactionIVoiceInteractionServiceDetectorRemoteExceptionOccurred = binder.FirstCallTransaction + 7 )
const ( MethodIVoiceInteractionServiceReady = "ready" MethodIVoiceInteractionServiceSoundModelsChanged = "soundModelsChanged" MethodIVoiceInteractionServiceShutdown = "shutdown" MethodIVoiceInteractionServiceLaunchVoiceAssistFromKeyguard = "launchVoiceAssistFromKeyguard" MethodIVoiceInteractionServiceGetActiveServiceSupportedActions = "getActiveServiceSupportedActions" MethodIVoiceInteractionServicePrepareToShowSession = "prepareToShowSession" MethodIVoiceInteractionServiceShowSessionFailed = "showSessionFailed" MethodIVoiceInteractionServiceDetectorRemoteExceptionOccurred = "detectorRemoteExceptionOccurred" )
const ( TransactionIVoiceInteractionSessionShow = binder.FirstCallTransaction + 0 TransactionIVoiceInteractionSessionHide = binder.FirstCallTransaction + 1 TransactionIVoiceInteractionSessionHandleAssist = binder.FirstCallTransaction + 2 TransactionIVoiceInteractionSessionHandleScreenshot = binder.FirstCallTransaction + 3 TransactionIVoiceInteractionSessionTaskStarted = binder.FirstCallTransaction + 4 TransactionIVoiceInteractionSessionTaskFinished = binder.FirstCallTransaction + 5 TransactionIVoiceInteractionSessionCloseSystemDialogs = binder.FirstCallTransaction + 6 TransactionIVoiceInteractionSessionOnLockscreenShown = binder.FirstCallTransaction + 7 TransactionIVoiceInteractionSessionDestroy = binder.FirstCallTransaction + 8 TransactionIVoiceInteractionSessionNotifyVisibleActivityInfoChanged = binder.FirstCallTransaction + 9 )
const ( MethodIVoiceInteractionSessionShow = "show" MethodIVoiceInteractionSessionHide = "hide" MethodIVoiceInteractionSessionHandleAssist = "handleAssist" MethodIVoiceInteractionSessionHandleScreenshot = "handleScreenshot" MethodIVoiceInteractionSessionTaskStarted = "taskStarted" MethodIVoiceInteractionSessionTaskFinished = "taskFinished" MethodIVoiceInteractionSessionCloseSystemDialogs = "closeSystemDialogs" MethodIVoiceInteractionSessionOnLockscreenShown = "onLockscreenShown" MethodIVoiceInteractionSessionDestroy = "destroy" MethodIVoiceInteractionSessionNotifyVisibleActivityInfoChanged = "notifyVisibleActivityInfoChanged" )
const DescriptorIDetectorSessionStorageService = "android.service.voice.IDetectorSessionStorageService"
const DescriptorIDetectorSessionVisualQueryDetectionCallback = "android.service.voice.IDetectorSessionVisualQueryDetectionCallback"
const DescriptorIDspHotwordDetectionCallback = "android.service.voice.IDspHotwordDetectionCallback"
const DescriptorIMicrophoneHotwordDetectionVoiceInteractionCallback = "android.service.voice.IMicrophoneHotwordDetectionVoiceInteractionCallback"
const DescriptorISandboxedDetectionService = "android.service.voice.ISandboxedDetectionService"
const DescriptorIVisualQueryDetectionVoiceInteractionCallback = "android.service.voice.IVisualQueryDetectionVoiceInteractionCallback"
const DescriptorIVoiceInteractionService = "android.service.voice.IVoiceInteractionService"
const DescriptorIVoiceInteractionSession = "android.service.voice.IVoiceInteractionSession"
const DescriptorIVoiceInteractionSessionService = "android.service.voice.IVoiceInteractionSessionService"
const (
MethodIDetectorSessionStorageServiceOpenFile = "openFile"
)
const (
MethodIVoiceInteractionSessionServiceNewSession = "newSession"
)
const (
TransactionIDetectorSessionStorageServiceOpenFile = binder.FirstCallTransaction + 0
)
const (
TransactionIVoiceInteractionSessionServiceNewSession = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DetectorSessionStorageServiceProxy ¶
func NewDetectorSessionStorageServiceProxy ¶
func NewDetectorSessionStorageServiceProxy( remote binder.IBinder, ) *DetectorSessionStorageServiceProxy
func (*DetectorSessionStorageServiceProxy) AsBinder ¶
func (p *DetectorSessionStorageServiceProxy) AsBinder() binder.IBinder
func (*DetectorSessionStorageServiceProxy) OpenFile ¶
func (p *DetectorSessionStorageServiceProxy) OpenFile( ctx context.Context, filename string, future infra.AndroidFuture, ) error
type DetectorSessionStorageServiceStub ¶
type DetectorSessionStorageServiceStub struct {
Impl IDetectorSessionStorageService
Transport binder.VersionAwareTransport
}
DetectorSessionStorageServiceStub dispatches incoming binder transactions to a typed IDetectorSessionStorageService implementation.
func (*DetectorSessionStorageServiceStub) Descriptor ¶
func (s *DetectorSessionStorageServiceStub) Descriptor() string
func (*DetectorSessionStorageServiceStub) OnTransaction ¶
func (s *DetectorSessionStorageServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type DetectorSessionVisualQueryDetectionCallbackProxy ¶
func NewDetectorSessionVisualQueryDetectionCallbackProxy ¶
func NewDetectorSessionVisualQueryDetectionCallbackProxy( remote binder.IBinder, ) *DetectorSessionVisualQueryDetectionCallbackProxy
func (*DetectorSessionVisualQueryDetectionCallbackProxy) AsBinder ¶
func (p *DetectorSessionVisualQueryDetectionCallbackProxy) AsBinder() binder.IBinder
func (*DetectorSessionVisualQueryDetectionCallbackProxy) OnAttentionGained ¶
func (p *DetectorSessionVisualQueryDetectionCallbackProxy) OnAttentionGained( ctx context.Context, attentionResult VisualQueryAttentionResult, ) error
func (*DetectorSessionVisualQueryDetectionCallbackProxy) OnAttentionLost ¶
func (p *DetectorSessionVisualQueryDetectionCallbackProxy) OnAttentionLost( ctx context.Context, interactionIntention int32, ) error
func (*DetectorSessionVisualQueryDetectionCallbackProxy) OnQueryDetected ¶
func (p *DetectorSessionVisualQueryDetectionCallbackProxy) OnQueryDetected( ctx context.Context, partialQuery string, ) error
func (*DetectorSessionVisualQueryDetectionCallbackProxy) OnQueryFinished ¶
func (p *DetectorSessionVisualQueryDetectionCallbackProxy) OnQueryFinished( ctx context.Context, ) error
func (*DetectorSessionVisualQueryDetectionCallbackProxy) OnQueryRejected ¶
func (p *DetectorSessionVisualQueryDetectionCallbackProxy) OnQueryRejected( ctx context.Context, ) error
func (*DetectorSessionVisualQueryDetectionCallbackProxy) OnResultDetected ¶
func (p *DetectorSessionVisualQueryDetectionCallbackProxy) OnResultDetected( ctx context.Context, partialResult VisualQueryDetectedResult, ) error
type DetectorSessionVisualQueryDetectionCallbackStub ¶
type DetectorSessionVisualQueryDetectionCallbackStub struct {
Impl IDetectorSessionVisualQueryDetectionCallback
Transport binder.VersionAwareTransport
}
DetectorSessionVisualQueryDetectionCallbackStub dispatches incoming binder transactions to a typed IDetectorSessionVisualQueryDetectionCallback implementation.
func (*DetectorSessionVisualQueryDetectionCallbackStub) Descriptor ¶
func (s *DetectorSessionVisualQueryDetectionCallbackStub) Descriptor() string
func (*DetectorSessionVisualQueryDetectionCallbackStub) OnTransaction ¶
func (s *DetectorSessionVisualQueryDetectionCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type DspHotwordDetectionCallbackProxy ¶
func NewDspHotwordDetectionCallbackProxy ¶
func NewDspHotwordDetectionCallbackProxy( remote binder.IBinder, ) *DspHotwordDetectionCallbackProxy
func (*DspHotwordDetectionCallbackProxy) AsBinder ¶
func (p *DspHotwordDetectionCallbackProxy) AsBinder() binder.IBinder
func (*DspHotwordDetectionCallbackProxy) OnDetected ¶
func (p *DspHotwordDetectionCallbackProxy) OnDetected( ctx context.Context, hotwordDetectedResult HotwordDetectedResult, ) error
func (*DspHotwordDetectionCallbackProxy) OnRejected ¶
func (p *DspHotwordDetectionCallbackProxy) OnRejected( ctx context.Context, result HotwordRejectedResult, ) error
type DspHotwordDetectionCallbackStub ¶
type DspHotwordDetectionCallbackStub struct {
Impl IDspHotwordDetectionCallback
Transport binder.VersionAwareTransport
}
DspHotwordDetectionCallbackStub dispatches incoming binder transactions to a typed IDspHotwordDetectionCallback implementation.
func (*DspHotwordDetectionCallbackStub) Descriptor ¶
func (s *DspHotwordDetectionCallbackStub) Descriptor() string
func (*DspHotwordDetectionCallbackStub) OnTransaction ¶
func (s *DspHotwordDetectionCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type HotwordAudioStream ¶
type HotwordAudioStream struct {
Flg int32
AudioFormat *types.AudioFormat
}
func (*HotwordAudioStream) MarshalParcel ¶
func (s *HotwordAudioStream) MarshalParcel( p *parcel.Parcel, ) error
func (*HotwordAudioStream) UnmarshalParcel ¶
func (s *HotwordAudioStream) UnmarshalParcel( p *parcel.Parcel, ) error
type HotwordDetectedResult ¶
type HotwordDetectedResult struct {
Flg int32
SpeakerId int32
ConfidenceLevel int32
HotwordOffsetMillis int32
HotwordDurationMillis int32
AudioChannel int32
Score int32
PersonalizedScore int32
HotwordPhraseId int32
BackgroundAudioPower int32
}
func (*HotwordDetectedResult) MarshalParcel ¶
func (s *HotwordDetectedResult) MarshalParcel( p *parcel.Parcel, ) error
func (*HotwordDetectedResult) UnmarshalParcel ¶
func (s *HotwordDetectedResult) UnmarshalParcel( p *parcel.Parcel, ) error
type HotwordDetectionServiceFailure ¶
func (*HotwordDetectionServiceFailure) MarshalParcel ¶
func (s *HotwordDetectionServiceFailure) MarshalParcel( p *parcel.Parcel, ) error
func (*HotwordDetectionServiceFailure) UnmarshalParcel ¶
func (s *HotwordDetectionServiceFailure) UnmarshalParcel( p *parcel.Parcel, ) error
type HotwordRejectedResult ¶
type HotwordRejectedResult struct {
ConfidenceLevel int32
}
func (*HotwordRejectedResult) MarshalParcel ¶
func (s *HotwordRejectedResult) MarshalParcel( p *parcel.Parcel, ) error
func (*HotwordRejectedResult) UnmarshalParcel ¶
func (s *HotwordRejectedResult) UnmarshalParcel( p *parcel.Parcel, ) error
type IDetectorSessionStorageService ¶
type IDetectorSessionStorageService interface {
AsBinder() binder.IBinder
OpenFile(ctx context.Context, filename string, future infra.AndroidFuture) error
}
func NewDetectorSessionStorageServiceStub ¶
func NewDetectorSessionStorageServiceStub( impl IDetectorSessionStorageServiceServer, ) IDetectorSessionStorageService
NewDetectorSessionStorageServiceStub creates a server-side IDetectorSessionStorageService wrapping the given server implementation. The returned value satisfies IDetectorSessionStorageService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IDetectorSessionStorageServiceServer ¶
type IDetectorSessionStorageServiceServer interface {
OpenFile(ctx context.Context, filename string, future infra.AndroidFuture) error
}
IDetectorSessionStorageServiceServer is the server-side interface that user implementations provide to NewDetectorSessionStorageServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IDetectorSessionVisualQueryDetectionCallback ¶
type IDetectorSessionVisualQueryDetectionCallback interface {
AsBinder() binder.IBinder
OnAttentionGained(ctx context.Context, attentionResult VisualQueryAttentionResult) error
OnAttentionLost(ctx context.Context, interactionIntention int32) error
OnQueryDetected(ctx context.Context, partialQuery string) error
OnResultDetected(ctx context.Context, partialResult VisualQueryDetectedResult) error
OnQueryFinished(ctx context.Context) error
OnQueryRejected(ctx context.Context) error
}
func NewDetectorSessionVisualQueryDetectionCallbackStub ¶
func NewDetectorSessionVisualQueryDetectionCallbackStub( impl IDetectorSessionVisualQueryDetectionCallbackServer, ) IDetectorSessionVisualQueryDetectionCallback
NewDetectorSessionVisualQueryDetectionCallbackStub creates a server-side IDetectorSessionVisualQueryDetectionCallback wrapping the given server implementation. The returned value satisfies IDetectorSessionVisualQueryDetectionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IDetectorSessionVisualQueryDetectionCallbackServer ¶
type IDetectorSessionVisualQueryDetectionCallbackServer interface {
OnAttentionGained(ctx context.Context, attentionResult VisualQueryAttentionResult) error
OnAttentionLost(ctx context.Context, interactionIntention int32) error
OnQueryDetected(ctx context.Context, partialQuery string) error
OnResultDetected(ctx context.Context, partialResult VisualQueryDetectedResult) error
OnQueryFinished(ctx context.Context) error
OnQueryRejected(ctx context.Context) error
}
IDetectorSessionVisualQueryDetectionCallbackServer is the server-side interface that user implementations provide to NewDetectorSessionVisualQueryDetectionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IDspHotwordDetectionCallback ¶
type IDspHotwordDetectionCallback interface {
AsBinder() binder.IBinder
OnDetected(ctx context.Context, hotwordDetectedResult HotwordDetectedResult) error
OnRejected(ctx context.Context, result HotwordRejectedResult) error
}
func NewDspHotwordDetectionCallbackStub ¶
func NewDspHotwordDetectionCallbackStub( impl IDspHotwordDetectionCallbackServer, ) IDspHotwordDetectionCallback
NewDspHotwordDetectionCallbackStub creates a server-side IDspHotwordDetectionCallback wrapping the given server implementation. The returned value satisfies IDspHotwordDetectionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IDspHotwordDetectionCallbackServer ¶
type IDspHotwordDetectionCallbackServer interface {
OnDetected(ctx context.Context, hotwordDetectedResult HotwordDetectedResult) error
OnRejected(ctx context.Context, result HotwordRejectedResult) error
}
IDspHotwordDetectionCallbackServer is the server-side interface that user implementations provide to NewDspHotwordDetectionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IMicrophoneHotwordDetectionVoiceInteractionCallback ¶
type IMicrophoneHotwordDetectionVoiceInteractionCallback interface {
AsBinder() binder.IBinder
OnDetected(ctx context.Context, hotwordDetectedResult HotwordDetectedResult, audioFormat media.AudioFormat, audioStream int32) error
OnHotwordDetectionServiceFailure(ctx context.Context, hotwordDetectionServiceFailure HotwordDetectionServiceFailure) error
OnRejected(ctx context.Context, hotwordRejectedResult HotwordRejectedResult) error
}
func NewMicrophoneHotwordDetectionVoiceInteractionCallbackStub ¶
func NewMicrophoneHotwordDetectionVoiceInteractionCallbackStub( impl IMicrophoneHotwordDetectionVoiceInteractionCallbackServer, ) IMicrophoneHotwordDetectionVoiceInteractionCallback
NewMicrophoneHotwordDetectionVoiceInteractionCallbackStub creates a server-side IMicrophoneHotwordDetectionVoiceInteractionCallback wrapping the given server implementation. The returned value satisfies IMicrophoneHotwordDetectionVoiceInteractionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IMicrophoneHotwordDetectionVoiceInteractionCallbackServer ¶
type IMicrophoneHotwordDetectionVoiceInteractionCallbackServer interface {
OnDetected(ctx context.Context, hotwordDetectedResult HotwordDetectedResult, audioFormat media.AudioFormat, audioStream int32) error
OnHotwordDetectionServiceFailure(ctx context.Context, hotwordDetectionServiceFailure HotwordDetectionServiceFailure) error
OnRejected(ctx context.Context, hotwordRejectedResult HotwordRejectedResult) error
}
IMicrophoneHotwordDetectionVoiceInteractionCallbackServer is the server-side interface that user implementations provide to NewMicrophoneHotwordDetectionVoiceInteractionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ISandboxedDetectionService ¶
type ISandboxedDetectionService interface {
AsBinder() binder.IBinder
DetectFromDspSource(ctx context.Context, event soundtrigger.SoundTriggerKeyphraseRecognitionEvent, audioFormat media.AudioFormat, timeoutMillis int64, callback IDspHotwordDetectionCallback) error
DetectFromMicrophoneSource(ctx context.Context, audioStream int32, audioSource int32, audioFormat media.AudioFormat, options os.PersistableBundle, callback IDspHotwordDetectionCallback) error
DetectWithVisualSignals(ctx context.Context, callback IDetectorSessionVisualQueryDetectionCallback) error
UpdateState(ctx context.Context, options os.PersistableBundle, sharedMemory os.SharedMemory, callback os.IRemoteCallback) error
UpdateAudioFlinger(ctx context.Context, audioFlinger binder.IBinder) error
UpdateContentCaptureManager(ctx context.Context, contentCaptureManager contentcapture.IContentCaptureManager, options content.ContentCaptureOptions) error
UpdateRecognitionServiceManager(ctx context.Context, recognitionServiceManager speech.IRecognitionServiceManager) error
Ping(ctx context.Context, callback os.IRemoteCallback) error
StopDetection(ctx context.Context) error
RegisterRemoteStorageService(ctx context.Context, detectorSessionStorageService IDetectorSessionStorageService) error
}
func NewSandboxedDetectionServiceStub ¶
func NewSandboxedDetectionServiceStub( impl ISandboxedDetectionServiceServer, ) ISandboxedDetectionService
NewSandboxedDetectionServiceStub creates a server-side ISandboxedDetectionService wrapping the given server implementation. The returned value satisfies ISandboxedDetectionService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ISandboxedDetectionServiceServer ¶
type ISandboxedDetectionServiceServer interface {
DetectFromDspSource(ctx context.Context, event soundtrigger.SoundTriggerKeyphraseRecognitionEvent, audioFormat media.AudioFormat, timeoutMillis int64, callback IDspHotwordDetectionCallback) error
DetectFromMicrophoneSource(ctx context.Context, audioStream int32, audioSource int32, audioFormat media.AudioFormat, options os.PersistableBundle, callback IDspHotwordDetectionCallback) error
DetectWithVisualSignals(ctx context.Context, callback IDetectorSessionVisualQueryDetectionCallback) error
UpdateState(ctx context.Context, options os.PersistableBundle, sharedMemory os.SharedMemory, callback os.IRemoteCallback) error
UpdateAudioFlinger(ctx context.Context, audioFlinger binder.IBinder) error
UpdateContentCaptureManager(ctx context.Context, contentCaptureManager contentcapture.IContentCaptureManager, options content.ContentCaptureOptions) error
UpdateRecognitionServiceManager(ctx context.Context, recognitionServiceManager speech.IRecognitionServiceManager) error
Ping(ctx context.Context, callback os.IRemoteCallback) error
StopDetection(ctx context.Context) error
RegisterRemoteStorageService(ctx context.Context, detectorSessionStorageService IDetectorSessionStorageService) error
}
ISandboxedDetectionServiceServer is the server-side interface that user implementations provide to NewSandboxedDetectionServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IVisualQueryDetectionVoiceInteractionCallback ¶
type IVisualQueryDetectionVoiceInteractionCallback interface {
AsBinder() binder.IBinder
OnQueryDetected(ctx context.Context, partialQuery string) error
OnResultDetected(ctx context.Context, partialResult VisualQueryDetectedResult) error
OnQueryFinished(ctx context.Context) error
OnQueryRejected(ctx context.Context) error
OnVisualQueryDetectionServiceFailure(ctx context.Context, visualQueryDetectionServiceFailure VisualQueryDetectionServiceFailure) error
}
func NewVisualQueryDetectionVoiceInteractionCallbackStub ¶
func NewVisualQueryDetectionVoiceInteractionCallbackStub( impl IVisualQueryDetectionVoiceInteractionCallbackServer, ) IVisualQueryDetectionVoiceInteractionCallback
NewVisualQueryDetectionVoiceInteractionCallbackStub creates a server-side IVisualQueryDetectionVoiceInteractionCallback wrapping the given server implementation. The returned value satisfies IVisualQueryDetectionVoiceInteractionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IVisualQueryDetectionVoiceInteractionCallbackServer ¶
type IVisualQueryDetectionVoiceInteractionCallbackServer interface {
OnQueryDetected(ctx context.Context, partialQuery string) error
OnResultDetected(ctx context.Context, partialResult VisualQueryDetectedResult) error
OnQueryFinished(ctx context.Context) error
OnQueryRejected(ctx context.Context) error
OnVisualQueryDetectionServiceFailure(ctx context.Context, visualQueryDetectionServiceFailure VisualQueryDetectionServiceFailure) error
}
IVisualQueryDetectionVoiceInteractionCallbackServer is the server-side interface that user implementations provide to NewVisualQueryDetectionVoiceInteractionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IVoiceInteractionService ¶
type IVoiceInteractionService interface {
AsBinder() binder.IBinder
Ready(ctx context.Context) error
SoundModelsChanged(ctx context.Context) error
Shutdown(ctx context.Context) error
LaunchVoiceAssistFromKeyguard(ctx context.Context) error
GetActiveServiceSupportedActions(ctx context.Context, voiceActions []string, callback app.IVoiceActionCheckCallback) error
PrepareToShowSession(ctx context.Context, args os.Bundle, flags int32) error
ShowSessionFailed(ctx context.Context, args os.Bundle) error
DetectorRemoteExceptionOccurred(ctx context.Context, token binder.IBinder, detectorType int32) error
}
func NewVoiceInteractionServiceStub ¶
func NewVoiceInteractionServiceStub( impl IVoiceInteractionServiceServer, ) IVoiceInteractionService
NewVoiceInteractionServiceStub creates a server-side IVoiceInteractionService wrapping the given server implementation. The returned value satisfies IVoiceInteractionService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IVoiceInteractionServiceServer ¶
type IVoiceInteractionServiceServer interface {
Ready(ctx context.Context) error
SoundModelsChanged(ctx context.Context) error
Shutdown(ctx context.Context) error
LaunchVoiceAssistFromKeyguard(ctx context.Context) error
GetActiveServiceSupportedActions(ctx context.Context, voiceActions []string, callback app.IVoiceActionCheckCallback) error
PrepareToShowSession(ctx context.Context, args os.Bundle, flags int32) error
ShowSessionFailed(ctx context.Context, args os.Bundle) error
DetectorRemoteExceptionOccurred(ctx context.Context, token binder.IBinder, detectorType int32) error
}
IVoiceInteractionServiceServer is the server-side interface that user implementations provide to NewVoiceInteractionServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IVoiceInteractionSession ¶
type IVoiceInteractionSession interface {
AsBinder() binder.IBinder
Show(ctx context.Context, sessionArgs os.Bundle, flags int32, showCallback app.IVoiceInteractionSessionShowCallback) error
Hide(ctx context.Context) error
HandleAssist(ctx context.Context, taskId int32, activityId binder.IBinder, assistData os.Bundle, structure assist.AssistStructure, content assist.AssistContent, index int32, count int32) error
HandleScreenshot(ctx context.Context, screenshot graphics.Bitmap) error
TaskStarted(ctx context.Context, intent androidContent.Intent, taskId int32) error
TaskFinished(ctx context.Context, intent androidContent.Intent, taskId int32) error
CloseSystemDialogs(ctx context.Context) error
OnLockscreenShown(ctx context.Context) error
Destroy(ctx context.Context) error
NotifyVisibleActivityInfoChanged(ctx context.Context, visibleActivityInfo VisibleActivityInfo, type_ int32) error
}
func NewVoiceInteractionSessionStub ¶
func NewVoiceInteractionSessionStub( impl IVoiceInteractionSessionServer, ) IVoiceInteractionSession
NewVoiceInteractionSessionStub creates a server-side IVoiceInteractionSession wrapping the given server implementation. The returned value satisfies IVoiceInteractionSession and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IVoiceInteractionSessionServer ¶
type IVoiceInteractionSessionServer interface {
Show(ctx context.Context, sessionArgs os.Bundle, flags int32, showCallback app.IVoiceInteractionSessionShowCallback) error
Hide(ctx context.Context) error
HandleAssist(ctx context.Context, taskId int32, activityId binder.IBinder, assistData os.Bundle, structure assist.AssistStructure, content assist.AssistContent, index int32, count int32) error
HandleScreenshot(ctx context.Context, screenshot graphics.Bitmap) error
TaskStarted(ctx context.Context, intent androidContent.Intent, taskId int32) error
TaskFinished(ctx context.Context, intent androidContent.Intent, taskId int32) error
CloseSystemDialogs(ctx context.Context) error
OnLockscreenShown(ctx context.Context) error
Destroy(ctx context.Context) error
NotifyVisibleActivityInfoChanged(ctx context.Context, visibleActivityInfo VisibleActivityInfo, type_ int32) error
}
IVoiceInteractionSessionServer is the server-side interface that user implementations provide to NewVoiceInteractionSessionStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IVoiceInteractionSessionService ¶
type IVoiceInteractionSessionService interface {
AsBinder() binder.IBinder
NewSession(ctx context.Context, token binder.IBinder, args os.Bundle, startFlags int32) error
}
func NewVoiceInteractionSessionServiceStub ¶
func NewVoiceInteractionSessionServiceStub( impl IVoiceInteractionSessionServiceServer, ) IVoiceInteractionSessionService
NewVoiceInteractionSessionServiceStub creates a server-side IVoiceInteractionSessionService wrapping the given server implementation. The returned value satisfies IVoiceInteractionSessionService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IVoiceInteractionSessionServiceServer ¶
type IVoiceInteractionSessionServiceServer interface {
NewSession(ctx context.Context, token binder.IBinder, args os.Bundle, startFlags int32) error
}
IVoiceInteractionSessionServiceServer is the server-side interface that user implementations provide to NewVoiceInteractionSessionServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type MicrophoneHotwordDetectionVoiceInteractionCallbackProxy ¶
func NewMicrophoneHotwordDetectionVoiceInteractionCallbackProxy ¶
func NewMicrophoneHotwordDetectionVoiceInteractionCallbackProxy( remote binder.IBinder, ) *MicrophoneHotwordDetectionVoiceInteractionCallbackProxy
func (*MicrophoneHotwordDetectionVoiceInteractionCallbackProxy) AsBinder ¶
func (p *MicrophoneHotwordDetectionVoiceInteractionCallbackProxy) AsBinder() binder.IBinder
func (*MicrophoneHotwordDetectionVoiceInteractionCallbackProxy) OnDetected ¶
func (p *MicrophoneHotwordDetectionVoiceInteractionCallbackProxy) OnDetected( ctx context.Context, hotwordDetectedResult HotwordDetectedResult, audioFormat media.AudioFormat, audioStream int32, ) error
func (*MicrophoneHotwordDetectionVoiceInteractionCallbackProxy) OnHotwordDetectionServiceFailure ¶
func (p *MicrophoneHotwordDetectionVoiceInteractionCallbackProxy) OnHotwordDetectionServiceFailure( ctx context.Context, hotwordDetectionServiceFailure HotwordDetectionServiceFailure, ) error
func (*MicrophoneHotwordDetectionVoiceInteractionCallbackProxy) OnRejected ¶
func (p *MicrophoneHotwordDetectionVoiceInteractionCallbackProxy) OnRejected( ctx context.Context, hotwordRejectedResult HotwordRejectedResult, ) error
type MicrophoneHotwordDetectionVoiceInteractionCallbackStub ¶
type MicrophoneHotwordDetectionVoiceInteractionCallbackStub struct {
Impl IMicrophoneHotwordDetectionVoiceInteractionCallback
Transport binder.VersionAwareTransport
}
MicrophoneHotwordDetectionVoiceInteractionCallbackStub dispatches incoming binder transactions to a typed IMicrophoneHotwordDetectionVoiceInteractionCallback implementation.
func (*MicrophoneHotwordDetectionVoiceInteractionCallbackStub) Descriptor ¶
func (s *MicrophoneHotwordDetectionVoiceInteractionCallbackStub) Descriptor() string
func (*MicrophoneHotwordDetectionVoiceInteractionCallbackStub) OnTransaction ¶
func (s *MicrophoneHotwordDetectionVoiceInteractionCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type SandboxedDetectionServiceProxy ¶
func NewSandboxedDetectionServiceProxy ¶
func NewSandboxedDetectionServiceProxy( remote binder.IBinder, ) *SandboxedDetectionServiceProxy
func (*SandboxedDetectionServiceProxy) AsBinder ¶
func (p *SandboxedDetectionServiceProxy) AsBinder() binder.IBinder
func (*SandboxedDetectionServiceProxy) DetectFromDspSource ¶
func (p *SandboxedDetectionServiceProxy) DetectFromDspSource( ctx context.Context, event soundtrigger.SoundTriggerKeyphraseRecognitionEvent, audioFormat media.AudioFormat, timeoutMillis int64, callback IDspHotwordDetectionCallback, ) error
func (*SandboxedDetectionServiceProxy) DetectFromMicrophoneSource ¶
func (p *SandboxedDetectionServiceProxy) DetectFromMicrophoneSource( ctx context.Context, audioStream int32, audioSource int32, audioFormat media.AudioFormat, options os.PersistableBundle, callback IDspHotwordDetectionCallback, ) error
func (*SandboxedDetectionServiceProxy) DetectWithVisualSignals ¶
func (p *SandboxedDetectionServiceProxy) DetectWithVisualSignals( ctx context.Context, callback IDetectorSessionVisualQueryDetectionCallback, ) error
func (*SandboxedDetectionServiceProxy) Ping ¶
func (p *SandboxedDetectionServiceProxy) Ping( ctx context.Context, callback os.IRemoteCallback, ) error
func (*SandboxedDetectionServiceProxy) RegisterRemoteStorageService ¶
func (p *SandboxedDetectionServiceProxy) RegisterRemoteStorageService( ctx context.Context, detectorSessionStorageService IDetectorSessionStorageService, ) error
func (*SandboxedDetectionServiceProxy) StopDetection ¶
func (p *SandboxedDetectionServiceProxy) StopDetection( ctx context.Context, ) error
func (*SandboxedDetectionServiceProxy) UpdateAudioFlinger ¶
func (*SandboxedDetectionServiceProxy) UpdateContentCaptureManager ¶
func (p *SandboxedDetectionServiceProxy) UpdateContentCaptureManager( ctx context.Context, contentCaptureManager contentcapture.IContentCaptureManager, options content.ContentCaptureOptions, ) error
func (*SandboxedDetectionServiceProxy) UpdateRecognitionServiceManager ¶
func (p *SandboxedDetectionServiceProxy) UpdateRecognitionServiceManager( ctx context.Context, recognitionServiceManager speech.IRecognitionServiceManager, ) error
func (*SandboxedDetectionServiceProxy) UpdateState ¶
func (p *SandboxedDetectionServiceProxy) UpdateState( ctx context.Context, options os.PersistableBundle, sharedMemory os.SharedMemory, callback os.IRemoteCallback, ) error
type SandboxedDetectionServiceStub ¶
type SandboxedDetectionServiceStub struct {
Impl ISandboxedDetectionService
Transport binder.VersionAwareTransport
}
SandboxedDetectionServiceStub dispatches incoming binder transactions to a typed ISandboxedDetectionService implementation.
func (*SandboxedDetectionServiceStub) Descriptor ¶
func (s *SandboxedDetectionServiceStub) Descriptor() string
func (*SandboxedDetectionServiceStub) OnTransaction ¶
func (s *SandboxedDetectionServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type SoundTriggerFailure ¶
func (*SoundTriggerFailure) MarshalParcel ¶
func (s *SoundTriggerFailure) MarshalParcel( p *parcel.Parcel, ) error
func (*SoundTriggerFailure) UnmarshalParcel ¶
func (s *SoundTriggerFailure) UnmarshalParcel( p *parcel.Parcel, ) error
type VisibleActivityInfo ¶
type VisibleActivityInfo struct {
TaskId int32
}
func (*VisibleActivityInfo) MarshalParcel ¶
func (s *VisibleActivityInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*VisibleActivityInfo) UnmarshalParcel ¶
func (s *VisibleActivityInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type VisualQueryAttentionResult ¶
func (*VisualQueryAttentionResult) MarshalParcel ¶
func (s *VisualQueryAttentionResult) MarshalParcel( p *parcel.Parcel, ) error
func (*VisualQueryAttentionResult) UnmarshalParcel ¶
func (s *VisualQueryAttentionResult) UnmarshalParcel( p *parcel.Parcel, ) error
type VisualQueryDetectedResult ¶
func (*VisualQueryDetectedResult) MarshalParcel ¶
func (s *VisualQueryDetectedResult) MarshalParcel( p *parcel.Parcel, ) error
func (*VisualQueryDetectedResult) UnmarshalParcel ¶
func (s *VisualQueryDetectedResult) UnmarshalParcel( p *parcel.Parcel, ) error
type VisualQueryDetectionServiceFailure ¶
func (*VisualQueryDetectionServiceFailure) MarshalParcel ¶
func (s *VisualQueryDetectionServiceFailure) MarshalParcel( p *parcel.Parcel, ) error
func (*VisualQueryDetectionServiceFailure) UnmarshalParcel ¶
func (s *VisualQueryDetectionServiceFailure) UnmarshalParcel( p *parcel.Parcel, ) error
type VisualQueryDetectionVoiceInteractionCallbackProxy ¶
func NewVisualQueryDetectionVoiceInteractionCallbackProxy ¶
func NewVisualQueryDetectionVoiceInteractionCallbackProxy( remote binder.IBinder, ) *VisualQueryDetectionVoiceInteractionCallbackProxy
func (*VisualQueryDetectionVoiceInteractionCallbackProxy) AsBinder ¶
func (p *VisualQueryDetectionVoiceInteractionCallbackProxy) AsBinder() binder.IBinder
func (*VisualQueryDetectionVoiceInteractionCallbackProxy) OnQueryDetected ¶
func (p *VisualQueryDetectionVoiceInteractionCallbackProxy) OnQueryDetected( ctx context.Context, partialQuery string, ) error
func (*VisualQueryDetectionVoiceInteractionCallbackProxy) OnQueryFinished ¶
func (p *VisualQueryDetectionVoiceInteractionCallbackProxy) OnQueryFinished( ctx context.Context, ) error
func (*VisualQueryDetectionVoiceInteractionCallbackProxy) OnQueryRejected ¶
func (p *VisualQueryDetectionVoiceInteractionCallbackProxy) OnQueryRejected( ctx context.Context, ) error
func (*VisualQueryDetectionVoiceInteractionCallbackProxy) OnResultDetected ¶
func (p *VisualQueryDetectionVoiceInteractionCallbackProxy) OnResultDetected( ctx context.Context, partialResult VisualQueryDetectedResult, ) error
func (*VisualQueryDetectionVoiceInteractionCallbackProxy) OnVisualQueryDetectionServiceFailure ¶
func (p *VisualQueryDetectionVoiceInteractionCallbackProxy) OnVisualQueryDetectionServiceFailure( ctx context.Context, visualQueryDetectionServiceFailure VisualQueryDetectionServiceFailure, ) error
type VisualQueryDetectionVoiceInteractionCallbackStub ¶
type VisualQueryDetectionVoiceInteractionCallbackStub struct {
Impl IVisualQueryDetectionVoiceInteractionCallback
Transport binder.VersionAwareTransport
}
VisualQueryDetectionVoiceInteractionCallbackStub dispatches incoming binder transactions to a typed IVisualQueryDetectionVoiceInteractionCallback implementation.
func (*VisualQueryDetectionVoiceInteractionCallbackStub) Descriptor ¶
func (s *VisualQueryDetectionVoiceInteractionCallbackStub) Descriptor() string
func (*VisualQueryDetectionVoiceInteractionCallbackStub) OnTransaction ¶
func (s *VisualQueryDetectionVoiceInteractionCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type VoiceInteractionServiceProxy ¶
func NewVoiceInteractionServiceProxy ¶
func NewVoiceInteractionServiceProxy( remote binder.IBinder, ) *VoiceInteractionServiceProxy
func (*VoiceInteractionServiceProxy) AsBinder ¶
func (p *VoiceInteractionServiceProxy) AsBinder() binder.IBinder
func (*VoiceInteractionServiceProxy) DetectorRemoteExceptionOccurred ¶
func (*VoiceInteractionServiceProxy) GetActiveServiceSupportedActions ¶
func (p *VoiceInteractionServiceProxy) GetActiveServiceSupportedActions( ctx context.Context, voiceActions []string, callback app.IVoiceActionCheckCallback, ) error
func (*VoiceInteractionServiceProxy) LaunchVoiceAssistFromKeyguard ¶
func (p *VoiceInteractionServiceProxy) LaunchVoiceAssistFromKeyguard( ctx context.Context, ) error
func (*VoiceInteractionServiceProxy) PrepareToShowSession ¶
func (*VoiceInteractionServiceProxy) Ready ¶
func (p *VoiceInteractionServiceProxy) Ready( ctx context.Context, ) error
func (*VoiceInteractionServiceProxy) ShowSessionFailed ¶
func (*VoiceInteractionServiceProxy) Shutdown ¶
func (p *VoiceInteractionServiceProxy) Shutdown( ctx context.Context, ) error
func (*VoiceInteractionServiceProxy) SoundModelsChanged ¶
func (p *VoiceInteractionServiceProxy) SoundModelsChanged( ctx context.Context, ) error
type VoiceInteractionServiceStub ¶
type VoiceInteractionServiceStub struct {
Impl IVoiceInteractionService
Transport binder.VersionAwareTransport
}
VoiceInteractionServiceStub dispatches incoming binder transactions to a typed IVoiceInteractionService implementation.
func (*VoiceInteractionServiceStub) Descriptor ¶
func (s *VoiceInteractionServiceStub) Descriptor() string
func (*VoiceInteractionServiceStub) OnTransaction ¶
func (s *VoiceInteractionServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type VoiceInteractionSessionProxy ¶
func NewVoiceInteractionSessionProxy ¶
func NewVoiceInteractionSessionProxy( remote binder.IBinder, ) *VoiceInteractionSessionProxy
func (*VoiceInteractionSessionProxy) AsBinder ¶
func (p *VoiceInteractionSessionProxy) AsBinder() binder.IBinder
func (*VoiceInteractionSessionProxy) CloseSystemDialogs ¶
func (p *VoiceInteractionSessionProxy) CloseSystemDialogs( ctx context.Context, ) error
func (*VoiceInteractionSessionProxy) Destroy ¶
func (p *VoiceInteractionSessionProxy) Destroy( ctx context.Context, ) error
func (*VoiceInteractionSessionProxy) HandleAssist ¶
func (p *VoiceInteractionSessionProxy) HandleAssist( ctx context.Context, taskId int32, activityId binder.IBinder, assistData os.Bundle, structure assist.AssistStructure, content assist.AssistContent, index int32, count int32, ) error
func (*VoiceInteractionSessionProxy) HandleScreenshot ¶
func (*VoiceInteractionSessionProxy) Hide ¶
func (p *VoiceInteractionSessionProxy) Hide( ctx context.Context, ) error
func (*VoiceInteractionSessionProxy) NotifyVisibleActivityInfoChanged ¶
func (p *VoiceInteractionSessionProxy) NotifyVisibleActivityInfoChanged( ctx context.Context, visibleActivityInfo VisibleActivityInfo, type_ int32, ) error
func (*VoiceInteractionSessionProxy) OnLockscreenShown ¶
func (p *VoiceInteractionSessionProxy) OnLockscreenShown( ctx context.Context, ) error
func (*VoiceInteractionSessionProxy) Show ¶
func (p *VoiceInteractionSessionProxy) Show( ctx context.Context, sessionArgs os.Bundle, flags int32, showCallback app.IVoiceInteractionSessionShowCallback, ) error
func (*VoiceInteractionSessionProxy) TaskFinished ¶
func (p *VoiceInteractionSessionProxy) TaskFinished( ctx context.Context, intent androidContent.Intent, taskId int32, ) error
func (*VoiceInteractionSessionProxy) TaskStarted ¶
func (p *VoiceInteractionSessionProxy) TaskStarted( ctx context.Context, intent androidContent.Intent, taskId int32, ) error
type VoiceInteractionSessionServiceProxy ¶
func NewVoiceInteractionSessionServiceProxy ¶
func NewVoiceInteractionSessionServiceProxy( remote binder.IBinder, ) *VoiceInteractionSessionServiceProxy
func (*VoiceInteractionSessionServiceProxy) AsBinder ¶
func (p *VoiceInteractionSessionServiceProxy) AsBinder() binder.IBinder
type VoiceInteractionSessionServiceStub ¶
type VoiceInteractionSessionServiceStub struct {
Impl IVoiceInteractionSessionService
Transport binder.VersionAwareTransport
}
VoiceInteractionSessionServiceStub dispatches incoming binder transactions to a typed IVoiceInteractionSessionService implementation.
func (*VoiceInteractionSessionServiceStub) Descriptor ¶
func (s *VoiceInteractionSessionServiceStub) Descriptor() string
func (*VoiceInteractionSessionServiceStub) OnTransaction ¶
func (s *VoiceInteractionSessionServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type VoiceInteractionSessionStub ¶
type VoiceInteractionSessionStub struct {
Impl IVoiceInteractionSession
Transport binder.VersionAwareTransport
}
VoiceInteractionSessionStub dispatches incoming binder transactions to a typed IVoiceInteractionSession implementation.
func (*VoiceInteractionSessionStub) Descriptor ¶
func (s *VoiceInteractionSessionStub) Descriptor() string
func (*VoiceInteractionSessionStub) OnTransaction ¶
func (s *VoiceInteractionSessionStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
Source Files
¶
- hotwordaudiostream.go
- hotworddetectedresult.go
- hotworddetectionservicefailure.go
- hotwordrejectedresult.go
- idetectorsessionstorageservice.go
- idetectorsessionvisualquerydetectioncallback.go
- idsphotworddetectioncallback.go
- imicrophonehotworddetectionvoiceinteractioncallback.go
- isandboxeddetectionservice.go
- ivisualquerydetectionvoiceinteractioncallback.go
- ivoiceinteractionservice.go
- ivoiceinteractionsession.go
- ivoiceinteractionsessionservice.go
- soundtriggerfailure.go
- visibleactivityinfo.go
- visualqueryattentionresult.go
- visualquerydetectedresult.go
- visualquerydetectionservicefailure.go