Documentation
¶
Index ¶
- Constants
- type AlternativeSpan
- type AlternativeSpans
- type IModelDownloadListener
- type IModelDownloadListenerServer
- type IRecognitionListener
- type IRecognitionListenerServer
- type IRecognitionService
- type IRecognitionServiceManager
- type IRecognitionServiceManagerCallback
- type IRecognitionServiceManagerCallbackServer
- type IRecognitionServiceManagerServer
- type IRecognitionServiceServer
- type IRecognitionSupportCallback
- type IRecognitionSupportCallbackServer
- type ModelDownloadListenerProxy
- func (p *ModelDownloadListenerProxy) AsBinder() binder.IBinder
- func (p *ModelDownloadListenerProxy) OnError(ctx context.Context, error_ int32) error
- func (p *ModelDownloadListenerProxy) OnProgress(ctx context.Context, completedPercent int32) error
- func (p *ModelDownloadListenerProxy) OnScheduled(ctx context.Context) error
- func (p *ModelDownloadListenerProxy) OnSuccess(ctx context.Context) error
- type ModelDownloadListenerStub
- type RecognitionListenerProxy
- func (p *RecognitionListenerProxy) AsBinder() binder.IBinder
- func (p *RecognitionListenerProxy) OnBeginningOfSpeech(ctx context.Context) error
- func (p *RecognitionListenerProxy) OnBufferReceived(ctx context.Context, buffer []byte) error
- func (p *RecognitionListenerProxy) OnEndOfSegmentedSession(ctx context.Context) error
- func (p *RecognitionListenerProxy) OnEndOfSpeech(ctx context.Context) error
- func (p *RecognitionListenerProxy) OnError(ctx context.Context, error_ int32) error
- func (p *RecognitionListenerProxy) OnEvent(ctx context.Context, eventType int32, params os.Bundle) error
- func (p *RecognitionListenerProxy) OnLanguageDetection(ctx context.Context, results os.Bundle) error
- func (p *RecognitionListenerProxy) OnPartialResults(ctx context.Context, results os.Bundle) error
- func (p *RecognitionListenerProxy) OnReadyForSpeech(ctx context.Context, params os.Bundle) error
- func (p *RecognitionListenerProxy) OnResults(ctx context.Context, results os.Bundle) error
- func (p *RecognitionListenerProxy) OnRmsChanged(ctx context.Context, rmsdB float32) error
- func (p *RecognitionListenerProxy) OnSegmentResults(ctx context.Context, results os.Bundle) error
- type RecognitionListenerStub
- type RecognitionPart
- type RecognitionServiceManagerCallbackProxy
- type RecognitionServiceManagerCallbackStub
- type RecognitionServiceManagerProxy
- func (p *RecognitionServiceManagerProxy) AsBinder() binder.IBinder
- func (p *RecognitionServiceManagerProxy) CreateSession(ctx context.Context, componentName content.ComponentName, ...) error
- func (p *RecognitionServiceManagerProxy) SetTemporaryComponent(ctx context.Context, componentName content.ComponentName) error
- type RecognitionServiceManagerStub
- type RecognitionServiceProxy
- func (p *RecognitionServiceProxy) AsBinder() binder.IBinder
- func (p *RecognitionServiceProxy) Cancel(ctx context.Context, listener IRecognitionListener, isShutdown bool) error
- func (p *RecognitionServiceProxy) CheckRecognitionSupport(ctx context.Context, recognizerIntent content.Intent, ...) error
- func (p *RecognitionServiceProxy) StartListening(ctx context.Context, recognizerIntent content.Intent, ...) error
- func (p *RecognitionServiceProxy) StopListening(ctx context.Context, listener IRecognitionListener) error
- func (p *RecognitionServiceProxy) TriggerModelDownload(ctx context.Context, recognizerIntent content.Intent, ...) error
- type RecognitionServiceStub
- type RecognitionSupport
- type RecognitionSupportCallbackProxy
- type RecognitionSupportCallbackStub
Constants ¶
const ( TransactionIModelDownloadListenerOnProgress = binder.FirstCallTransaction + 0 TransactionIModelDownloadListenerOnSuccess = binder.FirstCallTransaction + 1 TransactionIModelDownloadListenerOnScheduled = binder.FirstCallTransaction + 2 TransactionIModelDownloadListenerOnError = binder.FirstCallTransaction + 3 )
const ( MethodIModelDownloadListenerOnProgress = "onProgress" MethodIModelDownloadListenerOnSuccess = "onSuccess" MethodIModelDownloadListenerOnScheduled = "onScheduled" MethodIModelDownloadListenerOnError = "onError" )
const ( TransactionIRecognitionListenerOnReadyForSpeech = binder.FirstCallTransaction + 0 TransactionIRecognitionListenerOnBeginningOfSpeech = binder.FirstCallTransaction + 1 TransactionIRecognitionListenerOnRmsChanged = binder.FirstCallTransaction + 2 TransactionIRecognitionListenerOnBufferReceived = binder.FirstCallTransaction + 3 TransactionIRecognitionListenerOnEndOfSpeech = binder.FirstCallTransaction + 4 TransactionIRecognitionListenerOnError = binder.FirstCallTransaction + 5 TransactionIRecognitionListenerOnResults = binder.FirstCallTransaction + 6 TransactionIRecognitionListenerOnPartialResults = binder.FirstCallTransaction + 7 TransactionIRecognitionListenerOnSegmentResults = binder.FirstCallTransaction + 8 TransactionIRecognitionListenerOnEndOfSegmentedSession = binder.FirstCallTransaction + 9 TransactionIRecognitionListenerOnLanguageDetection = binder.FirstCallTransaction + 10 TransactionIRecognitionListenerOnEvent = binder.FirstCallTransaction + 11 )
const ( MethodIRecognitionListenerOnReadyForSpeech = "onReadyForSpeech" MethodIRecognitionListenerOnBeginningOfSpeech = "onBeginningOfSpeech" MethodIRecognitionListenerOnRmsChanged = "onRmsChanged" MethodIRecognitionListenerOnBufferReceived = "onBufferReceived" MethodIRecognitionListenerOnEndOfSpeech = "onEndOfSpeech" MethodIRecognitionListenerOnError = "onError" MethodIRecognitionListenerOnResults = "onResults" MethodIRecognitionListenerOnPartialResults = "onPartialResults" MethodIRecognitionListenerOnSegmentResults = "onSegmentResults" MethodIRecognitionListenerOnEndOfSegmentedSession = "onEndOfSegmentedSession" MethodIRecognitionListenerOnLanguageDetection = "onLanguageDetection" MethodIRecognitionListenerOnEvent = "onEvent" )
const ( TransactionIRecognitionServiceStartListening = binder.FirstCallTransaction + 0 TransactionIRecognitionServiceStopListening = binder.FirstCallTransaction + 1 TransactionIRecognitionServiceCancel = binder.FirstCallTransaction + 2 TransactionIRecognitionServiceCheckRecognitionSupport = binder.FirstCallTransaction + 3 TransactionIRecognitionServiceTriggerModelDownload = binder.FirstCallTransaction + 4 )
const ( MethodIRecognitionServiceStartListening = "startListening" MethodIRecognitionServiceStopListening = "stopListening" MethodIRecognitionServiceCancel = "cancel" MethodIRecognitionServiceCheckRecognitionSupport = "checkRecognitionSupport" MethodIRecognitionServiceTriggerModelDownload = "triggerModelDownload" )
const ( TransactionIRecognitionServiceManagerCreateSession = binder.FirstCallTransaction + 0 TransactionIRecognitionServiceManagerSetTemporaryComponent = binder.FirstCallTransaction + 1 )
const ( MethodIRecognitionServiceManagerCreateSession = "createSession" MethodIRecognitionServiceManagerSetTemporaryComponent = "setTemporaryComponent" )
const ( TransactionIRecognitionServiceManagerCallbackOnSuccess = binder.FirstCallTransaction + 0 TransactionIRecognitionServiceManagerCallbackOnError = binder.FirstCallTransaction + 1 )
const ( MethodIRecognitionServiceManagerCallbackOnSuccess = "onSuccess" MethodIRecognitionServiceManagerCallbackOnError = "onError" )
const ( TransactionIRecognitionSupportCallbackOnSupportResult = binder.FirstCallTransaction + 0 TransactionIRecognitionSupportCallbackOnError = binder.FirstCallTransaction + 1 )
const ( MethodIRecognitionSupportCallbackOnSupportResult = "onSupportResult" MethodIRecognitionSupportCallbackOnError = "onError" )
const DescriptorIModelDownloadListener = "android.speech.IModelDownloadListener"
const DescriptorIRecognitionListener = "android.speech.IRecognitionListener"
const DescriptorIRecognitionService = "android.speech.IRecognitionService"
const DescriptorIRecognitionServiceManager = "android.speech.IRecognitionServiceManager"
const DescriptorIRecognitionServiceManagerCallback = "android.speech.IRecognitionServiceManagerCallback"
const DescriptorIRecognitionSupportCallback = "android.speech.IRecognitionSupportCallback"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AlternativeSpan ¶
func (*AlternativeSpan) MarshalParcel ¶
func (s *AlternativeSpan) MarshalParcel( p *parcel.Parcel, ) error
func (*AlternativeSpan) UnmarshalParcel ¶
func (s *AlternativeSpan) UnmarshalParcel( p *parcel.Parcel, ) error
type AlternativeSpans ¶
type AlternativeSpans struct {
}
func (*AlternativeSpans) MarshalParcel ¶
func (s *AlternativeSpans) MarshalParcel( p *parcel.Parcel, ) error
func (*AlternativeSpans) UnmarshalParcel ¶
func (s *AlternativeSpans) UnmarshalParcel( p *parcel.Parcel, ) error
type IModelDownloadListener ¶
type IModelDownloadListener interface {
AsBinder() binder.IBinder
OnProgress(ctx context.Context, completedPercent int32) error
OnSuccess(ctx context.Context) error
OnScheduled(ctx context.Context) error
OnError(ctx context.Context, error_ int32) error
}
func NewModelDownloadListenerStub ¶
func NewModelDownloadListenerStub( impl IModelDownloadListenerServer, ) IModelDownloadListener
NewModelDownloadListenerStub creates a server-side IModelDownloadListener wrapping the given server implementation. The returned value satisfies IModelDownloadListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IModelDownloadListenerServer ¶
type IModelDownloadListenerServer interface {
OnProgress(ctx context.Context, completedPercent int32) error
OnSuccess(ctx context.Context) error
OnScheduled(ctx context.Context) error
OnError(ctx context.Context, error_ int32) error
}
IModelDownloadListenerServer is the server-side interface that user implementations provide to NewModelDownloadListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IRecognitionListener ¶
type IRecognitionListener interface {
AsBinder() binder.IBinder
OnReadyForSpeech(ctx context.Context, params os.Bundle) error
OnBeginningOfSpeech(ctx context.Context) error
OnRmsChanged(ctx context.Context, rmsdB float32) error
OnBufferReceived(ctx context.Context, buffer []byte) error
OnEndOfSpeech(ctx context.Context) error
OnError(ctx context.Context, error_ int32) error
OnResults(ctx context.Context, results os.Bundle) error
OnPartialResults(ctx context.Context, results os.Bundle) error
OnSegmentResults(ctx context.Context, results os.Bundle) error
OnEndOfSegmentedSession(ctx context.Context) error
OnLanguageDetection(ctx context.Context, results os.Bundle) error
OnEvent(ctx context.Context, eventType int32, params os.Bundle) error
}
func NewRecognitionListenerStub ¶
func NewRecognitionListenerStub( impl IRecognitionListenerServer, ) IRecognitionListener
NewRecognitionListenerStub creates a server-side IRecognitionListener wrapping the given server implementation. The returned value satisfies IRecognitionListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IRecognitionListenerServer ¶
type IRecognitionListenerServer interface {
OnReadyForSpeech(ctx context.Context, params os.Bundle) error
OnBeginningOfSpeech(ctx context.Context) error
OnRmsChanged(ctx context.Context, rmsdB float32) error
OnBufferReceived(ctx context.Context, buffer []byte) error
OnEndOfSpeech(ctx context.Context) error
OnError(ctx context.Context, error_ int32) error
OnResults(ctx context.Context, results os.Bundle) error
OnPartialResults(ctx context.Context, results os.Bundle) error
OnSegmentResults(ctx context.Context, results os.Bundle) error
OnEndOfSegmentedSession(ctx context.Context) error
OnLanguageDetection(ctx context.Context, results os.Bundle) error
OnEvent(ctx context.Context, eventType int32, params os.Bundle) error
}
IRecognitionListenerServer is the server-side interface that user implementations provide to NewRecognitionListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IRecognitionService ¶
type IRecognitionService interface {
AsBinder() binder.IBinder
StartListening(ctx context.Context, recognizerIntent content.Intent, listener IRecognitionListener, attributionSource content.AttributionSource) error
StopListening(ctx context.Context, listener IRecognitionListener) error
Cancel(ctx context.Context, listener IRecognitionListener, isShutdown bool) error
CheckRecognitionSupport(ctx context.Context, recognizerIntent content.Intent, attributionSource content.AttributionSource, listener IRecognitionSupportCallback) error
TriggerModelDownload(ctx context.Context, recognizerIntent content.Intent, attributionSource content.AttributionSource, listener IModelDownloadListener) error
}
func NewRecognitionServiceStub ¶
func NewRecognitionServiceStub( impl IRecognitionServiceServer, ) IRecognitionService
NewRecognitionServiceStub creates a server-side IRecognitionService wrapping the given server implementation. The returned value satisfies IRecognitionService and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IRecognitionServiceManager ¶
type IRecognitionServiceManager interface {
AsBinder() binder.IBinder
CreateSession(ctx context.Context, componentName content.ComponentName, clientToken binder.IBinder, onDevice bool, callback IRecognitionServiceManagerCallback) error
SetTemporaryComponent(ctx context.Context, componentName content.ComponentName) error
}
func NewRecognitionServiceManagerStub ¶
func NewRecognitionServiceManagerStub( impl IRecognitionServiceManagerServer, ) IRecognitionServiceManager
NewRecognitionServiceManagerStub creates a server-side IRecognitionServiceManager wrapping the given server implementation. The returned value satisfies IRecognitionServiceManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IRecognitionServiceManagerCallback ¶
type IRecognitionServiceManagerCallback interface {
AsBinder() binder.IBinder
OnSuccess(ctx context.Context, service IRecognitionService) error
OnError(ctx context.Context, errorCode int32) error
}
func NewRecognitionServiceManagerCallbackStub ¶
func NewRecognitionServiceManagerCallbackStub( impl IRecognitionServiceManagerCallbackServer, ) IRecognitionServiceManagerCallback
NewRecognitionServiceManagerCallbackStub creates a server-side IRecognitionServiceManagerCallback wrapping the given server implementation. The returned value satisfies IRecognitionServiceManagerCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IRecognitionServiceManagerCallbackServer ¶
type IRecognitionServiceManagerCallbackServer interface {
OnSuccess(ctx context.Context, service IRecognitionService) error
OnError(ctx context.Context, errorCode int32) error
}
IRecognitionServiceManagerCallbackServer is the server-side interface that user implementations provide to NewRecognitionServiceManagerCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IRecognitionServiceManagerServer ¶
type IRecognitionServiceManagerServer interface {
CreateSession(ctx context.Context, componentName content.ComponentName, clientToken binder.IBinder, onDevice bool, callback IRecognitionServiceManagerCallback) error
SetTemporaryComponent(ctx context.Context, componentName content.ComponentName) error
}
IRecognitionServiceManagerServer is the server-side interface that user implementations provide to NewRecognitionServiceManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IRecognitionServiceServer ¶
type IRecognitionServiceServer interface {
StartListening(ctx context.Context, recognizerIntent content.Intent, listener IRecognitionListener, attributionSource content.AttributionSource) error
StopListening(ctx context.Context, listener IRecognitionListener) error
Cancel(ctx context.Context, listener IRecognitionListener, isShutdown bool) error
CheckRecognitionSupport(ctx context.Context, recognizerIntent content.Intent, attributionSource content.AttributionSource, listener IRecognitionSupportCallback) error
TriggerModelDownload(ctx context.Context, recognizerIntent content.Intent, attributionSource content.AttributionSource, listener IModelDownloadListener) error
}
IRecognitionServiceServer is the server-side interface that user implementations provide to NewRecognitionServiceStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IRecognitionSupportCallback ¶
type IRecognitionSupportCallback interface {
AsBinder() binder.IBinder
OnSupportResult(ctx context.Context, recognitionSupport RecognitionSupport) error
OnError(ctx context.Context, error_ int32) error
}
func NewRecognitionSupportCallbackStub ¶
func NewRecognitionSupportCallbackStub( impl IRecognitionSupportCallbackServer, ) IRecognitionSupportCallback
NewRecognitionSupportCallbackStub creates a server-side IRecognitionSupportCallback wrapping the given server implementation. The returned value satisfies IRecognitionSupportCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IRecognitionSupportCallbackServer ¶
type IRecognitionSupportCallbackServer interface {
OnSupportResult(ctx context.Context, recognitionSupport RecognitionSupport) error
OnError(ctx context.Context, error_ int32) error
}
IRecognitionSupportCallbackServer is the server-side interface that user implementations provide to NewRecognitionSupportCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ModelDownloadListenerProxy ¶
func NewModelDownloadListenerProxy ¶
func NewModelDownloadListenerProxy( remote binder.IBinder, ) *ModelDownloadListenerProxy
func (*ModelDownloadListenerProxy) AsBinder ¶
func (p *ModelDownloadListenerProxy) AsBinder() binder.IBinder
func (*ModelDownloadListenerProxy) OnError ¶
func (p *ModelDownloadListenerProxy) OnError( ctx context.Context, error_ int32, ) error
func (*ModelDownloadListenerProxy) OnProgress ¶
func (p *ModelDownloadListenerProxy) OnProgress( ctx context.Context, completedPercent int32, ) error
func (*ModelDownloadListenerProxy) OnScheduled ¶
func (p *ModelDownloadListenerProxy) OnScheduled( ctx context.Context, ) error
type ModelDownloadListenerStub ¶
type ModelDownloadListenerStub struct {
Impl IModelDownloadListener
Transport binder.VersionAwareTransport
}
ModelDownloadListenerStub dispatches incoming binder transactions to a typed IModelDownloadListener implementation.
func (*ModelDownloadListenerStub) Descriptor ¶
func (s *ModelDownloadListenerStub) Descriptor() string
func (*ModelDownloadListenerStub) OnTransaction ¶
func (s *ModelDownloadListenerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type RecognitionListenerProxy ¶
func NewRecognitionListenerProxy ¶
func NewRecognitionListenerProxy( remote binder.IBinder, ) *RecognitionListenerProxy
func (*RecognitionListenerProxy) AsBinder ¶
func (p *RecognitionListenerProxy) AsBinder() binder.IBinder
func (*RecognitionListenerProxy) OnBeginningOfSpeech ¶
func (p *RecognitionListenerProxy) OnBeginningOfSpeech( ctx context.Context, ) error
func (*RecognitionListenerProxy) OnBufferReceived ¶
func (p *RecognitionListenerProxy) OnBufferReceived( ctx context.Context, buffer []byte, ) error
func (*RecognitionListenerProxy) OnEndOfSegmentedSession ¶
func (p *RecognitionListenerProxy) OnEndOfSegmentedSession( ctx context.Context, ) error
func (*RecognitionListenerProxy) OnEndOfSpeech ¶
func (p *RecognitionListenerProxy) OnEndOfSpeech( ctx context.Context, ) error
func (*RecognitionListenerProxy) OnError ¶
func (p *RecognitionListenerProxy) OnError( ctx context.Context, error_ int32, ) error
func (*RecognitionListenerProxy) OnLanguageDetection ¶
func (*RecognitionListenerProxy) OnPartialResults ¶
func (*RecognitionListenerProxy) OnReadyForSpeech ¶
func (*RecognitionListenerProxy) OnRmsChanged ¶
func (p *RecognitionListenerProxy) OnRmsChanged( ctx context.Context, rmsdB float32, ) error
func (*RecognitionListenerProxy) OnSegmentResults ¶
type RecognitionListenerStub ¶
type RecognitionListenerStub struct {
Impl IRecognitionListener
Transport binder.VersionAwareTransport
}
RecognitionListenerStub dispatches incoming binder transactions to a typed IRecognitionListener implementation.
func (*RecognitionListenerStub) Descriptor ¶
func (s *RecognitionListenerStub) Descriptor() string
func (*RecognitionListenerStub) OnTransaction ¶
func (s *RecognitionListenerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type RecognitionPart ¶
type RecognitionPart struct {
Flg int32
RawText string
TimestampMillis int64
ConfidenceLevel int32
}
func (*RecognitionPart) MarshalParcel ¶
func (s *RecognitionPart) MarshalParcel( p *parcel.Parcel, ) error
func (*RecognitionPart) UnmarshalParcel ¶
func (s *RecognitionPart) UnmarshalParcel( p *parcel.Parcel, ) error
type RecognitionServiceManagerCallbackProxy ¶
func NewRecognitionServiceManagerCallbackProxy ¶
func NewRecognitionServiceManagerCallbackProxy( remote binder.IBinder, ) *RecognitionServiceManagerCallbackProxy
func (*RecognitionServiceManagerCallbackProxy) AsBinder ¶
func (p *RecognitionServiceManagerCallbackProxy) AsBinder() binder.IBinder
func (*RecognitionServiceManagerCallbackProxy) OnError ¶
func (p *RecognitionServiceManagerCallbackProxy) OnError( ctx context.Context, errorCode int32, ) error
func (*RecognitionServiceManagerCallbackProxy) OnSuccess ¶
func (p *RecognitionServiceManagerCallbackProxy) OnSuccess( ctx context.Context, service IRecognitionService, ) error
type RecognitionServiceManagerCallbackStub ¶
type RecognitionServiceManagerCallbackStub struct {
Impl IRecognitionServiceManagerCallback
Transport binder.VersionAwareTransport
}
RecognitionServiceManagerCallbackStub dispatches incoming binder transactions to a typed IRecognitionServiceManagerCallback implementation.
func (*RecognitionServiceManagerCallbackStub) Descriptor ¶
func (s *RecognitionServiceManagerCallbackStub) Descriptor() string
func (*RecognitionServiceManagerCallbackStub) OnTransaction ¶
func (s *RecognitionServiceManagerCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type RecognitionServiceManagerProxy ¶
func NewRecognitionServiceManagerProxy ¶
func NewRecognitionServiceManagerProxy( remote binder.IBinder, ) *RecognitionServiceManagerProxy
func (*RecognitionServiceManagerProxy) AsBinder ¶
func (p *RecognitionServiceManagerProxy) AsBinder() binder.IBinder
func (*RecognitionServiceManagerProxy) CreateSession ¶
func (p *RecognitionServiceManagerProxy) CreateSession( ctx context.Context, componentName content.ComponentName, clientToken binder.IBinder, onDevice bool, callback IRecognitionServiceManagerCallback, ) error
func (*RecognitionServiceManagerProxy) SetTemporaryComponent ¶
func (p *RecognitionServiceManagerProxy) SetTemporaryComponent( ctx context.Context, componentName content.ComponentName, ) error
type RecognitionServiceManagerStub ¶
type RecognitionServiceManagerStub struct {
Impl IRecognitionServiceManager
Transport binder.VersionAwareTransport
}
RecognitionServiceManagerStub dispatches incoming binder transactions to a typed IRecognitionServiceManager implementation.
func (*RecognitionServiceManagerStub) Descriptor ¶
func (s *RecognitionServiceManagerStub) Descriptor() string
func (*RecognitionServiceManagerStub) OnTransaction ¶
func (s *RecognitionServiceManagerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type RecognitionServiceProxy ¶
func NewRecognitionServiceProxy ¶
func NewRecognitionServiceProxy( remote binder.IBinder, ) *RecognitionServiceProxy
func (*RecognitionServiceProxy) AsBinder ¶
func (p *RecognitionServiceProxy) AsBinder() binder.IBinder
func (*RecognitionServiceProxy) Cancel ¶
func (p *RecognitionServiceProxy) Cancel( ctx context.Context, listener IRecognitionListener, isShutdown bool, ) error
func (*RecognitionServiceProxy) CheckRecognitionSupport ¶
func (p *RecognitionServiceProxy) CheckRecognitionSupport( ctx context.Context, recognizerIntent content.Intent, attributionSource content.AttributionSource, listener IRecognitionSupportCallback, ) error
func (*RecognitionServiceProxy) StartListening ¶
func (p *RecognitionServiceProxy) StartListening( ctx context.Context, recognizerIntent content.Intent, listener IRecognitionListener, attributionSource content.AttributionSource, ) error
func (*RecognitionServiceProxy) StopListening ¶
func (p *RecognitionServiceProxy) StopListening( ctx context.Context, listener IRecognitionListener, ) error
func (*RecognitionServiceProxy) TriggerModelDownload ¶
func (p *RecognitionServiceProxy) TriggerModelDownload( ctx context.Context, recognizerIntent content.Intent, attributionSource content.AttributionSource, listener IModelDownloadListener, ) error
type RecognitionServiceStub ¶
type RecognitionServiceStub struct {
Impl IRecognitionService
Transport binder.VersionAwareTransport
}
RecognitionServiceStub dispatches incoming binder transactions to a typed IRecognitionService implementation.
func (*RecognitionServiceStub) Descriptor ¶
func (s *RecognitionServiceStub) Descriptor() string
func (*RecognitionServiceStub) OnTransaction ¶
func (s *RecognitionServiceStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type RecognitionSupport ¶
type RecognitionSupport struct {
}
func (*RecognitionSupport) MarshalParcel ¶
func (s *RecognitionSupport) MarshalParcel( p *parcel.Parcel, ) error
func (*RecognitionSupport) UnmarshalParcel ¶
func (s *RecognitionSupport) UnmarshalParcel( p *parcel.Parcel, ) error
type RecognitionSupportCallbackProxy ¶
func NewRecognitionSupportCallbackProxy ¶
func NewRecognitionSupportCallbackProxy( remote binder.IBinder, ) *RecognitionSupportCallbackProxy
func (*RecognitionSupportCallbackProxy) AsBinder ¶
func (p *RecognitionSupportCallbackProxy) AsBinder() binder.IBinder
func (*RecognitionSupportCallbackProxy) OnError ¶
func (p *RecognitionSupportCallbackProxy) OnError( ctx context.Context, error_ int32, ) error
func (*RecognitionSupportCallbackProxy) OnSupportResult ¶
func (p *RecognitionSupportCallbackProxy) OnSupportResult( ctx context.Context, recognitionSupport RecognitionSupport, ) error
type RecognitionSupportCallbackStub ¶
type RecognitionSupportCallbackStub struct {
Impl IRecognitionSupportCallback
Transport binder.VersionAwareTransport
}
RecognitionSupportCallbackStub dispatches incoming binder transactions to a typed IRecognitionSupportCallback implementation.
func (*RecognitionSupportCallbackStub) Descriptor ¶
func (s *RecognitionSupportCallbackStub) Descriptor() string
func (*RecognitionSupportCallbackStub) OnTransaction ¶
func (s *RecognitionSupportCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)