Documentation
¶
Index ¶
- Constants
- type DownloadProgressListenerProxy
- type DownloadProgressListenerStub
- type DownloadRequest
- type DownloadStatusListenerProxy
- type DownloadStatusListenerStub
- type FileInfo
- type FileServiceInfo
- type GroupCallCallbackProxy
- func (p *GroupCallCallbackProxy) AsBinder() binder.IBinder
- func (p *GroupCallCallbackProxy) OnBroadcastSignalStrengthUpdated(ctx context.Context, signalStrength int32) error
- func (p *GroupCallCallbackProxy) OnError(ctx context.Context, errorCode int32, message string) error
- func (p *GroupCallCallbackProxy) OnGroupCallStateChanged(ctx context.Context, state int32, reason int32) error
- type GroupCallCallbackStub
- type IDownloadProgressListener
- type IDownloadProgressListenerServer
- type IDownloadStatusListener
- type IDownloadStatusListenerServer
- type IGroupCallCallback
- type IGroupCallCallbackServer
- type IMbmsDownloadSessionCallback
- type IMbmsDownloadSessionCallbackServer
- type IMbmsGroupCallSessionCallback
- type IMbmsGroupCallSessionCallbackServer
- type IMbmsStreamingSessionCallback
- type IMbmsStreamingSessionCallbackServer
- type IStreamingServiceCallback
- type IStreamingServiceCallbackServer
- type MbmsDownloadSessionCallbackProxy
- func (p *MbmsDownloadSessionCallbackProxy) AsBinder() binder.IBinder
- func (p *MbmsDownloadSessionCallbackProxy) OnError(ctx context.Context, errorCode int32, message string) error
- func (p *MbmsDownloadSessionCallbackProxy) OnFileServicesUpdated(ctx context.Context, services []FileServiceInfo) error
- func (p *MbmsDownloadSessionCallbackProxy) OnMiddlewareReady(ctx context.Context) error
- type MbmsDownloadSessionCallbackStub
- type MbmsGroupCallSessionCallbackProxy
- func (p *MbmsGroupCallSessionCallbackProxy) AsBinder() binder.IBinder
- func (p *MbmsGroupCallSessionCallbackProxy) OnAvailableSaisUpdated(ctx context.Context, currentSai []any, availableSais []any) error
- func (p *MbmsGroupCallSessionCallbackProxy) OnError(ctx context.Context, errorCode int32, message string) error
- func (p *MbmsGroupCallSessionCallbackProxy) OnMiddlewareReady(ctx context.Context) error
- func (p *MbmsGroupCallSessionCallbackProxy) OnServiceInterfaceAvailable(ctx context.Context, interfaceName string, index int32) error
- type MbmsGroupCallSessionCallbackStub
- type MbmsStreamingSessionCallbackProxy
- func (p *MbmsStreamingSessionCallbackProxy) AsBinder() binder.IBinder
- func (p *MbmsStreamingSessionCallbackProxy) OnError(ctx context.Context, errorCode int32, message string) error
- func (p *MbmsStreamingSessionCallbackProxy) OnMiddlewareReady(ctx context.Context) error
- func (p *MbmsStreamingSessionCallbackProxy) OnStreamingServicesUpdated(ctx context.Context, services []StreamingServiceInfo) error
- type MbmsStreamingSessionCallbackStub
- type ServiceInfo
- type StreamingServiceCallbackProxy
- func (p *StreamingServiceCallbackProxy) AsBinder() binder.IBinder
- func (p *StreamingServiceCallbackProxy) OnBroadcastSignalStrengthUpdated(ctx context.Context, signalStrength int32) error
- func (p *StreamingServiceCallbackProxy) OnError(ctx context.Context, errorCode int32, message string) error
- func (p *StreamingServiceCallbackProxy) OnMediaDescriptionUpdated(ctx context.Context) error
- func (p *StreamingServiceCallbackProxy) OnStreamMethodUpdated(ctx context.Context, methodType int32) error
- func (p *StreamingServiceCallbackProxy) OnStreamStateUpdated(ctx context.Context, state int32, reason int32) error
- type StreamingServiceCallbackStub
- type StreamingServiceInfo
- type UriPathPair
Constants ¶
const ( TransactionIGroupCallCallbackOnError = binder.FirstCallTransaction + 0 TransactionIGroupCallCallbackOnGroupCallStateChanged = binder.FirstCallTransaction + 1 TransactionIGroupCallCallbackOnBroadcastSignalStrengthUpdated = binder.FirstCallTransaction + 2 )
const ( MethodIGroupCallCallbackOnError = "onError" MethodIGroupCallCallbackOnGroupCallStateChanged = "onGroupCallStateChanged" MethodIGroupCallCallbackOnBroadcastSignalStrengthUpdated = "onBroadcastSignalStrengthUpdated" )
const ( TransactionIMbmsDownloadSessionCallbackOnError = binder.FirstCallTransaction + 0 TransactionIMbmsDownloadSessionCallbackOnFileServicesUpdated = binder.FirstCallTransaction + 1 TransactionIMbmsDownloadSessionCallbackOnMiddlewareReady = binder.FirstCallTransaction + 2 )
const ( MethodIMbmsDownloadSessionCallbackOnError = "onError" MethodIMbmsDownloadSessionCallbackOnFileServicesUpdated = "onFileServicesUpdated" MethodIMbmsDownloadSessionCallbackOnMiddlewareReady = "onMiddlewareReady" )
const ( TransactionIMbmsGroupCallSessionCallbackOnError = binder.FirstCallTransaction + 0 TransactionIMbmsGroupCallSessionCallbackOnAvailableSaisUpdated = binder.FirstCallTransaction + 1 TransactionIMbmsGroupCallSessionCallbackOnServiceInterfaceAvailable = binder.FirstCallTransaction + 2 TransactionIMbmsGroupCallSessionCallbackOnMiddlewareReady = binder.FirstCallTransaction + 3 )
const ( MethodIMbmsGroupCallSessionCallbackOnError = "onError" MethodIMbmsGroupCallSessionCallbackOnAvailableSaisUpdated = "onAvailableSaisUpdated" MethodIMbmsGroupCallSessionCallbackOnServiceInterfaceAvailable = "onServiceInterfaceAvailable" MethodIMbmsGroupCallSessionCallbackOnMiddlewareReady = "onMiddlewareReady" )
const ( TransactionIMbmsStreamingSessionCallbackOnError = binder.FirstCallTransaction + 0 TransactionIMbmsStreamingSessionCallbackOnStreamingServicesUpdated = binder.FirstCallTransaction + 1 TransactionIMbmsStreamingSessionCallbackOnMiddlewareReady = binder.FirstCallTransaction + 2 )
const ( MethodIMbmsStreamingSessionCallbackOnError = "onError" MethodIMbmsStreamingSessionCallbackOnStreamingServicesUpdated = "onStreamingServicesUpdated" MethodIMbmsStreamingSessionCallbackOnMiddlewareReady = "onMiddlewareReady" )
const ( TransactionIStreamingServiceCallbackOnError = binder.FirstCallTransaction + 0 TransactionIStreamingServiceCallbackOnStreamStateUpdated = binder.FirstCallTransaction + 1 TransactionIStreamingServiceCallbackOnMediaDescriptionUpdated = binder.FirstCallTransaction + 2 TransactionIStreamingServiceCallbackOnBroadcastSignalStrengthUpdated = binder.FirstCallTransaction + 3 TransactionIStreamingServiceCallbackOnStreamMethodUpdated = binder.FirstCallTransaction + 4 )
const ( MethodIStreamingServiceCallbackOnError = "onError" MethodIStreamingServiceCallbackOnStreamStateUpdated = "onStreamStateUpdated" MethodIStreamingServiceCallbackOnMediaDescriptionUpdated = "onMediaDescriptionUpdated" MethodIStreamingServiceCallbackOnBroadcastSignalStrengthUpdated = "onBroadcastSignalStrengthUpdated" MethodIStreamingServiceCallbackOnStreamMethodUpdated = "onStreamMethodUpdated" )
const DescriptorIDownloadProgressListener = "android.telephony.mbms.IDownloadProgressListener"
const DescriptorIDownloadStatusListener = "android.telephony.mbms.IDownloadStatusListener"
const DescriptorIGroupCallCallback = "android.telephony.mbms.IGroupCallCallback"
const DescriptorIMbmsDownloadSessionCallback = "android.telephony.mbms.IMbmsDownloadSessionCallback"
const DescriptorIMbmsGroupCallSessionCallback = "android.telephony.mbms.IMbmsGroupCallSessionCallback"
const DescriptorIMbmsStreamingSessionCallback = "android.telephony.mbms.IMbmsStreamingSessionCallback"
const DescriptorIStreamingServiceCallback = "android.telephony.mbms.IStreamingServiceCallback"
const (
MethodIDownloadProgressListenerOnProgressUpdated = "onProgressUpdated"
)
const (
MethodIDownloadStatusListenerOnStatusUpdated = "onStatusUpdated"
)
const (
TransactionIDownloadProgressListenerOnProgressUpdated = binder.FirstCallTransaction + 0
)
const (
TransactionIDownloadStatusListenerOnStatusUpdated = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DownloadProgressListenerProxy ¶
func NewDownloadProgressListenerProxy ¶
func NewDownloadProgressListenerProxy( remote binder.IBinder, ) *DownloadProgressListenerProxy
func (*DownloadProgressListenerProxy) AsBinder ¶
func (p *DownloadProgressListenerProxy) AsBinder() binder.IBinder
func (*DownloadProgressListenerProxy) OnProgressUpdated ¶
func (p *DownloadProgressListenerProxy) OnProgressUpdated( ctx context.Context, request DownloadRequest, fileInfo FileInfo, currentDownloadSize int32, fullDownloadSize int32, currentDecodedSize int32, fullDecodedSize int32, ) error
type DownloadProgressListenerStub ¶
type DownloadProgressListenerStub struct {
Impl IDownloadProgressListener
Transport binder.VersionAwareTransport
}
DownloadProgressListenerStub dispatches incoming binder transactions to a typed IDownloadProgressListener implementation.
func (*DownloadProgressListenerStub) Descriptor ¶
func (s *DownloadProgressListenerStub) Descriptor() string
func (*DownloadProgressListenerStub) OnTransaction ¶
func (s *DownloadProgressListenerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type DownloadRequest ¶
type DownloadRequest struct {
FileServiceId string
SubscriptionId int32
SerializedResultIntentForApp string
Version int32
}
func (*DownloadRequest) MarshalParcel ¶
func (s *DownloadRequest) MarshalParcel( p *parcel.Parcel, ) error
func (*DownloadRequest) UnmarshalParcel ¶
func (s *DownloadRequest) UnmarshalParcel( p *parcel.Parcel, ) error
type DownloadStatusListenerProxy ¶
func NewDownloadStatusListenerProxy ¶
func NewDownloadStatusListenerProxy( remote binder.IBinder, ) *DownloadStatusListenerProxy
func (*DownloadStatusListenerProxy) AsBinder ¶
func (p *DownloadStatusListenerProxy) AsBinder() binder.IBinder
func (*DownloadStatusListenerProxy) OnStatusUpdated ¶
func (p *DownloadStatusListenerProxy) OnStatusUpdated( ctx context.Context, request DownloadRequest, fileInfo FileInfo, status int32, ) error
type DownloadStatusListenerStub ¶
type DownloadStatusListenerStub struct {
Impl IDownloadStatusListener
Transport binder.VersionAwareTransport
}
DownloadStatusListenerStub dispatches incoming binder transactions to a typed IDownloadStatusListener implementation.
func (*DownloadStatusListenerStub) Descriptor ¶
func (s *DownloadStatusListenerStub) Descriptor() string
func (*DownloadStatusListenerStub) OnTransaction ¶
func (s *DownloadStatusListenerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type FileServiceInfo ¶
type FileServiceInfo struct {
}
func (*FileServiceInfo) MarshalParcel ¶
func (s *FileServiceInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*FileServiceInfo) UnmarshalParcel ¶
func (s *FileServiceInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type GroupCallCallbackProxy ¶
func NewGroupCallCallbackProxy ¶
func NewGroupCallCallbackProxy( remote binder.IBinder, ) *GroupCallCallbackProxy
func (*GroupCallCallbackProxy) AsBinder ¶
func (p *GroupCallCallbackProxy) AsBinder() binder.IBinder
func (*GroupCallCallbackProxy) OnBroadcastSignalStrengthUpdated ¶
func (p *GroupCallCallbackProxy) OnBroadcastSignalStrengthUpdated( ctx context.Context, signalStrength int32, ) error
func (*GroupCallCallbackProxy) OnGroupCallStateChanged ¶
type GroupCallCallbackStub ¶
type GroupCallCallbackStub struct {
Impl IGroupCallCallback
Transport binder.VersionAwareTransport
}
GroupCallCallbackStub dispatches incoming binder transactions to a typed IGroupCallCallback implementation.
func (*GroupCallCallbackStub) Descriptor ¶
func (s *GroupCallCallbackStub) Descriptor() string
func (*GroupCallCallbackStub) OnTransaction ¶
func (s *GroupCallCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type IDownloadProgressListener ¶
type IDownloadProgressListener interface {
AsBinder() binder.IBinder
OnProgressUpdated(ctx context.Context, request DownloadRequest, fileInfo FileInfo, currentDownloadSize int32, fullDownloadSize int32, currentDecodedSize int32, fullDecodedSize int32) error
}
func NewDownloadProgressListenerStub ¶
func NewDownloadProgressListenerStub( impl IDownloadProgressListenerServer, ) IDownloadProgressListener
NewDownloadProgressListenerStub creates a server-side IDownloadProgressListener wrapping the given server implementation. The returned value satisfies IDownloadProgressListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IDownloadProgressListenerServer ¶
type IDownloadProgressListenerServer interface {
OnProgressUpdated(ctx context.Context, request DownloadRequest, fileInfo FileInfo, currentDownloadSize int32, fullDownloadSize int32, currentDecodedSize int32, fullDecodedSize int32) error
}
IDownloadProgressListenerServer is the server-side interface that user implementations provide to NewDownloadProgressListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IDownloadStatusListener ¶
type IDownloadStatusListener interface {
AsBinder() binder.IBinder
OnStatusUpdated(ctx context.Context, request DownloadRequest, fileInfo FileInfo, status int32) error
}
func NewDownloadStatusListenerStub ¶
func NewDownloadStatusListenerStub( impl IDownloadStatusListenerServer, ) IDownloadStatusListener
NewDownloadStatusListenerStub creates a server-side IDownloadStatusListener wrapping the given server implementation. The returned value satisfies IDownloadStatusListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IDownloadStatusListenerServer ¶
type IDownloadStatusListenerServer interface {
OnStatusUpdated(ctx context.Context, request DownloadRequest, fileInfo FileInfo, status int32) error
}
IDownloadStatusListenerServer is the server-side interface that user implementations provide to NewDownloadStatusListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IGroupCallCallback ¶
type IGroupCallCallback interface {
AsBinder() binder.IBinder
OnError(ctx context.Context, errorCode int32, message string) error
OnGroupCallStateChanged(ctx context.Context, state int32, reason int32) error
OnBroadcastSignalStrengthUpdated(ctx context.Context, signalStrength int32) error
}
func NewGroupCallCallbackStub ¶
func NewGroupCallCallbackStub( impl IGroupCallCallbackServer, ) IGroupCallCallback
NewGroupCallCallbackStub creates a server-side IGroupCallCallback wrapping the given server implementation. The returned value satisfies IGroupCallCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IGroupCallCallbackServer ¶
type IGroupCallCallbackServer interface {
OnError(ctx context.Context, errorCode int32, message string) error
OnGroupCallStateChanged(ctx context.Context, state int32, reason int32) error
OnBroadcastSignalStrengthUpdated(ctx context.Context, signalStrength int32) error
}
IGroupCallCallbackServer is the server-side interface that user implementations provide to NewGroupCallCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IMbmsDownloadSessionCallback ¶
type IMbmsDownloadSessionCallback interface {
AsBinder() binder.IBinder
OnError(ctx context.Context, errorCode int32, message string) error
OnFileServicesUpdated(ctx context.Context, services []FileServiceInfo) error
OnMiddlewareReady(ctx context.Context) error
}
func NewMbmsDownloadSessionCallbackStub ¶
func NewMbmsDownloadSessionCallbackStub( impl IMbmsDownloadSessionCallbackServer, ) IMbmsDownloadSessionCallback
NewMbmsDownloadSessionCallbackStub creates a server-side IMbmsDownloadSessionCallback wrapping the given server implementation. The returned value satisfies IMbmsDownloadSessionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IMbmsDownloadSessionCallbackServer ¶
type IMbmsDownloadSessionCallbackServer interface {
OnError(ctx context.Context, errorCode int32, message string) error
OnFileServicesUpdated(ctx context.Context, services []FileServiceInfo) error
OnMiddlewareReady(ctx context.Context) error
}
IMbmsDownloadSessionCallbackServer is the server-side interface that user implementations provide to NewMbmsDownloadSessionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IMbmsGroupCallSessionCallback ¶
type IMbmsGroupCallSessionCallback interface {
AsBinder() binder.IBinder
OnError(ctx context.Context, errorCode int32, message string) error
OnAvailableSaisUpdated(ctx context.Context, currentSai []any, availableSais []any) error
OnServiceInterfaceAvailable(ctx context.Context, interfaceName string, index int32) error
OnMiddlewareReady(ctx context.Context) error
}
func NewMbmsGroupCallSessionCallbackStub ¶
func NewMbmsGroupCallSessionCallbackStub( impl IMbmsGroupCallSessionCallbackServer, ) IMbmsGroupCallSessionCallback
NewMbmsGroupCallSessionCallbackStub creates a server-side IMbmsGroupCallSessionCallback wrapping the given server implementation. The returned value satisfies IMbmsGroupCallSessionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IMbmsGroupCallSessionCallbackServer ¶
type IMbmsGroupCallSessionCallbackServer interface {
OnError(ctx context.Context, errorCode int32, message string) error
OnAvailableSaisUpdated(ctx context.Context, currentSai []any, availableSais []any) error
OnServiceInterfaceAvailable(ctx context.Context, interfaceName string, index int32) error
OnMiddlewareReady(ctx context.Context) error
}
IMbmsGroupCallSessionCallbackServer is the server-side interface that user implementations provide to NewMbmsGroupCallSessionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IMbmsStreamingSessionCallback ¶
type IMbmsStreamingSessionCallback interface {
AsBinder() binder.IBinder
OnError(ctx context.Context, errorCode int32, message string) error
OnStreamingServicesUpdated(ctx context.Context, services []StreamingServiceInfo) error
OnMiddlewareReady(ctx context.Context) error
}
func NewMbmsStreamingSessionCallbackStub ¶
func NewMbmsStreamingSessionCallbackStub( impl IMbmsStreamingSessionCallbackServer, ) IMbmsStreamingSessionCallback
NewMbmsStreamingSessionCallbackStub creates a server-side IMbmsStreamingSessionCallback wrapping the given server implementation. The returned value satisfies IMbmsStreamingSessionCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IMbmsStreamingSessionCallbackServer ¶
type IMbmsStreamingSessionCallbackServer interface {
OnError(ctx context.Context, errorCode int32, message string) error
OnStreamingServicesUpdated(ctx context.Context, services []StreamingServiceInfo) error
OnMiddlewareReady(ctx context.Context) error
}
IMbmsStreamingSessionCallbackServer is the server-side interface that user implementations provide to NewMbmsStreamingSessionCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IStreamingServiceCallback ¶
type IStreamingServiceCallback interface {
AsBinder() binder.IBinder
OnError(ctx context.Context, errorCode int32, message string) error
OnStreamStateUpdated(ctx context.Context, state int32, reason int32) error
OnMediaDescriptionUpdated(ctx context.Context) error
OnBroadcastSignalStrengthUpdated(ctx context.Context, signalStrength int32) error
OnStreamMethodUpdated(ctx context.Context, methodType int32) error
}
func NewStreamingServiceCallbackStub ¶
func NewStreamingServiceCallbackStub( impl IStreamingServiceCallbackServer, ) IStreamingServiceCallback
NewStreamingServiceCallbackStub creates a server-side IStreamingServiceCallback wrapping the given server implementation. The returned value satisfies IStreamingServiceCallback and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IStreamingServiceCallbackServer ¶
type IStreamingServiceCallbackServer interface {
OnError(ctx context.Context, errorCode int32, message string) error
OnStreamStateUpdated(ctx context.Context, state int32, reason int32) error
OnMediaDescriptionUpdated(ctx context.Context) error
OnBroadcastSignalStrengthUpdated(ctx context.Context, signalStrength int32) error
OnStreamMethodUpdated(ctx context.Context, methodType int32) error
}
IStreamingServiceCallbackServer is the server-side interface that user implementations provide to NewStreamingServiceCallbackStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type MbmsDownloadSessionCallbackProxy ¶
func NewMbmsDownloadSessionCallbackProxy ¶
func NewMbmsDownloadSessionCallbackProxy( remote binder.IBinder, ) *MbmsDownloadSessionCallbackProxy
func (*MbmsDownloadSessionCallbackProxy) AsBinder ¶
func (p *MbmsDownloadSessionCallbackProxy) AsBinder() binder.IBinder
func (*MbmsDownloadSessionCallbackProxy) OnFileServicesUpdated ¶
func (p *MbmsDownloadSessionCallbackProxy) OnFileServicesUpdated( ctx context.Context, services []FileServiceInfo, ) error
func (*MbmsDownloadSessionCallbackProxy) OnMiddlewareReady ¶
func (p *MbmsDownloadSessionCallbackProxy) OnMiddlewareReady( ctx context.Context, ) error
type MbmsDownloadSessionCallbackStub ¶
type MbmsDownloadSessionCallbackStub struct {
Impl IMbmsDownloadSessionCallback
Transport binder.VersionAwareTransport
}
MbmsDownloadSessionCallbackStub dispatches incoming binder transactions to a typed IMbmsDownloadSessionCallback implementation.
func (*MbmsDownloadSessionCallbackStub) Descriptor ¶
func (s *MbmsDownloadSessionCallbackStub) Descriptor() string
func (*MbmsDownloadSessionCallbackStub) OnTransaction ¶
func (s *MbmsDownloadSessionCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type MbmsGroupCallSessionCallbackProxy ¶
func NewMbmsGroupCallSessionCallbackProxy ¶
func NewMbmsGroupCallSessionCallbackProxy( remote binder.IBinder, ) *MbmsGroupCallSessionCallbackProxy
func (*MbmsGroupCallSessionCallbackProxy) AsBinder ¶
func (p *MbmsGroupCallSessionCallbackProxy) AsBinder() binder.IBinder
func (*MbmsGroupCallSessionCallbackProxy) OnAvailableSaisUpdated ¶
func (*MbmsGroupCallSessionCallbackProxy) OnMiddlewareReady ¶
func (p *MbmsGroupCallSessionCallbackProxy) OnMiddlewareReady( ctx context.Context, ) error
func (*MbmsGroupCallSessionCallbackProxy) OnServiceInterfaceAvailable ¶
type MbmsGroupCallSessionCallbackStub ¶
type MbmsGroupCallSessionCallbackStub struct {
Impl IMbmsGroupCallSessionCallback
Transport binder.VersionAwareTransport
}
MbmsGroupCallSessionCallbackStub dispatches incoming binder transactions to a typed IMbmsGroupCallSessionCallback implementation.
func (*MbmsGroupCallSessionCallbackStub) Descriptor ¶
func (s *MbmsGroupCallSessionCallbackStub) Descriptor() string
func (*MbmsGroupCallSessionCallbackStub) OnTransaction ¶
func (s *MbmsGroupCallSessionCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type MbmsStreamingSessionCallbackProxy ¶
func NewMbmsStreamingSessionCallbackProxy ¶
func NewMbmsStreamingSessionCallbackProxy( remote binder.IBinder, ) *MbmsStreamingSessionCallbackProxy
func (*MbmsStreamingSessionCallbackProxy) AsBinder ¶
func (p *MbmsStreamingSessionCallbackProxy) AsBinder() binder.IBinder
func (*MbmsStreamingSessionCallbackProxy) OnMiddlewareReady ¶
func (p *MbmsStreamingSessionCallbackProxy) OnMiddlewareReady( ctx context.Context, ) error
func (*MbmsStreamingSessionCallbackProxy) OnStreamingServicesUpdated ¶
func (p *MbmsStreamingSessionCallbackProxy) OnStreamingServicesUpdated( ctx context.Context, services []StreamingServiceInfo, ) error
type MbmsStreamingSessionCallbackStub ¶
type MbmsStreamingSessionCallbackStub struct {
Impl IMbmsStreamingSessionCallback
Transport binder.VersionAwareTransport
}
MbmsStreamingSessionCallbackStub dispatches incoming binder transactions to a typed IMbmsStreamingSessionCallback implementation.
func (*MbmsStreamingSessionCallbackStub) Descriptor ¶
func (s *MbmsStreamingSessionCallbackStub) Descriptor() string
func (*MbmsStreamingSessionCallbackStub) OnTransaction ¶
func (s *MbmsStreamingSessionCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type ServiceInfo ¶
func (*ServiceInfo) MarshalParcel ¶
func (s *ServiceInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*ServiceInfo) UnmarshalParcel ¶
func (s *ServiceInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type StreamingServiceCallbackProxy ¶
func NewStreamingServiceCallbackProxy ¶
func NewStreamingServiceCallbackProxy( remote binder.IBinder, ) *StreamingServiceCallbackProxy
func (*StreamingServiceCallbackProxy) AsBinder ¶
func (p *StreamingServiceCallbackProxy) AsBinder() binder.IBinder
func (*StreamingServiceCallbackProxy) OnBroadcastSignalStrengthUpdated ¶
func (p *StreamingServiceCallbackProxy) OnBroadcastSignalStrengthUpdated( ctx context.Context, signalStrength int32, ) error
func (*StreamingServiceCallbackProxy) OnMediaDescriptionUpdated ¶
func (p *StreamingServiceCallbackProxy) OnMediaDescriptionUpdated( ctx context.Context, ) error
func (*StreamingServiceCallbackProxy) OnStreamMethodUpdated ¶
func (p *StreamingServiceCallbackProxy) OnStreamMethodUpdated( ctx context.Context, methodType int32, ) error
func (*StreamingServiceCallbackProxy) OnStreamStateUpdated ¶
type StreamingServiceCallbackStub ¶
type StreamingServiceCallbackStub struct {
Impl IStreamingServiceCallback
Transport binder.VersionAwareTransport
}
StreamingServiceCallbackStub dispatches incoming binder transactions to a typed IStreamingServiceCallback implementation.
func (*StreamingServiceCallbackStub) Descriptor ¶
func (s *StreamingServiceCallbackStub) Descriptor() string
func (*StreamingServiceCallbackStub) OnTransaction ¶
func (s *StreamingServiceCallbackStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type StreamingServiceInfo ¶
type StreamingServiceInfo struct {
}
func (*StreamingServiceInfo) MarshalParcel ¶
func (s *StreamingServiceInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*StreamingServiceInfo) UnmarshalParcel ¶
func (s *StreamingServiceInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type UriPathPair ¶
type UriPathPair struct {
}
func (*UriPathPair) MarshalParcel ¶
func (s *UriPathPair) MarshalParcel( p *parcel.Parcel, ) error
func (*UriPathPair) UnmarshalParcel ¶
func (s *UriPathPair) UnmarshalParcel( p *parcel.Parcel, ) error