Documentation
¶
Index ¶
- Constants
- type CompatibilityChangeConfig
- type CompatibilityChangeInfo
- type CompatibilityOverrideConfig
- type CompatibilityOverridesByPackageConfig
- type CompatibilityOverridesToRemoveByPackageConfig
- type CompatibilityOverridesToRemoveConfig
- type IOverrideValidator
- type IOverrideValidatorServer
- type IPlatformCompat
- type IPlatformCompatNative
- type IPlatformCompatNativeServer
- type IPlatformCompatServer
- type OverrideAllowedState
- type OverrideValidatorProxy
- type OverrideValidatorStub
- type PlatformCompatNativeProxy
- func (p *PlatformCompatNativeProxy) AsBinder() binder.IBinder
- func (p *PlatformCompatNativeProxy) IsChangeEnabledByPackageName(ctx context.Context, changeId int64, packageName string) (bool, error)
- func (p *PlatformCompatNativeProxy) IsChangeEnabledByUid(ctx context.Context, changeId int64, uid int32) (bool, error)
- func (p *PlatformCompatNativeProxy) ReportChangeByPackageName(ctx context.Context, changeId int64, packageName string) error
- func (p *PlatformCompatNativeProxy) ReportChangeByUid(ctx context.Context, changeId int64, uid int32) error
- type PlatformCompatNativeStub
- type PlatformCompatProxy
- func (p *PlatformCompatProxy) AsBinder() binder.IBinder
- func (p *PlatformCompatProxy) ClearOverride(ctx context.Context, changeId int64, packageName string) (bool, error)
- func (p *PlatformCompatProxy) ClearOverrideForTest(ctx context.Context, changeId int64, packageName string) (bool, error)
- func (p *PlatformCompatProxy) ClearOverrides(ctx context.Context, packageName string) error
- func (p *PlatformCompatProxy) ClearOverridesForTest(ctx context.Context, packageName string) error
- func (p *PlatformCompatProxy) DisableTargetSdkChanges(ctx context.Context, packageName string, targetSdkVersion int32) (int32, error)
- func (p *PlatformCompatProxy) EnableTargetSdkChanges(ctx context.Context, packageName string, targetSdkVersion int32) (int32, error)
- func (p *PlatformCompatProxy) GetAppConfig(ctx context.Context, appInfo pm.ApplicationInfo) (CompatibilityChangeConfig, error)
- func (p *PlatformCompatProxy) GetOverrideValidator(ctx context.Context) (IOverrideValidator, error)
- func (p *PlatformCompatProxy) IsChangeEnabled(ctx context.Context, changeId int64, appInfo pm.ApplicationInfo) (bool, error)
- func (p *PlatformCompatProxy) IsChangeEnabledByPackageName(ctx context.Context, changeId int64, packageName string) (bool, error)
- func (p *PlatformCompatProxy) IsChangeEnabledByUid(ctx context.Context, changeId int64, uid int32) (bool, error)
- func (p *PlatformCompatProxy) ListAllChanges(ctx context.Context) ([]CompatibilityChangeInfo, error)
- func (p *PlatformCompatProxy) ListUIChanges(ctx context.Context) ([]CompatibilityChangeInfo, error)
- func (p *PlatformCompatProxy) PutAllOverridesOnReleaseBuilds(ctx context.Context, overridesByPackage CompatibilityOverridesByPackageConfig) error
- func (p *PlatformCompatProxy) PutOverridesOnReleaseBuilds(ctx context.Context, overrides CompatibilityOverrideConfig, packageName string) error
- func (p *PlatformCompatProxy) RemoveAllOverridesOnReleaseBuilds(ctx context.Context, ...) error
- func (p *PlatformCompatProxy) RemoveOverridesOnReleaseBuilds(ctx context.Context, overridesToRemove CompatibilityOverridesToRemoveConfig, ...) error
- func (p *PlatformCompatProxy) ReportChange(ctx context.Context, changeId int64, appInfo pm.ApplicationInfo) error
- func (p *PlatformCompatProxy) ReportChangeByPackageName(ctx context.Context, changeId int64, packageName string) error
- func (p *PlatformCompatProxy) ReportChangeByUid(ctx context.Context, changeId int64, uid int32) error
- func (p *PlatformCompatProxy) SetOverrides(ctx context.Context, overrides CompatibilityChangeConfig, packageName string) error
- func (p *PlatformCompatProxy) SetOverridesForTest(ctx context.Context, overrides CompatibilityChangeConfig, packageName string) error
- type PlatformCompatStub
Constants ¶
const ( TransactionIPlatformCompatReportChange = binder.FirstCallTransaction + 0 TransactionIPlatformCompatReportChangeByPackageName = binder.FirstCallTransaction + 1 TransactionIPlatformCompatReportChangeByUid = binder.FirstCallTransaction + 2 TransactionIPlatformCompatIsChangeEnabled = binder.FirstCallTransaction + 3 TransactionIPlatformCompatIsChangeEnabledByPackageName = binder.FirstCallTransaction + 4 TransactionIPlatformCompatIsChangeEnabledByUid = binder.FirstCallTransaction + 5 TransactionIPlatformCompatSetOverrides = binder.FirstCallTransaction + 6 TransactionIPlatformCompatPutAllOverridesOnReleaseBuilds = binder.FirstCallTransaction + 7 TransactionIPlatformCompatPutOverridesOnReleaseBuilds = binder.FirstCallTransaction + 8 TransactionIPlatformCompatSetOverridesForTest = binder.FirstCallTransaction + 9 TransactionIPlatformCompatClearOverride = binder.FirstCallTransaction + 10 TransactionIPlatformCompatClearOverrideForTest = binder.FirstCallTransaction + 11 TransactionIPlatformCompatRemoveAllOverridesOnReleaseBuilds = binder.FirstCallTransaction + 12 TransactionIPlatformCompatRemoveOverridesOnReleaseBuilds = binder.FirstCallTransaction + 13 TransactionIPlatformCompatEnableTargetSdkChanges = binder.FirstCallTransaction + 14 TransactionIPlatformCompatDisableTargetSdkChanges = binder.FirstCallTransaction + 15 TransactionIPlatformCompatClearOverrides = binder.FirstCallTransaction + 16 TransactionIPlatformCompatClearOverridesForTest = binder.FirstCallTransaction + 17 TransactionIPlatformCompatGetAppConfig = binder.FirstCallTransaction + 18 TransactionIPlatformCompatListAllChanges = binder.FirstCallTransaction + 19 TransactionIPlatformCompatListUIChanges = binder.FirstCallTransaction + 20 TransactionIPlatformCompatGetOverrideValidator = binder.FirstCallTransaction + 21 )
const ( MethodIPlatformCompatReportChange = "reportChange" MethodIPlatformCompatReportChangeByPackageName = "reportChangeByPackageName" MethodIPlatformCompatReportChangeByUid = "reportChangeByUid" MethodIPlatformCompatIsChangeEnabled = "isChangeEnabled" MethodIPlatformCompatIsChangeEnabledByPackageName = "isChangeEnabledByPackageName" MethodIPlatformCompatIsChangeEnabledByUid = "isChangeEnabledByUid" MethodIPlatformCompatSetOverrides = "setOverrides" MethodIPlatformCompatPutAllOverridesOnReleaseBuilds = "putAllOverridesOnReleaseBuilds" MethodIPlatformCompatPutOverridesOnReleaseBuilds = "putOverridesOnReleaseBuilds" MethodIPlatformCompatSetOverridesForTest = "setOverridesForTest" MethodIPlatformCompatClearOverride = "clearOverride" MethodIPlatformCompatClearOverrideForTest = "clearOverrideForTest" MethodIPlatformCompatRemoveAllOverridesOnReleaseBuilds = "removeAllOverridesOnReleaseBuilds" MethodIPlatformCompatRemoveOverridesOnReleaseBuilds = "removeOverridesOnReleaseBuilds" MethodIPlatformCompatEnableTargetSdkChanges = "enableTargetSdkChanges" MethodIPlatformCompatDisableTargetSdkChanges = "disableTargetSdkChanges" MethodIPlatformCompatClearOverrides = "clearOverrides" MethodIPlatformCompatClearOverridesForTest = "clearOverridesForTest" MethodIPlatformCompatGetAppConfig = "getAppConfig" MethodIPlatformCompatListAllChanges = "listAllChanges" MethodIPlatformCompatListUIChanges = "listUIChanges" MethodIPlatformCompatGetOverrideValidator = "getOverrideValidator" )
const ( TransactionIPlatformCompatNativeReportChangeByPackageName = binder.FirstCallTransaction + 0 TransactionIPlatformCompatNativeReportChangeByUid = binder.FirstCallTransaction + 1 TransactionIPlatformCompatNativeIsChangeEnabledByPackageName = binder.FirstCallTransaction + 2 TransactionIPlatformCompatNativeIsChangeEnabledByUid = binder.FirstCallTransaction + 3 )
const ( MethodIPlatformCompatNativeReportChangeByPackageName = "reportChangeByPackageName" MethodIPlatformCompatNativeReportChangeByUid = "reportChangeByUid" MethodIPlatformCompatNativeIsChangeEnabledByPackageName = "isChangeEnabledByPackageName" MethodIPlatformCompatNativeIsChangeEnabledByUid = "isChangeEnabledByUid" )
const DescriptorIOverrideValidator = "com.android.internal.compat.IOverrideValidator"
const DescriptorIPlatformCompat = "com.android.internal.compat.IPlatformCompat"
const DescriptorIPlatformCompatNative = "com.android.internal.compat.IPlatformCompatNative"
const (
MethodIOverrideValidatorGetOverrideAllowedState = "getOverrideAllowedState"
)
const (
TransactionIOverrideValidatorGetOverrideAllowedState = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CompatibilityChangeConfig ¶
type CompatibilityChangeConfig struct {
}
func (*CompatibilityChangeConfig) MarshalParcel ¶
func (s *CompatibilityChangeConfig) MarshalParcel( p *parcel.Parcel, ) error
func (*CompatibilityChangeConfig) UnmarshalParcel ¶
func (s *CompatibilityChangeConfig) UnmarshalParcel( p *parcel.Parcel, ) error
type CompatibilityChangeInfo ¶
type CompatibilityChangeInfo struct {
ChangeId int64
Name string
EnableSinceTargetSdk int32
Disabled bool
LoggingOnly bool
Description string
Overridable bool
}
func (*CompatibilityChangeInfo) MarshalParcel ¶
func (s *CompatibilityChangeInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*CompatibilityChangeInfo) UnmarshalParcel ¶
func (s *CompatibilityChangeInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type CompatibilityOverrideConfig ¶
type CompatibilityOverrideConfig struct {
}
func (*CompatibilityOverrideConfig) MarshalParcel ¶
func (s *CompatibilityOverrideConfig) MarshalParcel( p *parcel.Parcel, ) error
func (*CompatibilityOverrideConfig) UnmarshalParcel ¶
func (s *CompatibilityOverrideConfig) UnmarshalParcel( p *parcel.Parcel, ) error
type CompatibilityOverridesByPackageConfig ¶
type CompatibilityOverridesByPackageConfig struct {
}
func (*CompatibilityOverridesByPackageConfig) MarshalParcel ¶
func (s *CompatibilityOverridesByPackageConfig) MarshalParcel( p *parcel.Parcel, ) error
func (*CompatibilityOverridesByPackageConfig) UnmarshalParcel ¶
func (s *CompatibilityOverridesByPackageConfig) UnmarshalParcel( p *parcel.Parcel, ) error
type CompatibilityOverridesToRemoveByPackageConfig ¶
type CompatibilityOverridesToRemoveByPackageConfig struct {
}
func (*CompatibilityOverridesToRemoveByPackageConfig) MarshalParcel ¶
func (s *CompatibilityOverridesToRemoveByPackageConfig) MarshalParcel( p *parcel.Parcel, ) error
func (*CompatibilityOverridesToRemoveByPackageConfig) UnmarshalParcel ¶
func (s *CompatibilityOverridesToRemoveByPackageConfig) UnmarshalParcel( p *parcel.Parcel, ) error
type CompatibilityOverridesToRemoveConfig ¶
type CompatibilityOverridesToRemoveConfig struct {
}
func (*CompatibilityOverridesToRemoveConfig) MarshalParcel ¶
func (s *CompatibilityOverridesToRemoveConfig) MarshalParcel( p *parcel.Parcel, ) error
func (*CompatibilityOverridesToRemoveConfig) UnmarshalParcel ¶
func (s *CompatibilityOverridesToRemoveConfig) UnmarshalParcel( p *parcel.Parcel, ) error
type IOverrideValidator ¶
type IOverrideValidator interface {
AsBinder() binder.IBinder
GetOverrideAllowedState(ctx context.Context, changeId int64, packageName string) (OverrideAllowedState, error)
}
func NewOverrideValidatorStub ¶
func NewOverrideValidatorStub( impl IOverrideValidatorServer, ) IOverrideValidator
NewOverrideValidatorStub creates a server-side IOverrideValidator wrapping the given server implementation. The returned value satisfies IOverrideValidator and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IOverrideValidatorServer ¶
type IOverrideValidatorServer interface {
GetOverrideAllowedState(ctx context.Context, changeId int64, packageName string) (OverrideAllowedState, error)
}
IOverrideValidatorServer is the server-side interface that user implementations provide to NewOverrideValidatorStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IPlatformCompat ¶
type IPlatformCompat interface {
AsBinder() binder.IBinder
ReportChange(ctx context.Context, changeId int64, appInfo pm.ApplicationInfo) error
ReportChangeByPackageName(ctx context.Context, changeId int64, packageName string) error
ReportChangeByUid(ctx context.Context, changeId int64, uid int32) error
IsChangeEnabled(ctx context.Context, changeId int64, appInfo pm.ApplicationInfo) (bool, error)
IsChangeEnabledByPackageName(ctx context.Context, changeId int64, packageName string) (bool, error)
IsChangeEnabledByUid(ctx context.Context, changeId int64, uid int32) (bool, error)
SetOverrides(ctx context.Context, overrides CompatibilityChangeConfig, packageName string) error
PutAllOverridesOnReleaseBuilds(ctx context.Context, overridesByPackage CompatibilityOverridesByPackageConfig) error
PutOverridesOnReleaseBuilds(ctx context.Context, overrides CompatibilityOverrideConfig, packageName string) error
SetOverridesForTest(ctx context.Context, overrides CompatibilityChangeConfig, packageName string) error
ClearOverride(ctx context.Context, changeId int64, packageName string) (bool, error)
ClearOverrideForTest(ctx context.Context, changeId int64, packageName string) (bool, error)
RemoveAllOverridesOnReleaseBuilds(ctx context.Context, overridesToRemoveByPackage CompatibilityOverridesToRemoveByPackageConfig) error
RemoveOverridesOnReleaseBuilds(ctx context.Context, overridesToRemove CompatibilityOverridesToRemoveConfig, packageName string) error
EnableTargetSdkChanges(ctx context.Context, packageName string, targetSdkVersion int32) (int32, error)
DisableTargetSdkChanges(ctx context.Context, packageName string, targetSdkVersion int32) (int32, error)
ClearOverrides(ctx context.Context, packageName string) error
ClearOverridesForTest(ctx context.Context, packageName string) error
GetAppConfig(ctx context.Context, appInfo pm.ApplicationInfo) (CompatibilityChangeConfig, error)
ListAllChanges(ctx context.Context) ([]CompatibilityChangeInfo, error)
ListUIChanges(ctx context.Context) ([]CompatibilityChangeInfo, error)
GetOverrideValidator(ctx context.Context) (IOverrideValidator, error)
}
func NewPlatformCompatStub ¶
func NewPlatformCompatStub( impl IPlatformCompatServer, ) IPlatformCompat
NewPlatformCompatStub creates a server-side IPlatformCompat wrapping the given server implementation. The returned value satisfies IPlatformCompat and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IPlatformCompatNative ¶
type IPlatformCompatNative interface {
AsBinder() binder.IBinder
ReportChangeByPackageName(ctx context.Context, changeId int64, packageName string) error
ReportChangeByUid(ctx context.Context, changeId int64, uid int32) error
IsChangeEnabledByPackageName(ctx context.Context, changeId int64, packageName string) (bool, error)
IsChangeEnabledByUid(ctx context.Context, changeId int64, uid int32) (bool, error)
}
func NewPlatformCompatNativeStub ¶
func NewPlatformCompatNativeStub( impl IPlatformCompatNativeServer, ) IPlatformCompatNative
NewPlatformCompatNativeStub creates a server-side IPlatformCompatNative wrapping the given server implementation. The returned value satisfies IPlatformCompatNative and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IPlatformCompatNativeServer ¶
type IPlatformCompatNativeServer interface {
ReportChangeByPackageName(ctx context.Context, changeId int64, packageName string) error
ReportChangeByUid(ctx context.Context, changeId int64, uid int32) error
IsChangeEnabledByPackageName(ctx context.Context, changeId int64, packageName string) (bool, error)
IsChangeEnabledByUid(ctx context.Context, changeId int64, uid int32) (bool, error)
}
IPlatformCompatNativeServer is the server-side interface that user implementations provide to NewPlatformCompatNativeStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IPlatformCompatServer ¶
type IPlatformCompatServer interface {
ReportChange(ctx context.Context, changeId int64, appInfo pm.ApplicationInfo) error
ReportChangeByPackageName(ctx context.Context, changeId int64, packageName string) error
ReportChangeByUid(ctx context.Context, changeId int64, uid int32) error
IsChangeEnabled(ctx context.Context, changeId int64, appInfo pm.ApplicationInfo) (bool, error)
IsChangeEnabledByPackageName(ctx context.Context, changeId int64, packageName string) (bool, error)
IsChangeEnabledByUid(ctx context.Context, changeId int64, uid int32) (bool, error)
SetOverrides(ctx context.Context, overrides CompatibilityChangeConfig, packageName string) error
PutAllOverridesOnReleaseBuilds(ctx context.Context, overridesByPackage CompatibilityOverridesByPackageConfig) error
PutOverridesOnReleaseBuilds(ctx context.Context, overrides CompatibilityOverrideConfig, packageName string) error
SetOverridesForTest(ctx context.Context, overrides CompatibilityChangeConfig, packageName string) error
ClearOverride(ctx context.Context, changeId int64, packageName string) (bool, error)
ClearOverrideForTest(ctx context.Context, changeId int64, packageName string) (bool, error)
RemoveAllOverridesOnReleaseBuilds(ctx context.Context, overridesToRemoveByPackage CompatibilityOverridesToRemoveByPackageConfig) error
RemoveOverridesOnReleaseBuilds(ctx context.Context, overridesToRemove CompatibilityOverridesToRemoveConfig, packageName string) error
EnableTargetSdkChanges(ctx context.Context, packageName string, targetSdkVersion int32) (int32, error)
DisableTargetSdkChanges(ctx context.Context, packageName string, targetSdkVersion int32) (int32, error)
ClearOverrides(ctx context.Context, packageName string) error
ClearOverridesForTest(ctx context.Context, packageName string) error
GetAppConfig(ctx context.Context, appInfo pm.ApplicationInfo) (CompatibilityChangeConfig, error)
ListAllChanges(ctx context.Context) ([]CompatibilityChangeInfo, error)
ListUIChanges(ctx context.Context) ([]CompatibilityChangeInfo, error)
GetOverrideValidator(ctx context.Context) (IOverrideValidator, error)
}
IPlatformCompatServer is the server-side interface that user implementations provide to NewPlatformCompatStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type OverrideAllowedState ¶
func (*OverrideAllowedState) MarshalParcel ¶
func (s *OverrideAllowedState) MarshalParcel( p *parcel.Parcel, ) error
func (*OverrideAllowedState) UnmarshalParcel ¶
func (s *OverrideAllowedState) UnmarshalParcel( p *parcel.Parcel, ) error
type OverrideValidatorProxy ¶
func NewOverrideValidatorProxy ¶
func NewOverrideValidatorProxy( remote binder.IBinder, ) *OverrideValidatorProxy
func (*OverrideValidatorProxy) AsBinder ¶
func (p *OverrideValidatorProxy) AsBinder() binder.IBinder
func (*OverrideValidatorProxy) GetOverrideAllowedState ¶
func (p *OverrideValidatorProxy) GetOverrideAllowedState( ctx context.Context, changeId int64, packageName string, ) (OverrideAllowedState, error)
type OverrideValidatorStub ¶
type OverrideValidatorStub struct {
Impl IOverrideValidator
Transport binder.VersionAwareTransport
}
OverrideValidatorStub dispatches incoming binder transactions to a typed IOverrideValidator implementation.
func (*OverrideValidatorStub) Descriptor ¶
func (s *OverrideValidatorStub) Descriptor() string
func (*OverrideValidatorStub) OnTransaction ¶
func (s *OverrideValidatorStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type PlatformCompatNativeProxy ¶
func NewPlatformCompatNativeProxy ¶
func NewPlatformCompatNativeProxy( remote binder.IBinder, ) *PlatformCompatNativeProxy
func (*PlatformCompatNativeProxy) AsBinder ¶
func (p *PlatformCompatNativeProxy) AsBinder() binder.IBinder
func (*PlatformCompatNativeProxy) IsChangeEnabledByPackageName ¶
func (*PlatformCompatNativeProxy) IsChangeEnabledByUid ¶
func (*PlatformCompatNativeProxy) ReportChangeByPackageName ¶
func (*PlatformCompatNativeProxy) ReportChangeByUid ¶
type PlatformCompatNativeStub ¶
type PlatformCompatNativeStub struct {
Impl IPlatformCompatNative
Transport binder.VersionAwareTransport
}
PlatformCompatNativeStub dispatches incoming binder transactions to a typed IPlatformCompatNative implementation.
func (*PlatformCompatNativeStub) Descriptor ¶
func (s *PlatformCompatNativeStub) Descriptor() string
func (*PlatformCompatNativeStub) OnTransaction ¶
func (s *PlatformCompatNativeStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type PlatformCompatProxy ¶
func NewPlatformCompatProxy ¶
func NewPlatformCompatProxy( remote binder.IBinder, ) *PlatformCompatProxy
func (*PlatformCompatProxy) AsBinder ¶
func (p *PlatformCompatProxy) AsBinder() binder.IBinder
func (*PlatformCompatProxy) ClearOverride ¶
func (*PlatformCompatProxy) ClearOverrideForTest ¶
func (*PlatformCompatProxy) ClearOverrides ¶
func (p *PlatformCompatProxy) ClearOverrides( ctx context.Context, packageName string, ) error
func (*PlatformCompatProxy) ClearOverridesForTest ¶
func (p *PlatformCompatProxy) ClearOverridesForTest( ctx context.Context, packageName string, ) error
func (*PlatformCompatProxy) DisableTargetSdkChanges ¶
func (*PlatformCompatProxy) EnableTargetSdkChanges ¶
func (*PlatformCompatProxy) GetAppConfig ¶
func (p *PlatformCompatProxy) GetAppConfig( ctx context.Context, appInfo pm.ApplicationInfo, ) (CompatibilityChangeConfig, error)
func (*PlatformCompatProxy) GetOverrideValidator ¶
func (p *PlatformCompatProxy) GetOverrideValidator( ctx context.Context, ) (IOverrideValidator, error)
func (*PlatformCompatProxy) IsChangeEnabled ¶
func (p *PlatformCompatProxy) IsChangeEnabled( ctx context.Context, changeId int64, appInfo pm.ApplicationInfo, ) (bool, error)
func (*PlatformCompatProxy) IsChangeEnabledByPackageName ¶
func (*PlatformCompatProxy) IsChangeEnabledByUid ¶
func (*PlatformCompatProxy) ListAllChanges ¶
func (p *PlatformCompatProxy) ListAllChanges( ctx context.Context, ) ([]CompatibilityChangeInfo, error)
func (*PlatformCompatProxy) ListUIChanges ¶
func (p *PlatformCompatProxy) ListUIChanges( ctx context.Context, ) ([]CompatibilityChangeInfo, error)
func (*PlatformCompatProxy) PutAllOverridesOnReleaseBuilds ¶
func (p *PlatformCompatProxy) PutAllOverridesOnReleaseBuilds( ctx context.Context, overridesByPackage CompatibilityOverridesByPackageConfig, ) error
func (*PlatformCompatProxy) PutOverridesOnReleaseBuilds ¶
func (p *PlatformCompatProxy) PutOverridesOnReleaseBuilds( ctx context.Context, overrides CompatibilityOverrideConfig, packageName string, ) error
func (*PlatformCompatProxy) RemoveAllOverridesOnReleaseBuilds ¶
func (p *PlatformCompatProxy) RemoveAllOverridesOnReleaseBuilds( ctx context.Context, overridesToRemoveByPackage CompatibilityOverridesToRemoveByPackageConfig, ) error
func (*PlatformCompatProxy) RemoveOverridesOnReleaseBuilds ¶
func (p *PlatformCompatProxy) RemoveOverridesOnReleaseBuilds( ctx context.Context, overridesToRemove CompatibilityOverridesToRemoveConfig, packageName string, ) error
func (*PlatformCompatProxy) ReportChange ¶
func (p *PlatformCompatProxy) ReportChange( ctx context.Context, changeId int64, appInfo pm.ApplicationInfo, ) error
func (*PlatformCompatProxy) ReportChangeByPackageName ¶
func (*PlatformCompatProxy) ReportChangeByUid ¶
func (*PlatformCompatProxy) SetOverrides ¶
func (p *PlatformCompatProxy) SetOverrides( ctx context.Context, overrides CompatibilityChangeConfig, packageName string, ) error
func (*PlatformCompatProxy) SetOverridesForTest ¶
func (p *PlatformCompatProxy) SetOverridesForTest( ctx context.Context, overrides CompatibilityChangeConfig, packageName string, ) error
type PlatformCompatStub ¶
type PlatformCompatStub struct {
Impl IPlatformCompat
Transport binder.VersionAwareTransport
}
PlatformCompatStub dispatches incoming binder transactions to a typed IPlatformCompat implementation.
func (*PlatformCompatStub) Descriptor ¶
func (s *PlatformCompatStub) Descriptor() string
func (*PlatformCompatStub) OnTransaction ¶
func (s *PlatformCompatStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)