Documentation
¶
Index ¶
- Constants
- type INetworkWatchlistManager
- type INetworkWatchlistManagerServer
- type IOemNetd
- type IOemNetdServer
- type IOemNetdUnsolicitedEventListener
- type IOemNetdUnsolicitedEventListenerServer
- type LegacyVpnInfo
- type NetworkWatchlistManagerProxy
- func (p *NetworkWatchlistManagerProxy) AsBinder() binder.IBinder
- func (p *NetworkWatchlistManagerProxy) GetWatchlistConfigHash(ctx context.Context) ([]byte, error)
- func (p *NetworkWatchlistManagerProxy) ReloadWatchlist(ctx context.Context) error
- func (p *NetworkWatchlistManagerProxy) ReportWatchlistIfNecessary(ctx context.Context) error
- func (p *NetworkWatchlistManagerProxy) StartWatchlistLogging(ctx context.Context) (bool, error)
- func (p *NetworkWatchlistManagerProxy) StopWatchlistLogging(ctx context.Context) (bool, error)
- type NetworkWatchlistManagerStub
- type OemNetdProxy
- type OemNetdStub
- type OemNetdUnsolicitedEventListenerProxy
- type OemNetdUnsolicitedEventListenerStub
- type VpnConfig
- type VpnProfile
Constants ¶
const ( TransactionINetworkWatchlistManagerStartWatchlistLogging = binder.FirstCallTransaction + 0 TransactionINetworkWatchlistManagerStopWatchlistLogging = binder.FirstCallTransaction + 1 TransactionINetworkWatchlistManagerReloadWatchlist = binder.FirstCallTransaction + 2 TransactionINetworkWatchlistManagerReportWatchlistIfNecessary = binder.FirstCallTransaction + 3 TransactionINetworkWatchlistManagerGetWatchlistConfigHash = binder.FirstCallTransaction + 4 )
const ( MethodINetworkWatchlistManagerStartWatchlistLogging = "startWatchlistLogging" MethodINetworkWatchlistManagerStopWatchlistLogging = "stopWatchlistLogging" MethodINetworkWatchlistManagerReloadWatchlist = "reloadWatchlist" MethodINetworkWatchlistManagerReportWatchlistIfNecessary = "reportWatchlistIfNecessary" MethodINetworkWatchlistManagerGetWatchlistConfigHash = "getWatchlistConfigHash" )
const ( TransactionIOemNetdIsAlive = binder.FirstCallTransaction + 0 TransactionIOemNetdRegisterOemUnsolicitedEventListener = binder.FirstCallTransaction + 1 )
const ( MethodIOemNetdIsAlive = "isAlive" MethodIOemNetdRegisterOemUnsolicitedEventListener = "registerOemUnsolicitedEventListener" )
const DescriptorINetworkWatchlistManager = "com.android.internal.net.INetworkWatchlistManager"
const DescriptorIOemNetd = "com.android.internal.net.IOemNetd"
const DescriptorIOemNetdUnsolicitedEventListener = "com.android.internal.net.IOemNetdUnsolicitedEventListener"
const (
MethodIOemNetdUnsolicitedEventListenerOnRegistered = "onRegistered"
)
const (
TransactionIOemNetdUnsolicitedEventListenerOnRegistered = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type INetworkWatchlistManager ¶
type INetworkWatchlistManager interface {
AsBinder() binder.IBinder
StartWatchlistLogging(ctx context.Context) (bool, error)
StopWatchlistLogging(ctx context.Context) (bool, error)
ReloadWatchlist(ctx context.Context) error
ReportWatchlistIfNecessary(ctx context.Context) error
GetWatchlistConfigHash(ctx context.Context) ([]byte, error)
}
func NewNetworkWatchlistManagerStub ¶
func NewNetworkWatchlistManagerStub( impl INetworkWatchlistManagerServer, ) INetworkWatchlistManager
NewNetworkWatchlistManagerStub creates a server-side INetworkWatchlistManager wrapping the given server implementation. The returned value satisfies INetworkWatchlistManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type INetworkWatchlistManagerServer ¶
type INetworkWatchlistManagerServer interface {
StartWatchlistLogging(ctx context.Context) (bool, error)
StopWatchlistLogging(ctx context.Context) (bool, error)
ReloadWatchlist(ctx context.Context) error
ReportWatchlistIfNecessary(ctx context.Context) error
GetWatchlistConfigHash(ctx context.Context) ([]byte, error)
}
INetworkWatchlistManagerServer is the server-side interface that user implementations provide to NewNetworkWatchlistManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IOemNetd ¶
type IOemNetd interface {
AsBinder() binder.IBinder
IsAlive(ctx context.Context) (bool, error)
RegisterOemUnsolicitedEventListener(ctx context.Context, listener IOemNetdUnsolicitedEventListener) error
}
func NewOemNetdStub ¶
func NewOemNetdStub( impl IOemNetdServer, ) IOemNetd
NewOemNetdStub creates a server-side IOemNetd wrapping the given server implementation. The returned value satisfies IOemNetd and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IOemNetdServer ¶
type IOemNetdServer interface {
IsAlive(ctx context.Context) (bool, error)
RegisterOemUnsolicitedEventListener(ctx context.Context, listener IOemNetdUnsolicitedEventListener) error
}
IOemNetdServer is the server-side interface that user implementations provide to NewOemNetdStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IOemNetdUnsolicitedEventListener ¶
type IOemNetdUnsolicitedEventListener interface {
AsBinder() binder.IBinder
OnRegistered(ctx context.Context) error
}
func NewOemNetdUnsolicitedEventListenerStub ¶
func NewOemNetdUnsolicitedEventListenerStub( impl IOemNetdUnsolicitedEventListenerServer, ) IOemNetdUnsolicitedEventListener
NewOemNetdUnsolicitedEventListenerStub creates a server-side IOemNetdUnsolicitedEventListener wrapping the given server implementation. The returned value satisfies IOemNetdUnsolicitedEventListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IOemNetdUnsolicitedEventListenerServer ¶
IOemNetdUnsolicitedEventListenerServer is the server-side interface that user implementations provide to NewOemNetdUnsolicitedEventListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type LegacyVpnInfo ¶
func (*LegacyVpnInfo) MarshalParcel ¶
func (s *LegacyVpnInfo) MarshalParcel( p *parcel.Parcel, ) error
func (*LegacyVpnInfo) UnmarshalParcel ¶
func (s *LegacyVpnInfo) UnmarshalParcel( p *parcel.Parcel, ) error
type NetworkWatchlistManagerProxy ¶
func GetNetworkWatchlistManager ¶
func GetNetworkWatchlistManager( ctx context.Context, sm *servicemanager.ServiceManager, ) (*NetworkWatchlistManagerProxy, error)
GetNetworkWatchlistManager retrieves the NetworkWatchlistService service and returns a typed proxy.
func NewNetworkWatchlistManagerProxy ¶
func NewNetworkWatchlistManagerProxy( remote binder.IBinder, ) *NetworkWatchlistManagerProxy
func (*NetworkWatchlistManagerProxy) AsBinder ¶
func (p *NetworkWatchlistManagerProxy) AsBinder() binder.IBinder
func (*NetworkWatchlistManagerProxy) GetWatchlistConfigHash ¶
func (p *NetworkWatchlistManagerProxy) GetWatchlistConfigHash( ctx context.Context, ) ([]byte, error)
func (*NetworkWatchlistManagerProxy) ReloadWatchlist ¶
func (p *NetworkWatchlistManagerProxy) ReloadWatchlist( ctx context.Context, ) error
func (*NetworkWatchlistManagerProxy) ReportWatchlistIfNecessary ¶
func (p *NetworkWatchlistManagerProxy) ReportWatchlistIfNecessary( ctx context.Context, ) error
func (*NetworkWatchlistManagerProxy) StartWatchlistLogging ¶
func (p *NetworkWatchlistManagerProxy) StartWatchlistLogging( ctx context.Context, ) (bool, error)
func (*NetworkWatchlistManagerProxy) StopWatchlistLogging ¶
func (p *NetworkWatchlistManagerProxy) StopWatchlistLogging( ctx context.Context, ) (bool, error)
type NetworkWatchlistManagerStub ¶
type NetworkWatchlistManagerStub struct {
Impl INetworkWatchlistManager
Transport binder.VersionAwareTransport
}
NetworkWatchlistManagerStub dispatches incoming binder transactions to a typed INetworkWatchlistManager implementation.
func (*NetworkWatchlistManagerStub) Descriptor ¶
func (s *NetworkWatchlistManagerStub) Descriptor() string
func (*NetworkWatchlistManagerStub) OnTransaction ¶
func (s *NetworkWatchlistManagerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type OemNetdProxy ¶
func NewOemNetdProxy ¶
func NewOemNetdProxy( remote binder.IBinder, ) *OemNetdProxy
func (*OemNetdProxy) AsBinder ¶
func (p *OemNetdProxy) AsBinder() binder.IBinder
func (*OemNetdProxy) RegisterOemUnsolicitedEventListener ¶
func (p *OemNetdProxy) RegisterOemUnsolicitedEventListener( ctx context.Context, listener IOemNetdUnsolicitedEventListener, ) error
type OemNetdStub ¶
type OemNetdStub struct {
Impl IOemNetd
Transport binder.VersionAwareTransport
}
OemNetdStub dispatches incoming binder transactions to a typed IOemNetd implementation.
func (*OemNetdStub) Descriptor ¶
func (s *OemNetdStub) Descriptor() string
func (*OemNetdStub) OnTransaction ¶
func (s *OemNetdStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type OemNetdUnsolicitedEventListenerProxy ¶
func NewOemNetdUnsolicitedEventListenerProxy ¶
func NewOemNetdUnsolicitedEventListenerProxy( remote binder.IBinder, ) *OemNetdUnsolicitedEventListenerProxy
func (*OemNetdUnsolicitedEventListenerProxy) AsBinder ¶
func (p *OemNetdUnsolicitedEventListenerProxy) AsBinder() binder.IBinder
func (*OemNetdUnsolicitedEventListenerProxy) OnRegistered ¶
func (p *OemNetdUnsolicitedEventListenerProxy) OnRegistered( ctx context.Context, ) error
type OemNetdUnsolicitedEventListenerStub ¶
type OemNetdUnsolicitedEventListenerStub struct {
Impl IOemNetdUnsolicitedEventListener
Transport binder.VersionAwareTransport
}
OemNetdUnsolicitedEventListenerStub dispatches incoming binder transactions to a typed IOemNetdUnsolicitedEventListener implementation.
func (*OemNetdUnsolicitedEventListenerStub) Descriptor ¶
func (s *OemNetdUnsolicitedEventListenerStub) Descriptor() string
func (*OemNetdUnsolicitedEventListenerStub) OnTransaction ¶
func (s *OemNetdUnsolicitedEventListenerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type VpnProfile ¶
type VpnProfile struct {
Key string
Name string
Type int32
Server string
Username string
Password string
DnsServers string
SearchDomains string
Routes string
L2tpSecret string
IpsecIdentifier string
IpsecSecret string
IpsecUserCert string
IpsecCaCert string
IpsecServerCert string
IsBypassable bool
IsMetered bool
MaxMtu int32
AreAuthParamsInline bool
IsRestrictedToTestNetworks bool
ExcludeLocalRoutes bool
RequiresInternetValidation bool
AutomaticNattKeepaliveTimerEnabled bool
AutomaticIpVersionSelectionEnabled bool
}
func (*VpnProfile) MarshalParcel ¶
func (s *VpnProfile) MarshalParcel( p *parcel.Parcel, ) error
func (*VpnProfile) UnmarshalParcel ¶
func (s *VpnProfile) UnmarshalParcel( p *parcel.Parcel, ) error