Documentation
¶
Index ¶
- Constants
- type AppearanceRegion
- type DragAndDropPermissionsProxy
- func (p *DragAndDropPermissionsProxy) AsBinder() binder.IBinder
- func (p *DragAndDropPermissionsProxy) Release(ctx context.Context) error
- func (p *DragAndDropPermissionsProxy) Take(ctx context.Context, activityToken binder.IBinder) error
- func (p *DragAndDropPermissionsProxy) TakeTransient(ctx context.Context) error
- type DragAndDropPermissionsStub
- type IDragAndDropPermissions
- type IDragAndDropPermissionsServer
- type IInputMethodManager
- type IInputMethodManagerServer
- type InputMethodManagerProxy
- func (p *InputMethodManagerProxy) AcceptStylusHandwritingDelegation(ctx context.Context, client internalInputmethod.IInputMethodClient, ...) (bool, error)
- func (p *InputMethodManagerProxy) AcceptStylusHandwritingDelegationAsync(ctx context.Context, client internalInputmethod.IInputMethodClient, ...) error
- func (p *InputMethodManagerProxy) AddClient(ctx context.Context, client internalInputmethod.IInputMethodClient, ...) error
- func (p *InputMethodManagerProxy) AddVirtualStylusIdForTestSession(ctx context.Context, client internalInputmethod.IInputMethodClient) error
- func (p *InputMethodManagerProxy) AsBinder() binder.IBinder
- func (p *InputMethodManagerProxy) GetCurrentInputMethodInfoAsUser(ctx context.Context) (viewInputmethod.InputMethodInfo, error)
- func (p *InputMethodManagerProxy) GetCurrentInputMethodSubtype(ctx context.Context) (viewInputmethod.InputMethodSubtype, error)
- func (p *InputMethodManagerProxy) GetEnabledInputMethodList(ctx context.Context) ([]viewInputmethod.InputMethodInfo, error)
- func (p *InputMethodManagerProxy) GetEnabledInputMethodSubtypeList(ctx context.Context, imiId string, allowsImplicitlyEnabledSubtypes bool) ([]viewInputmethod.InputMethodSubtype, error)
- func (p *InputMethodManagerProxy) GetImeTrackerService(ctx context.Context) (internalInputmethod.IImeTracker, error)
- func (p *InputMethodManagerProxy) GetInputMethodList(ctx context.Context, directBootAwareness int32) ([]viewInputmethod.InputMethodInfo, error)
- func (p *InputMethodManagerProxy) GetInputMethodWindowVisibleHeight(ctx context.Context, client internalInputmethod.IInputMethodClient) (int32, error)
- func (p *InputMethodManagerProxy) GetLastInputMethodSubtype(ctx context.Context) (viewInputmethod.InputMethodSubtype, error)
- func (p *InputMethodManagerProxy) HideSoftInput(ctx context.Context, client internalInputmethod.IInputMethodClient, ...) (bool, error)
- func (p *InputMethodManagerProxy) HideSoftInputFromServerForTest(ctx context.Context) error
- func (p *InputMethodManagerProxy) IsImeTraceEnabled(ctx context.Context) (bool, error)
- func (p *InputMethodManagerProxy) IsInputMethodPickerShownForTest(ctx context.Context) (bool, error)
- func (p *InputMethodManagerProxy) IsStylusHandwritingAvailableAsUser(ctx context.Context, connectionless bool) (bool, error)
- func (p *InputMethodManagerProxy) PrepareStylusHandwritingDelegation(ctx context.Context, client internalInputmethod.IInputMethodClient, ...) error
- func (p *InputMethodManagerProxy) RemoveImeSurface(ctx context.Context) error
- func (p *InputMethodManagerProxy) RemoveImeSurfaceFromWindowAsync(ctx context.Context, windowToken binder.IBinder) error
- func (p *InputMethodManagerProxy) ReportPerceptibleAsync(ctx context.Context, windowToken binder.IBinder, perceptible bool) error
- func (p *InputMethodManagerProxy) SetAdditionalInputMethodSubtypes(ctx context.Context, id string, subtypes []viewInputmethod.InputMethodSubtype) error
- func (p *InputMethodManagerProxy) SetExplicitlyEnabledInputMethodSubtypes(ctx context.Context, imeId string, subtypeHashCodes []int32) error
- func (p *InputMethodManagerProxy) SetStylusWindowIdleTimeoutForTest(ctx context.Context, client internalInputmethod.IInputMethodClient, ...) error
- func (p *InputMethodManagerProxy) ShowInputMethodPickerFromClient(ctx context.Context, client internalInputmethod.IInputMethodClient, ...) error
- func (p *InputMethodManagerProxy) ShowInputMethodPickerFromSystem(ctx context.Context, auxiliarySubtypeMode int32, displayId int32) error
- func (p *InputMethodManagerProxy) ShowSoftInput(ctx context.Context, client internalInputmethod.IInputMethodClient, ...) (bool, error)
- func (p *InputMethodManagerProxy) StartConnectionlessStylusHandwriting(ctx context.Context, client internalInputmethod.IInputMethodClient, ...) error
- func (p *InputMethodManagerProxy) StartImeTrace(ctx context.Context) error
- func (p *InputMethodManagerProxy) StartInputOrWindowGainedFocus(ctx context.Context, startInputReason int32, ...) (internalInputmethod.InputBindResult, error)
- func (p *InputMethodManagerProxy) StartInputOrWindowGainedFocusAsync(ctx context.Context, startInputReason int32, ...) error
- func (p *InputMethodManagerProxy) StartProtoDump(ctx context.Context, protoDump []byte, source int32, where string) error
- func (p *InputMethodManagerProxy) StartStylusHandwriting(ctx context.Context, client internalInputmethod.IInputMethodClient) error
- func (p *InputMethodManagerProxy) StopImeTrace(ctx context.Context) error
- type InputMethodManagerStub
Constants ¶
const ( TransactionIDragAndDropPermissionsTake = binder.FirstCallTransaction + 0 TransactionIDragAndDropPermissionsTakeTransient = binder.FirstCallTransaction + 1 TransactionIDragAndDropPermissionsRelease = binder.FirstCallTransaction + 2 )
const ( MethodIDragAndDropPermissionsTake = "take" MethodIDragAndDropPermissionsTakeTransient = "takeTransient" MethodIDragAndDropPermissionsRelease = "release" )
const ( TransactionIInputMethodManagerAddClient = binder.FirstCallTransaction + 0 TransactionIInputMethodManagerGetCurrentInputMethodInfoAsUser = binder.FirstCallTransaction + 1 TransactionIInputMethodManagerGetInputMethodList = binder.FirstCallTransaction + 2 TransactionIInputMethodManagerGetEnabledInputMethodList = binder.FirstCallTransaction + 3 TransactionIInputMethodManagerGetEnabledInputMethodSubtypeList = binder.FirstCallTransaction + 4 TransactionIInputMethodManagerGetLastInputMethodSubtype = binder.FirstCallTransaction + 5 TransactionIInputMethodManagerShowSoftInput = binder.FirstCallTransaction + 6 TransactionIInputMethodManagerHideSoftInput = binder.FirstCallTransaction + 7 TransactionIInputMethodManagerHideSoftInputFromServerForTest = binder.FirstCallTransaction + 8 TransactionIInputMethodManagerStartInputOrWindowGainedFocus = binder.FirstCallTransaction + 9 TransactionIInputMethodManagerStartInputOrWindowGainedFocusAsync = binder.FirstCallTransaction + 10 TransactionIInputMethodManagerShowInputMethodPickerFromClient = binder.FirstCallTransaction + 11 TransactionIInputMethodManagerShowInputMethodPickerFromSystem = binder.FirstCallTransaction + 12 TransactionIInputMethodManagerIsInputMethodPickerShownForTest = binder.FirstCallTransaction + 13 TransactionIInputMethodManagerGetCurrentInputMethodSubtype = binder.FirstCallTransaction + 14 TransactionIInputMethodManagerSetAdditionalInputMethodSubtypes = binder.FirstCallTransaction + 15 TransactionIInputMethodManagerSetExplicitlyEnabledInputMethodSubtypes = binder.FirstCallTransaction + 16 TransactionIInputMethodManagerGetInputMethodWindowVisibleHeight = binder.FirstCallTransaction + 17 TransactionIInputMethodManagerReportPerceptibleAsync = binder.FirstCallTransaction + 18 TransactionIInputMethodManagerRemoveImeSurface = binder.FirstCallTransaction + 19 TransactionIInputMethodManagerRemoveImeSurfaceFromWindowAsync = binder.FirstCallTransaction + 20 TransactionIInputMethodManagerStartProtoDump = binder.FirstCallTransaction + 21 TransactionIInputMethodManagerIsImeTraceEnabled = binder.FirstCallTransaction + 22 TransactionIInputMethodManagerStartImeTrace = binder.FirstCallTransaction + 23 TransactionIInputMethodManagerStopImeTrace = binder.FirstCallTransaction + 24 TransactionIInputMethodManagerStartStylusHandwriting = binder.FirstCallTransaction + 25 TransactionIInputMethodManagerStartConnectionlessStylusHandwriting = binder.FirstCallTransaction + 26 TransactionIInputMethodManagerPrepareStylusHandwritingDelegation = binder.FirstCallTransaction + 27 TransactionIInputMethodManagerAcceptStylusHandwritingDelegation = binder.FirstCallTransaction + 28 TransactionIInputMethodManagerAcceptStylusHandwritingDelegationAsync = binder.FirstCallTransaction + 29 TransactionIInputMethodManagerIsStylusHandwritingAvailableAsUser = binder.FirstCallTransaction + 30 TransactionIInputMethodManagerAddVirtualStylusIdForTestSession = binder.FirstCallTransaction + 31 TransactionIInputMethodManagerSetStylusWindowIdleTimeoutForTest = binder.FirstCallTransaction + 32 TransactionIInputMethodManagerGetImeTrackerService = binder.FirstCallTransaction + 33 )
const ( MethodIInputMethodManagerAddClient = "addClient" MethodIInputMethodManagerGetCurrentInputMethodInfoAsUser = "getCurrentInputMethodInfoAsUser" MethodIInputMethodManagerGetInputMethodList = "getInputMethodList" MethodIInputMethodManagerGetEnabledInputMethodList = "getEnabledInputMethodList" MethodIInputMethodManagerGetEnabledInputMethodSubtypeList = "getEnabledInputMethodSubtypeList" MethodIInputMethodManagerGetLastInputMethodSubtype = "getLastInputMethodSubtype" MethodIInputMethodManagerShowSoftInput = "showSoftInput" MethodIInputMethodManagerHideSoftInput = "hideSoftInput" MethodIInputMethodManagerHideSoftInputFromServerForTest = "hideSoftInputFromServerForTest" MethodIInputMethodManagerStartInputOrWindowGainedFocus = "startInputOrWindowGainedFocus" MethodIInputMethodManagerStartInputOrWindowGainedFocusAsync = "startInputOrWindowGainedFocusAsync" MethodIInputMethodManagerShowInputMethodPickerFromClient = "showInputMethodPickerFromClient" MethodIInputMethodManagerShowInputMethodPickerFromSystem = "showInputMethodPickerFromSystem" MethodIInputMethodManagerIsInputMethodPickerShownForTest = "isInputMethodPickerShownForTest" MethodIInputMethodManagerGetCurrentInputMethodSubtype = "getCurrentInputMethodSubtype" MethodIInputMethodManagerSetAdditionalInputMethodSubtypes = "setAdditionalInputMethodSubtypes" MethodIInputMethodManagerSetExplicitlyEnabledInputMethodSubtypes = "setExplicitlyEnabledInputMethodSubtypes" MethodIInputMethodManagerGetInputMethodWindowVisibleHeight = "getInputMethodWindowVisibleHeight" MethodIInputMethodManagerReportPerceptibleAsync = "reportPerceptibleAsync" MethodIInputMethodManagerRemoveImeSurface = "removeImeSurface" MethodIInputMethodManagerRemoveImeSurfaceFromWindowAsync = "removeImeSurfaceFromWindowAsync" MethodIInputMethodManagerStartProtoDump = "startProtoDump" MethodIInputMethodManagerIsImeTraceEnabled = "isImeTraceEnabled" MethodIInputMethodManagerStartImeTrace = "startImeTrace" MethodIInputMethodManagerStopImeTrace = "stopImeTrace" MethodIInputMethodManagerStartStylusHandwriting = "startStylusHandwriting" MethodIInputMethodManagerStartConnectionlessStylusHandwriting = "startConnectionlessStylusHandwriting" MethodIInputMethodManagerPrepareStylusHandwritingDelegation = "prepareStylusHandwritingDelegation" MethodIInputMethodManagerAcceptStylusHandwritingDelegation = "acceptStylusHandwritingDelegation" MethodIInputMethodManagerAcceptStylusHandwritingDelegationAsync = "acceptStylusHandwritingDelegationAsync" MethodIInputMethodManagerIsStylusHandwritingAvailableAsUser = "isStylusHandwritingAvailableAsUser" MethodIInputMethodManagerAddVirtualStylusIdForTestSession = "addVirtualStylusIdForTestSession" MethodIInputMethodManagerSetStylusWindowIdleTimeoutForTest = "setStylusWindowIdleTimeoutForTest" MethodIInputMethodManagerGetImeTrackerService = "getImeTrackerService" )
const DescriptorIDragAndDropPermissions = "com.android.internal.view.IDragAndDropPermissions"
const DescriptorIInputMethodManager = "com.android.internal.view.IInputMethodManager"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AppearanceRegion ¶
type AppearanceRegion struct {
Appearance int32
}
func (*AppearanceRegion) MarshalParcel ¶
func (s *AppearanceRegion) MarshalParcel( p *parcel.Parcel, ) error
func (*AppearanceRegion) UnmarshalParcel ¶
func (s *AppearanceRegion) UnmarshalParcel( p *parcel.Parcel, ) error
type DragAndDropPermissionsProxy ¶
func NewDragAndDropPermissionsProxy ¶
func NewDragAndDropPermissionsProxy( remote binder.IBinder, ) *DragAndDropPermissionsProxy
func (*DragAndDropPermissionsProxy) AsBinder ¶
func (p *DragAndDropPermissionsProxy) AsBinder() binder.IBinder
func (*DragAndDropPermissionsProxy) Release ¶
func (p *DragAndDropPermissionsProxy) Release( ctx context.Context, ) error
func (*DragAndDropPermissionsProxy) TakeTransient ¶
func (p *DragAndDropPermissionsProxy) TakeTransient( ctx context.Context, ) error
type DragAndDropPermissionsStub ¶
type DragAndDropPermissionsStub struct {
Impl IDragAndDropPermissions
Transport binder.VersionAwareTransport
}
DragAndDropPermissionsStub dispatches incoming binder transactions to a typed IDragAndDropPermissions implementation.
func (*DragAndDropPermissionsStub) Descriptor ¶
func (s *DragAndDropPermissionsStub) Descriptor() string
func (*DragAndDropPermissionsStub) OnTransaction ¶
func (s *DragAndDropPermissionsStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type IDragAndDropPermissions ¶
type IDragAndDropPermissions interface {
AsBinder() binder.IBinder
Take(ctx context.Context, activityToken binder.IBinder) error
TakeTransient(ctx context.Context) error
Release(ctx context.Context) error
}
func NewDragAndDropPermissionsStub ¶
func NewDragAndDropPermissionsStub( impl IDragAndDropPermissionsServer, ) IDragAndDropPermissions
NewDragAndDropPermissionsStub creates a server-side IDragAndDropPermissions wrapping the given server implementation. The returned value satisfies IDragAndDropPermissions and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IDragAndDropPermissionsServer ¶
type IDragAndDropPermissionsServer interface {
Take(ctx context.Context, activityToken binder.IBinder) error
TakeTransient(ctx context.Context) error
Release(ctx context.Context) error
}
IDragAndDropPermissionsServer is the server-side interface that user implementations provide to NewDragAndDropPermissionsStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IInputMethodManager ¶
type IInputMethodManager interface {
AsBinder() binder.IBinder
AddClient(ctx context.Context, client internalInputmethod.IInputMethodClient, inputmethod internalInputmethod.IRemoteInputConnection, untrustedDisplayId int32) error
GetCurrentInputMethodInfoAsUser(ctx context.Context) (viewInputmethod.InputMethodInfo, error)
GetInputMethodList(ctx context.Context, directBootAwareness int32) ([]viewInputmethod.InputMethodInfo, error)
GetEnabledInputMethodList(ctx context.Context) ([]viewInputmethod.InputMethodInfo, error)
GetEnabledInputMethodSubtypeList(ctx context.Context, imiId string, allowsImplicitlyEnabledSubtypes bool) ([]viewInputmethod.InputMethodSubtype, error)
GetLastInputMethodSubtype(ctx context.Context) (viewInputmethod.InputMethodSubtype, error)
ShowSoftInput(ctx context.Context, client internalInputmethod.IInputMethodClient, windowToken binder.IBinder, statsToken viewInputmethod.ImeTrackerToken, flags int32, lastClickToolType int32, resultReceiver *os.ResultReceiver, reason int32) (bool, error)
HideSoftInput(ctx context.Context, client internalInputmethod.IInputMethodClient, windowToken binder.IBinder, statsToken viewInputmethod.ImeTrackerToken, flags int32, resultReceiver *os.ResultReceiver, reason int32) (bool, error)
HideSoftInputFromServerForTest(ctx context.Context) error
StartInputOrWindowGainedFocus(ctx context.Context, startInputReason int32, client internalInputmethod.IInputMethodClient, windowToken binder.IBinder, startInputFlags int32, softInputMode int32, windowFlags int32, editorInfo *viewInputmethod.EditorInfo, inputConnection internalInputmethod.IRemoteInputConnection, remoteAccessibilityInputConnection internalInputmethod.IRemoteAccessibilityInputConnection, unverifiedTargetSdkVersion int32, imeDispatcher window.ImeOnBackInvokedDispatcher) (internalInputmethod.InputBindResult, error)
StartInputOrWindowGainedFocusAsync(ctx context.Context, startInputReason int32, client internalInputmethod.IInputMethodClient, windowToken binder.IBinder, startInputFlags int32, softInputMode int32, windowFlags int32, editorInfo *viewInputmethod.EditorInfo, inputConnection internalInputmethod.IRemoteInputConnection, remoteAccessibilityInputConnection internalInputmethod.IRemoteAccessibilityInputConnection, unverifiedTargetSdkVersion int32, imeDispatcher window.ImeOnBackInvokedDispatcher, startInputSeq int32) error
ShowInputMethodPickerFromClient(ctx context.Context, client internalInputmethod.IInputMethodClient, auxiliarySubtypeMode int32) error
ShowInputMethodPickerFromSystem(ctx context.Context, auxiliarySubtypeMode int32, displayId int32) error
IsInputMethodPickerShownForTest(ctx context.Context) (bool, error)
GetCurrentInputMethodSubtype(ctx context.Context) (viewInputmethod.InputMethodSubtype, error)
SetAdditionalInputMethodSubtypes(ctx context.Context, id string, subtypes []viewInputmethod.InputMethodSubtype) error
SetExplicitlyEnabledInputMethodSubtypes(ctx context.Context, imeId string, subtypeHashCodes []int32) error
GetInputMethodWindowVisibleHeight(ctx context.Context, client internalInputmethod.IInputMethodClient) (int32, error)
ReportPerceptibleAsync(ctx context.Context, windowToken binder.IBinder, perceptible bool) error
RemoveImeSurface(ctx context.Context) error
RemoveImeSurfaceFromWindowAsync(ctx context.Context, windowToken binder.IBinder) error
StartProtoDump(ctx context.Context, protoDump []byte, source int32, where string) error
IsImeTraceEnabled(ctx context.Context) (bool, error)
StartImeTrace(ctx context.Context) error
StopImeTrace(ctx context.Context) error
StartStylusHandwriting(ctx context.Context, client internalInputmethod.IInputMethodClient) error
StartConnectionlessStylusHandwriting(ctx context.Context, client internalInputmethod.IInputMethodClient, cursorAnchorInfo viewInputmethod.CursorAnchorInfo, delegatePackageName string, delegatorPackageName string, callback internalInputmethod.IConnectionlessHandwritingCallback) error
PrepareStylusHandwritingDelegation(ctx context.Context, client internalInputmethod.IInputMethodClient, delegatePackageName string, delegatorPackageName string) error
AcceptStylusHandwritingDelegation(ctx context.Context, client internalInputmethod.IInputMethodClient, delegatePackageName string, delegatorPackageName string, flags int32) (bool, error)
AcceptStylusHandwritingDelegationAsync(ctx context.Context, client internalInputmethod.IInputMethodClient, delegatePackageName string, delegatorPackageName string, flags int32, callback internalInputmethod.IBooleanListener) error
IsStylusHandwritingAvailableAsUser(ctx context.Context, connectionless bool) (bool, error)
AddVirtualStylusIdForTestSession(ctx context.Context, client internalInputmethod.IInputMethodClient) error
SetStylusWindowIdleTimeoutForTest(ctx context.Context, client internalInputmethod.IInputMethodClient, timeout int64) error
GetImeTrackerService(ctx context.Context) (internalInputmethod.IImeTracker, error)
}
func NewInputMethodManagerStub ¶
func NewInputMethodManagerStub( impl IInputMethodManagerServer, ) IInputMethodManager
NewInputMethodManagerStub creates a server-side IInputMethodManager wrapping the given server implementation. The returned value satisfies IInputMethodManager and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IInputMethodManagerServer ¶
type IInputMethodManagerServer interface {
AddClient(ctx context.Context, client internalInputmethod.IInputMethodClient, inputmethod internalInputmethod.IRemoteInputConnection, untrustedDisplayId int32) error
GetCurrentInputMethodInfoAsUser(ctx context.Context) (viewInputmethod.InputMethodInfo, error)
GetInputMethodList(ctx context.Context, directBootAwareness int32) ([]viewInputmethod.InputMethodInfo, error)
GetEnabledInputMethodList(ctx context.Context) ([]viewInputmethod.InputMethodInfo, error)
GetEnabledInputMethodSubtypeList(ctx context.Context, imiId string, allowsImplicitlyEnabledSubtypes bool) ([]viewInputmethod.InputMethodSubtype, error)
GetLastInputMethodSubtype(ctx context.Context) (viewInputmethod.InputMethodSubtype, error)
ShowSoftInput(ctx context.Context, client internalInputmethod.IInputMethodClient, windowToken binder.IBinder, statsToken viewInputmethod.ImeTrackerToken, flags int32, lastClickToolType int32, resultReceiver *os.ResultReceiver, reason int32) (bool, error)
HideSoftInput(ctx context.Context, client internalInputmethod.IInputMethodClient, windowToken binder.IBinder, statsToken viewInputmethod.ImeTrackerToken, flags int32, resultReceiver *os.ResultReceiver, reason int32) (bool, error)
HideSoftInputFromServerForTest(ctx context.Context) error
StartInputOrWindowGainedFocus(ctx context.Context, startInputReason int32, client internalInputmethod.IInputMethodClient, windowToken binder.IBinder, startInputFlags int32, softInputMode int32, windowFlags int32, editorInfo *viewInputmethod.EditorInfo, inputConnection internalInputmethod.IRemoteInputConnection, remoteAccessibilityInputConnection internalInputmethod.IRemoteAccessibilityInputConnection, unverifiedTargetSdkVersion int32, imeDispatcher window.ImeOnBackInvokedDispatcher) (internalInputmethod.InputBindResult, error)
StartInputOrWindowGainedFocusAsync(ctx context.Context, startInputReason int32, client internalInputmethod.IInputMethodClient, windowToken binder.IBinder, startInputFlags int32, softInputMode int32, windowFlags int32, editorInfo *viewInputmethod.EditorInfo, inputConnection internalInputmethod.IRemoteInputConnection, remoteAccessibilityInputConnection internalInputmethod.IRemoteAccessibilityInputConnection, unverifiedTargetSdkVersion int32, imeDispatcher window.ImeOnBackInvokedDispatcher, startInputSeq int32) error
ShowInputMethodPickerFromClient(ctx context.Context, client internalInputmethod.IInputMethodClient, auxiliarySubtypeMode int32) error
ShowInputMethodPickerFromSystem(ctx context.Context, auxiliarySubtypeMode int32, displayId int32) error
IsInputMethodPickerShownForTest(ctx context.Context) (bool, error)
GetCurrentInputMethodSubtype(ctx context.Context) (viewInputmethod.InputMethodSubtype, error)
SetAdditionalInputMethodSubtypes(ctx context.Context, id string, subtypes []viewInputmethod.InputMethodSubtype) error
SetExplicitlyEnabledInputMethodSubtypes(ctx context.Context, imeId string, subtypeHashCodes []int32) error
GetInputMethodWindowVisibleHeight(ctx context.Context, client internalInputmethod.IInputMethodClient) (int32, error)
ReportPerceptibleAsync(ctx context.Context, windowToken binder.IBinder, perceptible bool) error
RemoveImeSurface(ctx context.Context) error
RemoveImeSurfaceFromWindowAsync(ctx context.Context, windowToken binder.IBinder) error
StartProtoDump(ctx context.Context, protoDump []byte, source int32, where string) error
IsImeTraceEnabled(ctx context.Context) (bool, error)
StartImeTrace(ctx context.Context) error
StopImeTrace(ctx context.Context) error
StartStylusHandwriting(ctx context.Context, client internalInputmethod.IInputMethodClient) error
StartConnectionlessStylusHandwriting(ctx context.Context, client internalInputmethod.IInputMethodClient, cursorAnchorInfo viewInputmethod.CursorAnchorInfo, delegatePackageName string, delegatorPackageName string, callback internalInputmethod.IConnectionlessHandwritingCallback) error
PrepareStylusHandwritingDelegation(ctx context.Context, client internalInputmethod.IInputMethodClient, delegatePackageName string, delegatorPackageName string) error
AcceptStylusHandwritingDelegation(ctx context.Context, client internalInputmethod.IInputMethodClient, delegatePackageName string, delegatorPackageName string, flags int32) (bool, error)
AcceptStylusHandwritingDelegationAsync(ctx context.Context, client internalInputmethod.IInputMethodClient, delegatePackageName string, delegatorPackageName string, flags int32, callback internalInputmethod.IBooleanListener) error
IsStylusHandwritingAvailableAsUser(ctx context.Context, connectionless bool) (bool, error)
AddVirtualStylusIdForTestSession(ctx context.Context, client internalInputmethod.IInputMethodClient) error
SetStylusWindowIdleTimeoutForTest(ctx context.Context, client internalInputmethod.IInputMethodClient, timeout int64) error
GetImeTrackerService(ctx context.Context) (internalInputmethod.IImeTracker, error)
}
IInputMethodManagerServer is the server-side interface that user implementations provide to NewInputMethodManagerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type InputMethodManagerProxy ¶
func NewInputMethodManagerProxy ¶
func NewInputMethodManagerProxy( remote binder.IBinder, ) *InputMethodManagerProxy
func (*InputMethodManagerProxy) AcceptStylusHandwritingDelegation ¶
func (p *InputMethodManagerProxy) AcceptStylusHandwritingDelegation( ctx context.Context, client internalInputmethod.IInputMethodClient, delegatePackageName string, delegatorPackageName string, flags int32, ) (bool, error)
func (*InputMethodManagerProxy) AcceptStylusHandwritingDelegationAsync ¶
func (p *InputMethodManagerProxy) AcceptStylusHandwritingDelegationAsync( ctx context.Context, client internalInputmethod.IInputMethodClient, delegatePackageName string, delegatorPackageName string, flags int32, callback internalInputmethod.IBooleanListener, ) error
func (*InputMethodManagerProxy) AddClient ¶
func (p *InputMethodManagerProxy) AddClient( ctx context.Context, client internalInputmethod.IInputMethodClient, inputmethod internalInputmethod.IRemoteInputConnection, untrustedDisplayId int32, ) error
func (*InputMethodManagerProxy) AddVirtualStylusIdForTestSession ¶
func (p *InputMethodManagerProxy) AddVirtualStylusIdForTestSession( ctx context.Context, client internalInputmethod.IInputMethodClient, ) error
func (*InputMethodManagerProxy) AsBinder ¶
func (p *InputMethodManagerProxy) AsBinder() binder.IBinder
func (*InputMethodManagerProxy) GetCurrentInputMethodInfoAsUser ¶
func (p *InputMethodManagerProxy) GetCurrentInputMethodInfoAsUser( ctx context.Context, ) (viewInputmethod.InputMethodInfo, error)
func (*InputMethodManagerProxy) GetCurrentInputMethodSubtype ¶
func (p *InputMethodManagerProxy) GetCurrentInputMethodSubtype( ctx context.Context, ) (viewInputmethod.InputMethodSubtype, error)
func (*InputMethodManagerProxy) GetEnabledInputMethodList ¶
func (p *InputMethodManagerProxy) GetEnabledInputMethodList( ctx context.Context, ) ([]viewInputmethod.InputMethodInfo, error)
func (*InputMethodManagerProxy) GetEnabledInputMethodSubtypeList ¶
func (p *InputMethodManagerProxy) GetEnabledInputMethodSubtypeList( ctx context.Context, imiId string, allowsImplicitlyEnabledSubtypes bool, ) ([]viewInputmethod.InputMethodSubtype, error)
func (*InputMethodManagerProxy) GetImeTrackerService ¶
func (p *InputMethodManagerProxy) GetImeTrackerService( ctx context.Context, ) (internalInputmethod.IImeTracker, error)
func (*InputMethodManagerProxy) GetInputMethodList ¶
func (p *InputMethodManagerProxy) GetInputMethodList( ctx context.Context, directBootAwareness int32, ) ([]viewInputmethod.InputMethodInfo, error)
func (*InputMethodManagerProxy) GetInputMethodWindowVisibleHeight ¶
func (p *InputMethodManagerProxy) GetInputMethodWindowVisibleHeight( ctx context.Context, client internalInputmethod.IInputMethodClient, ) (int32, error)
func (*InputMethodManagerProxy) GetLastInputMethodSubtype ¶
func (p *InputMethodManagerProxy) GetLastInputMethodSubtype( ctx context.Context, ) (viewInputmethod.InputMethodSubtype, error)
func (*InputMethodManagerProxy) HideSoftInput ¶
func (p *InputMethodManagerProxy) HideSoftInput( ctx context.Context, client internalInputmethod.IInputMethodClient, windowToken binder.IBinder, statsToken viewInputmethod.ImeTrackerToken, flags int32, resultReceiver *os.ResultReceiver, reason int32, ) (bool, error)
func (*InputMethodManagerProxy) HideSoftInputFromServerForTest ¶
func (p *InputMethodManagerProxy) HideSoftInputFromServerForTest( ctx context.Context, ) error
func (*InputMethodManagerProxy) IsImeTraceEnabled ¶
func (p *InputMethodManagerProxy) IsImeTraceEnabled( ctx context.Context, ) (bool, error)
func (*InputMethodManagerProxy) IsInputMethodPickerShownForTest ¶
func (p *InputMethodManagerProxy) IsInputMethodPickerShownForTest( ctx context.Context, ) (bool, error)
func (*InputMethodManagerProxy) IsStylusHandwritingAvailableAsUser ¶
func (*InputMethodManagerProxy) PrepareStylusHandwritingDelegation ¶
func (p *InputMethodManagerProxy) PrepareStylusHandwritingDelegation( ctx context.Context, client internalInputmethod.IInputMethodClient, delegatePackageName string, delegatorPackageName string, ) error
func (*InputMethodManagerProxy) RemoveImeSurface ¶
func (p *InputMethodManagerProxy) RemoveImeSurface( ctx context.Context, ) error
func (*InputMethodManagerProxy) RemoveImeSurfaceFromWindowAsync ¶
func (*InputMethodManagerProxy) ReportPerceptibleAsync ¶
func (*InputMethodManagerProxy) SetAdditionalInputMethodSubtypes ¶
func (p *InputMethodManagerProxy) SetAdditionalInputMethodSubtypes( ctx context.Context, id string, subtypes []viewInputmethod.InputMethodSubtype, ) error
func (*InputMethodManagerProxy) SetExplicitlyEnabledInputMethodSubtypes ¶
func (*InputMethodManagerProxy) SetStylusWindowIdleTimeoutForTest ¶
func (p *InputMethodManagerProxy) SetStylusWindowIdleTimeoutForTest( ctx context.Context, client internalInputmethod.IInputMethodClient, timeout int64, ) error
func (*InputMethodManagerProxy) ShowInputMethodPickerFromClient ¶
func (p *InputMethodManagerProxy) ShowInputMethodPickerFromClient( ctx context.Context, client internalInputmethod.IInputMethodClient, auxiliarySubtypeMode int32, ) error
func (*InputMethodManagerProxy) ShowInputMethodPickerFromSystem ¶
func (*InputMethodManagerProxy) ShowSoftInput ¶
func (p *InputMethodManagerProxy) ShowSoftInput( ctx context.Context, client internalInputmethod.IInputMethodClient, windowToken binder.IBinder, statsToken viewInputmethod.ImeTrackerToken, flags int32, lastClickToolType int32, resultReceiver *os.ResultReceiver, reason int32, ) (bool, error)
func (*InputMethodManagerProxy) StartConnectionlessStylusHandwriting ¶
func (p *InputMethodManagerProxy) StartConnectionlessStylusHandwriting( ctx context.Context, client internalInputmethod.IInputMethodClient, cursorAnchorInfo viewInputmethod.CursorAnchorInfo, delegatePackageName string, delegatorPackageName string, callback internalInputmethod.IConnectionlessHandwritingCallback, ) error
func (*InputMethodManagerProxy) StartImeTrace ¶
func (p *InputMethodManagerProxy) StartImeTrace( ctx context.Context, ) error
func (*InputMethodManagerProxy) StartInputOrWindowGainedFocus ¶
func (p *InputMethodManagerProxy) StartInputOrWindowGainedFocus( ctx context.Context, startInputReason int32, client internalInputmethod.IInputMethodClient, windowToken binder.IBinder, startInputFlags int32, softInputMode int32, windowFlags int32, editorInfo *viewInputmethod.EditorInfo, inputConnection internalInputmethod.IRemoteInputConnection, remoteAccessibilityInputConnection internalInputmethod.IRemoteAccessibilityInputConnection, unverifiedTargetSdkVersion int32, imeDispatcher window.ImeOnBackInvokedDispatcher, ) (internalInputmethod.InputBindResult, error)
func (*InputMethodManagerProxy) StartInputOrWindowGainedFocusAsync ¶
func (p *InputMethodManagerProxy) StartInputOrWindowGainedFocusAsync( ctx context.Context, startInputReason int32, client internalInputmethod.IInputMethodClient, windowToken binder.IBinder, startInputFlags int32, softInputMode int32, windowFlags int32, editorInfo *viewInputmethod.EditorInfo, inputConnection internalInputmethod.IRemoteInputConnection, remoteAccessibilityInputConnection internalInputmethod.IRemoteAccessibilityInputConnection, unverifiedTargetSdkVersion int32, imeDispatcher window.ImeOnBackInvokedDispatcher, startInputSeq int32, ) error
func (*InputMethodManagerProxy) StartProtoDump ¶
func (*InputMethodManagerProxy) StartStylusHandwriting ¶
func (p *InputMethodManagerProxy) StartStylusHandwriting( ctx context.Context, client internalInputmethod.IInputMethodClient, ) error
func (*InputMethodManagerProxy) StopImeTrace ¶
func (p *InputMethodManagerProxy) StopImeTrace( ctx context.Context, ) error
type InputMethodManagerStub ¶
type InputMethodManagerStub struct {
Impl IInputMethodManager
Transport binder.VersionAwareTransport
}
InputMethodManagerStub dispatches incoming binder transactions to a typed IInputMethodManager implementation.
func (*InputMethodManagerStub) Descriptor ¶
func (s *InputMethodManagerStub) Descriptor() string
func (*InputMethodManagerStub) OnTransaction ¶
func (s *InputMethodManagerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)