Documentation
¶
Index ¶
- Constants
- type IOverviewProxy
- type IOverviewProxyServer
- type ISystemUiProxy
- type ISystemUiProxyServer
- type OverviewProxyProxy
- func (p *OverviewProxyProxy) AsBinder() binder.IBinder
- func (p *OverviewProxyProxy) Disable(ctx context.Context, displayId int32, state1 int32, state2 int32, animate bool) error
- func (p *OverviewProxyProxy) EnterStageSplitFromRunningApp(ctx context.Context, leftOrTop bool) error
- func (p *OverviewProxyProxy) OnActiveNavBarRegionChanges(ctx context.Context, activeRegion graphics.Region) error
- func (p *OverviewProxyProxy) OnAssistantAvailable(ctx context.Context, available bool, longPressHomeEnabled bool) error
- func (p *OverviewProxyProxy) OnAssistantOverrideInvoked(ctx context.Context, invocationType int32) error
- func (p *OverviewProxyProxy) OnAssistantVisibilityChanged(ctx context.Context, visibility float32) error
- func (p *OverviewProxyProxy) OnInitialize(ctx context.Context, params os.Bundle) error
- func (p *OverviewProxyProxy) OnNavButtonsDarkIntensityChanged(ctx context.Context, darkIntensity float32) error
- func (p *OverviewProxyProxy) OnNavigationBarLumaSamplingEnabled(ctx context.Context, displayId int32, enable bool) error
- func (p *OverviewProxyProxy) OnOverviewHidden(ctx context.Context, triggeredFromAltTab bool, triggeredFromHomeKey bool) error
- func (p *OverviewProxyProxy) OnOverviewShown(ctx context.Context, triggeredFromAltTab bool) error
- func (p *OverviewProxyProxy) OnOverviewToggle(ctx context.Context) error
- func (p *OverviewProxyProxy) OnRotationProposal(ctx context.Context, rotation int32, isValid bool) error
- func (p *OverviewProxyProxy) OnSystemBarAttributesChanged(ctx context.Context, displayId int32, behavior int32) error
- func (p *OverviewProxyProxy) OnSystemUiStateChanged(ctx context.Context, stateFlags int32) error
- func (p *OverviewProxyProxy) OnTaskbarToggled(ctx context.Context) error
- type OverviewProxyStub
- type SystemUiProxyProxy
- func (p *SystemUiProxyProxy) AnimateNavBarLongPress(ctx context.Context, isTouchDown bool, shrink bool, durationMs int64) error
- func (p *SystemUiProxyProxy) AsBinder() binder.IBinder
- func (p *SystemUiProxyProxy) ExpandNotificationPanel(ctx context.Context) error
- func (p *SystemUiProxyProxy) NotifyAccessibilityButtonClicked(ctx context.Context, displayId int32) error
- func (p *SystemUiProxyProxy) NotifyAccessibilityButtonLongClicked(ctx context.Context) error
- func (p *SystemUiProxyProxy) NotifyPrioritizedRotation(ctx context.Context, rotation int32) error
- func (p *SystemUiProxyProxy) NotifyTaskbarAutohideSuspend(ctx context.Context, suspend bool) error
- func (p *SystemUiProxyProxy) NotifyTaskbarStatus(ctx context.Context, visible bool, stashed bool) error
- func (p *SystemUiProxyProxy) OnAssistantGestureCompletion(ctx context.Context, velocity float32) error
- func (p *SystemUiProxyProxy) OnAssistantProgress(ctx context.Context, progress float32) error
- func (p *SystemUiProxyProxy) OnBackPressed(ctx context.Context) error
- func (p *SystemUiProxyProxy) OnImeSwitcherPressed(ctx context.Context) error
- func (p *SystemUiProxyProxy) OnOverviewShown(ctx context.Context, fromHome bool) error
- func (p *SystemUiProxyProxy) OnStatusBarTouchEvent(ctx context.Context, event view.MotionEvent) error
- func (p *SystemUiProxyProxy) OnStatusBarTrackpadEvent(ctx context.Context, event view.MotionEvent) error
- func (p *SystemUiProxyProxy) SetAssistantOverridesRequested(ctx context.Context, invocationTypes []int32) error
- func (p *SystemUiProxyProxy) SetHomeRotationEnabled(ctx context.Context, enabled bool) error
- func (p *SystemUiProxyProxy) StartAssistant(ctx context.Context, bundle os.Bundle) error
- func (p *SystemUiProxyProxy) StartScreenPinning(ctx context.Context, taskId int32) error
- func (p *SystemUiProxyProxy) StopScreenPinning(ctx context.Context) error
- func (p *SystemUiProxyProxy) TakeScreenshot(ctx context.Context, request util.ScreenshotRequest) error
- func (p *SystemUiProxyProxy) ToggleNotificationPanel(ctx context.Context) error
- type SystemUiProxyStub
Constants ¶
const ( TransactionIOverviewProxyOnInitialize = binder.FirstCallTransaction + 11 TransactionIOverviewProxyOnOverviewToggle = binder.FirstCallTransaction + 5 TransactionIOverviewProxyOnOverviewShown = binder.FirstCallTransaction + 6 TransactionIOverviewProxyOnOverviewHidden = binder.FirstCallTransaction + 7 TransactionIOverviewProxyOnAssistantAvailable = binder.FirstCallTransaction + 12 TransactionIOverviewProxyOnAssistantVisibilityChanged = binder.FirstCallTransaction + 13 TransactionIOverviewProxyOnAssistantOverrideInvoked = binder.FirstCallTransaction + 27 TransactionIOverviewProxyOnSystemUiStateChanged = binder.FirstCallTransaction + 15 TransactionIOverviewProxyOnRotationProposal = binder.FirstCallTransaction + 17 TransactionIOverviewProxyDisable = binder.FirstCallTransaction + 18 TransactionIOverviewProxyOnSystemBarAttributesChanged = binder.FirstCallTransaction + 19 TransactionIOverviewProxyEnterStageSplitFromRunningApp = binder.FirstCallTransaction + 24 TransactionIOverviewProxyOnTaskbarToggled = binder.FirstCallTransaction + 26 )
const ( MethodIOverviewProxyOnInitialize = "onInitialize" MethodIOverviewProxyOnOverviewToggle = "onOverviewToggle" MethodIOverviewProxyOnOverviewShown = "onOverviewShown" MethodIOverviewProxyOnOverviewHidden = "onOverviewHidden" MethodIOverviewProxyOnAssistantAvailable = "onAssistantAvailable" MethodIOverviewProxyOnAssistantVisibilityChanged = "onAssistantVisibilityChanged" MethodIOverviewProxyOnAssistantOverrideInvoked = "onAssistantOverrideInvoked" MethodIOverviewProxyOnSystemUiStateChanged = "onSystemUiStateChanged" MethodIOverviewProxyOnRotationProposal = "onRotationProposal" MethodIOverviewProxyDisable = "disable" MethodIOverviewProxyOnSystemBarAttributesChanged = "onSystemBarAttributesChanged" MethodIOverviewProxyEnterStageSplitFromRunningApp = "enterStageSplitFromRunningApp" MethodIOverviewProxyOnTaskbarToggled = "onTaskbarToggled" )
const ( TransactionISystemUiProxyStartScreenPinning = binder.FirstCallTransaction + 0 TransactionISystemUiProxyOnOverviewShown = binder.FirstCallTransaction + 5 TransactionISystemUiProxyOnStatusBarTouchEvent = binder.FirstCallTransaction + 8 TransactionISystemUiProxyOnAssistantProgress = binder.FirstCallTransaction + 11 TransactionISystemUiProxyOnAssistantGestureCompletion = binder.FirstCallTransaction + 17 TransactionISystemUiProxyStartAssistant = binder.FirstCallTransaction + 12 TransactionISystemUiProxySetAssistantOverridesRequested = binder.FirstCallTransaction + 52 TransactionISystemUiProxyNotifyAccessibilityButtonClicked = binder.FirstCallTransaction + 14 TransactionISystemUiProxyNotifyAccessibilityButtonLongClicked = binder.FirstCallTransaction + 15 TransactionISystemUiProxyStopScreenPinning = binder.FirstCallTransaction + 16 TransactionISystemUiProxyNotifyPrioritizedRotation = binder.FirstCallTransaction + 24 TransactionISystemUiProxyExpandNotificationPanel = binder.FirstCallTransaction + 28 TransactionISystemUiProxyOnBackPressed = binder.FirstCallTransaction + 43 TransactionISystemUiProxySetHomeRotationEnabled = binder.FirstCallTransaction + 44 TransactionISystemUiProxyNotifyTaskbarStatus = binder.FirstCallTransaction + 46 TransactionISystemUiProxyNotifyTaskbarAutohideSuspend = binder.FirstCallTransaction + 47 TransactionISystemUiProxyOnImeSwitcherPressed = binder.FirstCallTransaction + 48 TransactionISystemUiProxyToggleNotificationPanel = binder.FirstCallTransaction + 49 TransactionISystemUiProxyTakeScreenshot = binder.FirstCallTransaction + 50 TransactionISystemUiProxyOnStatusBarTrackpadEvent = binder.FirstCallTransaction + 51 )
const ( MethodISystemUiProxyStartScreenPinning = "startScreenPinning" MethodISystemUiProxyOnOverviewShown = "onOverviewShown" MethodISystemUiProxyOnStatusBarTouchEvent = "onStatusBarTouchEvent" MethodISystemUiProxyOnAssistantProgress = "onAssistantProgress" MethodISystemUiProxyOnAssistantGestureCompletion = "onAssistantGestureCompletion" MethodISystemUiProxyStartAssistant = "startAssistant" MethodISystemUiProxySetAssistantOverridesRequested = "setAssistantOverridesRequested" MethodISystemUiProxyNotifyAccessibilityButtonClicked = "notifyAccessibilityButtonClicked" MethodISystemUiProxyNotifyAccessibilityButtonLongClicked = "notifyAccessibilityButtonLongClicked" MethodISystemUiProxyStopScreenPinning = "stopScreenPinning" MethodISystemUiProxyNotifyPrioritizedRotation = "notifyPrioritizedRotation" MethodISystemUiProxyExpandNotificationPanel = "expandNotificationPanel" MethodISystemUiProxyOnBackPressed = "onBackPressed" MethodISystemUiProxySetHomeRotationEnabled = "setHomeRotationEnabled" MethodISystemUiProxyNotifyTaskbarStatus = "notifyTaskbarStatus" MethodISystemUiProxyNotifyTaskbarAutohideSuspend = "notifyTaskbarAutohideSuspend" MethodISystemUiProxyOnImeSwitcherPressed = "onImeSwitcherPressed" MethodISystemUiProxyToggleNotificationPanel = "toggleNotificationPanel" MethodISystemUiProxyTakeScreenshot = "takeScreenshot" MethodISystemUiProxyOnStatusBarTrackpadEvent = "onStatusBarTrackpadEvent" )
const DescriptorIOverviewProxy = "com.android.systemui.shared.recents.IOverviewProxy"
const DescriptorISystemUiProxy = "com.android.systemui.shared.recents.ISystemUiProxy"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IOverviewProxy ¶
type IOverviewProxy interface {
AsBinder() binder.IBinder
OnInitialize(ctx context.Context, params os.Bundle) error
OnOverviewToggle(ctx context.Context) error
OnOverviewShown(ctx context.Context, triggeredFromAltTab bool) error
OnOverviewHidden(ctx context.Context, triggeredFromAltTab bool, triggeredFromHomeKey bool) error
OnAssistantAvailable(ctx context.Context, available bool, longPressHomeEnabled bool) error
OnAssistantVisibilityChanged(ctx context.Context, visibility float32) error
OnAssistantOverrideInvoked(ctx context.Context, invocationType int32) error
OnSystemUiStateChanged(ctx context.Context, stateFlags int32) error
OnRotationProposal(ctx context.Context, rotation int32, isValid bool) error
Disable(ctx context.Context, displayId int32, state1 int32, state2 int32, animate bool) error
OnSystemBarAttributesChanged(ctx context.Context, displayId int32, behavior int32) error
EnterStageSplitFromRunningApp(ctx context.Context, leftOrTop bool) error
OnTaskbarToggled(ctx context.Context) error
}
func NewOverviewProxyStub ¶
func NewOverviewProxyStub( impl IOverviewProxyServer, ) IOverviewProxy
NewOverviewProxyStub creates a server-side IOverviewProxy wrapping the given server implementation. The returned value satisfies IOverviewProxy and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IOverviewProxyServer ¶
type IOverviewProxyServer interface {
OnInitialize(ctx context.Context, params os.Bundle) error
OnOverviewToggle(ctx context.Context) error
OnOverviewShown(ctx context.Context, triggeredFromAltTab bool) error
OnOverviewHidden(ctx context.Context, triggeredFromAltTab bool, triggeredFromHomeKey bool) error
OnAssistantAvailable(ctx context.Context, available bool, longPressHomeEnabled bool) error
OnAssistantVisibilityChanged(ctx context.Context, visibility float32) error
OnAssistantOverrideInvoked(ctx context.Context, invocationType int32) error
OnSystemUiStateChanged(ctx context.Context, stateFlags int32) error
OnRotationProposal(ctx context.Context, rotation int32, isValid bool) error
Disable(ctx context.Context, displayId int32, state1 int32, state2 int32, animate bool) error
OnSystemBarAttributesChanged(ctx context.Context, displayId int32, behavior int32) error
EnterStageSplitFromRunningApp(ctx context.Context, leftOrTop bool) error
OnTaskbarToggled(ctx context.Context) error
}
IOverviewProxyServer is the server-side interface that user implementations provide to NewOverviewProxyStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ISystemUiProxy ¶
type ISystemUiProxy interface {
AsBinder() binder.IBinder
StartScreenPinning(ctx context.Context, taskId int32) error
OnOverviewShown(ctx context.Context, fromHome bool) error
OnStatusBarTouchEvent(ctx context.Context, event view.MotionEvent) error
OnAssistantProgress(ctx context.Context, progress float32) error
OnAssistantGestureCompletion(ctx context.Context, velocity float32) error
StartAssistant(ctx context.Context, bundle os.Bundle) error
SetAssistantOverridesRequested(ctx context.Context, invocationTypes []int32) error
NotifyAccessibilityButtonClicked(ctx context.Context, displayId int32) error
NotifyAccessibilityButtonLongClicked(ctx context.Context) error
StopScreenPinning(ctx context.Context) error
NotifyPrioritizedRotation(ctx context.Context, rotation int32) error
ExpandNotificationPanel(ctx context.Context) error
OnBackPressed(ctx context.Context) error
SetHomeRotationEnabled(ctx context.Context, enabled bool) error
NotifyTaskbarStatus(ctx context.Context, visible bool, stashed bool) error
NotifyTaskbarAutohideSuspend(ctx context.Context, suspend bool) error
OnImeSwitcherPressed(ctx context.Context) error
ToggleNotificationPanel(ctx context.Context) error
TakeScreenshot(ctx context.Context, request util.ScreenshotRequest) error
OnStatusBarTrackpadEvent(ctx context.Context, event view.MotionEvent) error
}
func NewSystemUiProxyStub ¶
func NewSystemUiProxyStub( impl ISystemUiProxyServer, ) ISystemUiProxy
NewSystemUiProxyStub creates a server-side ISystemUiProxy wrapping the given server implementation. The returned value satisfies ISystemUiProxy and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type ISystemUiProxyServer ¶
type ISystemUiProxyServer interface {
StartScreenPinning(ctx context.Context, taskId int32) error
OnOverviewShown(ctx context.Context, fromHome bool) error
OnStatusBarTouchEvent(ctx context.Context, event view.MotionEvent) error
OnAssistantProgress(ctx context.Context, progress float32) error
OnAssistantGestureCompletion(ctx context.Context, velocity float32) error
StartAssistant(ctx context.Context, bundle os.Bundle) error
SetAssistantOverridesRequested(ctx context.Context, invocationTypes []int32) error
NotifyAccessibilityButtonClicked(ctx context.Context, displayId int32) error
NotifyAccessibilityButtonLongClicked(ctx context.Context) error
StopScreenPinning(ctx context.Context) error
NotifyPrioritizedRotation(ctx context.Context, rotation int32) error
ExpandNotificationPanel(ctx context.Context) error
OnBackPressed(ctx context.Context) error
SetHomeRotationEnabled(ctx context.Context, enabled bool) error
NotifyTaskbarStatus(ctx context.Context, visible bool, stashed bool) error
NotifyTaskbarAutohideSuspend(ctx context.Context, suspend bool) error
OnImeSwitcherPressed(ctx context.Context) error
ToggleNotificationPanel(ctx context.Context) error
TakeScreenshot(ctx context.Context, request util.ScreenshotRequest) error
OnStatusBarTrackpadEvent(ctx context.Context, event view.MotionEvent) error
}
ISystemUiProxyServer is the server-side interface that user implementations provide to NewSystemUiProxyStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type OverviewProxyProxy ¶
func NewOverviewProxyProxy ¶
func NewOverviewProxyProxy( remote binder.IBinder, ) *OverviewProxyProxy
func (*OverviewProxyProxy) AsBinder ¶
func (p *OverviewProxyProxy) AsBinder() binder.IBinder
func (*OverviewProxyProxy) EnterStageSplitFromRunningApp ¶
func (p *OverviewProxyProxy) EnterStageSplitFromRunningApp( ctx context.Context, leftOrTop bool, ) error
func (*OverviewProxyProxy) OnActiveNavBarRegionChanges ¶
func (*OverviewProxyProxy) OnAssistantAvailable ¶
func (*OverviewProxyProxy) OnAssistantOverrideInvoked ¶
func (p *OverviewProxyProxy) OnAssistantOverrideInvoked( ctx context.Context, invocationType int32, ) error
func (*OverviewProxyProxy) OnAssistantVisibilityChanged ¶
func (p *OverviewProxyProxy) OnAssistantVisibilityChanged( ctx context.Context, visibility float32, ) error
func (*OverviewProxyProxy) OnInitialize ¶
func (*OverviewProxyProxy) OnNavButtonsDarkIntensityChanged ¶
func (p *OverviewProxyProxy) OnNavButtonsDarkIntensityChanged( ctx context.Context, darkIntensity float32, ) error
func (*OverviewProxyProxy) OnNavigationBarLumaSamplingEnabled ¶
func (*OverviewProxyProxy) OnOverviewHidden ¶
func (*OverviewProxyProxy) OnOverviewShown ¶
func (p *OverviewProxyProxy) OnOverviewShown( ctx context.Context, triggeredFromAltTab bool, ) error
func (*OverviewProxyProxy) OnOverviewToggle ¶
func (p *OverviewProxyProxy) OnOverviewToggle( ctx context.Context, ) error
func (*OverviewProxyProxy) OnRotationProposal ¶
func (*OverviewProxyProxy) OnSystemBarAttributesChanged ¶
func (*OverviewProxyProxy) OnSystemUiStateChanged ¶
func (p *OverviewProxyProxy) OnSystemUiStateChanged( ctx context.Context, stateFlags int32, ) error
func (*OverviewProxyProxy) OnTaskbarToggled ¶
func (p *OverviewProxyProxy) OnTaskbarToggled( ctx context.Context, ) error
type OverviewProxyStub ¶
type OverviewProxyStub struct {
Impl IOverviewProxy
Transport binder.VersionAwareTransport
}
OverviewProxyStub dispatches incoming binder transactions to a typed IOverviewProxy implementation.
func (*OverviewProxyStub) Descriptor ¶
func (s *OverviewProxyStub) Descriptor() string
func (*OverviewProxyStub) OnTransaction ¶
func (s *OverviewProxyStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type SystemUiProxyProxy ¶
func NewSystemUiProxyProxy ¶
func NewSystemUiProxyProxy( remote binder.IBinder, ) *SystemUiProxyProxy
func (*SystemUiProxyProxy) AnimateNavBarLongPress ¶
func (*SystemUiProxyProxy) AsBinder ¶
func (p *SystemUiProxyProxy) AsBinder() binder.IBinder
func (*SystemUiProxyProxy) ExpandNotificationPanel ¶
func (p *SystemUiProxyProxy) ExpandNotificationPanel( ctx context.Context, ) error
func (*SystemUiProxyProxy) NotifyAccessibilityButtonClicked ¶
func (p *SystemUiProxyProxy) NotifyAccessibilityButtonClicked( ctx context.Context, displayId int32, ) error
func (*SystemUiProxyProxy) NotifyAccessibilityButtonLongClicked ¶
func (p *SystemUiProxyProxy) NotifyAccessibilityButtonLongClicked( ctx context.Context, ) error
func (*SystemUiProxyProxy) NotifyPrioritizedRotation ¶
func (p *SystemUiProxyProxy) NotifyPrioritizedRotation( ctx context.Context, rotation int32, ) error
func (*SystemUiProxyProxy) NotifyTaskbarAutohideSuspend ¶
func (p *SystemUiProxyProxy) NotifyTaskbarAutohideSuspend( ctx context.Context, suspend bool, ) error
func (*SystemUiProxyProxy) NotifyTaskbarStatus ¶
func (*SystemUiProxyProxy) OnAssistantGestureCompletion ¶
func (p *SystemUiProxyProxy) OnAssistantGestureCompletion( ctx context.Context, velocity float32, ) error
func (*SystemUiProxyProxy) OnAssistantProgress ¶
func (p *SystemUiProxyProxy) OnAssistantProgress( ctx context.Context, progress float32, ) error
func (*SystemUiProxyProxy) OnBackPressed ¶
func (p *SystemUiProxyProxy) OnBackPressed( ctx context.Context, ) error
func (*SystemUiProxyProxy) OnImeSwitcherPressed ¶
func (p *SystemUiProxyProxy) OnImeSwitcherPressed( ctx context.Context, ) error
func (*SystemUiProxyProxy) OnOverviewShown ¶
func (p *SystemUiProxyProxy) OnOverviewShown( ctx context.Context, fromHome bool, ) error
func (*SystemUiProxyProxy) OnStatusBarTouchEvent ¶
func (p *SystemUiProxyProxy) OnStatusBarTouchEvent( ctx context.Context, event view.MotionEvent, ) error
func (*SystemUiProxyProxy) OnStatusBarTrackpadEvent ¶
func (p *SystemUiProxyProxy) OnStatusBarTrackpadEvent( ctx context.Context, event view.MotionEvent, ) error
func (*SystemUiProxyProxy) SetAssistantOverridesRequested ¶
func (p *SystemUiProxyProxy) SetAssistantOverridesRequested( ctx context.Context, invocationTypes []int32, ) error
func (*SystemUiProxyProxy) SetHomeRotationEnabled ¶
func (p *SystemUiProxyProxy) SetHomeRotationEnabled( ctx context.Context, enabled bool, ) error
func (*SystemUiProxyProxy) StartAssistant ¶
func (*SystemUiProxyProxy) StartScreenPinning ¶
func (p *SystemUiProxyProxy) StartScreenPinning( ctx context.Context, taskId int32, ) error
func (*SystemUiProxyProxy) StopScreenPinning ¶
func (p *SystemUiProxyProxy) StopScreenPinning( ctx context.Context, ) error
func (*SystemUiProxyProxy) TakeScreenshot ¶
func (p *SystemUiProxyProxy) TakeScreenshot( ctx context.Context, request util.ScreenshotRequest, ) error
func (*SystemUiProxyProxy) ToggleNotificationPanel ¶
func (p *SystemUiProxyProxy) ToggleNotificationPanel( ctx context.Context, ) error
type SystemUiProxyStub ¶
type SystemUiProxyStub struct {
Impl ISystemUiProxy
Transport binder.VersionAwareTransport
}
SystemUiProxyStub dispatches incoming binder transactions to a typed ISystemUiProxy implementation.
func (*SystemUiProxyStub) Descriptor ¶
func (s *SystemUiProxyStub) Descriptor() string
func (*SystemUiProxyStub) OnTransaction ¶
func (s *SystemUiProxyStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)