Documentation
¶
Index ¶
- Constants
- type IUnfoldAnimation
- type IUnfoldAnimationServer
- type IUnfoldTransitionListener
- type IUnfoldTransitionListenerServer
- type UnfoldAnimationProxy
- type UnfoldAnimationStub
- type UnfoldTransitionListenerProxy
- func (p *UnfoldTransitionListenerProxy) AsBinder() binder.IBinder
- func (p *UnfoldTransitionListenerProxy) OnTransitionFinished(ctx context.Context) error
- func (p *UnfoldTransitionListenerProxy) OnTransitionProgress(ctx context.Context, progress float32) error
- func (p *UnfoldTransitionListenerProxy) OnTransitionStarted(ctx context.Context) error
- type UnfoldTransitionListenerStub
Constants ¶
const ( TransactionIUnfoldTransitionListenerOnTransitionStarted = binder.FirstCallTransaction + 0 TransactionIUnfoldTransitionListenerOnTransitionProgress = binder.FirstCallTransaction + 1 TransactionIUnfoldTransitionListenerOnTransitionFinished = binder.FirstCallTransaction + 2 )
const ( MethodIUnfoldTransitionListenerOnTransitionStarted = "onTransitionStarted" MethodIUnfoldTransitionListenerOnTransitionProgress = "onTransitionProgress" MethodIUnfoldTransitionListenerOnTransitionFinished = "onTransitionFinished" )
const DescriptorIUnfoldAnimation = "com.android.systemui.unfold.progress.IUnfoldAnimation"
const DescriptorIUnfoldTransitionListener = "com.android.systemui.unfold.progress.IUnfoldTransitionListener"
const (
MethodIUnfoldAnimationSetListener = "setListener"
)
const (
TransactionIUnfoldAnimationSetListener = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IUnfoldAnimation ¶
type IUnfoldAnimation interface {
AsBinder() binder.IBinder
SetListener(ctx context.Context, listener IUnfoldTransitionListener) error
}
func NewUnfoldAnimationStub ¶
func NewUnfoldAnimationStub( impl IUnfoldAnimationServer, ) IUnfoldAnimation
NewUnfoldAnimationStub creates a server-side IUnfoldAnimation wrapping the given server implementation. The returned value satisfies IUnfoldAnimation and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IUnfoldAnimationServer ¶
type IUnfoldAnimationServer interface {
SetListener(ctx context.Context, listener IUnfoldTransitionListener) error
}
IUnfoldAnimationServer is the server-side interface that user implementations provide to NewUnfoldAnimationStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IUnfoldTransitionListener ¶
type IUnfoldTransitionListener interface {
AsBinder() binder.IBinder
OnTransitionStarted(ctx context.Context) error
OnTransitionProgress(ctx context.Context, progress float32) error
OnTransitionFinished(ctx context.Context) error
}
func NewUnfoldTransitionListenerStub ¶
func NewUnfoldTransitionListenerStub( impl IUnfoldTransitionListenerServer, ) IUnfoldTransitionListener
NewUnfoldTransitionListenerStub creates a server-side IUnfoldTransitionListener wrapping the given server implementation. The returned value satisfies IUnfoldTransitionListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IUnfoldTransitionListenerServer ¶
type IUnfoldTransitionListenerServer interface {
OnTransitionStarted(ctx context.Context) error
OnTransitionProgress(ctx context.Context, progress float32) error
OnTransitionFinished(ctx context.Context) error
}
IUnfoldTransitionListenerServer is the server-side interface that user implementations provide to NewUnfoldTransitionListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type UnfoldAnimationProxy ¶
func NewUnfoldAnimationProxy ¶
func NewUnfoldAnimationProxy( remote binder.IBinder, ) *UnfoldAnimationProxy
func (*UnfoldAnimationProxy) AsBinder ¶
func (p *UnfoldAnimationProxy) AsBinder() binder.IBinder
func (*UnfoldAnimationProxy) SetListener ¶
func (p *UnfoldAnimationProxy) SetListener( ctx context.Context, listener IUnfoldTransitionListener, ) error
type UnfoldAnimationStub ¶
type UnfoldAnimationStub struct {
Impl IUnfoldAnimation
Transport binder.VersionAwareTransport
}
UnfoldAnimationStub dispatches incoming binder transactions to a typed IUnfoldAnimation implementation.
func (*UnfoldAnimationStub) Descriptor ¶
func (s *UnfoldAnimationStub) Descriptor() string
func (*UnfoldAnimationStub) OnTransaction ¶
func (s *UnfoldAnimationStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type UnfoldTransitionListenerProxy ¶
func NewUnfoldTransitionListenerProxy ¶
func NewUnfoldTransitionListenerProxy( remote binder.IBinder, ) *UnfoldTransitionListenerProxy
func (*UnfoldTransitionListenerProxy) AsBinder ¶
func (p *UnfoldTransitionListenerProxy) AsBinder() binder.IBinder
func (*UnfoldTransitionListenerProxy) OnTransitionFinished ¶
func (p *UnfoldTransitionListenerProxy) OnTransitionFinished( ctx context.Context, ) error
func (*UnfoldTransitionListenerProxy) OnTransitionProgress ¶
func (p *UnfoldTransitionListenerProxy) OnTransitionProgress( ctx context.Context, progress float32, ) error
func (*UnfoldTransitionListenerProxy) OnTransitionStarted ¶
func (p *UnfoldTransitionListenerProxy) OnTransitionStarted( ctx context.Context, ) error
type UnfoldTransitionListenerStub ¶
type UnfoldTransitionListenerStub struct {
Impl IUnfoldTransitionListener
Transport binder.VersionAwareTransport
}
UnfoldTransitionListenerStub dispatches incoming binder transactions to a typed IUnfoldTransitionListener implementation.
func (*UnfoldTransitionListenerStub) Descriptor ¶
func (s *UnfoldTransitionListenerStub) Descriptor() string
func (*UnfoldTransitionListenerStub) OnTransaction ¶
func (s *UnfoldTransitionListenerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)