Documentation
¶
Index ¶
- Constants
- type HomeTransitionListenerProxy
- type HomeTransitionListenerStub
- type IHomeTransitionListener
- type IHomeTransitionListenerServer
- type IShellTransitions
- type IShellTransitionsServer
- type ShellTransitionsProxy
- func (p *ShellTransitionsProxy) AsBinder() binder.IBinder
- func (p *ShellTransitionsProxy) GetHomeTaskOverlayContainer(ctx context.Context) (view.SurfaceControl, error)
- func (p *ShellTransitionsProxy) GetShellApplyToken(ctx context.Context) (binder.IBinder, error)
- func (p *ShellTransitionsProxy) RegisterRemote(ctx context.Context, filter window.TransitionFilter, ...) error
- func (p *ShellTransitionsProxy) SetHomeTransitionListener(ctx context.Context, listener IHomeTransitionListener) error
- func (p *ShellTransitionsProxy) UnregisterRemote(ctx context.Context, remoteTransition window.RemoteTransition) error
- type ShellTransitionsStub
Constants ¶
const ( TransactionIShellTransitionsRegisterRemote = binder.FirstCallTransaction + 0 TransactionIShellTransitionsUnregisterRemote = binder.FirstCallTransaction + 1 TransactionIShellTransitionsGetShellApplyToken = binder.FirstCallTransaction + 2 TransactionIShellTransitionsSetHomeTransitionListener = binder.FirstCallTransaction + 3 TransactionIShellTransitionsGetHomeTaskOverlayContainer = binder.FirstCallTransaction + 4 )
const ( MethodIShellTransitionsRegisterRemote = "registerRemote" MethodIShellTransitionsUnregisterRemote = "unregisterRemote" MethodIShellTransitionsGetShellApplyToken = "getShellApplyToken" MethodIShellTransitionsSetHomeTransitionListener = "setHomeTransitionListener" MethodIShellTransitionsGetHomeTaskOverlayContainer = "getHomeTaskOverlayContainer" )
const DescriptorIHomeTransitionListener = "com.android.wm.shell.transition.IHomeTransitionListener"
const DescriptorIShellTransitions = "com.android.wm.shell.transition.IShellTransitions"
const (
MethodIHomeTransitionListenerOnHomeVisibilityChanged = "onHomeVisibilityChanged"
)
const (
TransactionIHomeTransitionListenerOnHomeVisibilityChanged = binder.FirstCallTransaction + 0
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type HomeTransitionListenerProxy ¶
func NewHomeTransitionListenerProxy ¶
func NewHomeTransitionListenerProxy( remote binder.IBinder, ) *HomeTransitionListenerProxy
func (*HomeTransitionListenerProxy) AsBinder ¶
func (p *HomeTransitionListenerProxy) AsBinder() binder.IBinder
func (*HomeTransitionListenerProxy) OnHomeVisibilityChanged ¶
func (p *HomeTransitionListenerProxy) OnHomeVisibilityChanged( ctx context.Context, isVisible bool, ) error
type HomeTransitionListenerStub ¶
type HomeTransitionListenerStub struct {
Impl IHomeTransitionListener
Transport binder.VersionAwareTransport
}
HomeTransitionListenerStub dispatches incoming binder transactions to a typed IHomeTransitionListener implementation.
func (*HomeTransitionListenerStub) Descriptor ¶
func (s *HomeTransitionListenerStub) Descriptor() string
func (*HomeTransitionListenerStub) OnTransaction ¶
func (s *HomeTransitionListenerStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)
type IHomeTransitionListener ¶
type IHomeTransitionListener interface {
AsBinder() binder.IBinder
OnHomeVisibilityChanged(ctx context.Context, isVisible bool) error
}
func NewHomeTransitionListenerStub ¶
func NewHomeTransitionListenerStub( impl IHomeTransitionListenerServer, ) IHomeTransitionListener
NewHomeTransitionListenerStub creates a server-side IHomeTransitionListener wrapping the given server implementation. The returned value satisfies IHomeTransitionListener and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IHomeTransitionListenerServer ¶
type IHomeTransitionListenerServer interface {
OnHomeVisibilityChanged(ctx context.Context, isVisible bool) error
}
IHomeTransitionListenerServer is the server-side interface that user implementations provide to NewHomeTransitionListenerStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type IShellTransitions ¶
type IShellTransitions interface {
AsBinder() binder.IBinder
RegisterRemote(ctx context.Context, filter window.TransitionFilter, remoteTransition window.RemoteTransition) error
UnregisterRemote(ctx context.Context, remoteTransition window.RemoteTransition) error
GetShellApplyToken(ctx context.Context) (binder.IBinder, error)
SetHomeTransitionListener(ctx context.Context, listener IHomeTransitionListener) error
GetHomeTaskOverlayContainer(ctx context.Context) (view.SurfaceControl, error)
}
func NewShellTransitionsStub ¶
func NewShellTransitionsStub( impl IShellTransitionsServer, ) IShellTransitions
NewShellTransitionsStub creates a server-side IShellTransitions wrapping the given server implementation. The returned value satisfies IShellTransitions and can be passed to proxy methods; its AsBinder() returns a *binder.StubBinder that is auto-registered with the binder driver on first use.
type IShellTransitionsServer ¶
type IShellTransitionsServer interface {
RegisterRemote(ctx context.Context, filter window.TransitionFilter, remoteTransition window.RemoteTransition) error
UnregisterRemote(ctx context.Context, remoteTransition window.RemoteTransition) error
GetShellApplyToken(ctx context.Context) (binder.IBinder, error)
SetHomeTransitionListener(ctx context.Context, listener IHomeTransitionListener) error
GetHomeTaskOverlayContainer(ctx context.Context) (view.SurfaceControl, error)
}
IShellTransitionsServer is the server-side interface that user implementations provide to NewShellTransitionsStub. It contains only the business methods, without AsBinder (which is provided by the stub itself).
type ShellTransitionsProxy ¶
func NewShellTransitionsProxy ¶
func NewShellTransitionsProxy( remote binder.IBinder, ) *ShellTransitionsProxy
func (*ShellTransitionsProxy) AsBinder ¶
func (p *ShellTransitionsProxy) AsBinder() binder.IBinder
func (*ShellTransitionsProxy) GetHomeTaskOverlayContainer ¶
func (p *ShellTransitionsProxy) GetHomeTaskOverlayContainer( ctx context.Context, ) (view.SurfaceControl, error)
func (*ShellTransitionsProxy) GetShellApplyToken ¶
func (*ShellTransitionsProxy) RegisterRemote ¶
func (p *ShellTransitionsProxy) RegisterRemote( ctx context.Context, filter window.TransitionFilter, remoteTransition window.RemoteTransition, ) error
func (*ShellTransitionsProxy) SetHomeTransitionListener ¶
func (p *ShellTransitionsProxy) SetHomeTransitionListener( ctx context.Context, listener IHomeTransitionListener, ) error
func (*ShellTransitionsProxy) UnregisterRemote ¶
func (p *ShellTransitionsProxy) UnregisterRemote( ctx context.Context, remoteTransition window.RemoteTransition, ) error
type ShellTransitionsStub ¶
type ShellTransitionsStub struct {
Impl IShellTransitions
Transport binder.VersionAwareTransport
}
ShellTransitionsStub dispatches incoming binder transactions to a typed IShellTransitions implementation.
func (*ShellTransitionsStub) Descriptor ¶
func (s *ShellTransitionsStub) Descriptor() string
func (*ShellTransitionsStub) OnTransaction ¶
func (s *ShellTransitionsStub) OnTransaction( ctx context.Context, code binder.TransactionCode, _data *parcel.Parcel, ) (*parcel.Parcel, error)